'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

/**
* @see https://docs.github.com/rest/reference/migrations#list-user-migrations


* List user migrations
* Lists all migrations a user has started.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listForAuthenticatedUser$5 = {
    id: "migrations/list-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#start-a-user-migration


* Start a user migration
* Initiates the generation of a user migration archive.
*/
var startForAuthenticatedUser$1 = {
    id: "migrations/start-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#list-organization-migrations


* List organization migrations
* Lists the most recent migrations.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [exclude] - Exclude attributes from the API response to improve performance
*/
var listForOrg$3 = {
    id: "migrations/list-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#start-an-organization-migration


* Start an organization migration
* Initiates the generation of a migration archive.
* @param org - The organization name. The name is not case sensitive.
*/
var startForOrg = {
    id: "migrations/start-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#get-an-import-status


* Get an import status
* View the progress of an import.
 *
 * **Import status**
 *
 * This section includes details about the possible values of the `status` field of the Import Progress response.
 *
 * An import that does not have errors will progress through these steps:
 *
 * *   `detecting` - the "detection" step of the import is in progress because the request did not include a `vcs` parameter. The import is identifying the type of source control present at the URL.
 * *   `importing` - the "raw" step of the import is in progress. This is where commit data is fetched from the original repository. The import progress response will include `commit_count` (the total number of raw commits that will be imported) and `percent` (0 - 100, the current progress through the import).
 * *   `mapping` - the "rewrite" step of the import is in progress. This is where SVN branches are converted to Git branches, and where author updates are applied. The import progress response does not include progress information.
 * *   `pushing` - the "push" step of the import is in progress. This is where the importer updates the repository on GitHub. The import progress response will include `push_percent`, which is the percent value reported by `git push` when it is "Writing objects".
 * *   `complete` - the import is complete, and the repository is ready on GitHub.
 *
 * If there are problems, you will see one of these in the `status` field:
 *
 * *   `auth_failed` - the import requires authentication in order to connect to the original repository. To update authentication for the import, please see the [Update an import](https://docs.github.com/rest/reference/migrations#update-an-import) section.
 * *   `error` - the import encountered an error. The import progress response will include the `failed_step` and an error message. Contact [GitHub Support](https://support.github.com/contact?tags=dotcom-rest-api) for more information.
 * *   `detection_needs_auth` - the importer requires authentication for the originating repository to continue detection. To update authentication for the import, please see the [Update an import](https://docs.github.com/rest/reference/migrations#update-an-import) section.
 * *   `detection_found_nothing` - the importer didn't recognize any source control at the URL. To resolve, [Cancel the import](https://docs.github.com/rest/reference/migrations#cancel-an-import) and [retry](https://docs.github.com/rest/reference/migrations#start-an-import) with the correct URL.
 * *   `detection_found_multiple` - the importer found several projects or repositories at the provided URL. When this is the case, the Import Progress response will also include a `project_choices` field with the possible project choices as values. To update project choice, please see the [Update an import](https://docs.github.com/rest/reference/migrations#update-an-import) section.
 *
 * **The project_choices field**
 *
 * When multiple projects are found at the provided URL, the response hash will include a `project_choices` field, the value of which is an array of hashes each representing a project choice. The exact key/value pairs of the project hashes will differ depending on the version control type.
 *
 * **Git LFS related fields**
 *
 * This section includes details about Git LFS related fields that may be present in the Import Progress response.
 *
 * *   `use_lfs` - describes whether the import has been opted in or out of using Git LFS. The value can be `opt_in`, `opt_out`, or `undecided` if no action has been taken.
 * *   `has_large_files` - the boolean value describing whether files larger than 100MB were found during the `importing` step.
 * *   `large_files_size` - the total size in gigabytes of files larger than 100MB found in the originating repository.
 * *   `large_files_count` - the total number of files larger than 100MB found in the originating repository. To see a list of these files, make a "Get Large Files" request.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getImportStatus = {
    id: "migrations/get-import-status",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#start-an-import


* Start an import
* Start a source import to a GitHub repository using GitHub Importer.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var startImport = {
    id: "migrations/start-import",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#cancel-an-import


* Cancel an import
* Stop an import for a repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var cancelImport = {
    id: "migrations/cancel-import",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#update-an-import


* Update an import
* An import can be updated with credentials or a project choice by passing in the appropriate parameters in this API
 * request. If no parameters are provided, the import will be restarted.
 *
 * Some servers (e.g. TFS servers) can have several projects at a single URL. In those cases the import progress will
 * have the status `detection_found_multiple` and the Import Progress response will include a `project_choices` array.
 * You can select the project to import by providing one of the objects in the `project_choices` array in the update request.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var updateImport = {
    id: "migrations/update-import",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#get-a-user-migration-status


* Get a user migration status
* Fetches a single user migration. The response includes the `state` of the migration, which can be one of the following values:
 *
 * *   `pending` - the migration hasn't started yet.
 * *   `exporting` - the migration is in progress.
 * *   `exported` - the migration finished successfully.
 * *   `failed` - the migration failed.
 *
 * Once the migration has been `exported` you can [download the migration archive](https://docs.github.com/rest/reference/migrations#download-a-user-migration-archive).
* @param migrationId - The unique identifier of the migration.
* @param [exclude]
*/
var getStatusForAuthenticatedUser = {
    id: "migrations/get-status-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#update-git-lfs-preference


* Update Git LFS preference
* You can import repositories from Subversion, Mercurial, and TFS that include files larger than 100MB. This ability is powered by [Git LFS](https://git-lfs.github.com). You can learn more about our LFS feature and working with large files [on our help site](https://docs.github.com/articles/versioning-large-files/).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var setLfsPreference = {
    id: "migrations/set-lfs-preference",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#get-commit-authors


* Get commit authors
* Each type of source control system represents authors in a different way. For example, a Git commit author has a display name and an email address, but a Subversion commit author just has a username. The GitHub Importer will make the author information valid, but the author might not be correct. For example, it will change the bare Subversion username `hubot` into something like `hubot <hubot@12341234-abab-fefe-8787-fedcba987654>`.
 *
 * This endpoint and the [Map a commit author](https://docs.github.com/rest/reference/migrations#map-a-commit-author) endpoint allow you to provide correct Git author information.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [since] - A user ID. Only return users with an ID greater than this ID.
*/
var getCommitAuthors = {
    id: "migrations/get-commit-authors",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#get-an-organization-migration-status


* Get an organization migration status
* Fetches the status of a migration.
 *
 * The `state` of a migration can be one of the following values:
 *
 * *   `pending`, which means the migration hasn't started yet.
 * *   `exporting`, which means the migration is in progress.
 * *   `exported`, which means the migration finished successfully.
 * *   `failed`, which means the migration failed.
* @param org - The organization name. The name is not case sensitive.
* @param migrationId - The unique identifier of the migration.
* @param [exclude] - Exclude attributes from the API response to improve performance
*/
var getStatusForOrg = {
    id: "migrations/get-status-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#download-a-user-migration-archive


* Download a user migration archive
* Fetches the URL to download the migration archive as a `tar.gz` file. Depending on the resources your repository uses, the migration archive can contain JSON files with data for these objects:
 *
 * *   attachments
 * *   bases
 * *   commit\_comments
 * *   issue\_comments
 * *   issue\_events
 * *   issues
 * *   milestones
 * *   organizations
 * *   projects
 * *   protected\_branches
 * *   pull\_request\_reviews
 * *   pull\_requests
 * *   releases
 * *   repositories
 * *   review\_comments
 * *   schema
 * *   users
 *
 * The archive will also contain an `attachments` directory that includes all attachment files uploaded to GitHub.com and a `repositories` directory that contains the repository's Git data.
* @param migrationId - The unique identifier of the migration.
*/
var getArchiveForAuthenticatedUser = {
    id: "migrations/get-archive-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#delete-a-user-migration-archive


* Delete a user migration archive
* Deletes a previous migration archive. Downloadable migration archives are automatically deleted after seven days. Migration metadata, which is returned in the [List user migrations](https://docs.github.com/rest/reference/migrations#list-user-migrations) and [Get a user migration status](https://docs.github.com/rest/reference/migrations#get-a-user-migration-status) endpoints, will continue to be available even after an archive is deleted.
* @param migrationId - The unique identifier of the migration.
*/
var deleteArchiveForAuthenticatedUser = {
    id: "migrations/delete-archive-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#get-large-files


* Get large files
* List files larger than 100MB found during the import
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getLargeFiles = {
    id: "migrations/get-large-files",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#list-repositories-for-a-user-migration


* List repositories for a user migration
* Lists all the repositories for this user migration.
* @param migrationId - The unique identifier of the migration.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listReposForAuthenticatedUser = {
    id: "migrations/list-repos-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#download-an-organization-migration-archive


* Download an organization migration archive
* Fetches the URL to a migration archive.
* @param org - The organization name. The name is not case sensitive.
* @param migrationId - The unique identifier of the migration.
*/
var downloadArchiveForOrg = {
    id: "migrations/download-archive-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#delete-an-organization-migration-archive


* Delete an organization migration archive
* Deletes a previous migration archive. Migration archives are automatically deleted after seven days.
* @param org - The organization name. The name is not case sensitive.
* @param migrationId - The unique identifier of the migration.
*/
var deleteArchiveForOrg = {
    id: "migrations/delete-archive-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#map-a-commit-author


* Map a commit author
* Update an author's identity for the import. Your application can continue updating authors any time before you push new commits to the repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param authorId
*/
var mapCommitAuthor = {
    id: "migrations/map-commit-author",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#list-repositories-in-an-organization-migration


* List repositories in an organization migration
* List all the repositories for this organization migration.
* @param org - The organization name. The name is not case sensitive.
* @param migrationId - The unique identifier of the migration.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listReposForOrg = {
    id: "migrations/list-repos-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#unlock-a-user-repository


* Unlock a user repository
* Unlocks a repository. You can lock repositories when you [start a user migration](https://docs.github.com/rest/reference/migrations#start-a-user-migration). Once the migration is complete you can unlock each repository to begin using it again or [delete the repository](https://docs.github.com/rest/reference/repos#delete-a-repository) if you no longer need the source data. Returns a status of `404 Not Found` if the repository is not locked.
* @param migrationId - The unique identifier of the migration.
* @param repoName - repo_name parameter
*/
var unlockRepoForAuthenticatedUser = {
    id: "migrations/unlock-repo-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/migrations#unlock-an-organization-repository


* Unlock an organization repository
* Unlocks a repository that was locked for migration. You should unlock each migrated repository and [delete them](https://docs.github.com/rest/reference/repos#delete-a-repository) when the migration is complete and you no longer need the source data.
* @param org - The organization name. The name is not case sensitive.
* @param migrationId - The unique identifier of the migration.
* @param repoName - repo_name parameter
*/
var unlockRepoForOrg = {
    id: "migrations/unlock-repo-for-org",
    clientId: "github",
    version: "1.1.5",
};

var migrations = /*#__PURE__*/Object.freeze({
  __proto__: null,
  listForAuthenticatedUser: listForAuthenticatedUser$5,
  startForAuthenticatedUser: startForAuthenticatedUser$1,
  listForOrg: listForOrg$3,
  startForOrg: startForOrg,
  getImportStatus: getImportStatus,
  startImport: startImport,
  cancelImport: cancelImport,
  updateImport: updateImport,
  getStatusForAuthenticatedUser: getStatusForAuthenticatedUser,
  setLfsPreference: setLfsPreference,
  getCommitAuthors: getCommitAuthors,
  getStatusForOrg: getStatusForOrg,
  getArchiveForAuthenticatedUser: getArchiveForAuthenticatedUser,
  deleteArchiveForAuthenticatedUser: deleteArchiveForAuthenticatedUser,
  getLargeFiles: getLargeFiles,
  listReposForAuthenticatedUser: listReposForAuthenticatedUser,
  downloadArchiveForOrg: downloadArchiveForOrg,
  deleteArchiveForOrg: deleteArchiveForOrg,
  mapCommitAuthor: mapCommitAuthor,
  listReposForOrg: listReposForOrg,
  unlockRepoForAuthenticatedUser: unlockRepoForAuthenticatedUser,
  unlockRepoForOrg: unlockRepoForOrg
});

/**
* @see https://docs.github.com/rest/reference/oauth-authorizations#list-your-authorizations

* @deprecated

* List your authorizations
* **Deprecation Notice:** GitHub will discontinue the [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations), which is used by integrations to create personal access tokens and OAuth tokens, and you must now create these tokens using our [web application flow](https://docs.github.com/apps/building-oauth-apps/authorizing-oauth-apps/#web-application-flow). The [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations) will be removed on November, 13, 2020. For more information, including scheduled brownouts, see the [blog post](https://developer.github.com/changes/2020-02-14-deprecating-oauth-auth-endpoint/).
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [clientId] - The client ID of your GitHub app.
*/
var listAuthorizations = {
    id: "oauth-authorizations/list-authorizations",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/oauth-authorizations#create-a-new-authorization

* @deprecated

* Create a new authorization
* **Deprecation Notice:** GitHub will discontinue the [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations), which is used by integrations to create personal access tokens and OAuth tokens, and you must now create these tokens using our [web application flow](https://docs.github.com/developers/apps/authorizing-oauth-apps#web-application-flow). The [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations) will be removed on November, 13, 2020. For more information, including scheduled brownouts, see the [blog post](https://developer.github.com/changes/2020-02-14-deprecating-oauth-auth-endpoint/).
 *
 * **Warning:** Apps must use the [web application flow](https://docs.github.com/apps/building-oauth-apps/authorizing-oauth-apps/#web-application-flow) to obtain OAuth tokens that work with GitHub SAML organizations. OAuth tokens created using the Authorizations API will be unable to access GitHub SAML organizations. For more information, see the [blog post](https://developer.github.com/changes/2019-11-05-deprecated-passwords-and-authorizations-api).
 *
 * Creates OAuth tokens using [Basic Authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication). If you have two-factor authentication setup, Basic Authentication for this endpoint requires that you use a one-time password (OTP) and your username and password instead of tokens. For more information, see "[Working with two-factor authentication](https://docs.github.com/rest/overview/other-authentication-methods#working-with-two-factor-authentication)."
 *
 * To create tokens for a particular OAuth application using this endpoint, you must authenticate as the user you want to create an authorization for and provide the app's client ID and secret, found on your OAuth application's settings page. If your OAuth application intends to create multiple tokens for one user, use `fingerprint` to differentiate between them.
 *
 * You can also create tokens on GitHub from the [personal access tokens settings](https://github.com/settings/tokens) page. Read more about these tokens in [the GitHub Help documentation](https://docs.github.com/articles/creating-an-access-token-for-command-line-use).
 *
 * Organizations that enforce SAML SSO require personal access tokens to be allowed. Read more about allowing tokens in [the GitHub Help documentation](https://docs.github.com/articles/about-identity-and-access-management-with-saml-single-sign-on).
*/
var createAuthorization = {
    id: "oauth-authorizations/create-authorization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/oauth-authorizations#list-your-grants

* @deprecated

* List your grants
* **Deprecation Notice:** GitHub will discontinue the [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations/), which is used by integrations to create personal access tokens and OAuth tokens, and you must now create these tokens using our [web application flow](https://docs.github.com/developers/apps/authorizing-oauth-apps#web-application-flow). The [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations) will be removed on November, 13, 2020. For more information, including scheduled brownouts, see the [blog post](https://developer.github.com/changes/2020-02-14-deprecating-oauth-auth-endpoint/).
 *
 * You can use this API to list the set of OAuth applications that have been granted access to your account. Unlike the [list your authorizations](https://docs.github.com/rest/reference/oauth-authorizations#list-your-authorizations) API, this API does not manage individual tokens. This API will return one entry for each OAuth application that has been granted access to your account, regardless of the number of tokens an application has generated for your user. The list of OAuth applications returned matches what is shown on [the application authorizations settings screen within GitHub](https://github.com/settings/applications#authorized). The `scopes` returned are the union of scopes authorized for the application. For example, if an application has one token with `repo` scope and another token with `user` scope, the grant will return `["repo", "user"]`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [clientId] - The client ID of your GitHub app.
*/
var listGrants = {
    id: "oauth-authorizations/list-grants",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/oauth-authorizations#get-a-single-grant

* @deprecated

* Get a single grant
* **Deprecation Notice:** GitHub will discontinue the [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations), which is used by integrations to create personal access tokens and OAuth tokens, and you must now create these tokens using our [web application flow](https://docs.github.com/apps/building-oauth-apps/authorizing-oauth-apps/#web-application-flow). The [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations) will be removed on November, 13, 2020. For more information, including scheduled brownouts, see the [blog post](https://developer.github.com/changes/2020-02-14-deprecating-oauth-auth-endpoint/).
* @param grantId - The unique identifier of the grant.
*/
var getGrant = {
    id: "oauth-authorizations/get-grant",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/oauth-authorizations#delete-a-grant

* @deprecated

* Delete a grant
* **Deprecation Notice:** GitHub will discontinue the [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations/), which is used by integrations to create personal access tokens and OAuth tokens, and you must now create these tokens using our [web application flow](https://docs.github.com/developers/apps/authorizing-oauth-apps#web-application-flow). The [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations/) will be removed on November, 13, 2020. For more information, including scheduled brownouts, see the [blog post](https://developer.github.com/changes/2020-02-14-deprecating-oauth-auth-endpoint/).
 *
 * Deleting an OAuth application's grant will also delete all OAuth tokens associated with the application for your user. Once deleted, the application has no access to your account and is no longer listed on [the application authorizations settings screen within GitHub](https://github.com/settings/applications#authorized).
* @param grantId - The unique identifier of the grant.
*/
var deleteGrant = {
    id: "oauth-authorizations/delete-grant",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/oauth-authorizations#get-a-single-authorization

* @deprecated

* Get a single authorization
* **Deprecation Notice:** GitHub will discontinue the [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations), which is used by integrations to create personal access tokens and OAuth tokens, and you must now create these tokens using our [web application flow](https://docs.github.com/apps/building-oauth-apps/authorizing-oauth-apps/#web-application-flow). The [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations) will be removed on November, 13, 2020. For more information, including scheduled brownouts, see the [blog post](https://developer.github.com/changes/2020-02-14-deprecating-oauth-auth-endpoint/).
* @param authorizationId - The unique identifier of the authorization.
*/
var getAuthorization = {
    id: "oauth-authorizations/get-authorization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/oauth-authorizations#delete-an-authorization

* @deprecated

* Delete an authorization
* **Deprecation Notice:** GitHub will discontinue the [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations), which is used by integrations to create personal access tokens and OAuth tokens, and you must now create these tokens using our [web application flow](https://docs.github.com/apps/building-oauth-apps/authorizing-oauth-apps/#web-application-flow). The [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations) will be removed on November, 13, 2020. For more information, including scheduled brownouts, see the [blog post](https://developer.github.com/changes/2020-02-14-deprecating-oauth-auth-endpoint/).
* @param authorizationId - The unique identifier of the authorization.
*/
var deleteAuthorization$1 = {
    id: "oauth-authorizations/delete-authorization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/oauth-authorizations#update-an-existing-authorization

* @deprecated

* Update an existing authorization
* **Deprecation Notice:** GitHub will discontinue the [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations/), which is used by integrations to create personal access tokens and OAuth tokens, and you must now create these tokens using our [web application flow](https://docs.github.com/developers/apps/authorizing-oauth-apps#web-application-flow). The [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations) will be removed on November, 13, 2020. For more information, including scheduled brownouts, see the [blog post](https://developer.github.com/changes/2020-02-14-deprecating-oauth-auth-endpoint/).
 *
 * If you have two-factor authentication setup, Basic Authentication for this endpoint requires that you use a one-time password (OTP) and your username and password instead of tokens. For more information, see "[Working with two-factor authentication](https://docs.github.com/rest/overview/other-authentication-methods#working-with-two-factor-authentication)."
 *
 * You can only send one of these scope keys at a time.
* @param authorizationId - The unique identifier of the authorization.
*/
var updateAuthorization = {
    id: "oauth-authorizations/update-authorization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/oauth-authorizations#get-or-create-an-authorization-for-a-specific-app

* @deprecated

* Get-or-create an authorization for a specific app
* **Deprecation Notice:** GitHub will discontinue the [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations/), which is used by integrations to create personal access tokens and OAuth tokens, and you must now create these tokens using our [web application flow](https://docs.github.com/developers/apps/authorizing-oauth-apps#web-application-flow). The [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations) will be removed on November, 13, 2020. For more information, including scheduled brownouts, see the [blog post](https://developer.github.com/changes/2020-02-14-deprecating-oauth-auth-endpoint/).
 *
 * **Warning:** Apps must use the [web application flow](https://docs.github.com/apps/building-oauth-apps/authorizing-oauth-apps/#web-application-flow) to obtain OAuth tokens that work with GitHub SAML organizations. OAuth tokens created using the Authorizations API will be unable to access GitHub SAML organizations. For more information, see the [blog post](https://developer.github.com/changes/2019-11-05-deprecated-passwords-and-authorizations-api).
 *
 * Creates a new authorization for the specified OAuth application, only if an authorization for that application doesn't already exist for the user. The URL includes the 20 character client ID for the OAuth app that is requesting the token. It returns the user's existing authorization for the application if one is present. Otherwise, it creates and returns a new one.
 *
 * If you have two-factor authentication setup, Basic Authentication for this endpoint requires that you use a one-time password (OTP) and your username and password instead of tokens. For more information, see "[Working with two-factor authentication](https://docs.github.com/rest/overview/other-authentication-methods#working-with-two-factor-authentication)."
 *
 * **Deprecation Notice:** GitHub will discontinue the [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations/), which is used by integrations to create personal access tokens and OAuth tokens, and you must now create these tokens using our [web application flow](https://docs.github.com/developers/apps/authorizing-oauth-apps#web-application-flow). The [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations) will be removed on November, 13, 2020. For more information, including scheduled brownouts, see the [blog post](https://developer.github.com/changes/2020-02-14-deprecating-oauth-auth-endpoint/).
* @param clientId - The client ID of the OAuth app.
*/
var getOrCreateAuthorizationForApp = {
    id: "oauth-authorizations/get-or-create-authorization-for-app",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/oauth-authorizations#get-or-create-an-authorization-for-a-specific-app-and-fingerprint

* @deprecated

* Get-or-create an authorization for a specific app and fingerprint
* **Deprecation Notice:** GitHub will discontinue the [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations/), which is used by integrations to create personal access tokens and OAuth tokens, and you must now create these tokens using our [web application flow](https://docs.github.com/developers/apps/authorizing-oauth-apps#web-application-flow). The [OAuth Authorizations API](https://docs.github.com/rest/reference/oauth-authorizations) will be removed on November, 13, 2020. For more information, including scheduled brownouts, see the [blog post](https://developer.github.com/changes/2020-02-14-deprecating-oauth-auth-endpoint/).
 *
 * **Warning:** Apps must use the [web application flow](https://docs.github.com/apps/building-oauth-apps/authorizing-oauth-apps/#web-application-flow) to obtain OAuth tokens that work with GitHub SAML organizations. OAuth tokens created using the Authorizations API will be unable to access GitHub SAML organizations. For more information, see the [blog post](https://developer.github.com/changes/2019-11-05-deprecated-passwords-and-authorizations-api).
 *
 * This method will create a new authorization for the specified OAuth application, only if an authorization for that application and fingerprint do not already exist for the user. The URL includes the 20 character client ID for the OAuth app that is requesting the token. `fingerprint` is a unique string to distinguish an authorization from others created for the same client ID and user. It returns the user's existing authorization for the application if one is present. Otherwise, it creates and returns a new one.
 *
 * If you have two-factor authentication setup, Basic Authentication for this endpoint requires that you use a one-time password (OTP) and your username and password instead of tokens. For more information, see "[Working with two-factor authentication](https://docs.github.com/rest/overview/other-authentication-methods#working-with-two-factor-authentication)."
* @param clientId - The client ID of the OAuth app.
* @param fingerprint
*/
var getOrCreateAuthorizationForAppAndFingerprint = {
    id: "oauth-authorizations/get-or-create-authorization-for-app-and-fingerprint",
    clientId: "github",
    version: "1.1.5",
};

var oauthAuthorizations = /*#__PURE__*/Object.freeze({
  __proto__: null,
  listAuthorizations: listAuthorizations,
  createAuthorization: createAuthorization,
  listGrants: listGrants,
  getGrant: getGrant,
  deleteGrant: deleteGrant,
  getAuthorization: getAuthorization,
  deleteAuthorization: deleteAuthorization$1,
  updateAuthorization: updateAuthorization,
  getOrCreateAuthorizationForApp: getOrCreateAuthorizationForApp,
  getOrCreateAuthorizationForAppAndFingerprint: getOrCreateAuthorizationForAppAndFingerprint
});

/**
* @see https://docs.github.com/rest/actions/oidc#get-the-customization-template-for-an-oidc-subject-claim-for-an-organization


* Get the customization template for an OIDC subject claim for an organization
* Gets the customization template for an OpenID Connect (OIDC) subject claim.
 * You must authenticate using an access token with the `read:org` scope to use this endpoint.
 * GitHub Apps must have the `organization_administration:write` permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
*/
var getOidcCustomSubTemplateForOrg = {
    id: "oidc/get-oidc-custom-sub-template-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/actions/oidc#set-the-customization-template-for-an-oidc-subject-claim-for-an-organization


* Set the customization template for an OIDC subject claim for an organization
* Creates or updates the customization template for an OpenID Connect (OIDC) subject claim.
 * You must authenticate using an access token with the `write:org` scope to use this endpoint.
 * GitHub Apps must have the `admin:org` permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
*/
var updateOidcCustomSubTemplateForOrg = {
    id: "oidc/update-oidc-custom-sub-template-for-org",
    clientId: "github",
    version: "1.1.5",
};

var oidc = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getOidcCustomSubTemplateForOrg: getOidcCustomSubTemplateForOrg,
  updateOidcCustomSubTemplateForOrg: updateOidcCustomSubTemplateForOrg
});

/**
* @see https://docs.github.com/rest/reference/orgs#list-organizations-for-the-authenticated-user


* List organizations for the authenticated user
* List organizations for the authenticated user.
 *
 * **OAuth scope requirements**
 *
 * This only lists organizations that your authorization allows you to operate on in some way (e.g., you can list teams with `read:org` scope, you can publicize your organization membership with `user` scope, etc.). Therefore, this API requires at least `user` or `read:org` scope. OAuth requests with insufficient scope receive a `403 Forbidden` response.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listForAuthenticatedUser$4 = {
    id: "orgs/list-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#get-an-organization


* Get an organization
* To see many of the organization response values, you need to be an authenticated organization owner with the `admin:org` scope. When the value of `two_factor_requirement_enabled` is `true`, the organization requires all members, billing managers, and outside collaborators to enable [two-factor authentication](https://docs.github.com/articles/securing-your-account-with-two-factor-authentication-2fa/).
 *
 * GitHub Apps with the `Organization plan` permission can use this endpoint to retrieve information about an organization's GitHub plan. See "[Authenticating with GitHub Apps](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/)" for details. For an example response, see 'Response with GitHub plan information' below."
* @param org - The organization name. The name is not case sensitive.
*/
var getOrg = {
    id: "orgs/get",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs/#update-an-organization


* Update an organization
* **Parameter Deprecation Notice:** GitHub will replace and discontinue `members_allowed_repository_creation_type` in favor of more granular permissions. The new input parameters are `members_can_create_public_repositories`, `members_can_create_private_repositories` for all organizations and `members_can_create_internal_repositories` for organizations associated with an enterprise account using GitHub Enterprise Cloud or GitHub Enterprise Server 2.20+. For more information, see the [blog post](https://developer.github.com/changes/2019-12-03-internal-visibility-changes).
 *
 * Enables an authenticated organization owner with the `admin:org` scope to update the organization's profile and member privileges.
* @param org - The organization name. The name is not case sensitive.
*/
var update$6 = {
    id: "orgs/update",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-organizations


* List organizations
* Lists all organizations, in the order that they were created on GitHub.
 *
 * **Note:** Pagination is powered exclusively by the `since` parameter. Use the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header) to get the URL for the next page of organizations.
* @param [perPage=30] - The number of results per page (max 100).
* @param [since] - An organization ID. Only return organizations with an ID greater than this ID.
*/
var list$5 = {
    id: "orgs/list",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-organization-webhooks


* List organization webhooks
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listWebhooks$1 = {
    id: "orgs/list-webhooks",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#create-an-organization-webhook


* Create an organization webhook
* Here's how you can create a hook that posts payloads in JSON format:
* @param org - The organization name. The name is not case sensitive.
*/
var createWebhook$1 = {
    id: "orgs/create-webhook",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-users-blocked-by-an-organization


* List users blocked by an organization
* List the users blocked by an organization.
* @param org - The organization name. The name is not case sensitive.
*/
var listBlockedUsers = {
    id: "orgs/list-blocked-users",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-organization-members


* List organization members
* List all users who are members of an organization. If the authenticated user is also a member of this organization then both concealed and public members will be returned.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [filter] - Filter members returned in the list. `2fa_disabled` means that only members without [two-factor authentication](https://github.com/blog/1614-two-factor-authentication) enabled will be returned. This options is only available for organization owners.
* @param [role] - Filter members returned by their role.
*/
var listMembers = {
    id: "orgs/list-members",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#get-audit-log


* Get the audit log for an organization
* Gets the audit log for an organization. For more information, see "[Reviewing the audit log for your organization](https://docs.github.com/github/setting-up-and-managing-organizations-and-teams/reviewing-the-audit-log-for-your-organization)."
 *
 * This endpoint is available for organizations on GitHub Enterprise Cloud. To use this endpoint, you must be an organization owner, and you must use an access token with the `admin:org` scope. GitHub Apps must have the `organization_administration` read permission to use this endpoint.
 *
 * By default, the response includes up to 30 events from the past three months. Use the `phrase` parameter to filter results and retrieve older events. For example, use the `phrase` parameter with the `created` qualifier to filter events based on when the events occurred. For more information, see "[Reviewing the audit log for your organization](https://docs.github.com/organizations/keeping-your-organization-secure/managing-security-settings-for-your-organization/reviewing-the-audit-log-for-your-organization#searching-the-audit-log)."
 *
 * Use pagination to retrieve fewer or more than 30 events. For more information, see "[Resources in the REST API](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination)."
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [phrase] - A search phrase. For more information, see [Searching the audit log](https://docs.github.com/github/setting-up-and-managing-organizations-and-teams/reviewing-the-audit-log-for-your-organization#searching-the-audit-log).
* @param [order] - The order of audit log events. To list newest events first, specify `desc`. To list oldest events first, specify `asc`.

The default is `desc`.
* @param [include] - The event types to include:

- `web` - returns web (non-Git) events.
- `git` - returns Git events.
- `all` - returns both web and Git events.

The default is `web`.
* @param [after] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events after this cursor.
* @param [before] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events before this cursor.
*/
var getAuditLog$1 = {
    id: "orgs/get-audit-log",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-organization-memberships-for-the-authenticated-user


* List organization memberships for the authenticated user
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [state] - Indicates the state of the memberships to return. Can be either `active` or `pending`. If not specified, the API returns both active and pending memberships.
*/
var listMembershipsForAuthenticatedUser = {
    id: "orgs/list-memberships-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-organizations-for-a-user


* List organizations for a user
* List [public organization memberships](https://docs.github.com/articles/publicizing-or-concealing-organization-membership) for the specified user.
 *
 * This method only lists _public_ memberships, regardless of authentication. If you need to fetch all of the organization memberships (public and private) for the authenticated user, use the [List organizations for the authenticated user](https://docs.github.com/rest/reference/orgs#list-organizations-for-the-authenticated-user) API instead.
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listForUser$3 = {
    id: "orgs/list-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-pending-organization-invitations


* List pending organization invitations
* The return hash contains a `role` field which refers to the Organization Invitation role and will be one of the following values: `direct_member`, `admin`, `billing_manager`, `hiring_manager`, or `reinstate`. If the invitee is not a GitHub member, the `login` field in the return hash will be `null`.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPendingInvitations = {
    id: "orgs/list-pending-invitations",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#create-an-organization-invitation


* Create an organization invitation
* Invite people to an organization by using their GitHub user ID or their email address. In order to create invitations in an organization, the authenticated user must be an organization owner.
 *
 * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
* @param org - The organization name. The name is not case sensitive.
*/
var createInvitation = {
    id: "orgs/create-invitation",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-app-installations-for-an-organization


* List app installations for an organization
* Lists all GitHub Apps in an organization. The installation count includes all GitHub Apps installed on repositories in the organization. You must be an organization owner with `admin:read` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listAppInstallations = {
    id: "orgs/list-app-installations",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-public-organization-members


* List public organization members
* Members of an organization can choose to have their membership publicized or not.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPublicMembers = {
    id: "orgs/list-public-members",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#get-an-organization-webhook


* Get an organization webhook
* Returns a webhook configured in an organization. To get only the webhook `config` properties, see "[Get a webhook configuration for an organization](/rest/reference/orgs#get-a-webhook-configuration-for-an-organization)."
* @param org - The organization name. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
*/
var getWebhook$1 = {
    id: "orgs/get-webhook",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#delete-an-organization-webhook


* Delete an organization webhook
* @param org - The organization name. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
*/
var deleteWebhook$1 = {
    id: "orgs/delete-webhook",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#update-an-organization-webhook


* Update an organization webhook
* Updates a webhook configured in an organization. When you update a webhook, the `secret` will be overwritten. If you previously had a `secret` set, you must provide the same `secret` or set a new `secret` or the secret will be removed. If you are only updating individual webhook `config` properties, use "[Update a webhook configuration for an organization](/rest/reference/orgs#update-a-webhook-configuration-for-an-organization)."
* @param org - The organization name. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
*/
var updateWebhook$1 = {
    id: "orgs/update-webhook",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#get-an-organization-membership-for-the-authenticated-user


* Get an organization membership for the authenticated user
* @param org - The organization name. The name is not case sensitive.
*/
var getMembershipForAuthenticatedUser = {
    id: "orgs/get-membership-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#update-an-organization-membership-for-the-authenticated-user


* Update an organization membership for the authenticated user
* @param org - The organization name. The name is not case sensitive.
*/
var updateMembershipForAuthenticatedUser = {
    id: "orgs/update-membership-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#check-if-a-user-is-blocked-by-an-organization


* Check if a user is blocked by an organization
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
*/
var checkBlockedUser = {
    id: "orgs/check-blocked-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#block-a-user-from-an-organization


* Block a user from an organization
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
*/
var blockUser = {
    id: "orgs/block-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#unblock-a-user-from-an-organization


* Unblock a user from an organization
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
*/
var unblockUser = {
    id: "orgs/unblock-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-security-manager-teams


* List security manager teams
* Lists teams that are security managers for an organization. For more information, see "[Managing security managers in your organization](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/managing-security-managers-in-your-organization)."
 *
 * To use this endpoint, you must be an administrator or security manager for the organization, and you must use an access token with the `read:org` scope.
 *
 * GitHub Apps must have the `administration` organization read permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
*/
var listSecurityManagerTeams = {
    id: "orgs/list-security-manager-teams",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-failed-organization-invitations


* List failed organization invitations
* The return hash contains `failed_at` and `failed_reason` fields which represent the time at which the invitation failed and the reason for the failure.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listFailedInvitations = {
    id: "orgs/list-failed-invitations",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#check-organization-membership-for-a-user


* Check organization membership for a user
* Check if a user is, publicly or privately, a member of the organization.
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
*/
var checkMembershipForUser = {
    id: "orgs/check-membership-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#remove-an-organization-member


* Remove an organization member
* Removing a user from this list will remove them from all teams and they will no longer have any access to the organization's repositories.
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
*/
var removeMember = {
    id: "orgs/remove-member",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#ping-an-organization-webhook


* Ping an organization webhook
* This will trigger a [ping event](https://docs.github.com/webhooks/#ping-event) to be sent to the hook.
* @param org - The organization name. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
*/
var pingWebhook$1 = {
    id: "orgs/ping-webhook",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-outside-collaborators-for-an-organization


* List outside collaborators for an organization
* List all users who are outside collaborators of an organization.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [filter] - Filter the list of outside collaborators. `2fa_disabled` means that only outside collaborators without [two-factor authentication](https://github.com/blog/1614-two-factor-authentication) enabled will be returned.
*/
var listOutsideCollaborators = {
    id: "orgs/list-outside-collaborators",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#get-a-webhook-configuration-for-an-organization


* Get a webhook configuration for an organization
* Returns the webhook configuration for an organization. To get more information about the webhook, including the `active` state and `events`, use "[Get an organization webhook ](/rest/reference/orgs#get-an-organization-webhook)."
 *
 * Access tokens must have the `admin:org_hook` scope, and GitHub Apps must have the `organization_hooks:read` permission.
* @param org - The organization name. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
*/
var getWebhookConfigForOrg = {
    id: "orgs/get-webhook-config-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#update-a-webhook-configuration-for-an-organization


* Update a webhook configuration for an organization
* Updates the webhook configuration for an organization. To update more information about the webhook, including the `active` state and `events`, use "[Update an organization webhook ](/rest/reference/orgs#update-an-organization-webhook)."
 *
 * Access tokens must have the `admin:org_hook` scope, and GitHub Apps must have the `organization_hooks:write` permission.
* @param org - The organization name. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
*/
var updateWebhookConfigForOrg = {
    id: "orgs/update-webhook-config-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#get-organization-membership-for-a-user


* Get organization membership for a user
* In order to get a user's membership with an organization, the authenticated user must be an organization member. The `state` parameter in the response can be used to identify the user's membership status.
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
*/
var getMembershipForUser = {
    id: "orgs/get-membership-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#set-organization-membership-for-a-user


* Set organization membership for a user
* Only authenticated organization owners can add a member to the organization or update the member's role.
 *
 * *   If the authenticated user is _adding_ a member to the organization, the invited user will receive an email inviting them to the organization. The user's [membership status](https://docs.github.com/rest/reference/orgs#get-organization-membership-for-a-user) will be `pending` until they accept the invitation.
 *
 * *   Authenticated users can _update_ a user's membership by passing the `role` parameter. If the authenticated user changes a member's role to `admin`, the affected user will receive an email notifying them that they've been made an organization owner. If the authenticated user changes an owner's role to `member`, no email will be sent.
 *
 * **Rate limits**
 *
 * To prevent abuse, the authenticated user is limited to 50 organization invitations per 24 hour period. If the organization is more than one month old or on a paid plan, the limit is 500 invitations per 24 hour period.
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
*/
var setMembershipForUser = {
    id: "orgs/set-membership-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#remove-organization-membership-for-a-user


* Remove organization membership for a user
* In order to remove a user's membership with an organization, the authenticated user must be an organization owner.
 *
 * If the specified user is an active member of the organization, this will remove them from the organization. If the specified user has been invited to the organization, this will cancel their invitation. The specified user will receive an email notification in both cases.
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
*/
var removeMembershipForUser = {
    id: "orgs/remove-membership-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-saml-sso-authorizations-for-an-organization


* List SAML SSO authorizations for an organization
* Listing and deleting credential authorizations is available to organizations with GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products).
 *
 * An authenticated organization owner with the `read:org` scope can list all credential authorizations for an organization that uses SAML single sign-on (SSO). The credentials are either personal access tokens or SSH keys that organization members have authorized for the organization. For more information, see [About authentication with SAML single sign-on](https://docs.github.com/en/articles/about-authentication-with-saml-single-sign-on).
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page] - Page token
* @param [login] - Limits the list of credentials authorizations for an organization to a specific login
*/
var listSamlSsoAuthorizations = {
    id: "orgs/list-saml-sso-authorizations",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#check-public-organization-membership-for-a-user


* Check public organization membership for a user
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
*/
var checkPublicMembershipForUser = {
    id: "orgs/check-public-membership-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#set-public-organization-membership-for-the-authenticated-user


* Set public organization membership for the authenticated user
* The user can publicize their own membership. (A user cannot publicize the membership for another user.)
 *
 * Note that you'll need to set `Content-Length` to zero when calling out to this endpoint. For more information, see "[HTTP verbs](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-verbs)."
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
*/
var setPublicMembershipForAuthenticatedUser = {
    id: "orgs/set-public-membership-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#remove-public-organization-membership-for-the-authenticated-user


* Remove public organization membership for the authenticated user
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
*/
var removePublicMembershipForAuthenticatedUser = {
    id: "orgs/remove-public-membership-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-deliveries-for-an-organization-webhook


* List deliveries for an organization webhook
* Returns a list of webhook deliveries for a webhook configured in an organization.
* @param org - The organization name. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
* @param [perPage=30] - The number of results per page (max 100).
* @param [cursor] - Used for pagination: the starting delivery from which the page of deliveries is fetched. Refer to the `link` header for the next and previous page cursors.
*/
var listWebhookDeliveries$2 = {
    id: "orgs/list-webhook-deliveries",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#cancel-an-organization-invitation


* Cancel an organization invitation
* Cancel an organization invitation. In order to cancel an organization invitation, the authenticated user must be an organization owner.
 *
 * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications).
* @param org - The organization name. The name is not case sensitive.
* @param invitationId - The unique identifier of the invitation.
*/
var cancelInvitation = {
    id: "orgs/cancel-invitation",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#convert-an-organization-member-to-outside-collaborator


* Convert an organization member to outside collaborator
* When an organization member is converted to an outside collaborator, they'll only have access to the repositories that their current team membership allows. The user will no longer be a member of the organization. For more information, see "[Converting an organization member to an outside collaborator](https://docs.github.com/articles/converting-an-organization-member-to-an-outside-collaborator/)". Converting an organization member to an outside collaborator may be restricted by enterprise administrators. For more information, see "[Enforcing repository management policies in your enterprise](https://docs.github.com/enterprise-cloud@latest/admin/policies/enforcing-policies-for-your-enterprise/enforcing-repository-management-policies-in-your-enterprise#enforcing-a-policy-for-inviting-outside-collaborators-to-repositories)."
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
*/
var convertMemberToOutsideCollaborator = {
    id: "orgs/convert-member-to-outside-collaborator",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#remove-outside-collaborator-from-an-organization


* Remove outside collaborator from an organization
* Removing a user from this list will remove them from all the organization's repositories.
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
*/
var removeOutsideCollaborator = {
    id: "orgs/remove-outside-collaborator",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-custom-repository-roles-in-an-organization


* List custom repository roles in an organization
* List the custom repository roles available in this organization. In order to see custom
 * repository roles in an organization, the authenticated user must be an organization owner.
 *
 * For more information on custom repository roles, see "[Managing custom repository roles for an organization](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/managing-custom-repository-roles-for-an-organization)".
* @param organizationId
*/
var listCustomRoles = {
    id: "orgs/list-custom-roles",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#list-organization-invitation-teams


* List organization invitation teams
* List all teams associated with an invitation. In order to see invitations in an organization, the authenticated user must be an organization owner.
* @param org - The organization name. The name is not case sensitive.
* @param invitationId - The unique identifier of the invitation.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listInvitationTeams = {
    id: "orgs/list-invitation-teams",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#add-a-security-manager-team


* Add a security manager team
* Adds a team as a security manager for an organization. For more information, see "[Managing security for an organization](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/managing-security-managers-in-your-organization) for an organization."
 *
 * To use this endpoint, you must be an administrator for the organization, and you must use an access token with the `write:org` scope.
 *
 * GitHub Apps must have the `administration` organization read-write permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
*/
var addSecurityManagerTeam = {
    id: "orgs/add-security-manager-team",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#remove-a-security-manager-team


* Remove a security manager team
* Removes the security manager role from a team for an organization. For more information, see "[Managing security managers in your organization](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/managing-security-managers-in-your-organization) team from an organization."
 *
 * To use this endpoint, you must be an administrator for the organization, and you must use an access token with the `admin:org` scope.
 *
 * GitHub Apps must have the `administration` organization read-write permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
*/
var removeSecurityManagerTeam = {
    id: "orgs/remove-security-manager-team",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#get-a-webhook-delivery-for-an-organization-webhook


* Get a webhook delivery for an organization webhook
* Returns a delivery for a webhook configured in an organization.
* @param org - The organization name. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
* @param deliveryId
*/
var getWebhookDelivery$2 = {
    id: "orgs/get-webhook-delivery",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#remove-a-saml-sso-authorization-for-an-organization


* Remove a SAML SSO authorization for an organization
* Listing and deleting credential authorizations is available to organizations with GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products).
 *
 * An authenticated organization owner with the `admin:org` scope can remove a credential authorization for an organization that uses SAML SSO. Once you remove someone's credential authorization, they will need to create a new personal access token or SSH key and authorize it for the organization they want to access.
* @param org - The organization name. The name is not case sensitive.
* @param credentialId
*/
var removeSamlSsoAuthorization = {
    id: "orgs/remove-saml-sso-authorization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/orgs#redeliver-a-delivery-for-an-organization-webhook


* Redeliver a delivery for an organization webhook
* Redeliver a delivery for a webhook configured in an organization.
* @param org - The organization name. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
* @param deliveryId
*/
var redeliverWebhookDelivery$2 = {
    id: "orgs/redeliver-webhook-delivery",
    clientId: "github",
    version: "1.1.5",
};

var orgs = /*#__PURE__*/Object.freeze({
  __proto__: null,
  listForAuthenticatedUser: listForAuthenticatedUser$4,
  getOrg: getOrg,
  update: update$6,
  list: list$5,
  listWebhooks: listWebhooks$1,
  createWebhook: createWebhook$1,
  listBlockedUsers: listBlockedUsers,
  listMembers: listMembers,
  getAuditLog: getAuditLog$1,
  listMembershipsForAuthenticatedUser: listMembershipsForAuthenticatedUser,
  listForUser: listForUser$3,
  listPendingInvitations: listPendingInvitations,
  createInvitation: createInvitation,
  listAppInstallations: listAppInstallations,
  listPublicMembers: listPublicMembers,
  getWebhook: getWebhook$1,
  deleteWebhook: deleteWebhook$1,
  updateWebhook: updateWebhook$1,
  getMembershipForAuthenticatedUser: getMembershipForAuthenticatedUser,
  updateMembershipForAuthenticatedUser: updateMembershipForAuthenticatedUser,
  checkBlockedUser: checkBlockedUser,
  blockUser: blockUser,
  unblockUser: unblockUser,
  listSecurityManagerTeams: listSecurityManagerTeams,
  listFailedInvitations: listFailedInvitations,
  checkMembershipForUser: checkMembershipForUser,
  removeMember: removeMember,
  pingWebhook: pingWebhook$1,
  listOutsideCollaborators: listOutsideCollaborators,
  getWebhookConfigForOrg: getWebhookConfigForOrg,
  updateWebhookConfigForOrg: updateWebhookConfigForOrg,
  getMembershipForUser: getMembershipForUser,
  setMembershipForUser: setMembershipForUser,
  removeMembershipForUser: removeMembershipForUser,
  listSamlSsoAuthorizations: listSamlSsoAuthorizations,
  checkPublicMembershipForUser: checkPublicMembershipForUser,
  setPublicMembershipForAuthenticatedUser: setPublicMembershipForAuthenticatedUser,
  removePublicMembershipForAuthenticatedUser: removePublicMembershipForAuthenticatedUser,
  listWebhookDeliveries: listWebhookDeliveries$2,
  cancelInvitation: cancelInvitation,
  convertMemberToOutsideCollaborator: convertMemberToOutsideCollaborator,
  removeOutsideCollaborator: removeOutsideCollaborator,
  listCustomRoles: listCustomRoles,
  listInvitationTeams: listInvitationTeams,
  addSecurityManagerTeam: addSecurityManagerTeam,
  removeSecurityManagerTeam: removeSecurityManagerTeam,
  getWebhookDelivery: getWebhookDelivery$2,
  removeSamlSsoAuthorization: removeSamlSsoAuthorization,
  redeliverWebhookDelivery: redeliverWebhookDelivery$2
});

/**
* @see https://docs.github.com/rest/reference/packages#list-packages-for-the-authenticated-user


* List packages for the authenticated user's namespace
* Lists packages owned by the authenticated user within the user's namespace.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` scope.
 * If `package_type` is not `container`, your token must also include the `repo` scope.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param [visibility] - The selected visibility of the packages. Only `container` package_types currently support `internal` visibility properly. For other ecosystems `internal` is synonymous with `private`. This parameter is optional and only filters an existing result set.
*/
var listPackagesForAuthenticatedUser = {
    id: "packages/list-packages-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#list-packages-for-an-organization


* List packages for an organization
* Lists all packages in an organization readable by the user.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` scope.
 * If `package_type` is not `container`, your token must also include the `repo` scope.
* @param org - The organization name. The name is not case sensitive.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param [visibility] - The selected visibility of the packages. Only `container` package_types currently support `internal` visibility properly. For other ecosystems `internal` is synonymous with `private`. This parameter is optional and only filters an existing result set.
*/
var listPackagesForOrganization = {
    id: "packages/list-packages-for-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#list-packages-for-user


* List packages for a user
* Lists all packages in a user's namespace for which the requesting user has access.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` scope.
 * If `package_type` is not `container`, your token must also include the `repo` scope.
* @param username - The handle for the GitHub user account.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param [visibility] - The selected visibility of the packages. Only `container` package_types currently support `internal` visibility properly. For other ecosystems `internal` is synonymous with `private`. This parameter is optional and only filters an existing result set.
*/
var listPackagesForUser = {
    id: "packages/list-packages-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#get-a-package-for-the-authenticated-user


* Get a package for the authenticated user
* Gets a specific package for a package owned by the authenticated user.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` scope.
 * If `package_type` is not `container`, your token must also include the `repo` scope.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
*/
var getPackageForAuthenticatedUser = {
    id: "packages/get-package-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#delete-a-package-for-the-authenticated-user


* Delete a package for the authenticated user
* Deletes a package owned by the authenticated user. You cannot delete a public package if any version of the package has more than 5,000 downloads. In this scenario, contact GitHub support for further assistance.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` and `packages:delete` scopes.
 * If `package_type` is not `container`, your token must also include the `repo` scope.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
*/
var deletePackageForAuthenticatedUser = {
    id: "packages/delete-package-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#get-a-package-for-an-organization


* Get a package for an organization
* Gets a specific package in an organization.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` scope.
 * If `package_type` is not `container`, your token must also include the `repo` scope.
* @param org - The organization name. The name is not case sensitive.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
*/
var getPackageForOrganization = {
    id: "packages/get-package-for-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#delete-a-package-for-an-organization


* Delete a package for an organization
* Deletes an entire package in an organization. You cannot delete a public package if any version of the package has more than 5,000 downloads. In this scenario, contact GitHub support for further assistance.
 *
 * To use this endpoint, you must have admin permissions in the organization and authenticate using an access token with the `packages:read` and `packages:delete` scopes. In addition:
 * - If `package_type` is not `container`, your token must also include the `repo` scope.
 * - If `package_type` is `container`, you must also have admin permissions to the container you want to delete.
* @param org - The organization name. The name is not case sensitive.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
*/
var deletePackageForOrg = {
    id: "packages/delete-package-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#restore-a-package-for-the-authenticated-user


* Restore a package for the authenticated user
* Restores a package owned by the authenticated user.
 *
 * You can restore a deleted package under the following conditions:
 * - The package was deleted within the last 30 days.
 * - The same package namespace and version is still available and not reused for a new package. If the same package namespace is not available, you will not be able to restore your package. In this scenario, to restore the deleted package, you must delete the new package that uses the deleted package's namespace first.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` and `packages:write` scopes. If `package_type` is not `container`, your token must also include the `repo` scope.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param [token] - package token
*/
var restorePackageForAuthenticatedUser = {
    id: "packages/restore-package-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#get-all-package-versions-for-a-package-owned-by-the-authenticated-user


* Get all package versions for a package owned by the authenticated user
* Returns all package versions for a package owned by the authenticated user.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` scope.
 * If `package_type` is not `container`, your token must also include the `repo` scope.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [state] - The state of the package, either active or deleted.
*/
var getAllPackageVersionsForPackageOwnedByAuthenticatedUser = {
    id: "packages/get-all-package-versions-for-package-owned-by-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#get-a-package-for-a-user


* Get a package for a user
* Gets a specific package metadata for a public package owned by a user.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` scope.
 * If `package_type` is not `container`, your token must also include the `repo` scope.
* @param username - The handle for the GitHub user account.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
*/
var getPackageForUser = {
    id: "packages/get-package-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#delete-a-package-for-a-user


* Delete a package for a user
* Deletes an entire package for a user. You cannot delete a public package if any version of the package has more than 5,000 downloads. In this scenario, contact GitHub support for further assistance.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` and `packages:delete` scopes. In addition:
 * - If `package_type` is not `container`, your token must also include the `repo` scope.
 * - If `package_type` is `container`, you must also have admin permissions to the container you want to delete.
* @param username - The handle for the GitHub user account.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
*/
var deletePackageForUser = {
    id: "packages/delete-package-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#restore-a-package-for-an-organization


* Restore a package for an organization
* Restores an entire package in an organization.
 *
 * You can restore a deleted package under the following conditions:
 * - The package was deleted within the last 30 days.
 * - The same package namespace and version is still available and not reused for a new package. If the same package namespace is not available, you will not be able to restore your package. In this scenario, to restore the deleted package, you must delete the new package that uses the deleted package's namespace first.
 *
 * To use this endpoint, you must have admin permissions in the organization and authenticate using an access token with the `packages:read` and `packages:write` scopes. In addition:
 * - If `package_type` is not `container`, your token must also include the `repo` scope.
 * - If `package_type` is `container`, you must also have admin permissions to the container that you want to restore.
* @param org - The organization name. The name is not case sensitive.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param [token] - package token
*/
var restorePackageForOrg = {
    id: "packages/restore-package-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#get-all-package-versions-for-a-package-owned-by-an-organization


* Get all package versions for a package owned by an organization
* Returns all package versions for a package owned by an organization.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` scope.
 * If `package_type` is not `container`, your token must also include the `repo` scope.
* @param org - The organization name. The name is not case sensitive.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [state] - The state of the package, either active or deleted.
*/
var getAllPackageVersionsForPackageOwnedByOrg = {
    id: "packages/get-all-package-versions-for-package-owned-by-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#restore-a-package-for-a-user


* Restore a package for a user
* Restores an entire package for a user.
 *
 * You can restore a deleted package under the following conditions:
 * - The package was deleted within the last 30 days.
 * - The same package namespace and version is still available and not reused for a new package. If the same package namespace is not available, you will not be able to restore your package. In this scenario, to restore the deleted package, you must delete the new package that uses the deleted package's namespace first.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` and `packages:write` scopes. In addition:
 * - If `package_type` is not `container`, your token must also include the `repo` scope.
 * - If `package_type` is `container`, you must also have admin permissions to the container that you want to restore.
* @param username - The handle for the GitHub user account.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param [token] - package token
*/
var restorePackageForUser = {
    id: "packages/restore-package-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#get-all-package-versions-for-a-package-owned-by-a-user


* Get all package versions for a package owned by a user
* Returns all package versions for a public package owned by a specified user.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` scope.
 * If `package_type` is not `container`, your token must also include the `repo` scope.
* @param username - The handle for the GitHub user account.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
*/
var getAllPackageVersionsForPackageOwnedByUser = {
    id: "packages/get-all-package-versions-for-package-owned-by-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#get-a-package-version-for-the-authenticated-user


* Get a package version for the authenticated user
* Gets a specific package version for a package owned by the authenticated user.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` scope.
 * If `package_type` is not `container`, your token must also include the `repo` scope.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param packageVersionId - Unique identifier of the package version.
*/
var getPackageVersionForAuthenticatedUser = {
    id: "packages/get-package-version-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#delete-a-package-version-for-the-authenticated-user


* Delete a package version for the authenticated user
* Deletes a specific package version for a package owned by the authenticated user.  If the package is public and the package version has more than 5,000 downloads, you cannot delete the package version. In this scenario, contact GitHub support for further assistance.
 *
 * To use this endpoint, you must have admin permissions in the organization and authenticate using an access token with the `packages:read` and `packages:delete` scopes.
 * If `package_type` is not `container`, your token must also include the `repo` scope.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param packageVersionId - Unique identifier of the package version.
*/
var deletePackageVersionForAuthenticatedUser = {
    id: "packages/delete-package-version-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#get-a-package-version-for-an-organization


* Get a package version for an organization
* Gets a specific package version in an organization.
 *
 * You must authenticate using an access token with the `packages:read` scope.
 * If `package_type` is not `container`, your token must also include the `repo` scope.
* @param org - The organization name. The name is not case sensitive.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param packageVersionId - Unique identifier of the package version.
*/
var getPackageVersionForOrganization = {
    id: "packages/get-package-version-for-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#delete-a-package-version-for-an-organization


* Delete package version for an organization
* Deletes a specific package version in an organization. If the package is public and the package version has more than 5,000 downloads, you cannot delete the package version. In this scenario, contact GitHub support for further assistance.
 *
 * To use this endpoint, you must have admin permissions in the organization and authenticate using an access token with the `packages:read` and `packages:delete` scopes. In addition:
 * - If `package_type` is not `container`, your token must also include the `repo` scope.
 * - If `package_type` is `container`, you must also have admin permissions to the container you want to delete.
* @param org - The organization name. The name is not case sensitive.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param packageVersionId - Unique identifier of the package version.
*/
var deletePackageVersionForOrg = {
    id: "packages/delete-package-version-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#restore-a-package-version-for-the-authenticated-user


* Restore a package version for the authenticated user
* Restores a package version owned by the authenticated user.
 *
 * You can restore a deleted package version under the following conditions:
 * - The package was deleted within the last 30 days.
 * - The same package namespace and version is still available and not reused for a new package. If the same package namespace is not available, you will not be able to restore your package. In this scenario, to restore the deleted package, you must delete the new package that uses the deleted package's namespace first.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` and `packages:write` scopes. If `package_type` is not `container`, your token must also include the `repo` scope.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param packageVersionId - Unique identifier of the package version.
*/
var restorePackageVersionForAuthenticatedUser = {
    id: "packages/restore-package-version-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#get-a-package-version-for-a-user


* Get a package version for a user
* Gets a specific package version for a public package owned by a specified user.
 *
 * At this time, to use this endpoint, you must authenticate using an access token with the `packages:read` scope.
 * If `package_type` is not `container`, your token must also include the `repo` scope.
* @param username - The handle for the GitHub user account.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param packageVersionId - Unique identifier of the package version.
*/
var getPackageVersionForUser = {
    id: "packages/get-package-version-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#delete-a-package-version-for-a-user


* Delete package version for a user
* Deletes a specific package version for a user. If the package is public and the package version has more than 5,000 downloads, you cannot delete the package version. In this scenario, contact GitHub support for further assistance.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` and `packages:delete` scopes. In addition:
 * - If `package_type` is not `container`, your token must also include the `repo` scope.
 * - If `package_type` is `container`, you must also have admin permissions to the container you want to delete.
* @param username - The handle for the GitHub user account.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param packageVersionId - Unique identifier of the package version.
*/
var deletePackageVersionForUser = {
    id: "packages/delete-package-version-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#restore-a-package-version-for-an-organization


* Restore package version for an organization
* Restores a specific package version in an organization.
 *
 * You can restore a deleted package under the following conditions:
 * - The package was deleted within the last 30 days.
 * - The same package namespace and version is still available and not reused for a new package. If the same package namespace is not available, you will not be able to restore your package. In this scenario, to restore the deleted package, you must delete the new package that uses the deleted package's namespace first.
 *
 * To use this endpoint, you must have admin permissions in the organization and authenticate using an access token with the `packages:read` and `packages:write` scopes. In addition:
 * - If `package_type` is not `container`, your token must also include the `repo` scope.
 * - If `package_type` is `container`, you must also have admin permissions to the container that you want to restore.
* @param org - The organization name. The name is not case sensitive.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param packageVersionId - Unique identifier of the package version.
*/
var restorePackageVersionForOrg = {
    id: "packages/restore-package-version-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/packages#restore-a-package-version-for-a-user


* Restore package version for a user
* Restores a specific package version for a user.
 *
 * You can restore a deleted package under the following conditions:
 * - The package was deleted within the last 30 days.
 * - The same package namespace and version is still available and not reused for a new package. If the same package namespace is not available, you will not be able to restore your package. In this scenario, to restore the deleted package, you must delete the new package that uses the deleted package's namespace first.
 *
 * To use this endpoint, you must authenticate using an access token with the `packages:read` and `packages:write` scopes. In addition:
 * - If `package_type` is not `container`, your token must also include the `repo` scope.
 * - If `package_type` is `container`, you must also have admin permissions to the container that you want to restore.
* @param username - The handle for the GitHub user account.
* @param packageName - The name of the package.
* @param packageType - The type of supported package. Packages in GitHub's Gradle registry have the type `maven`. Docker images pushed to GitHub's Container registry (`ghcr.io`) have the type `container`. You can use the type `docker` to find images that were pushed to GitHub's Docker registry (`docker.pkg.github.com`), even if these have now been migrated to the Container registry.
* @param packageVersionId - Unique identifier of the package version.
*/
var restorePackageVersionForUser = {
    id: "packages/restore-package-version-for-user",
    clientId: "github",
    version: "1.1.5",
};

var packages = /*#__PURE__*/Object.freeze({
  __proto__: null,
  listPackagesForAuthenticatedUser: listPackagesForAuthenticatedUser,
  listPackagesForOrganization: listPackagesForOrganization,
  listPackagesForUser: listPackagesForUser,
  getPackageForAuthenticatedUser: getPackageForAuthenticatedUser,
  deletePackageForAuthenticatedUser: deletePackageForAuthenticatedUser,
  getPackageForOrganization: getPackageForOrganization,
  deletePackageForOrg: deletePackageForOrg,
  restorePackageForAuthenticatedUser: restorePackageForAuthenticatedUser,
  getAllPackageVersionsForPackageOwnedByAuthenticatedUser: getAllPackageVersionsForPackageOwnedByAuthenticatedUser,
  getPackageForUser: getPackageForUser,
  deletePackageForUser: deletePackageForUser,
  restorePackageForOrg: restorePackageForOrg,
  getAllPackageVersionsForPackageOwnedByOrg: getAllPackageVersionsForPackageOwnedByOrg,
  restorePackageForUser: restorePackageForUser,
  getAllPackageVersionsForPackageOwnedByUser: getAllPackageVersionsForPackageOwnedByUser,
  getPackageVersionForAuthenticatedUser: getPackageVersionForAuthenticatedUser,
  deletePackageVersionForAuthenticatedUser: deletePackageVersionForAuthenticatedUser,
  getPackageVersionForOrganization: getPackageVersionForOrganization,
  deletePackageVersionForOrg: deletePackageVersionForOrg,
  restorePackageVersionForAuthenticatedUser: restorePackageVersionForAuthenticatedUser,
  getPackageVersionForUser: getPackageVersionForUser,
  deletePackageVersionForUser: deletePackageVersionForUser,
  restorePackageVersionForOrg: restorePackageVersionForOrg,
  restorePackageVersionForUser: restorePackageVersionForUser
});

/**
* @see https://docs.github.com/rest/reference/projects#create-a-user-project


* Create a user project
* Creates a user project board. Returns a `410 Gone` status if the user does not have existing classic projects. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
*/
var createForAuthenticatedUser$2 = {
    id: "projects/create-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#list-organization-projects


* List organization projects
* Lists the projects in an organization. Returns a `404 Not Found` status if projects are disabled in the organization. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [state] - Indicates the state of the projects to return. Can be either `open`, `closed`, or `all`.
*/
var listForOrg$2 = {
    id: "projects/list-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#create-an-organization-project


* Create an organization project
* Creates an organization project board. Returns a `410 Gone` status if projects are disabled in the organization or if the organization does not have existing classic projects. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
* @param org - The organization name. The name is not case sensitive.
*/
var createForOrg = {
    id: "projects/create-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#get-a-project


* Get a project
* Gets a project by its `id`. Returns a `404 Not Found` status if projects are disabled. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
* @param projectId - The unique identifier of the project.
*/
var getProject = {
    id: "projects/get",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#delete-a-project


* Delete a project
* Deletes a project board. Returns a `404 Not Found` status if projects are disabled.
* @param projectId - The unique identifier of the project.
*/
var deleteProject = {
    id: "projects/delete",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#update-a-project


* Update a project
* Updates a project board's information. Returns a `404 Not Found` status if projects are disabled. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
* @param projectId - The unique identifier of the project.
*/
var update$5 = {
    id: "projects/update",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#list-user-projects


* List user projects
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [state] - Indicates the state of the projects to return. Can be either `open`, `closed`, or `all`.
*/
var listForUser$2 = {
    id: "projects/list-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#get-a-project-column


* Get a project column
* @param columnId - The unique identifier of the column.
*/
var getColumn = {
    id: "projects/get-column",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#delete-a-project-column


* Delete a project column
* @param columnId - The unique identifier of the column.
*/
var deleteColumn = {
    id: "projects/delete-column",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#update-a-project-column


* Update an existing project column
* @param columnId - The unique identifier of the column.
*/
var updateColumn = {
    id: "projects/update-column",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#list-project-columns


* List project columns
* @param projectId - The unique identifier of the project.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listColumns = {
    id: "projects/list-columns",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#create-a-project-column


* Create a project column
* @param projectId - The unique identifier of the project.
*/
var createColumn = {
    id: "projects/create-column",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#list-repository-projects


* List repository projects
* Lists the projects in a repository. Returns a `404 Not Found` status if projects are disabled in the repository. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [state] - Indicates the state of the projects to return. Can be either `open`, `closed`, or `all`.
*/
var listForRepo$1 = {
    id: "projects/list-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#create-a-repository-project


* Create a repository project
* Creates a repository project board. Returns a `410 Gone` status if projects are disabled in the repository or if the repository does not have existing classic projects. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createForRepo = {
    id: "projects/create-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#get-a-project-card


* Get a project card
* @param cardId - The unique identifier of the card.
*/
var getCard = {
    id: "projects/get-card",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#delete-a-project-card


* Delete a project card
* @param cardId - The unique identifier of the card.
*/
var deleteCard = {
    id: "projects/delete-card",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#update-a-project-card


* Update an existing project card
* @param cardId - The unique identifier of the card.
*/
var updateCard = {
    id: "projects/update-card",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#list-project-cards


* List project cards
* @param columnId - The unique identifier of the column.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [archivedState] - Filters the project cards that are returned by the card's state.
*/
var listCards = {
    id: "projects/list-cards",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#create-a-project-card


* Create a project card
* @param columnId - The unique identifier of the column.
*/
var createCard = {
    id: "projects/create-card",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#move-a-project-column


* Move a project column
* @param columnId - The unique identifier of the column.
*/
var moveColumn = {
    id: "projects/move-column",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#list-project-collaborators


* List project collaborators
* Lists the collaborators for an organization project. For a project, the list of collaborators includes outside collaborators, organization members that are direct collaborators, organization members with access through team memberships, organization members with access through default organization permissions, and organization owners. You must be an organization owner or a project `admin` to list collaborators.
* @param projectId - The unique identifier of the project.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [affiliation] - Filters the collaborators by their affiliation. `outside` means outside collaborators of a project that are not a member of the project's organization. `direct` means collaborators with permissions to a project, regardless of organization membership status. `all` means all collaborators the authenticated user can see.
*/
var listCollaborators$1 = {
    id: "projects/list-collaborators",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#move-a-project-card


* Move a project card
* @param cardId - The unique identifier of the card.
*/
var moveCard = {
    id: "projects/move-card",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#add-project-collaborator


* Add project collaborator
* Adds a collaborator to an organization project and sets their permission level. You must be an organization owner or a project `admin` to add a collaborator.
* @param username - The handle for the GitHub user account.
* @param projectId - The unique identifier of the project.
*/
var addCollaborator$1 = {
    id: "projects/add-collaborator",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#remove-project-collaborator


* Remove user as a collaborator
* Removes a collaborator from an organization project. You must be an organization owner or a project `admin` to remove a collaborator.
* @param username - The handle for the GitHub user account.
* @param projectId - The unique identifier of the project.
*/
var removeCollaborator$1 = {
    id: "projects/remove-collaborator",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/projects#get-project-permission-for-a-user


* Get project permission for a user
* Returns the collaborator's permission level for an organization project. Possible values for the `permission` key: `admin`, `write`, `read`, `none`. You must be an organization owner or a project `admin` to review a user's permission level.
* @param username - The handle for the GitHub user account.
* @param projectId - The unique identifier of the project.
*/
var getPermissionForUser = {
    id: "projects/get-permission-for-user",
    clientId: "github",
    version: "1.1.5",
};

var projects = /*#__PURE__*/Object.freeze({
  __proto__: null,
  createForAuthenticatedUser: createForAuthenticatedUser$2,
  listForOrg: listForOrg$2,
  createForOrg: createForOrg,
  getProject: getProject,
  deleteProject: deleteProject,
  update: update$5,
  listForUser: listForUser$2,
  getColumn: getColumn,
  deleteColumn: deleteColumn,
  updateColumn: updateColumn,
  listColumns: listColumns,
  createColumn: createColumn,
  listForRepo: listForRepo$1,
  createForRepo: createForRepo,
  getCard: getCard,
  deleteCard: deleteCard,
  updateCard: updateCard,
  listCards: listCards,
  createCard: createCard,
  moveColumn: moveColumn,
  listCollaborators: listCollaborators$1,
  moveCard: moveCard,
  addCollaborator: addCollaborator$1,
  removeCollaborator: removeCollaborator$1,
  getPermissionForUser: getPermissionForUser
});

/**
* @see https://docs.github.com/rest/reference/pulls#list-pull-requests


* List pull requests
* Draft pull requests are available in public repositories with GitHub Free and GitHub Free for organizations, GitHub Pro, and legacy per-repository billing plans, and in public and private repositories with GitHub Team and GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [sort] - What to sort results by. Can be either `created`, `updated`, `popularity` (comment count) or `long-running` (age, filtering by pulls updated in the last month).
* @param [state] - Either `open`, `closed`, or `all` to filter by state.
* @param [head] - Filter pulls by head user or head organization and branch name in the format of `user:ref-name` or `organization:ref-name`. For example: `github:new-script-format` or `octocat:test-branch`.
* @param [base] - Filter pulls by base branch name. Example: `gh-pages`.
* @param [direction] - The direction of the sort. Can be either `asc` or `desc`. Default: `desc` when sort is `created` or sort is not specified, otherwise `asc`.
*/
var list$4 = {
    id: "pulls/list",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#create-a-pull-request


* Create a pull request
* Draft pull requests are available in public repositories with GitHub Free and GitHub Free for organizations, GitHub Pro, and legacy per-repository billing plans, and in public and private repositories with GitHub Team and GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * To open or update a pull request in a public repository, you must have write access to the head or the source branch. For organization-owned repositories, you must be a member of the organization that owns the repository to open or update a pull request.
 *
 * You can create a new pull request.
 *
 * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-rate-limits)" for details.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var create$4 = {
    id: "pulls/create",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#list-review-comments-in-a-repository


* List review comments in a repository
* Lists review comments for all pull requests in a repository. By default, review comments are in ascending order by ID.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [sort]
* @param [direction] - Can be either `asc` or `desc`. Ignored without `sort` parameter.
*/
var listReviewCommentsForRepo = {
    id: "pulls/list-review-comments-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#get-a-pull-request


* Get a pull request
* Draft pull requests are available in public repositories with GitHub Free and GitHub Free for organizations, GitHub Pro, and legacy per-repository billing plans, and in public and private repositories with GitHub Team and GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Lists details of a pull request by providing its number.
 *
 * When you get, [create](https://docs.github.com/rest/reference/pulls/#create-a-pull-request), or [edit](https://docs.github.com/rest/reference/pulls#update-a-pull-request) a pull request, GitHub creates a merge commit to test whether the pull request can be automatically merged into the base branch. This test commit is not added to the base branch or the head branch. You can review the status of the test commit using the `mergeable` key. For more information, see "[Checking mergeability of pull requests](https://docs.github.com/rest/guides/getting-started-with-the-git-database-api#checking-mergeability-of-pull-requests)".
 *
 * The value of the `mergeable` attribute can be `true`, `false`, or `null`. If the value is `null`, then GitHub has started a background job to compute the mergeability. After giving the job time to complete, resubmit the request. When the job finishes, you will see a non-`null` value for the `mergeable` attribute in the response. If `mergeable` is `true`, then `merge_commit_sha` will be the SHA of the _test_ merge commit.
 *
 * The value of the `merge_commit_sha` attribute changes depending on the state of the pull request. Before merging a pull request, the `merge_commit_sha` attribute holds the SHA of the _test_ merge commit. After merging a pull request, the `merge_commit_sha` attribute changes depending on how you merged the pull request:
 *
 * *   If merged as a [merge commit](https://docs.github.com/articles/about-merge-methods-on-github/), `merge_commit_sha` represents the SHA of the merge commit.
 * *   If merged via a [squash](https://docs.github.com/articles/about-merge-methods-on-github/#squashing-your-merge-commits), `merge_commit_sha` represents the SHA of the squashed commit on the base branch.
 * *   If [rebased](https://docs.github.com/articles/about-merge-methods-on-github/#rebasing-and-merging-your-commits), `merge_commit_sha` represents the commit that the base branch was updated to.
 *
 * Pass the appropriate [media type](https://docs.github.com/rest/overview/media-types/#commits-commit-comparison-and-pull-requests) to fetch diff and patch formats.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
*/
var getPull = {
    id: "pulls/get",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls/#update-a-pull-request


* Update a pull request
* Draft pull requests are available in public repositories with GitHub Free and GitHub Free for organizations, GitHub Pro, and legacy per-repository billing plans, and in public and private repositories with GitHub Team and GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * To open or update a pull request in a public repository, you must have write access to the head or the source branch. For organization-owned repositories, you must be a member of the organization that owns the repository to open or update a pull request.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
*/
var update$4 = {
    id: "pulls/update",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#list-pull-requests-files


* List pull requests files
* **Note:** Responses include a maximum of 3000 files. The paginated response returns 30 files per page by default.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listFiles = {
    id: "pulls/list-files",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#check-if-a-pull-request-has-been-merged


* Check if a pull request has been merged
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
*/
var checkIfMerged = {
    id: "pulls/check-if-merged",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#merge-a-pull-request


* Merge a pull request
* This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
*/
var merge$1 = {
    id: "pulls/merge",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#get-a-review-comment-for-a-pull-request


* Get a review comment for a pull request
* Provides details for a review comment.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
*/
var getReviewComment = {
    id: "pulls/get-review-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#delete-a-review-comment-for-a-pull-request


* Delete a review comment for a pull request
* Deletes a review comment.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
*/
var deleteReviewComment = {
    id: "pulls/delete-review-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#update-a-review-comment-for-a-pull-request


* Update a review comment for a pull request
* Enables you to edit a review comment.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
*/
var updateReviewComment = {
    id: "pulls/update-review-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#list-commits-on-a-pull-request


* List commits on a pull request
* Lists a maximum of 250 commits for a pull request. To receive a complete commit list for pull requests with more than 250 commits, use the [List commits](https://docs.github.com/rest/reference/repos#list-commits) endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listCommits$2 = {
    id: "pulls/list-commits",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#list-reviews-for-a-pull-request


* List reviews for a pull request
* The list of reviews returns in chronological order.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listReviews = {
    id: "pulls/list-reviews",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#create-a-review-for-a-pull-request


* Create a review for a pull request
* This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
 *
 * Pull request reviews created in the `PENDING` state do not include the `submitted_at` property in the response.
 *
 * **Note:** To comment on a specific line in a file, you need to first determine the _position_ of that line in the diff. The GitHub REST API v3 offers the `application/vnd.github.v3.diff` [media type](https://docs.github.com/rest/overview/media-types#commits-commit-comparison-and-pull-requests). To see a pull request diff, add this media type to the `Accept` header of a call to the [single pull request](https://docs.github.com/rest/reference/pulls#get-a-pull-request) endpoint.
 *
 * The `position` value equals the number of lines down from the first "@@" hunk header in the file you want to add a comment. The line just below the "@@" line is position 1, the next line is position 2, and so on. The position in the diff continues to increase through lines of whitespace and additional hunks until the beginning of a new file.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
*/
var createReview = {
    id: "pulls/create-review",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#list-review-comments-on-a-pull-request


* List review comments on a pull request
* Lists all review comments for a pull request. By default, review comments are in ascending order by ID.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [sort] - The property to sort the results by. `created` means when the repository was starred. `updated` means when the repository was last pushed to.
* @param [direction] - Can be either `asc` or `desc`. Ignored without `sort` parameter.
*/
var listReviewComments = {
    id: "pulls/list-review-comments",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#create-a-review-comment-for-a-pull-request


* Create a review comment for a pull request
*
 * Creates a review comment in the pull request diff. To add a regular comment to a pull request timeline, see "[Create an issue comment](https://docs.github.com/rest/reference/issues#create-an-issue-comment)." We recommend creating a review comment using `line`, `side`, and optionally `start_line` and `start_side` if your comment applies to more than one line in the pull request diff.
 *
 * The `position` parameter is deprecated. If you use `position`, the `line`, `side`, `start_line`, and `start_side` parameters are not required.
 *
 * **Note:** The position value equals the number of lines down from the first "@@" hunk header in the file you want to add a comment. The line just below the "@@" line is position 1, the next line is position 2, and so on. The position in the diff continues to increase through lines of whitespace and additional hunks until the beginning of a new file.
 *
 * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
*/
var createReviewComment = {
    id: "pulls/create-review-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#update-a-pull-request-branch


* Update a pull request branch
* Updates the pull request branch with the latest upstream changes by merging HEAD from the base branch into the pull request branch.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
*/
var updateBranch = {
    id: "pulls/update-branch",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#list-requested-reviewers-for-a-pull-request


* List requested reviewers for a pull request
* Lists the users or teams whose review is requested for a pull request. Once a requested reviewer submits a review, they are no longer considered a requested reviewer. Their review will instead be returned by the [List reviews for a pull request](https://docs.github.com/rest/pulls/reviews#list-reviews-for-a-pull-request) operation.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listRequestedReviewers = {
    id: "pulls/list-requested-reviewers",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#request-reviewers-for-a-pull-request


* Request reviewers for a pull request
* This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
*/
var requestReviewers = {
    id: "pulls/request-reviewers",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#remove-requested-reviewers-from-a-pull-request


* Remove requested reviewers from a pull request
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
*/
var removeRequestedReviewers = {
    id: "pulls/remove-requested-reviewers",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#get-a-review-for-a-pull-request


* Get a review for a pull request
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
* @param reviewId - The unique identifier of the review.
*/
var getReview = {
    id: "pulls/get-review",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#update-a-review-for-a-pull-request


* Update a review for a pull request
* Update the review summary comment with new text.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
* @param reviewId - The unique identifier of the review.
*/
var updateReview = {
    id: "pulls/update-review",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#delete-a-pending-review-for-a-pull-request


* Delete a pending review for a pull request
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
* @param reviewId - The unique identifier of the review.
*/
var deletePendingReview = {
    id: "pulls/delete-pending-review",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#submit-a-review-for-a-pull-request


* Submit a review for a pull request
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
* @param reviewId - The unique identifier of the review.
*/
var submitReview = {
    id: "pulls/submit-review",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#list-comments-for-a-pull-request-review


* List comments for a pull request review
* List comments for a specific pull request review.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
* @param reviewId - The unique identifier of the review.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listCommentsForReview = {
    id: "pulls/list-comments-for-review",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#create-a-reply-for-a-review-comment


* Create a reply for a review comment
* Creates a reply to a review comment for a pull request. For the `comment_id`, provide the ID of the review comment you are replying to. This must be the ID of a _top-level review comment_, not a reply to that comment. Replies to replies are not supported.
 *
 * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
* @param pullNumber - The number that identifies the pull request.
*/
var createReplyForReviewComment = {
    id: "pulls/create-reply-for-review-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/pulls#dismiss-a-review-for-a-pull-request


* Dismiss a review for a pull request
* **Note:** To dismiss a pull request review on a [protected branch](https://docs.github.com/rest/reference/repos#branches), you must be a repository administrator or be included in the list of people or teams who can dismiss pull request reviews.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
* @param reviewId - The unique identifier of the review.
*/
var dismissReview = {
    id: "pulls/dismiss-review",
    clientId: "github",
    version: "1.1.5",
};

var pulls = /*#__PURE__*/Object.freeze({
  __proto__: null,
  list: list$4,
  create: create$4,
  listReviewCommentsForRepo: listReviewCommentsForRepo,
  getPull: getPull,
  update: update$4,
  listFiles: listFiles,
  checkIfMerged: checkIfMerged,
  merge: merge$1,
  getReviewComment: getReviewComment,
  deleteReviewComment: deleteReviewComment,
  updateReviewComment: updateReviewComment,
  listCommits: listCommits$2,
  listReviews: listReviews,
  createReview: createReview,
  listReviewComments: listReviewComments,
  createReviewComment: createReviewComment,
  updateBranch: updateBranch,
  listRequestedReviewers: listRequestedReviewers,
  requestReviewers: requestReviewers,
  removeRequestedReviewers: removeRequestedReviewers,
  getReview: getReview,
  updateReview: updateReview,
  deletePendingReview: deletePendingReview,
  submitReview: submitReview,
  listCommentsForReview: listCommentsForReview,
  createReplyForReviewComment: createReplyForReviewComment,
  dismissReview: dismissReview
});

/**
* @see https://docs.github.com/rest/reference/rate-limit#get-rate-limit-status-for-the-authenticated-user


* Get rate limit status for the authenticated user
* **Note:** Accessing this endpoint does not count against your REST API rate limit.
 *
 * **Note:** The `rate` object is deprecated. If you're writing new API client code or updating existing code, you should use the `core` object instead of the `rate` object. The `core` object contains the same information that is present in the `rate` object.
*/
var getRateLimits = {
    id: "rate-limit/get",
    clientId: "github",
    version: "1.1.5",
};

var rateLimit = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getRateLimits: getRateLimits
});

/**
* @see https://docs.github.com/rest/reference/reactions#list-reactions-for-a-commit-comment


* List reactions for a commit comment
* List the reactions to a [commit comment](https://docs.github.com/rest/reference/repos#comments).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [content] - Returns a single [reaction type](https://docs.github.com/rest/reference/reactions#reaction-types). Omit this parameter to list all reactions to a commit comment.
*/
var listForCommitComment = {
    id: "reactions/list-for-commit-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#create-reaction-for-a-commit-comment


* Create reaction for a commit comment
* Create a reaction to a [commit comment](https://docs.github.com/rest/reference/repos#comments). A response with an HTTP `200` status means that you already added the reaction type to this commit comment.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
*/
var createForCommitComment = {
    id: "reactions/create-for-commit-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#list-reactions-for-an-issue


* List reactions for an issue
* List the reactions to an [issue](https://docs.github.com/rest/reference/issues).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [content] - Returns a single [reaction type](https://docs.github.com/rest/reference/reactions#reaction-types). Omit this parameter to list all reactions to an issue.
*/
var listForIssue = {
    id: "reactions/list-for-issue",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#create-reaction-for-an-issue


* Create reaction for an issue
* Create a reaction to an [issue](https://docs.github.com/rest/reference/issues/). A response with an HTTP `200` status means that you already added the reaction type to this issue.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
*/
var createForIssue = {
    id: "reactions/create-for-issue",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions/#list-reactions-for-a-release


* List reactions for a release
* List the reactions to a [release](https://docs.github.com/rest/reference/repos#releases).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param releaseId - The unique identifier of the release.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [content] - Returns a single [reaction type](https://docs.github.com/rest/reference/reactions#reaction-types). Omit this parameter to list all reactions to a release.
*/
var listForRelease = {
    id: "reactions/list-for-release",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions/#create-reaction-for-a-release


* Create reaction for a release
* Create a reaction to a [release](https://docs.github.com/rest/reference/repos#releases). A response with a `Status: 200 OK` means that you already added the reaction type to this release.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param releaseId - The unique identifier of the release.
*/
var createForRelease = {
    id: "reactions/create-for-release",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions/#list-reactions-for-a-team-discussion-legacy

* @deprecated

* List reactions for a team discussion (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`List reactions for a team discussion`](https://docs.github.com/rest/reference/reactions#list-reactions-for-a-team-discussion) endpoint.
 *
 * List the reactions to a [team discussion](https://docs.github.com/rest/reference/teams#discussions). OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param teamId - The unique identifier of the team.
* @param discussionNumber - The number that identifies the discussion.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [content] - Returns a single [reaction type](https://docs.github.com/rest/reference/reactions#reaction-types). Omit this parameter to list all reactions to a team discussion.
*/
var listForTeamDiscussionLegacy = {
    id: "reactions/list-for-team-discussion-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions/#create-reaction-for-a-team-discussion-legacy

* @deprecated

* Create reaction for a team discussion (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`Create reaction for a team discussion`](https://docs.github.com/rest/reference/reactions#create-reaction-for-a-team-discussion) endpoint.
 *
 * Create a reaction to a [team discussion](https://docs.github.com/rest/reference/teams#discussions). OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/). A response with an HTTP `200` status means that you already added the reaction type to this team discussion.
* @param teamId - The unique identifier of the team.
* @param discussionNumber - The number that identifies the discussion.
*/
var createForTeamDiscussionLegacy = {
    id: "reactions/create-for-team-discussion-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#list-reactions-for-a-pull-request-review-comment


* List reactions for a pull request review comment
* List the reactions to a [pull request review comment](https://docs.github.com/rest/reference/pulls#review-comments).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [content] - Returns a single [reaction type](https://docs.github.com/rest/reference/reactions#reaction-types). Omit this parameter to list all reactions to a pull request review comment.
*/
var listForPullRequestReviewComment = {
    id: "reactions/list-for-pull-request-review-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#create-reaction-for-a-pull-request-review-comment


* Create reaction for a pull request review comment
* Create a reaction to a [pull request review comment](https://docs.github.com/rest/reference/pulls#comments). A response with an HTTP `200` status means that you already added the reaction type to this pull request review comment.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
*/
var createForPullRequestReviewComment = {
    id: "reactions/create-for-pull-request-review-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#list-reactions-for-an-issue-comment


* List reactions for an issue comment
* List the reactions to an [issue comment](https://docs.github.com/rest/reference/issues#comments).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [content] - Returns a single [reaction type](https://docs.github.com/rest/reference/reactions#reaction-types). Omit this parameter to list all reactions to an issue comment.
*/
var listForIssueComment = {
    id: "reactions/list-for-issue-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#create-reaction-for-an-issue-comment


* Create reaction for an issue comment
* Create a reaction to an [issue comment](https://docs.github.com/rest/reference/issues#comments). A response with an HTTP `200` status means that you already added the reaction type to this issue comment.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
*/
var createForIssueComment = {
    id: "reactions/create-for-issue-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#delete-a-commit-comment-reaction


* Delete a commit comment reaction
* **Note:** You can also specify a repository by `repository_id` using the route `DELETE /repositories/:repository_id/comments/:comment_id/reactions/:reaction_id`.
 *
 * Delete a reaction to a [commit comment](https://docs.github.com/rest/reference/repos#comments).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
* @param reactionId - The unique identifier of the reaction.
*/
var deleteForCommitComment = {
    id: "reactions/delete-for-commit-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#delete-an-issue-reaction


* Delete an issue reaction
* **Note:** You can also specify a repository by `repository_id` using the route `DELETE /repositories/:repository_id/issues/:issue_number/reactions/:reaction_id`.
 *
 * Delete a reaction to an [issue](https://docs.github.com/rest/reference/issues/).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
* @param reactionId - The unique identifier of the reaction.
*/
var deleteForIssue = {
    id: "reactions/delete-for-issue",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions/#delete-a-release-reaction


* Delete a release reaction
* **Note:** You can also specify a repository by `repository_id` using the route `DELETE delete /repositories/:repository_id/releases/:release_id/reactions/:reaction_id`.
 *
 * Delete a reaction to a [release](https://docs.github.com/rest/reference/repos#releases).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param releaseId - The unique identifier of the release.
* @param reactionId - The unique identifier of the reaction.
*/
var deleteForRelease = {
    id: "reactions/delete-for-release",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#list-reactions-for-a-team-discussion


* List reactions for a team discussion
* List the reactions to a [team discussion](https://docs.github.com/rest/reference/teams#discussions). OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/:org_id/team/:team_id/discussions/:discussion_number/reactions`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param discussionNumber - The number that identifies the discussion.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [content] - Returns a single [reaction type](https://docs.github.com/rest/reference/reactions#reaction-types). Omit this parameter to list all reactions to a team discussion.
*/
var listForTeamDiscussionInOrg = {
    id: "reactions/list-for-team-discussion-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#create-reaction-for-a-team-discussion


* Create reaction for a team discussion
* Create a reaction to a [team discussion](https://docs.github.com/rest/reference/teams#discussions). OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/). A response with an HTTP `200` status means that you already added the reaction type to this team discussion.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `POST /organizations/:org_id/team/:team_id/discussions/:discussion_number/reactions`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param discussionNumber - The number that identifies the discussion.
*/
var createForTeamDiscussionInOrg = {
    id: "reactions/create-for-team-discussion-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#delete-a-pull-request-comment-reaction


* Delete a pull request comment reaction
* **Note:** You can also specify a repository by `repository_id` using the route `DELETE /repositories/:repository_id/pulls/comments/:comment_id/reactions/:reaction_id.`
 *
 * Delete a reaction to a [pull request review comment](https://docs.github.com/rest/reference/pulls#review-comments).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
* @param reactionId - The unique identifier of the reaction.
*/
var deleteForPullRequestComment = {
    id: "reactions/delete-for-pull-request-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#delete-an-issue-comment-reaction


* Delete an issue comment reaction
* **Note:** You can also specify a repository by `repository_id` using the route `DELETE delete /repositories/:repository_id/issues/comments/:comment_id/reactions/:reaction_id`.
 *
 * Delete a reaction to an [issue comment](https://docs.github.com/rest/reference/issues#comments).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
* @param reactionId - The unique identifier of the reaction.
*/
var deleteForIssueComment = {
    id: "reactions/delete-for-issue-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions/#list-reactions-for-a-team-discussion-comment-legacy

* @deprecated

* List reactions for a team discussion comment (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`List reactions for a team discussion comment`](https://docs.github.com/rest/reference/reactions#list-reactions-for-a-team-discussion-comment) endpoint.
 *
 * List the reactions to a [team discussion comment](https://docs.github.com/rest/reference/teams#discussion-comments). OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param teamId - The unique identifier of the team.
* @param discussionNumber - The number that identifies the discussion.
* @param commentNumber - The number that identifies the comment.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [content] - Returns a single [reaction type](https://docs.github.com/rest/reference/reactions#reaction-types). Omit this parameter to list all reactions to a team discussion comment.
*/
var listForTeamDiscussionCommentLegacy = {
    id: "reactions/list-for-team-discussion-comment-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions/#create-reaction-for-a-team-discussion-comment-legacy

* @deprecated

* Create reaction for a team discussion comment (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new "[Create reaction for a team discussion comment](https://docs.github.com/rest/reference/reactions#create-reaction-for-a-team-discussion-comment)" endpoint.
 *
 * Create a reaction to a [team discussion comment](https://docs.github.com/rest/reference/teams#discussion-comments). OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/). A response with an HTTP `200` status means that you already added the reaction type to this team discussion comment.
* @param teamId - The unique identifier of the team.
* @param discussionNumber - The number that identifies the discussion.
* @param commentNumber - The number that identifies the comment.
*/
var createForTeamDiscussionCommentLegacy = {
    id: "reactions/create-for-team-discussion-comment-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#delete-team-discussion-reaction


* Delete team discussion reaction
* **Note:** You can also specify a team or organization with `team_id` and `org_id` using the route `DELETE /organizations/:org_id/team/:team_id/discussions/:discussion_number/reactions/:reaction_id`.
 *
 * Delete a reaction to a [team discussion](https://docs.github.com/rest/reference/teams#discussions). OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param discussionNumber - The number that identifies the discussion.
* @param reactionId - The unique identifier of the reaction.
*/
var deleteForTeamDiscussion = {
    id: "reactions/delete-for-team-discussion",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#list-reactions-for-a-team-discussion-comment


* List reactions for a team discussion comment
* List the reactions to a [team discussion comment](https://docs.github.com/rest/reference/teams#discussion-comments/). OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/:org_id/team/:team_id/discussions/:discussion_number/comments/:comment_number/reactions`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param discussionNumber - The number that identifies the discussion.
* @param commentNumber - The number that identifies the comment.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [content] - Returns a single [reaction type](https://docs.github.com/rest/reference/reactions#reaction-types). Omit this parameter to list all reactions to a team discussion comment.
*/
var listForTeamDiscussionCommentInOrg = {
    id: "reactions/list-for-team-discussion-comment-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#create-reaction-for-a-team-discussion-comment


* Create reaction for a team discussion comment
* Create a reaction to a [team discussion comment](https://docs.github.com/rest/reference/teams#discussion-comments). OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/). A response with an HTTP `200` status means that you already added the reaction type to this team discussion comment.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `POST /organizations/:org_id/team/:team_id/discussions/:discussion_number/comments/:comment_number/reactions`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param discussionNumber - The number that identifies the discussion.
* @param commentNumber - The number that identifies the comment.
*/
var createForTeamDiscussionCommentInOrg = {
    id: "reactions/create-for-team-discussion-comment-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/reactions#delete-team-discussion-comment-reaction


* Delete team discussion comment reaction
* **Note:** You can also specify a team or organization with `team_id` and `org_id` using the route `DELETE /organizations/:org_id/team/:team_id/discussions/:discussion_number/comments/:comment_number/reactions/:reaction_id`.
 *
 * Delete a reaction to a [team discussion comment](https://docs.github.com/rest/reference/teams#discussion-comments). OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param discussionNumber - The number that identifies the discussion.
* @param reactionId - The unique identifier of the reaction.
* @param commentNumber - The number that identifies the comment.
*/
var deleteForTeamDiscussionComment = {
    id: "reactions/delete-for-team-discussion-comment",
    clientId: "github",
    version: "1.1.5",
};

var reactions = /*#__PURE__*/Object.freeze({
  __proto__: null,
  listForCommitComment: listForCommitComment,
  createForCommitComment: createForCommitComment,
  listForIssue: listForIssue,
  createForIssue: createForIssue,
  listForRelease: listForRelease,
  createForRelease: createForRelease,
  listForTeamDiscussionLegacy: listForTeamDiscussionLegacy,
  createForTeamDiscussionLegacy: createForTeamDiscussionLegacy,
  listForPullRequestReviewComment: listForPullRequestReviewComment,
  createForPullRequestReviewComment: createForPullRequestReviewComment,
  listForIssueComment: listForIssueComment,
  createForIssueComment: createForIssueComment,
  deleteForCommitComment: deleteForCommitComment,
  deleteForIssue: deleteForIssue,
  deleteForRelease: deleteForRelease,
  listForTeamDiscussionInOrg: listForTeamDiscussionInOrg,
  createForTeamDiscussionInOrg: createForTeamDiscussionInOrg,
  deleteForPullRequestComment: deleteForPullRequestComment,
  deleteForIssueComment: deleteForIssueComment,
  listForTeamDiscussionCommentLegacy: listForTeamDiscussionCommentLegacy,
  createForTeamDiscussionCommentLegacy: createForTeamDiscussionCommentLegacy,
  deleteForTeamDiscussion: deleteForTeamDiscussion,
  listForTeamDiscussionCommentInOrg: listForTeamDiscussionCommentInOrg,
  createForTeamDiscussionCommentInOrg: createForTeamDiscussionCommentInOrg,
  deleteForTeamDiscussionComment: deleteForTeamDiscussionComment
});

/**
* @see https://docs.github.com/rest/reference/repos#list-repositories-for-the-authenticated-user


* List repositories for the authenticated user
* Lists repositories that the authenticated user has explicit permission (`:read`, `:write`, or `:admin`) to access.
 *
 * The authenticated user has explicit permission to access repositories they own, repositories where they are a collaborator, and repositories that they can access through an organization membership.
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [direction] - The order to sort by. Default: `asc` when using `full_name`, otherwise `desc`.
* @param [sort] - The property to sort the results by.
* @param [type] - Limit results to repositories of the specified type. Will cause a `422` error if used in the same request as **visibility** or **affiliation**.
* @param [visibility] - Limit results to repositories with the specified visibility.
* @param [affiliation='owner,collaborator,organization_member'] - Comma-separated list of values. Can include:
\* `owner`: Repositories that are owned by the authenticated user.
\* `collaborator`: Repositories that the user has been added to as a collaborator.
\* `organization_member`: Repositories that the user has access to through being a member of an organization. This includes every repository on every team that the user is on.
* @param [before] - Only show notifications updated before the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
*/
var listForAuthenticatedUser$3 = {
    id: "repos/list-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-a-repository-for-the-authenticated-user


* Create a repository for the authenticated user
* Creates a new repository for the authenticated user.
 *
 * **OAuth scope requirements**
 *
 * When using [OAuth](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/), authorizations must include:
 *
 * *   `public_repo` scope or `repo` scope to create a public repository. Note: For GitHub AE, use `repo` scope to create an internal repository.
 * *   `repo` scope to create a private repository.
*/
var createForAuthenticatedUser$1 = {
    id: "repos/create-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-public-repositories


* List public repositories
* Lists all public repositories in the order that they were created.
 *
 * Note:
 * - For GitHub Enterprise Server, this endpoint will only list repositories available to all users on the enterprise.
 * - Pagination is powered exclusively by the `since` parameter. Use the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header) to get the URL for the next page of repositories.
* @param [since] - A repository ID. Only return repositories with an ID greater than this ID.
*/
var listPublic$1 = {
    id: "repos/list-public",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-organization-repositories


* List organization repositories
* Lists repositories for the specified organization.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [type] - Specifies the types of repositories you want returned. If your organization is associated with an enterprise account using GitHub Enterprise Cloud or GitHub Enterprise Server 2.20+, `type` can also be `internal`. However, the `internal` value is not yet supported when a GitHub App calls this API with an installation access token.
* @param [sort] - The property to sort the results by.
* @param [direction] - The order to sort by. Default: `asc` when using `full_name`, otherwise `desc`.
*/
var listForOrg$1 = {
    id: "repos/list-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-an-organization-repository


* Create an organization repository
* Creates a new repository in the specified organization. The authenticated user must be a member of the organization.
 *
 * **OAuth scope requirements**
 *
 * When using [OAuth](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/), authorizations must include:
 *
 * *   `public_repo` scope or `repo` scope to create a public repository. Note: For GitHub AE, use `repo` scope to create an internal repository.
 * *   `repo` scope to create a private repository
* @param org - The organization name. The name is not case sensitive.
*/
var createInOrg = {
    id: "repos/create-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-repository


* Get a repository
* The `parent` and `source` objects are present when the repository is a fork. `parent` is the repository this repository was forked from, `source` is the ultimate source for the network.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getRepo = {
    id: "repos/get",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-a-repository


* Delete a repository
* Deleting a repository requires admin access. If OAuth is used, the `delete_repo` scope is required.
 *
 * If an organization owner has configured the organization to prevent members from deleting organization-owned
 * repositories, you will get a `403 Forbidden` response.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var deleteRepo = {
    id: "repos/delete",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos/#update-a-repository


* Update a repository
* **Note**: To edit a repository's topics, use the [Replace all repository topics](https://docs.github.com/rest/reference/repos#replace-all-repository-topics) endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var update$3 = {
    id: "repos/update",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-repositories-for-a-user


* List repositories for a user
* Lists public repositories for the specified user. Note: For GitHub AE, this endpoint will list internal repositories for the specified user.
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [type] - Limit results to repositories of the specified type.
* @param [direction] - The order to sort by. Default: `asc` when using `full_name`, otherwise `desc`.
* @param [sort] - The property to sort the results by.
*/
var listForUser$1 = {
    id: "repos/list-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#enable-git-lfs-for-a-repository


* Enable Git LFS for a repository
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var enableLfsForRepo = {
    id: "repos/enable-lfs-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#disable-git-lfs-for-a-repository


* Disable Git LFS for a repository
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var disableLfsForRepo = {
    id: "repos/disable-lfs-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-deploy-keys


* List deploy keys
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listDeployKeys = {
    id: "repos/list-deploy-keys",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-a-deploy-key


* Create a deploy key
* You can create a read-only deploy key.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createDeployKey = {
    id: "repos/create-deploy-key",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-repository-tags


* List repository tags
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listTags = {
    id: "repos/list-tags",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-forks


* List forks
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [sort] - The sort order. Can be either `newest`, `oldest`, or `stargazers`.
*/
var listForks$1 = {
    id: "repos/list-forks",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-a-fork


* Create a fork
* Create a fork for the authenticated user.
 *
 * **Note**: Forking a Repository happens asynchronously. You may have to wait a short period of time before you can access the git objects. If this takes longer than 5 minutes, be sure to contact [GitHub Support](https://support.github.com/contact?tags=dotcom-rest-api).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createFork = {
    id: "repos/create-fork",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-repository-webhooks


* List repository webhooks
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listWebhooks = {
    id: "repos/list-webhooks",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-a-repository-webhook


* Create a repository webhook
* Repositories can have multiple webhooks installed. Each webhook should have a unique `config`. Multiple webhooks can
 * share the same `config` as long as those webhooks do not have any `events` that overlap.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createWebhook = {
    id: "repos/create-webhook",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-github-pages-site


* Get a GitHub Pages site
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getPages = {
    id: "repos/get-pages",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-a-github-pages-site


* Create a GitHub Pages site
* Configures a GitHub Pages site. For more information, see "[About GitHub Pages](/github/working-with-github-pages/about-github-pages)."
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createPagesSite = {
    id: "repos/create-pages-site",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#update-information-about-a-github-pages-site


* Update information about a GitHub Pages site
* Updates information for a GitHub Pages site. For more information, see "[About GitHub Pages](/github/working-with-github-pages/about-github-pages).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var updateInformationAboutPagesSite = {
    id: "repos/update-information-about-pages-site",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-a-github-pages-site


* Delete a GitHub Pages site
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var deletePagesSite = {
    id: "repos/delete-pages-site",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-repository-teams


* List repository teams
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listTeams = {
    id: "repos/list-teams",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#merge-a-branch


* Merge a branch
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var merge = {
    id: "repos/merge",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-repository-readme


* Get a repository README
* Gets the preferred README for a repository.
 *
 * READMEs support [custom media types](https://docs.github.com/rest/reference/repos#custom-media-types) for retrieving the raw content or rendered HTML.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [ref] - The name of the commit/branch/tag. Default: the repository’s default branch (usually `master`)
*/
var getReadme = {
    id: "repos/get-readme",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-all-repository-topics


* Get all repository topics
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var getAllTopics = {
    id: "repos/get-all-topics",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#replace-all-repository-topics


* Replace all repository topics
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var replaceAllTopics = {
    id: "repos/replace-all-topics",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-repository-invitations-for-the-authenticated-user


* List repository invitations for the authenticated user
* When authenticating as a user, this endpoint will list all currently open repository invitations for that user.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listInvitationsForAuthenticatedUser = {
    id: "repos/list-invitations-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-commits


* List commits
* **Signature verification object**
 *
 * The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
 *
 * | Name | Type | Description |
 * | ---- | ---- | ----------- |
 * | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
 * | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in table below. |
 * | `signature` | `string` | The signature that was extracted from the commit. |
 * | `payload` | `string` | The value that was signed. |
 *
 * These are the possible values for `reason` in the `verification` object:
 *
 * | Value | Description |
 * | ----- | ----------- |
 * | `expired_key` | The key that made the signature is expired. |
 * | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
 * | `gpgverify_error` | There was an error communicating with the signature verification service. |
 * | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
 * | `unsigned` | The object does not include a signature. |
 * | `unknown_signature_type` | A non-PGP signature was found in the commit. |
 * | `no_user` | No user was associated with the `committer` email address in the commit. |
 * | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on her/his account. |
 * | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
 * | `unknown_key` | The key that made the signature has not been registered with any user's account. |
 * | `malformed_signature` | There was an error parsing the signature. |
 * | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
 * | `valid` | None of the above errors applied, so the signature is considered to be verified. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [sha] - SHA or branch to start listing commits from. Default: the repository’s default branch (usually `master`).
* @param [author] - GitHub login or email address by which to filter by commit author.
* @param [until] - Only commits before this date will be returned. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [path] - Only commits containing this file path will be returned.
*/
var listCommits$1 = {
    id: "repos/list-commits",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-branches


* List branches
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [_protected] - Setting to `true` returns only protected branches. When set to `false`, only unprotected branches are returned. Omitting this parameter returns all branches.
*/
var listBranches = {
    id: "repos/list-branches",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-commit-comments-for-a-repository


* List commit comments for a repository
* Commit Comments use [these custom media types](https://docs.github.com/rest/reference/repos#custom-media-types). You can read more about the use of media types in the API [here](https://docs.github.com/rest/overview/media-types/).
 *
 * Comments are ordered by ascending ID.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listCommitCommentsForRepo = {
    id: "repos/list-commit-comments-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-releases


* List releases
* This returns a list of releases, which does not include regular Git tags that have not been associated with a release. To get a list of Git tags, use the [Repository Tags API](https://docs.github.com/rest/reference/repos#list-repository-tags).
 *
 * Information about published releases are available to everyone. Only users with push access will receive listings for draft releases.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listReleases = {
    id: "repos/list-releases",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-a-release


* Create a release
* Users with push access to the repository can create a release.
 *
 * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createRelease = {
    id: "repos/create-release",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#transfer-a-repository


* Transfer a repository
* A transfer request will need to be accepted by the new owner when transferring a personal repository to another user. The response will contain the original `owner`, and the transfer will continue asynchronously. For more details on the requirements to transfer personal and organization-owned repositories, see [about repository transfers](https://docs.github.com/articles/about-repository-transfers/).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var transfer = {
    id: "repos/transfer",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/v3/repos#list-autolinks


* List all autolinks of a repository
* This returns a list of autolinks configured for the given repository.
 *
 * Information about autolinks are only available to repository administrators.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [page=1] - Page number of the results to fetch.
*/
var listAutolinks = {
    id: "repos/list-autolinks",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/v3/repos#create-an-autolink


* Create an autolink reference for a repository
* Users with admin access to the repository can create an autolink.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createAutolink = {
    id: "repos/create-autolink",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-repository-languages


* List repository languages
* Lists languages for the specified repository. The value shown for each language is the number of bytes of code written in that language.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var listLanguages = {
    id: "repos/list-languages",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-a-repository-dispatch-event


* Create a repository dispatch event
* You can use this endpoint to trigger a webhook event called `repository_dispatch` when you want activity that happens outside of GitHub to trigger a GitHub Actions workflow or GitHub App webhook. You must configure your GitHub Actions workflow or GitHub App to run when the `repository_dispatch` event occurs. For an example `repository_dispatch` webhook payload, see "[RepositoryDispatchEvent](https://docs.github.com/webhooks/event-payloads/#repository_dispatch)."
 *
 * The `client_payload` parameter is available for any extra information that your workflow might need. This parameter is a JSON payload that will be passed on when the webhook event is dispatched. For example, the `client_payload` can include a message that a user would like to send using a GitHub Actions workflow. Or the `client_payload` can be used as a test to debug your workflow.
 *
 * This endpoint requires write access to the repository by providing either:
 *
 * - Personal access tokens with `repo` scope. For more information, see "[Creating a personal access token for the command line](https://docs.github.com/articles/creating-a-personal-access-token-for-the-command-line)" in the GitHub Help documentation.
 * - GitHub Apps with both `metadata:read` and `contents:read&write` permissions.
 *
 * This input example shows how you can use the `client_payload` as a test to debug your workflow.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createDispatchEvent = {
    id: "repos/create-dispatch-event",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-deployments


* List deployments
* Simple filtering of deployments is available via query parameters:
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [sha='none'] - The SHA recorded at creation time.
* @param [ref='none'] - The name of the ref. This can be a branch, tag, or SHA.
* @param [environment] - The name of the environment that was deployed to (e.g., `staging` or `production`).
* @param [task='none'] - The name of the task for the deployment (e.g., `deploy` or `deploy:migrations`).
*/
var listDeployments = {
    id: "repos/list-deployments",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-a-deployment


* Create a deployment
* Deployments offer a few configurable parameters with certain defaults.
 *
 * The `ref` parameter can be any named branch, tag, or SHA. At GitHub we often deploy branches and verify them
 * before we merge a pull request.
 *
 * The `environment` parameter allows deployments to be issued to different runtime environments. Teams often have
 * multiple environments for verifying their applications, such as `production`, `staging`, and `qa`. This parameter
 * makes it easier to track which environments have requested deployments. The default environment is `production`.
 *
 * The `auto_merge` parameter is used to ensure that the requested ref is not behind the repository's default branch. If
 * the ref _is_ behind the default branch for the repository, we will attempt to merge it for you. If the merge succeeds,
 * the API will return a successful merge commit. If merge conflicts prevent the merge from succeeding, the API will
 * return a failure response.
 *
 * By default, [commit statuses](https://docs.github.com/rest/commits/statuses) for every submitted context must be in a `success`
 * state. The `required_contexts` parameter allows you to specify a subset of contexts that must be `success`, or to
 * specify contexts that have not yet been submitted. You are not required to use commit statuses to deploy. If you do
 * not require any contexts or create any commit statuses, the deployment will always succeed.
 *
 * The `payload` parameter is available for any extra information that a deployment system might need. It is a JSON text
 * field that will be passed on when a deployment event is dispatched.
 *
 * The `task` parameter is used by the deployment system to allow different execution paths. In the web world this might
 * be `deploy:migrations` to run schema changes on the system. In the compiled world this could be a flag to compile an
 * application with debugging enabled.
 *
 * Users with `repo` or `repo_deployment` scopes can create a deployment for a given ref.
 *
 * #### Merged branch response
 * You will see this response when GitHub automatically merges the base branch into the topic branch instead of creating
 * a deployment. This auto-merge happens when:
 * *   Auto-merge option is enabled in the repository
 * *   Topic branch does not include the latest changes on the base branch, which is `master` in the response example
 * *   There are no merge conflicts
 *
 * If there are no new commits in the base branch, a new request to create a deployment should give a successful
 * response.
 *
 * #### Merge conflict response
 * This error happens when the `auto_merge` option is enabled and when the default branch (in this case `master`), can't
 * be merged into the branch that's being deployed (in this case `topic-branch`), due to merge conflicts.
 *
 * #### Failed commit status checks
 * This error happens when the `required_contexts` parameter indicates that one or more contexts need to have a `success`
 * status for the commit to be deployed, but one or more of the required contexts do not have a state of `success`.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createDeployment = {
    id: "repos/create-deployment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-repository-invitations


* List repository invitations
* When authenticating as a user with admin rights to a repository, this endpoint will list all currently open repository invitations.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listInvitations = {
    id: "repos/list-invitations",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-repository-contributors


* List repository contributors
* Lists contributors to the specified repository and sorts them by the number of commits per contributor in descending order. This endpoint may return information that is a few hours old because the GitHub REST API v3 caches contributor data to improve performance.
 *
 * GitHub identifies contributors by author email address. This endpoint groups contribution counts by GitHub user, which includes all associated email addresses. To improve performance, only the first 500 author email addresses in the repository link to GitHub users. The rest will appear as anonymous contributors without associated GitHub user information.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [anon] - Set to `1` or `true` to include anonymous contributors in results.
*/
var listContributors = {
    id: "repos/list-contributors",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-all-environments


* Get all environments
* Get all environments for a repository.
 *
 * Anyone with read access to the repository can use this endpoint. If the repository is private, you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var getAllEnvironments = {
    id: "repos/get-all-environments",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-github-pages-builds


* List GitHub Pages builds
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPagesBuilds = {
    id: "repos/list-pages-builds",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#request-a-github-pages-build


* Request a GitHub Pages build
* You can request that your site be built from the latest revision on the default branch. This has the same effect as pushing a commit to your default branch, but does not require an additional commit. Manually triggering page builds can be helpful when diagnosing build warnings and failures.
 *
 * Build requests are limited to one concurrent build per repository and one concurrent build per requester. If you request a build while another is still in progress, the second request will be queued until the first completes.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var requestPagesBuild = {
    id: "repos/request-pages-build",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-dns-health-check-for-github-pages


* Get a DNS health check for GitHub Pages
* Gets a health check of the DNS settings for the `CNAME` record configured for a repository's GitHub Pages.
 *
 * The first request to this endpoint returns a `202 Accepted` status and starts an asynchronous background task to get the results for the domain. After the background task completes, subsequent requests to this endpoint return a `200 OK` status with the health check results in the response.
 *
 * Users must have admin or owner permissions. GitHub Apps must have the `pages:write` and `administration:write` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getPagesHealthCheck = {
    id: "repos/get-pages-health-check",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-repository-directory-readme


* Get a repository README for a directory
* Gets the README from a repository directory.
 *
 * READMEs support [custom media types](https://docs.github.com/rest/reference/repos#custom-media-types) for retrieving the raw content or rendered HTML.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param dir - The alternate path to look for a README file
* @param [ref] - The name of the commit/branch/tag. Default: the repository’s default branch (usually `master`)
*/
var getReadmeInDirectory = {
    id: "repos/get-readme-in-directory",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-repository-collaborators


* List repository collaborators
* For organization-owned repositories, the list of collaborators includes outside collaborators, organization members that are direct collaborators, organization members with access through team memberships, organization members with access through default organization permissions, and organization owners.
 * Organization members with write, maintain, or admin privileges on the organization-owned repository can use this endpoint.
 *
 * Team members will include the members of child teams.
 *
 * You must authenticate using an access token with the `read:org` and `repo` scopes with push access to use this
 * endpoint. GitHub Apps must have the `members` organization permission and `metadata` repository permission to use this
 * endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [affiliation] - Filter collaborators returned by their affiliation. `outside` means all outside collaborators of an organization-owned repository. `direct` means all collaborators with permissions to an organization-owned repository, regardless of organization membership status. `all` means all collaborators the authenticated user can see.
*/
var listCollaborators = {
    id: "repos/list-collaborators",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-commit


* Get a commit
* Returns the contents of a single commit reference. You must have `read` access for the repository to use this endpoint.
 *
 * **Note:** If there are more than 300 files in the commit diff, the response will include pagination link headers for the remaining files, up to a limit of 3000 files. Each page contains the static commit information, and the only changes are to the file listing.
 *
 * You can pass the appropriate [media type](https://docs.github.com/rest/overview/media-types/#commits-commit-comparison-and-pull-requests) to  fetch `diff` and `patch` formats. Diffs with binary data will have no `patch` property.
 *
 * To return only the SHA-1 hash of the commit reference, you can provide the `sha` custom [media type](https://docs.github.com/rest/overview/media-types/#commits-commit-comparison-and-pull-requests) in the `Accept` header. You can use this endpoint to check if a remote reference's SHA-1 hash is the same as your local reference's SHA-1 hash by providing the local SHA-1 reference as the ETag.
 *
 * **Signature verification object**
 *
 * The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
 *
 * | Name | Type | Description |
 * | ---- | ---- | ----------- |
 * | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
 * | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in table below. |
 * | `signature` | `string` | The signature that was extracted from the commit. |
 * | `payload` | `string` | The value that was signed. |
 *
 * These are the possible values for `reason` in the `verification` object:
 *
 * | Value | Description |
 * | ----- | ----------- |
 * | `expired_key` | The key that made the signature is expired. |
 * | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
 * | `gpgverify_error` | There was an error communicating with the signature verification service. |
 * | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
 * | `unsigned` | The object does not include a signature. |
 * | `unknown_signature_type` | A non-PGP signature was found in the commit. |
 * | `no_user` | No user was associated with the `committer` email address in the commit. |
 * | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on her/his account. |
 * | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
 * | `unknown_key` | The key that made the signature has not been registered with any user's account. |
 * | `malformed_signature` | There was an error parsing the signature. |
 * | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
 * | `valid` | None of the above errors applied, so the signature is considered to be verified. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param ref - ref parameter
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var getCommit$1 = {
    id: "repos/get-commit",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-deploy-key


* Get a deploy key
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param keyId - The unique identifier of the key.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getDeployKey = {
    id: "repos/get-deploy-key",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-a-deploy-key


* Delete a deploy key
* Deploy keys are immutable. If you need to update a key, remove the key and create a new one instead.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param keyId - The unique identifier of the key.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var deleteDeployKey = {
    id: "repos/delete-deploy-key",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#download-a-repository-archive


* Download a repository archive (tar)
* Gets a redirect URL to download a tar archive for a repository. If you omit `:ref`, the repository’s default branch (usually
 * `master`) will be used. Please make sure your HTTP framework is configured to follow redirects or you will need to use
 * the `Location` header to make a second `GET` request.
 * **Note**: For private repositories, these links are temporary and expire after five minutes.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param ref
*/
var downloadTarballArchive = {
    id: "repos/download-tarball-archive",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-page-views


* Get page views
* Get the total number of views and breakdown per day or week for the last 14 days. Timestamps are aligned to UTC midnight of the beginning of the day or week. Week begins on Monday.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [per] - The time frame to display results for.
*/
var getViews = {
    id: "repos/get-views",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#download-a-repository-archive


* Download a repository archive (zip)
* Gets a redirect URL to download a zip archive for a repository. If you omit `:ref`, the repository’s default branch (usually
 * `master`) will be used. Please make sure your HTTP framework is configured to follow redirects or you will need to use
 * the `Location` header to make a second `GET` request.
 * **Note**: For private repositories, these links are temporary and expire after five minutes.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param ref
*/
var downloadZipballArchive = {
    id: "repos/download-zipball-archive",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#sync-a-fork-branch-with-the-upstream-repository


* Sync a fork branch with the upstream repository
* Sync a branch of a forked repository to keep it up-to-date with the upstream repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var mergeUpstream = {
    id: "repos/merge-upstream",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-a-commit-status


* Create a commit status
* Users with push access in a repository can create commit statuses for a given SHA.
 *
 * Note: there is a limit of 1000 statuses per `sha` and `context` within a repository. Attempts to create more than 1000 statuses will result in a validation error.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param sha
*/
var createCommitStatus = {
    id: "repos/create-commit-status",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-repository-clones


* Get repository clones
* Get the total number of clones and breakdown per day or week for the last 14 days. Timestamps are aligned to UTC midnight of the beginning of the day or week. Week begins on Monday.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [per] - The time frame to display results for.
*/
var getClones = {
    id: "repos/get-clones",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-repository-content


* Get repository content
* Gets the contents of a file or directory in a repository. Specify the file path or directory in `:path`. If you omit
 * `:path`, you will receive the contents of the repository's root directory. See the description below regarding what the API response includes for directories.
 *
 * Files and symlinks support [a custom media type](https://docs.github.com/rest/reference/repos#custom-media-types) for
 * retrieving the raw content or rendered HTML (when supported). All content types support [a custom media
 * type](https://docs.github.com/rest/reference/repos#custom-media-types) to ensure the content is returned in a consistent
 * object format.
 *
 * **Note**:
 * *   To get a repository's contents recursively, you can [recursively get the tree](https://docs.github.com/rest/reference/git#trees).
 * *   This API has an upper limit of 1,000 files for a directory. If you need to retrieve more files, use the [Git Trees
 * API](https://docs.github.com/rest/reference/git#get-a-tree).
 *
 * #### Size limits
 * If the requested file's size is:
 * * 1 MB or smaller: All features of this endpoint are supported.
 * * Between 1-100 MB: Only the `raw` or `object` [custom media types](https://docs.github.com/rest/repos/contents#custom-media-types-for-repository-contents) are supported. Both will work as normal, except that when using the `object` media type, the `content` field will be an empty string and the `encoding` field will be `"none"`. To get the contents of these larger files, use the `raw` media type.
 * * Greater than 100 MB: This endpoint is not supported.
 *
 * #### If the content is a directory
 * The response will be an array of objects, one object for each item in the directory.
 * When listing the contents of a directory, submodules have their "type" specified as "file". Logically, the value
 * _should_ be "submodule". This behavior exists in API v3 [for backwards compatibility purposes](https://git.io/v1YCW).
 * In the next major version of the API, the type will be returned as "submodule".
 *
 * #### If the content is a symlink
 * If the requested `:path` points to a symlink, and the symlink's target is a normal file in the repository, then the
 * API responds with the content of the file (in the format shown in the example. Otherwise, the API responds with an object
 * describing the symlink itself.
 *
 * #### If the content is a submodule
 * The `submodule_git_url` identifies the location of the submodule repository, and the `sha` identifies a specific
 * commit within the submodule repository. Git uses the given URL when cloning the submodule repository, and checks out
 * the submodule at that specific commit.
 *
 * If the submodule repository is not hosted on github.com, the Git URLs (`git_url` and `_links["git"]`) and the
 * github.com URLs (`html_url` and `_links["html"]`) will have null values.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param path - path parameter
* @param [ref] - The name of the commit/branch/tag. Default: the repository’s default branch (usually `master`)
*/
var getContent = {
    id: "repos/get-content",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-or-update-file-contents


* Create or update file contents
* Creates a new file or replaces an existing file in a repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param path - path parameter
*/
var createOrUpdateFileContents = {
    id: "repos/create-or-update-file-contents",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-a-file


* Delete a file
* Deletes a file in a repository.
 *
 * You can provide an additional `committer` parameter, which is an object containing information about the committer. Or, you can provide an `author` parameter, which is an object containing information about the author.
 *
 * The `author` section is optional and is filled in with the `committer` information if omitted. If the `committer` information is omitted, the authenticated user's information is used.
 *
 * You must provide values for both `name` and `email`, whether you choose to use `author` or `committer`. Otherwise, you'll receive a `422` status code.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param path - path parameter
*/
var deleteFile = {
    id: "repos/delete-file",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-repository-webhook


* Get a repository webhook
* Returns a webhook configured in a repository. To get only the webhook `config` properties, see "[Get a webhook configuration for a repository](/rest/reference/repos#get-a-webhook-configuration-for-a-repository)."
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getWebhook = {
    id: "repos/get-webhook",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-a-repository-webhook


* Delete a repository webhook
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var deleteWebhook = {
    id: "repos/delete-webhook",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#update-a-repository-webhook


* Update a repository webhook
* Updates a webhook configured in a repository. If you previously had a `secret` set, you must provide the same `secret` or set a new `secret` or the secret will be removed. If you are only updating individual webhook `config` properties, use "[Update a webhook configuration for a repository](/rest/reference/repos#update-a-webhook-configuration-for-a-repository)."
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var updateWebhook = {
    id: "repos/update-webhook",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-the-latest-release


* Get the latest release
* View the latest published full release for the repository.
 *
 * The latest release is the most recent non-prerelease, non-draft release, sorted by the `created_at` attribute. The `created_at` attribute is the date of the commit used for the release, and not the date when the release was drafted or published.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getLatestRelease = {
    id: "repos/get-latest-release",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-tag-protection-state-of-a-repository


* List tag protection states for a repository
* This returns the tag protection states of a repository.
 *
 * This information is only available to repository administrators.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var listTagProtection = {
    id: "repos/list-tag-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-tag-protection-state-for-a-repository


* Create a tag protection state for a repository
* This creates a tag protection state for a repository.
 * This endpoint is only available to repository administrators.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createTagProtection = {
    id: "repos/create-tag-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-a-github-pages-deployment


* Create a GitHub Pages deployment
* Create a GitHub Pages deployment for a repository.
 *
 * Users must have write permissions. GitHub Apps must have the `pages:write` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createPagesDeployment = {
    id: "repos/create-pages-deployment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-the-hourly-commit-count-for-each-day


* Get the hourly commit count for each day
* Each array contains the day number, hour number, and number of commits:
 *
 * *   `0-6`: Sunday - Saturday
 * *   `0-23`: Hour of day
 * *   Number of commits
 *
 * For example, `[2, 14, 25]` indicates that there were 25 total commits, during the 2:00pm hour on Tuesdays. All times are based on the time zone of individual commits.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getPunchCardStats = {
    id: "repos/get-punch-card-stats",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-branch


* Get a branch
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var getBranch = {
    id: "repos/get-branch",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-codeowners-errors


* List CODEOWNERS errors
* List any syntax errors that are detected in the CODEOWNERS
 * file.
 *
 * For more information about the correct CODEOWNERS syntax,
 * see "[About code owners](https://docs.github.com/repositories/managing-your-repositorys-settings-and-features/customizing-your-repository/about-code-owners)."
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [ref] - A branch, tag or commit name used to determine which version of the CODEOWNERS file to use. Default: the repository's default branch (e.g. `main`)
*/
var codeownersErrors = {
    id: "repos/codeowners-errors",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-community-profile-metrics


* Get community profile metrics
* This endpoint will return all community profile metrics, including an
 * overall health score, repository description, the presence of documentation, detected
 * code of conduct, detected license, and the presence of ISSUE\_TEMPLATE, PULL\_REQUEST\_TEMPLATE,
 * README, and CONTRIBUTING files.
 *
 * The `health_percentage` score is defined as a percentage of how many of
 * these four documents are present: README, CONTRIBUTING, LICENSE, and
 * CODE_OF_CONDUCT. For example, if all four documents are present, then
 * the `health_percentage` is `100`. If only one is present, then the
 * `health_percentage` is `25`.
 *
 * `content_reports_enabled` is only returned for organization-owned repositories.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getCommunityProfileMetrics = {
    id: "repos/get-community-profile-metrics",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#compare-two-commits


* Compare two commits
* The `basehead` param is comprised of two parts: `base` and `head`. Both must be branch names in `repo`. To compare branches across other repositories in the same network as `repo`, use the format `<USERNAME>:branch`.
 *
 * The response from the API is equivalent to running the `git log base..head` command; however, commits are returned in chronological order. Pass the appropriate [media type](https://docs.github.com/rest/overview/media-types/#commits-commit-comparison-and-pull-requests) to fetch diff and patch formats.
 *
 * The response also includes details on the files that were changed between the two commits. This includes the status of the change (for example, if a file was added, removed, modified, or renamed), and details of the change itself. For example, files with a `renamed` status have a `previous_filename` field showing the previous filename of the file, and files with a `modified` status have a `patch` field showing the changes made to the file.
 *
 * **Working with large comparisons**
 *
 * To process a response with a large number of commits, you can use (`per_page` or `page`) to paginate the results. When using paging, the list of changed files is only returned with page 1, but includes all changed files for the entire comparison. For more information on working with pagination, see "[Traversing with pagination](/rest/guides/traversing-with-pagination)."
 *
 * When calling this API without any paging parameters (`per_page` or `page`), the returned list is limited to 250 commits and the last commit in the list is the most recent of the entire comparison. When a paging parameter is specified, the first commit in the returned list of each page is the earliest.
 *
 * **Signature verification object**
 *
 * The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
 *
 * | Name | Type | Description |
 * | ---- | ---- | ----------- |
 * | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
 * | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in table below. |
 * | `signature` | `string` | The signature that was extracted from the commit. |
 * | `payload` | `string` | The value that was signed. |
 *
 * These are the possible values for `reason` in the `verification` object:
 *
 * | Value | Description |
 * | ----- | ----------- |
 * | `expired_key` | The key that made the signature is expired. |
 * | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
 * | `gpgverify_error` | There was an error communicating with the signature verification service. |
 * | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
 * | `unsigned` | The object does not include a signature. |
 * | `unknown_signature_type` | A non-PGP signature was found in the commit. |
 * | `no_user` | No user was associated with the `committer` email address in the commit. |
 * | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on her/his account. |
 * | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
 * | `unknown_key` | The key that made the signature has not been registered with any user's account. |
 * | `malformed_signature` | There was an error parsing the signature. |
 * | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
 * | `valid` | None of the above errors applied, so the signature is considered to be verified. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param basehead - The base branch and head branch to compare. This parameter expects the format `{base}...{head}`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var compareCommits = {
    id: "repos/compare-commits",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-all-contributor-commit-activity


* Get all contributor commit activity
*
 * Returns the `total` number of commits authored by the contributor. In addition, the response includes a Weekly Hash (`weeks` array) with the following information:
 *
 * *   `w` - Start of the week, given as a [Unix timestamp](http://en.wikipedia.org/wiki/Unix_time).
 * *   `a` - Number of additions
 * *   `d` - Number of deletions
 * *   `c` - Number of commits
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getContributorsStats = {
    id: "repos/get-contributors-stats",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-latest-pages-build


* Get latest Pages build
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getLatestPagesBuild = {
    id: "repos/get-latest-pages-build",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-release-by-tag-name


* Get a release by tag name
* Get a published release with the specified tag.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param tag - tag parameter
*/
var getReleaseByTag = {
    id: "repos/get-release-by-tag",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-the-weekly-commit-count


* Get the weekly commit count
* Returns the total commit counts for the `owner` and total commit counts in `all`. `all` is everyone combined, including the `owner` in the last 52 weeks. If you'd like to get the commit counts for non-owners, you can subtract `owner` from `all`.
 *
 * The array order is oldest week (index 0) to most recent week.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getParticipationStats = {
    id: "repos/get-participation-stats",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-the-combined-status-for-a-specific-reference


* Get the combined status for a specific reference
* Users with pull access in a repository can access a combined view of commit statuses for a given ref. The ref can be a SHA, a branch name, or a tag name.
 *
 *
 * Additionally, a combined `state` is returned. The `state` is one of:
 *
 * *   **failure** if any of the contexts report as `error` or `failure`
 * *   **pending** if there are no statuses or a context is `pending`
 * *   **success** if the latest status for all contexts is `success`
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param ref - ref parameter
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var getCombinedStatusForRef = {
    id: "repos/get-combined-status-for-ref",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-the-weekly-commit-activity


* Get the weekly commit activity
* Returns a weekly aggregate of the number of additions and deletions pushed to a repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getCodeFrequencyStats = {
    id: "repos/get-code-frequency-stats",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#check-if-vulnerability-alerts-are-enabled-for-a-repository


* Check if vulnerability alerts are enabled for a repository
* Shows whether dependency alerts are enabled or disabled for a repository. The authenticated user must have admin read access to the repository. For more information, see "[About security alerts for vulnerable dependencies](https://docs.github.com/en/articles/about-security-alerts-for-vulnerable-dependencies)".
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var checkVulnerabilityAlerts = {
    id: "repos/check-vulnerability-alerts",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#enable-vulnerability-alerts


* Enable vulnerability alerts
* Enables dependency alerts and the dependency graph for a repository. The authenticated user must have admin access to the repository. For more information, see "[About security alerts for vulnerable dependencies](https://docs.github.com/en/articles/about-security-alerts-for-vulnerable-dependencies)".
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var enableVulnerabilityAlerts = {
    id: "repos/enable-vulnerability-alerts",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#disable-vulnerability-alerts


* Disable vulnerability alerts
* Disables dependency alerts and the dependency graph for a repository. The authenticated user must have admin access to the repository. For more information, see "[About security alerts for vulnerable dependencies](https://docs.github.com/en/articles/about-security-alerts-for-vulnerable-dependencies)".
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var disableVulnerabilityAlerts = {
    id: "repos/disable-vulnerability-alerts",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-commit-comment


* Get a commit comment
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
*/
var getCommitComment = {
    id: "repos/get-commit-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-a-commit-comment


* Delete a commit comment
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
*/
var deleteCommitComment = {
    id: "repos/delete-commit-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#update-a-commit-comment


* Update a commit comment
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
*/
var updateCommitComment = {
    id: "repos/update-commit-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#ping-a-repository-webhook


* Ping a repository webhook
* This will trigger a [ping event](https://docs.github.com/webhooks/#ping-event) to be sent to the hook.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var pingWebhook = {
    id: "repos/ping-webhook",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#test-the-push-repository-webhook


* Test the push repository webhook
* This will trigger the hook with the latest push to the current repository if the hook is subscribed to `push` events. If the hook is not subscribed to `push` events, the server will respond with 204 but no test POST will be generated.
 *
 * **Note**: Previously `/repos/:owner/:repo/hooks/:hook_id/test`
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var testPushWebhook = {
    id: "repos/test-push-webhook",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-release


* Get a release
* **Note:** This returns an `upload_url` key corresponding to the endpoint for uploading release assets. This key is a [hypermedia resource](https://docs.github.com/rest/overview/resources-in-the-rest-api#hypermedia).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param releaseId - The unique identifier of the release.
*/
var getRelease = {
    id: "repos/get-release",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-a-release


* Delete a release
* Users with push access to the repository can delete a release.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param releaseId - The unique identifier of the release.
*/
var deleteRelease = {
    id: "repos/delete-release",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#update-a-release


* Update a release
* Users with push access to the repository can edit a release.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param releaseId - The unique identifier of the release.
*/
var updateRelease = {
    id: "repos/update-release",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-the-last-year-of-commit-activity


* Get the last year of commit activity
* Returns the last year of commit activity grouped by week. The `days` array is a group of commits per day, starting on `Sunday`.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getCommitActivityStats = {
    id: "repos/get-commit-activity-stats",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-top-referral-paths


* Get top referral paths
* Get the top 10 popular contents over the last 14 days.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getTopPaths = {
    id: "repos/get-top-paths",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-commit-statuses-for-a-reference


* List commit statuses for a reference
* Users with pull access in a repository can view commit statuses for a given ref. The ref can be a SHA, a branch name, or a tag name. Statuses are returned in reverse chronological order. The first status in the list will be the latest one.
 *
 * This resource is also available via a legacy route: `GET /repos/:owner/:repo/statuses/:ref`.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param ref - ref parameter
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listCommitStatusesForRef = {
    id: "repos/list-commit-statuses-for-ref",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-webhook-configuration-for-a-repository


* Get a webhook configuration for a repository
* Returns the webhook configuration for a repository. To get more information about the webhook, including the `active` state and `events`, use "[Get a repository webhook](/rest/reference/orgs#get-a-repository-webhook)."
 *
 * Access tokens must have the `read:repo_hook` or `repo` scope, and GitHub Apps must have the `repository_hooks:read` permission.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getWebhookConfigForRepo = {
    id: "repos/get-webhook-config-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#update-a-webhook-configuration-for-a-repository


* Update a webhook configuration for a repository
* Updates the webhook configuration for a repository. To update more information about the webhook, including the `active` state and `events`, use "[Update a repository webhook](/rest/reference/orgs#update-a-repository-webhook)."
 *
 * Access tokens must have the `write:repo_hook` or `repo` scope, and GitHub Apps must have the `repository_hooks:write` permission.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var updateWebhookConfigForRepo = {
    id: "repos/update-webhook-config-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#decline-a-repository-invitation


* Decline a repository invitation
* @param invitationId - The unique identifier of the invitation.
*/
var declineInvitationForAuthenticatedUser = {
    id: "repos/decline-invitation-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#accept-a-repository-invitation


* Accept a repository invitation
* @param invitationId - The unique identifier of the invitation.
*/
var acceptInvitationForAuthenticatedUser = {
    id: "repos/accept-invitation-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/v3/repos#get-autolink


* Get an autolink reference of a repository
* This returns a single autolink reference by ID that was configured for the given repository.
 *
 * Information about autolinks are only available to repository administrators.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param autolinkId - The unique identifier of the autolink.
*/
var getAutolink = {
    id: "repos/get-autolink",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/v3/repos#delete-autolink


* Delete an autolink reference from a repository
* This deletes a single autolink reference by ID that was configured for the given repository.
 *
 * Information about autolinks are only available to repository administrators.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param autolinkId - The unique identifier of the autolink.
*/
var deleteAutolink = {
    id: "repos/delete-autolink",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-github-pages-build


* Get GitHub Pages build
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param buildId
*/
var getPagesBuild = {
    id: "repos/get-pages-build",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#generate-release-notes


* Generate release notes content for a release
* Generate a name and body describing a [release](https://docs.github.com/rest/reference/repos#releases). The body content will be markdown formatted and contain information like the changes since last release and users who contributed. The generated release notes are not saved anywhere. They are intended to be generated and used when creating a new release.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var generateReleaseNotes = {
    id: "repos/generate-release-notes",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#enable-automated-security-fixes


* Enable automated security fixes
* Enables automated security fixes for a repository. The authenticated user must have admin access to the repository. For more information, see "[Configuring automated security fixes](https://docs.github.com/en/articles/configuring-automated-security-fixes)".
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var enableAutomatedSecurityFixes = {
    id: "repos/enable-automated-security-fixes",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#disable-automated-security-fixes


* Disable automated security fixes
* Disables automated security fixes for a repository. The authenticated user must have admin access to the repository. For more information, see "[Configuring automated security fixes](https://docs.github.com/en/articles/configuring-automated-security-fixes)".
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var disableAutomatedSecurityFixes = {
    id: "repos/disable-automated-security-fixes",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#rename-a-branch


* Rename a branch
* Renames a branch in a repository.
 *
 * **Note:** Although the API responds immediately, the branch rename process might take some extra time to complete in the background. You won't be able to push to the old branch name while the rename process is in progress. For more information, see "[Renaming a branch](https://docs.github.com/github/administering-a-repository/renaming-a-branch)".
 *
 * The permissions required to use this endpoint depends on whether you are renaming the default branch.
 *
 * To rename a non-default branch:
 *
 * * Users must have push access.
 * * GitHub Apps must have the `contents:write` repository permission.
 *
 * To rename the default branch:
 *
 * * Users must have admin or owner permissions.
 * * GitHub Apps must have the `administration:write` repository permission.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var renameBranch = {
    id: "repos/rename-branch",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#check-if-a-user-is-a-repository-collaborator


* Check if a user is a repository collaborator
* For organization-owned repositories, the list of collaborators includes outside collaborators, organization members that are direct collaborators, organization members with access through team memberships, organization members with access through default organization permissions, and organization owners.
 *
 * Team members will include the members of child teams.
 *
 * You must authenticate using an access token with the `read:org` and `repo` scopes with push access to use this
 * endpoint. GitHub Apps must have the `members` organization permission and `metadata` repository permission to use this
 * endpoint.
* @param username - The handle for the GitHub user account.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var checkCollaborator = {
    id: "repos/check-collaborator",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#add-a-repository-collaborator


* Add a repository collaborator
* This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
 *
 * Adding an outside collaborator may be restricted by enterprise administrators. For more information, see "[Enforcing repository management policies in your enterprise](https://docs.github.com/enterprise-cloud@latest/admin/policies/enforcing-policies-for-your-enterprise/enforcing-repository-management-policies-in-your-enterprise#enforcing-a-policy-for-inviting-outside-collaborators-to-repositories)."
 *
 * For more information on permission levels, see "[Repository permission levels for an organization](https://docs.github.com/github/setting-up-and-managing-organizations-and-teams/repository-permission-levels-for-an-organization#permission-levels-for-repositories-owned-by-an-organization)". There are restrictions on which permissions can be granted to organization members when an organization base role is in place. In this case, the permission being given must be equal to or higher than the org base permission. Otherwise, the request will fail with:
 *
 * ```
 * Cannot assign {member} permission of {role name}
 * ```
 *
 * Note that, if you choose not to pass any parameters, you'll need to set `Content-Length` to zero when calling out to this endpoint. For more information, see "[HTTP verbs](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-verbs)."
 *
 * The invitee will receive a notification that they have been invited to the repository, which they must accept or decline. They may do this via the notifications page, the email they receive, or by using the [repository invitations API endpoints](https://docs.github.com/rest/reference/repos#invitations).
 *
 * **Updating an existing collaborator's permission level**
 *
 * The endpoint can also be used to change the permissions of an existing collaborator without first removing and re-adding the collaborator. To change the permissions, use the same endpoint and pass a different `permission` parameter. The response will be a `204`, with no other indication that the permission level changed.
 *
 * **Rate limits**
 *
 * You are limited to sending 50 invitations to a repository per 24 hour period. Note there is no limit if you are inviting organization members to an organization repository.
* @param username - The handle for the GitHub user account.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var addCollaborator = {
    id: "repos/add-collaborator",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#remove-a-repository-collaborator


* Remove a repository collaborator
* @param username - The handle for the GitHub user account.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var removeCollaborator = {
    id: "repos/remove-collaborator",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-top-referral-sources


* Get top referral sources
* Get the top 10 referrers over the last 14 days.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getTopReferrers = {
    id: "repos/get-top-referrers",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-pull-requests-associated-with-a-commit


* List pull requests associated with a commit
* Lists the merged pull request that introduced the commit to the repository. If the commit is not present in the default branch, additionally returns open pull requests associated with the commit. The results may include open and closed pull requests.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commitSha - The SHA of the commit.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPullRequestsAssociatedWithCommit = {
    id: "repos/list-pull-requests-associated-with-commit",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-deliveries-for-a-repository-webhook


* List deliveries for a repository webhook
* Returns a list of webhook deliveries for a webhook configured in a repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [cursor] - Used for pagination: the starting delivery from which the page of deliveries is fetched. Refer to the `link` header for the next and previous page cursors.
*/
var listWebhookDeliveries$1 = {
    id: "repos/list-webhook-deliveries",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-release-asset


* Get a release asset
* To download the asset's binary content, set the `Accept` header of the request to [`application/octet-stream`](https://docs.github.com/rest/overview/media-types). The API will either redirect the client to the location, or stream it directly if possible. API clients should handle both a `200` or `302` response.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param assetId - The unique identifier of the asset.
*/
var getReleaseAsset = {
    id: "repos/get-release-asset",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-a-release-asset


* Delete a release asset
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param assetId - The unique identifier of the asset.
*/
var deleteReleaseAsset = {
    id: "repos/delete-release-asset",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#update-a-release-asset


* Update a release asset
* Users with push access to the repository can edit a release asset.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param assetId - The unique identifier of the asset.
*/
var updateReleaseAsset = {
    id: "repos/update-release-asset",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-a-repository-using-a-template


* Create a repository using a template
* Creates a new repository using a repository template. Use the `template_owner` and `template_repo` route parameters to specify the repository to use as the template. The authenticated user must own or be a member of an organization that owns the repository. To check if a repository is available to use as a template, get the repository's information using the [Get a repository](https://docs.github.com/rest/reference/repos#get-a-repository) endpoint and check that the `is_template` key is `true`.
 *
 * **OAuth scope requirements**
 *
 * When using [OAuth](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/), authorizations must include:
 *
 * *   `public_repo` scope or `repo` scope to create a public repository. Note: For GitHub AE, use `repo` scope to create an internal repository.
 * *   `repo` scope to create a private repository
* @param templateOwner
* @param templateRepo
*/
var createUsingTemplate = {
    id: "repos/create-using-template",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-deployment


* Get a deployment
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param deploymentId - deployment_id parameter
*/
var getDeployment = {
    id: "repos/get-deployment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-a-deployment


* Delete a deployment
* If the repository only has one deployment, you can delete the deployment regardless of its status. If the repository has more than one deployment, you can only delete inactive deployments. This ensures that repositories with multiple deployments will always have an active deployment. Anyone with `repo` or `repo_deployment` scopes can delete a deployment.
 *
 * To set a deployment as inactive, you must:
 *
 * *   Create a new deployment that is active so that the system has a record of the current state, then delete the previously active deployment.
 * *   Mark the active deployment as inactive by adding any non-successful deployment status.
 *
 * For more information, see "[Create a deployment](https://docs.github.com/rest/reference/repos/#create-a-deployment)" and "[Create a deployment status](https://docs.github.com/rest/reference/repos#create-a-deployment-status)."
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param deploymentId - deployment_id parameter
*/
var deleteDeployment = {
    id: "repos/delete-deployment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-a-repository-invitation


* Delete a repository invitation
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param invitationId - The unique identifier of the invitation.
*/
var deleteInvitation = {
    id: "repos/delete-invitation",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#update-a-repository-invitation


* Update a repository invitation
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param invitationId - The unique identifier of the invitation.
*/
var updateInvitation = {
    id: "repos/update-invitation",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-branch-protection


* Get branch protection
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var getBranchProtection = {
    id: "repos/get-branch-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#update-branch-protection


* Update branch protection
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Protecting a branch requires admin or owner permissions to the repository.
 *
 * **Note**: Passing new arrays of `users` and `teams` replaces their previous values.
 *
 * **Note**: The list of users, apps, and teams in total is limited to 100 items.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var updateBranchProtection = {
    id: "repos/update-branch-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-branch-protection


* Delete branch protection
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var deleteBranchProtection = {
    id: "repos/delete-branch-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-release-assets


* List release assets
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param releaseId - The unique identifier of the release.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listReleaseAssets = {
    id: "repos/list-release-assets",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#upload-a-release-asset


* Upload a release asset
* This endpoint makes use of [a Hypermedia relation](https://docs.github.com/rest/overview/resources-in-the-rest-api#hypermedia) to determine which URL to access. The endpoint you call to upload release assets is specific to your release. Use the `upload_url` returned in
 * the response of the [Create a release endpoint](https://docs.github.com/rest/reference/repos#create-a-release) to upload a release asset.
 *
 * You need to use an HTTP client which supports [SNI](http://en.wikipedia.org/wiki/Server_Name_Indication) to make calls to this endpoint.
 *
 * Most libraries will set the required `Content-Length` header automatically. Use the required `Content-Type` header to provide the media type of the asset. For a list of media types, see [Media Types](https://www.iana.org/assignments/media-types/media-types.xhtml). For example:
 *
 * `application/zip`
 *
 * GitHub expects the asset data in its raw binary form, rather than JSON. You will send the raw binary content of the asset as the request body. Everything else about the endpoint is the same as the rest of the API. For example,
 * you'll still need to pass your authentication to be able to upload an asset.
 *
 * When an upstream failure occurs, you will receive a `502 Bad Gateway` status. This may leave an empty asset with a state of `starter`. It can be safely deleted.
 *
 * **Notes:**
 * *   GitHub renames asset filenames that have special characters, non-alphanumeric characters, and leading or trailing periods. The "[List assets for a release](https://docs.github.com/rest/reference/repos#list-assets-for-a-release)"
 * endpoint lists the renamed filenames. For more information and help, contact [GitHub Support](https://support.github.com/contact?tags=dotcom-rest-api).
 * *   If you upload an asset with the same filename as another uploaded asset, you'll receive an error and must delete the old file before you can re-upload the new asset.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param releaseId - The unique identifier of the release.
* @param name
* @param [label]
*/
var uploadReleaseAsset = {
    id: "repos/upload-release-asset",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-commit-comments


* List commit comments
* Use the `:commit_sha` to specify the commit that will have its comments listed.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commitSha - The SHA of the commit.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listCommentsForCommit = {
    id: "repos/list-comments-for-commit",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-a-commit-comment


* Create a commit comment
* Create a comment for a commit using its `:commit_sha`.
 *
 * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commitSha - The SHA of the commit.
*/
var createCommitComment = {
    id: "repos/create-commit-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-an-environment


* Get an environment
* Anyone with read access to the repository can use this endpoint. If the repository is private, you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param environmentName - The name of the environment
*/
var getEnvironment = {
    id: "repos/get-environment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-or-update-an-environment


* Create or update an environment
* Create or update an environment with protection rules, such as required reviewers. For more information about environment protection rules, see "[Environments](/actions/reference/environments#environment-protection-rules)."
 *
 * **Note:** Although you can use this operation to specify that only branches that match specified name patterns can deploy to this environment, you must use the UI to set the name patterns. For more information, see "[Environments](/actions/reference/environments#deployment-branches)."
 *
 * **Note:** To create or update secrets for an environment, see "[Secrets](/rest/reference/actions#secrets)."
 *
 * You must authenticate using an access token with the repo scope to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param environmentName - The name of the environment
*/
var createOrUpdateEnvironment = {
    id: "repos/create-or-update-environment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-an-environment


* Delete an environment
* You must authenticate using an access token with the repo scope to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param environmentName - The name of the environment
*/
var deleteAnEnvironment = {
    id: "repos/delete-an-environment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-repository-permissions-for-a-user


* Get repository permissions for a user
* Checks the repository permission of a collaborator. The possible repository permissions are `admin`, `write`, `read`, and `none`.
* @param username - The handle for the GitHub user account.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getCollaboratorPermissionLevel = {
    id: "repos/get-collaborator-permission-level",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-tag-protection-state-for-a-repository


* Delete a tag protection state for a repository
* This deletes a tag protection state for a repository.
 * This endpoint is only available to repository administrators.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param tagProtectionId - The unique identifier of the tag protection.
*/
var deleteTagProtection = {
    id: "repos/delete-tag-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-deployment-statuses


* List deployment statuses
* Users with pull access can view deployment statuses for a deployment:
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param deploymentId - deployment_id parameter
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listDeploymentStatuses = {
    id: "repos/list-deployment-statuses",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-a-deployment-status


* Create a deployment status
* Users with `push` access can create deployment statuses for a given deployment.
 *
 * GitHub Apps require `read & write` access to "Deployments" and `read-only` access to "Repo contents" (for private repos). OAuth Apps require the `repo_deployment` scope.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param deploymentId - deployment_id parameter
*/
var createDeploymentStatus = {
    id: "repos/create-deployment-status",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-branches-for-head-commit


* List branches for HEAD commit
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Returns all branches where the given commit SHA is the HEAD, or latest commit for the branch.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commitSha - The SHA of the commit.
*/
var listBranchesForHeadCommit = {
    id: "repos/list-branches-for-head-commit",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-delivery-for-a-repository-webhook


* Get a delivery for a repository webhook
* Returns a delivery for a webhook configured in a repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
* @param repo - The name of the repository. The name is not case sensitive.
* @param deliveryId
*/
var getWebhookDelivery$1 = {
    id: "repos/get-webhook-delivery",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-access-restrictions


* Get access restrictions
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Lists who has access to this protected branch.
 *
 * **Note**: Users, apps, and teams `restrictions` are only available for organization-owned repositories.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var getAccessRestrictions = {
    id: "repos/get-access-restrictions",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-access-restrictions


* Delete access restrictions
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Disables the ability to restrict who can push to this branch.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var deleteAccessRestrictions = {
    id: "repos/delete-access-restrictions",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-admin-branch-protection


* Get admin branch protection
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var getAdminBranchProtection = {
    id: "repos/get-admin-branch-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#set-admin-branch-protection


* Set admin branch protection
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Adding admin enforcement requires admin or owner permissions to the repository and branch protection to be enabled.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var setAdminBranchProtection = {
    id: "repos/set-admin-branch-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-admin-branch-protection


* Delete admin branch protection
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Removing admin enforcement requires admin or owner permissions to the repository and branch protection to be enabled.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var deleteAdminBranchProtection = {
    id: "repos/delete-admin-branch-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-apps-with-access-to-the-protected-branch


* Get apps with access to the protected branch
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Lists the GitHub Apps that have push access to this branch. Only installed GitHub Apps with `write` access to the `contents` permission can be added as authorized actors on a protected branch.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var getAppsWithAccessToProtectedBranch = {
    id: "repos/get-apps-with-access-to-protected-branch",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#add-app-access-restrictions


* Add app access restrictions
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Grants the specified apps push access for this branch. Only installed GitHub Apps with `write` access to the `contents` permission can be added as authorized actors on a protected branch.
 *
 * | Type    | Description                                                                                                                                                |
 * | ------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------- |
 * | `array` | The GitHub Apps that have push access to this branch. Use the app's `slug`. **Note**: The list of users, apps, and teams in total is limited to 100 items. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var addAppAccessRestrictions = {
    id: "repos/add-app-access-restrictions",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#set-app-access-restrictions


* Set app access restrictions
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Replaces the list of apps that have push access to this branch. This removes all apps that previously had push access and grants push access to the new list of apps. Only installed GitHub Apps with `write` access to the `contents` permission can be added as authorized actors on a protected branch.
 *
 * | Type    | Description                                                                                                                                                |
 * | ------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------- |
 * | `array` | The GitHub Apps that have push access to this branch. Use the app's `slug`. **Note**: The list of users, apps, and teams in total is limited to 100 items. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var setAppAccessRestrictions = {
    id: "repos/set-app-access-restrictions",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#remove-app-access-restrictions


* Remove app access restrictions
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Removes the ability of an app to push to this branch. Only installed GitHub Apps with `write` access to the `contents` permission can be added as authorized actors on a protected branch.
 *
 * | Type    | Description                                                                                                                                                |
 * | ------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------- |
 * | `array` | The GitHub Apps that have push access to this branch. Use the app's `slug`. **Note**: The list of users, apps, and teams in total is limited to 100 items. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var removeAppAccessRestrictions = {
    id: "repos/remove-app-access-restrictions",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-teams-with-access-to-the-protected-branch


* Get teams with access to the protected branch
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Lists the teams who have push access to this branch. The list includes child teams.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var getTeamsWithAccessToProtectedBranch = {
    id: "repos/get-teams-with-access-to-protected-branch",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#add-team-access-restrictions


* Add team access restrictions
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Grants the specified teams push access for this branch. You can also give push access to child teams.
 *
 * | Type    | Description                                                                                                                                |
 * | ------- | ------------------------------------------------------------------------------------------------------------------------------------------ |
 * | `array` | The teams that can have push access. Use the team's `slug`. **Note**: The list of users, apps, and teams in total is limited to 100 items. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var addTeamAccessRestrictions = {
    id: "repos/add-team-access-restrictions",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#set-team-access-restrictions


* Set team access restrictions
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Replaces the list of teams that have push access to this branch. This removes all teams that previously had push access and grants push access to the new list of teams. Team restrictions include child teams.
 *
 * | Type    | Description                                                                                                                                |
 * | ------- | ------------------------------------------------------------------------------------------------------------------------------------------ |
 * | `array` | The teams that can have push access. Use the team's `slug`. **Note**: The list of users, apps, and teams in total is limited to 100 items. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var setTeamAccessRestrictions = {
    id: "repos/set-team-access-restrictions",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#remove-team-access-restrictions


* Remove team access restrictions
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Removes the ability of a team to push to this branch. You can also remove push access for child teams.
 *
 * | Type    | Description                                                                                                                                         |
 * | ------- | --------------------------------------------------------------------------------------------------------------------------------------------------- |
 * | `array` | Teams that should no longer have push access. Use the team's `slug`. **Note**: The list of users, apps, and teams in total is limited to 100 items. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var removeTeamAccessRestrictions = {
    id: "repos/remove-team-access-restrictions",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#list-users-with-access-to-the-protected-branch


* Get users with access to the protected branch
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Lists the people who have push access to this branch.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var getUsersWithAccessToProtectedBranch = {
    id: "repos/get-users-with-access-to-protected-branch",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#add-user-access-restrictions


* Add user access restrictions
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Grants the specified people push access for this branch.
 *
 * | Type    | Description                                                                                                                   |
 * | ------- | ----------------------------------------------------------------------------------------------------------------------------- |
 * | `array` | Usernames for people who can have push access. **Note**: The list of users, apps, and teams in total is limited to 100 items. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var addUserAccessRestrictions = {
    id: "repos/add-user-access-restrictions",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#set-user-access-restrictions


* Set user access restrictions
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Replaces the list of people that have push access to this branch. This removes all people that previously had push access and grants push access to the new list of people.
 *
 * | Type    | Description                                                                                                                   |
 * | ------- | ----------------------------------------------------------------------------------------------------------------------------- |
 * | `array` | Usernames for people who can have push access. **Note**: The list of users, apps, and teams in total is limited to 100 items. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var setUserAccessRestrictions = {
    id: "repos/set-user-access-restrictions",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#remove-user-access-restrictions


* Remove user access restrictions
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Removes the ability of a user to push to this branch.
 *
 * | Type    | Description                                                                                                                                   |
 * | ------- | --------------------------------------------------------------------------------------------------------------------------------------------- |
 * | `array` | Usernames of the people who should no longer have push access. **Note**: The list of users, apps, and teams in total is limited to 100 items. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var removeUserAccessRestrictions = {
    id: "repos/remove-user-access-restrictions",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-commit-signature-protection


* Get commit signature protection
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * When authenticated with admin or owner permissions to the repository, you can use this endpoint to check whether a branch requires signed commits. An enabled status of `true` indicates you must sign commits on this branch. For more information, see [Signing commits with GPG](https://docs.github.com/articles/signing-commits-with-gpg) in GitHub Help.
 *
 * **Note**: You must enable branch protection to require signed commits.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var getCommitSignatureProtection = {
    id: "repos/get-commit-signature-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#create-commit-signature-protection


* Create commit signature protection
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * When authenticated with admin or owner permissions to the repository, you can use this endpoint to require signed commits on a branch. You must enable branch protection to require signed commits.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var createCommitSignatureProtection = {
    id: "repos/create-commit-signature-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-commit-signature-protection


* Delete commit signature protection
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * When authenticated with admin or owner permissions to the repository, you can use this endpoint to disable required signed commits on a branch. You must enable branch protection to require signed commits.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var deleteCommitSignatureProtection = {
    id: "repos/delete-commit-signature-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-a-deployment-status


* Get a deployment status
* Users with pull access can view a deployment status for a deployment:
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param deploymentId - deployment_id parameter
* @param statusId
*/
var getDeploymentStatus = {
    id: "repos/get-deployment-status",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#redeliver-a-delivery-for-a-repository-webhook


* Redeliver a delivery for a repository webhook
* Redeliver a webhook delivery for a webhook configured in a repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param hookId - The unique identifier of the hook.
* @param repo - The name of the repository. The name is not case sensitive.
* @param deliveryId
*/
var redeliverWebhookDelivery$1 = {
    id: "repos/redeliver-webhook-delivery",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-status-checks-protection


* Get status checks protection
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var getStatusChecksProtection = {
    id: "repos/get-status-checks-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#remove-status-check-protection


* Remove status check protection
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var removeStatusCheckProtection = {
    id: "repos/remove-status-check-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#update-status-check-protection


* Update status check protection
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Updating required status checks requires admin or owner permissions to the repository and branch protection to be enabled.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var updateStatusCheckProtection = {
    id: "repos/update-status-check-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-pull-request-review-protection


* Get pull request review protection
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var getPullRequestReviewProtection = {
    id: "repos/get-pull-request-review-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#delete-pull-request-review-protection


* Delete pull request review protection
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var deletePullRequestReviewProtection = {
    id: "repos/delete-pull-request-review-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#update-pull-request-review-protection


* Update pull request review protection
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Updating pull request review enforcement requires admin or owner permissions to the repository and branch protection to be enabled.
 *
 * **Note**: Passing new arrays of `users` and `teams` replaces their previous values.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var updatePullRequestReviewProtection = {
    id: "repos/update-pull-request-review-protection",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#get-all-status-check-contexts


* Get all status check contexts
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var getAllStatusCheckContexts = {
    id: "repos/get-all-status-check-contexts",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#add-status-check-contexts


* Add status check contexts
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var addStatusCheckContexts = {
    id: "repos/add-status-check-contexts",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#set-status-check-contexts


* Set status check contexts
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var setStatusCheckContexts = {
    id: "repos/set-status-check-contexts",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/repos#remove-status-check-contexts


* Remove status check contexts
* Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param branch - The name of the branch.
*/
var removeStatusCheckContexts = {
    id: "repos/remove-status-check-contexts",
    clientId: "github",
    version: "1.1.5",
};

var repos$1 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  listForAuthenticatedUser: listForAuthenticatedUser$3,
  createForAuthenticatedUser: createForAuthenticatedUser$1,
  listPublic: listPublic$1,
  listForOrg: listForOrg$1,
  createInOrg: createInOrg,
  getRepo: getRepo,
  deleteRepo: deleteRepo,
  update: update$3,
  listForUser: listForUser$1,
  enableLfsForRepo: enableLfsForRepo,
  disableLfsForRepo: disableLfsForRepo,
  listDeployKeys: listDeployKeys,
  createDeployKey: createDeployKey,
  listTags: listTags,
  listForks: listForks$1,
  createFork: createFork,
  listWebhooks: listWebhooks,
  createWebhook: createWebhook,
  getPages: getPages,
  createPagesSite: createPagesSite,
  updateInformationAboutPagesSite: updateInformationAboutPagesSite,
  deletePagesSite: deletePagesSite,
  listTeams: listTeams,
  merge: merge,
  getReadme: getReadme,
  getAllTopics: getAllTopics,
  replaceAllTopics: replaceAllTopics,
  listInvitationsForAuthenticatedUser: listInvitationsForAuthenticatedUser,
  listCommits: listCommits$1,
  listBranches: listBranches,
  listCommitCommentsForRepo: listCommitCommentsForRepo,
  listReleases: listReleases,
  createRelease: createRelease,
  transfer: transfer,
  listAutolinks: listAutolinks,
  createAutolink: createAutolink,
  listLanguages: listLanguages,
  createDispatchEvent: createDispatchEvent,
  listDeployments: listDeployments,
  createDeployment: createDeployment,
  listInvitations: listInvitations,
  listContributors: listContributors,
  getAllEnvironments: getAllEnvironments,
  listPagesBuilds: listPagesBuilds,
  requestPagesBuild: requestPagesBuild,
  getPagesHealthCheck: getPagesHealthCheck,
  getReadmeInDirectory: getReadmeInDirectory,
  listCollaborators: listCollaborators,
  getCommit: getCommit$1,
  getDeployKey: getDeployKey,
  deleteDeployKey: deleteDeployKey,
  downloadTarballArchive: downloadTarballArchive,
  getViews: getViews,
  downloadZipballArchive: downloadZipballArchive,
  mergeUpstream: mergeUpstream,
  createCommitStatus: createCommitStatus,
  getClones: getClones,
  getContent: getContent,
  createOrUpdateFileContents: createOrUpdateFileContents,
  deleteFile: deleteFile,
  getWebhook: getWebhook,
  deleteWebhook: deleteWebhook,
  updateWebhook: updateWebhook,
  getLatestRelease: getLatestRelease,
  listTagProtection: listTagProtection,
  createTagProtection: createTagProtection,
  createPagesDeployment: createPagesDeployment,
  getPunchCardStats: getPunchCardStats,
  getBranch: getBranch,
  codeownersErrors: codeownersErrors,
  getCommunityProfileMetrics: getCommunityProfileMetrics,
  compareCommits: compareCommits,
  getContributorsStats: getContributorsStats,
  getLatestPagesBuild: getLatestPagesBuild,
  getReleaseByTag: getReleaseByTag,
  getParticipationStats: getParticipationStats,
  getCombinedStatusForRef: getCombinedStatusForRef,
  getCodeFrequencyStats: getCodeFrequencyStats,
  checkVulnerabilityAlerts: checkVulnerabilityAlerts,
  enableVulnerabilityAlerts: enableVulnerabilityAlerts,
  disableVulnerabilityAlerts: disableVulnerabilityAlerts,
  getCommitComment: getCommitComment,
  deleteCommitComment: deleteCommitComment,
  updateCommitComment: updateCommitComment,
  pingWebhook: pingWebhook,
  testPushWebhook: testPushWebhook,
  getRelease: getRelease,
  deleteRelease: deleteRelease,
  updateRelease: updateRelease,
  getCommitActivityStats: getCommitActivityStats,
  getTopPaths: getTopPaths,
  listCommitStatusesForRef: listCommitStatusesForRef,
  getWebhookConfigForRepo: getWebhookConfigForRepo,
  updateWebhookConfigForRepo: updateWebhookConfigForRepo,
  declineInvitationForAuthenticatedUser: declineInvitationForAuthenticatedUser,
  acceptInvitationForAuthenticatedUser: acceptInvitationForAuthenticatedUser,
  getAutolink: getAutolink,
  deleteAutolink: deleteAutolink,
  getPagesBuild: getPagesBuild,
  generateReleaseNotes: generateReleaseNotes,
  enableAutomatedSecurityFixes: enableAutomatedSecurityFixes,
  disableAutomatedSecurityFixes: disableAutomatedSecurityFixes,
  renameBranch: renameBranch,
  checkCollaborator: checkCollaborator,
  addCollaborator: addCollaborator,
  removeCollaborator: removeCollaborator,
  getTopReferrers: getTopReferrers,
  listPullRequestsAssociatedWithCommit: listPullRequestsAssociatedWithCommit,
  listWebhookDeliveries: listWebhookDeliveries$1,
  getReleaseAsset: getReleaseAsset,
  deleteReleaseAsset: deleteReleaseAsset,
  updateReleaseAsset: updateReleaseAsset,
  createUsingTemplate: createUsingTemplate,
  getDeployment: getDeployment,
  deleteDeployment: deleteDeployment,
  deleteInvitation: deleteInvitation,
  updateInvitation: updateInvitation,
  getBranchProtection: getBranchProtection,
  updateBranchProtection: updateBranchProtection,
  deleteBranchProtection: deleteBranchProtection,
  listReleaseAssets: listReleaseAssets,
  uploadReleaseAsset: uploadReleaseAsset,
  listCommentsForCommit: listCommentsForCommit,
  createCommitComment: createCommitComment,
  getEnvironment: getEnvironment,
  createOrUpdateEnvironment: createOrUpdateEnvironment,
  deleteAnEnvironment: deleteAnEnvironment,
  getCollaboratorPermissionLevel: getCollaboratorPermissionLevel,
  deleteTagProtection: deleteTagProtection,
  listDeploymentStatuses: listDeploymentStatuses,
  createDeploymentStatus: createDeploymentStatus,
  listBranchesForHeadCommit: listBranchesForHeadCommit,
  getWebhookDelivery: getWebhookDelivery$1,
  getAccessRestrictions: getAccessRestrictions,
  deleteAccessRestrictions: deleteAccessRestrictions,
  getAdminBranchProtection: getAdminBranchProtection,
  setAdminBranchProtection: setAdminBranchProtection,
  deleteAdminBranchProtection: deleteAdminBranchProtection,
  getAppsWithAccessToProtectedBranch: getAppsWithAccessToProtectedBranch,
  addAppAccessRestrictions: addAppAccessRestrictions,
  setAppAccessRestrictions: setAppAccessRestrictions,
  removeAppAccessRestrictions: removeAppAccessRestrictions,
  getTeamsWithAccessToProtectedBranch: getTeamsWithAccessToProtectedBranch,
  addTeamAccessRestrictions: addTeamAccessRestrictions,
  setTeamAccessRestrictions: setTeamAccessRestrictions,
  removeTeamAccessRestrictions: removeTeamAccessRestrictions,
  getUsersWithAccessToProtectedBranch: getUsersWithAccessToProtectedBranch,
  addUserAccessRestrictions: addUserAccessRestrictions,
  setUserAccessRestrictions: setUserAccessRestrictions,
  removeUserAccessRestrictions: removeUserAccessRestrictions,
  getCommitSignatureProtection: getCommitSignatureProtection,
  createCommitSignatureProtection: createCommitSignatureProtection,
  deleteCommitSignatureProtection: deleteCommitSignatureProtection,
  getDeploymentStatus: getDeploymentStatus,
  redeliverWebhookDelivery: redeliverWebhookDelivery$1,
  getStatusChecksProtection: getStatusChecksProtection,
  removeStatusCheckProtection: removeStatusCheckProtection,
  updateStatusCheckProtection: updateStatusCheckProtection,
  getPullRequestReviewProtection: getPullRequestReviewProtection,
  deletePullRequestReviewProtection: deletePullRequestReviewProtection,
  updatePullRequestReviewProtection: updatePullRequestReviewProtection,
  getAllStatusCheckContexts: getAllStatusCheckContexts,
  addStatusCheckContexts: addStatusCheckContexts,
  setStatusCheckContexts: setStatusCheckContexts,
  removeStatusCheckContexts: removeStatusCheckContexts
});

/**
* @see https://docs.github.com/rest/reference/scim#list-scim-provisioned-identities


* List SCIM provisioned identities
* Retrieves a paginated list of all provisioned organization members, including pending invitations. If you provide the `filter` parameter, the resources for all matching provisions members are returned.
 *
 * When a user with a SAML-provisioned external identity leaves (or is removed from) an organization, the account's metadata is immediately removed. However, the returned list of user accounts might not always match the organization or enterprise member list you see on GitHub. This can happen in certain cases where an external identity associated with an organization will not match an organization member:
 * - When a user with a SCIM-provisioned external identity is removed from an organization, the account's metadata is preserved to allow the user to re-join the organization in the future.
 * - When inviting a user to join an organization, you can expect to see their external identity in the results before they accept the invitation, or if the invitation is cancelled (or never accepted).
 * - When a user is invited over SCIM, an external identity is created that matches with the invitee's email address. However, this identity is only linked to a user account when the user accepts the invitation by going through SAML SSO.
 *
 * The returned list of external identities can include an entry for a `null` user. These are unlinked SAML identities that are created when a user goes through the following Single Sign-On (SSO) process but does not sign in to their GitHub account after completing SSO:
 *
 * 1. The user is granted access by the IdP and is not a member of the GitHub organization.
 *
 * 1. The user attempts to access the GitHub organization and initiates the SAML SSO process, and is not currently signed in to their GitHub account.
 *
 * 1. After successfully authenticating with the SAML SSO IdP, the `null` external identity entry is created and the user is prompted to sign in to their GitHub account:
 * - If the user signs in, their GitHub account is linked to this entry.
 * - If the user does not sign in (or does not create a new account when prompted), they are not added to the GitHub organization, and the external identity `null` entry remains in place.
* @param org - The organization name. The name is not case sensitive.
* @param [filter] - Filters results using the equals query parameter operator (`eq`). You can filter results that are equal to `id`, `userName`, `emails`, and `external_id`. For example, to search for an identity with the `userName` Octocat, you would use this query:

`?filter=userName%20eq%20\"Octocat\"`.

To filter results for the identity with the email `octocat@github.com`, you would use this query:

`?filter=emails%20eq%20\"octocat@github.com\"`.
* @param [startIndex] - Used for pagination: the index of the first result to return.
* @param [count] - Used for pagination: the number of results to return.
*/
var listProvisionedIdentities = {
    id: "scim/list-provisioned-identities",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/scim#provision-and-invite-a-scim-user


* Provision and invite a SCIM user
* Provision organization membership for a user, and send an activation email to the email address.
* @param org - The organization name. The name is not case sensitive.
*/
var provisionAndInviteUser = {
    id: "scim/provision-and-invite-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/scim#get-scim-provisioning-information-for-a-user


* Get SCIM provisioning information for a user
* @param org - The organization name. The name is not case sensitive.
* @param scimUserId - The unique identifier of the SCIM user.
*/
var getProvisioningInformationForUser = {
    id: "scim/get-provisioning-information-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/scim#set-scim-information-for-a-provisioned-user


* Update a provisioned organization membership
* Replaces an existing provisioned user's information. You must provide all the information required for the user as if you were provisioning them for the first time. Any existing user information that you don't provide will be removed. If you want to only update a specific attribute, use the [Update an attribute for a SCIM user](https://docs.github.com/rest/reference/scim#update-an-attribute-for-a-scim-user) endpoint instead.
 *
 * You must at least provide the required values for the user: `userName`, `name`, and `emails`.
 *
 * **Warning:** Setting `active: false` removes the user from the organization, deletes the external identity, and deletes the associated `{scim_user_id}`.
* @param org - The organization name. The name is not case sensitive.
* @param scimUserId - The unique identifier of the SCIM user.
*/
var setInformationForProvisionedUser = {
    id: "scim/set-information-for-provisioned-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/scim#delete-a-scim-user-from-an-organization


* Delete a SCIM user from an organization
* @param org - The organization name. The name is not case sensitive.
* @param scimUserId - The unique identifier of the SCIM user.
*/
var deleteUserFromOrg = {
    id: "scim/delete-user-from-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/scim#update-an-attribute-for-a-scim-user


* Update an attribute for a SCIM user
* Allows you to change a provisioned user's individual attributes. To change a user's values, you must provide a specific `Operations` JSON format that contains at least one of the `add`, `remove`, or `replace` operations. For examples and more information on the SCIM operations format, see the [SCIM specification](https://tools.ietf.org/html/rfc7644#section-3.5.2).
 *
 * **Note:** Complicated SCIM `path` selectors that include filters are not supported. For example, a `path` selector defined as `"path": "emails[type eq \"work\"]"` will not work.
 *
 * **Warning:** If you set `active:false` using the `replace` operation (as shown in the JSON example below), it removes the user from the organization, deletes the external identity, and deletes the associated `:scim_user_id`.
 *
 * ```
 * {
 * "Operations":[{
 * "op":"replace",
 * "value":{
 * "active":false
 * }
 * }]
 * }
 * ```
* @param org - The organization name. The name is not case sensitive.
* @param scimUserId - The unique identifier of the SCIM user.
*/
var updateAttributeForUser = {
    id: "scim/update-attribute-for-user",
    clientId: "github",
    version: "1.1.5",
};

var scim = /*#__PURE__*/Object.freeze({
  __proto__: null,
  listProvisionedIdentities: listProvisionedIdentities,
  provisionAndInviteUser: provisionAndInviteUser,
  getProvisioningInformationForUser: getProvisioningInformationForUser,
  setInformationForProvisionedUser: setInformationForProvisionedUser,
  deleteUserFromOrg: deleteUserFromOrg,
  updateAttributeForUser: updateAttributeForUser
});

/**
* @see https://docs.github.com/rest/reference/search#search-code


* Search code
* Searches for query terms inside of a file. This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
 *
 * When searching for code, you can get text match metadata for the file **content** and file **path** fields when you pass the `text-match` media type. For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
 *
 * For example, if you want to find the definition of the `addClass` function inside [jQuery](https://github.com/jquery/jquery) repository, your query would look something like this:
 *
 * `q=addClass+in:file+language:js+repo:jquery/jquery`
 *
 * This query searches for the keyword `addClass` within a file's contents. The query limits the search to files where the language is JavaScript in the `jquery/jquery` repository.
 *
 * #### Considerations for code search
 *
 * Due to the complexity of searching code, there are a few restrictions on how searches are performed:
 *
 * *   Only the _default branch_ is considered. In most cases, this will be the `master` branch.
 * *   Only files smaller than 384 KB are searchable.
 * *   You must always include at least one search term when searching source code. For example, searching for [`language:go`](https://github.com/search?utf8=%E2%9C%93&q=language%3Ago&type=Code) is not valid, while [`amazing
 * language:go`](https://github.com/search?utf8=%E2%9C%93&q=amazing+language%3Ago&type=Code) is.
* @param q - The query contains one or more search keywords and qualifiers. Qualifiers allow you to limit your search to specific areas of GitHub. The REST API supports the same qualifiers as the web interface for GitHub. To learn more about the format of the query, see [Constructing a search query](https://docs.github.com/rest/reference/search#constructing-a-search-query). See "[Searching code](https://docs.github.com/search-github/searching-on-github/searching-code)" for a detailed list of qualifiers.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [sort] - Sorts the results of your query. Can only be `indexed`, which indicates how recently a file has been indexed by the GitHub search infrastructure. Default: [best match](https://docs.github.com/rest/reference/search#ranking-search-results)
* @param [order] - Determines whether the first search result returned is the highest number of matches (`desc`) or lowest number of matches (`asc`). This parameter is ignored unless you provide `sort`.
*/
var code = {
    id: "search/code",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/search#search-users


* Search users
* Find users via various criteria. This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
 *
 * When searching for users, you can get text match metadata for the issue **login**, **email**, and **name** fields when you pass the `text-match` media type. For more details about highlighting search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata). For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
 *
 * For example, if you're looking for a list of popular users, you might try this query:
 *
 * `q=tom+repos:%3E42+followers:%3E1000`
 *
 * This query searches for users with the name `tom`. The results are restricted to users with more than 42 repositories and over 1,000 followers.
* @param q - The query contains one or more search keywords and qualifiers. Qualifiers allow you to limit your search to specific areas of GitHub. The REST API supports the same qualifiers as the web interface for GitHub. To learn more about the format of the query, see [Constructing a search query](https://docs.github.com/rest/reference/search#constructing-a-search-query). See "[Searching users](https://docs.github.com/search-github/searching-on-github/searching-users)" for a detailed list of qualifiers.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [order] - Determines whether the first search result returned is the highest number of matches (`desc`) or lowest number of matches (`asc`). This parameter is ignored unless you provide `sort`.
* @param [sort] - Sorts the results of your query by number of `followers` or `repositories`, or when the person `joined` GitHub. Default: [best match](https://docs.github.com/rest/reference/search#ranking-search-results)
*/
var users$1 = {
    id: "search/users",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/search#search-issues-and-pull-requests


* Search issues and pull requests
* Find issues by state and keyword. This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
 *
 * When searching for issues, you can get text match metadata for the issue **title**, issue **body**, and issue **comment body** fields when you pass the `text-match` media type. For more details about how to receive highlighted
 * search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
 *
 * For example, if you want to find the oldest unresolved Python bugs on Windows. Your query might look something like this.
 *
 * `q=windows+label:bug+language:python+state:open&sort=created&order=asc`
 *
 * This query searches for the keyword `windows`, within any open issue that is labeled as `bug`. The search runs across repositories whose primary language is Python. The results are sorted by creation date in ascending order, which means the oldest issues appear first in the search results.
 *
 * **Note:** For [user-to-server](https://docs.github.com/developers/apps/identifying-and-authorizing-users-for-github-apps#user-to-server-requests) GitHub App requests, you can't retrieve a combination of issues and pull requests in a single query. Requests that don't include the `is:issue` or `is:pull-request` qualifier will receive an HTTP `422 Unprocessable Entity` response. To get results for both issues and pull requests, you must send separate queries for issues and pull requests. For more information about the `is` qualifier, see "[Searching only issues or pull requests](https://docs.github.com/github/searching-for-information-on-github/searching-issues-and-pull-requests#search-only-issues-or-pull-requests)."
* @param q - The query contains one or more search keywords and qualifiers. Qualifiers allow you to limit your search to specific areas of GitHub. The REST API supports the same qualifiers as the web interface for GitHub. To learn more about the format of the query, see [Constructing a search query](https://docs.github.com/rest/reference/search#constructing-a-search-query). See "[Searching issues and pull requests](https://docs.github.com/search-github/searching-on-github/searching-issues-and-pull-requests)" for a detailed list of qualifiers.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [order] - Determines whether the first search result returned is the highest number of matches (`desc`) or lowest number of matches (`asc`). This parameter is ignored unless you provide `sort`.
* @param [sort] - Sorts the results of your query by the number of `comments`, `reactions`, `reactions-+1`, `reactions--1`, `reactions-smile`, `reactions-thinking_face`, `reactions-heart`, `reactions-tada`, or `interactions`. You can also sort results by how recently the items were `created` or `updated`, Default: [best match](https://docs.github.com/rest/reference/search#ranking-search-results)
*/
var issuesAndPullRequests = {
    id: "search/issues-and-pull-requests",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/search#search-labels


* Search labels
* Find labels in a repository with names or descriptions that match search keywords. Returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
 *
 * When searching for labels, you can get text match metadata for the label **name** and **description** fields when you pass the `text-match` media type. For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
 *
 * For example, if you want to find labels in the `linguist` repository that match `bug`, `defect`, or `enhancement`. Your query might look like this:
 *
 * `q=bug+defect+enhancement&repository_id=64778136`
 *
 * The labels that best match the query appear first in the search results.
* @param q - The search keywords. This endpoint does not accept qualifiers in the query. To learn more about the format of the query, see [Constructing a search query](https://docs.github.com/rest/reference/search#constructing-a-search-query).
* @param repositoryId - The id of the repository.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [order] - Determines whether the first search result returned is the highest number of matches (`desc`) or lowest number of matches (`asc`). This parameter is ignored unless you provide `sort`.
* @param [sort] - Sorts the results of your query by when the label was `created` or `updated`. Default: [best match](https://docs.github.com/rest/reference/search#ranking-search-results)
*/
var labels = {
    id: "search/labels",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/search#search-topics


* Search topics
* Find topics via various criteria. Results are sorted by best match. This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination). See "[Searching topics](https://docs.github.com/articles/searching-topics/)" for a detailed list of qualifiers.
 *
 * When searching for topics, you can get text match metadata for the topic's **short\_description**, **description**, **name**, or **display\_name** field when you pass the `text-match` media type. For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
 *
 * For example, if you want to search for topics related to Ruby that are featured on https://github.com/topics. Your query might look like this:
 *
 * `q=ruby+is:featured`
 *
 * This query searches for topics with the keyword `ruby` and limits the results to find only topics that are featured. The topics that are the best match for the query appear first in the search results.
* @param q - The query contains one or more search keywords and qualifiers. Qualifiers allow you to limit your search to specific areas of GitHub. The REST API supports the same qualifiers as the web interface for GitHub. To learn more about the format of the query, see [Constructing a search query](https://docs.github.com/rest/reference/search#constructing-a-search-query).
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var topics = {
    id: "search/topics",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/search#search-commits


* Search commits
* Find commits via various criteria on the default branch (usually `master`). This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
 *
 * When searching for commits, you can get text match metadata for the **message** field when you provide the `text-match` media type. For more details about how to receive highlighted search results, see [Text match
 * metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
 *
 * For example, if you want to find commits related to CSS in the [octocat/Spoon-Knife](https://github.com/octocat/Spoon-Knife) repository. Your query would look something like this:
 *
 * `q=repo:octocat/Spoon-Knife+css`
* @param q - The query contains one or more search keywords and qualifiers. Qualifiers allow you to limit your search to specific areas of GitHub. The REST API supports the same qualifiers as the web interface for GitHub. To learn more about the format of the query, see [Constructing a search query](https://docs.github.com/rest/reference/search#constructing-a-search-query). See "[Searching commits](https://docs.github.com/search-github/searching-on-github/searching-commits)" for a detailed list of qualifiers.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [order] - Determines whether the first search result returned is the highest number of matches (`desc`) or lowest number of matches (`asc`). This parameter is ignored unless you provide `sort`.
* @param [sort] - Sorts the results of your query by `author-date` or `committer-date`. Default: [best match](https://docs.github.com/rest/reference/search#ranking-search-results)
*/
var commits = {
    id: "search/commits",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/search#search-repositories


* Search repositories
* Find repositories via various criteria. This method returns up to 100 results [per page](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination).
 *
 * When searching for repositories, you can get text match metadata for the **name** and **description** fields when you pass the `text-match` media type. For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/reference/search#text-match-metadata).
 *
 * For example, if you want to search for popular Tetris repositories written in assembly code, your query might look like this:
 *
 * `q=tetris+language:assembly&sort=stars&order=desc`
 *
 * This query searches for repositories with the word `tetris` in the name, the description, or the README. The results are limited to repositories where the primary language is assembly. The results are sorted by stars in descending order, so that the most popular repositories appear first in the search results.
* @param q - The query contains one or more search keywords and qualifiers. Qualifiers allow you to limit your search to specific areas of GitHub. The REST API supports the same qualifiers as the web interface for GitHub. To learn more about the format of the query, see [Constructing a search query](https://docs.github.com/rest/reference/search#constructing-a-search-query). See "[Searching for repositories](https://docs.github.com/articles/searching-for-repositories/)" for a detailed list of qualifiers.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [order] - Determines whether the first search result returned is the highest number of matches (`desc`) or lowest number of matches (`asc`). This parameter is ignored unless you provide `sort`.
* @param [sort] - Sorts the results of your query by number of `stars`, `forks`, or `help-wanted-issues` or how recently the items were `updated`. Default: [best match](https://docs.github.com/rest/reference/search#ranking-search-results)
*/
var repos = {
    id: "search/repos",
    clientId: "github",
    version: "1.1.5",
};

var search = /*#__PURE__*/Object.freeze({
  __proto__: null,
  code: code,
  users: users$1,
  issuesAndPullRequests: issuesAndPullRequests,
  labels: labels,
  topics: topics,
  commits: commits,
  repos: repos
});

/**
* @see https://docs.github.com/rest/reference/secret-scanning#list-secret-scanning-alerts-for-an-organization


* List secret scanning alerts for an organization
* Lists secret scanning alerts for eligible repositories in an organization, from newest to oldest.
 * To use this endpoint, you must be an administrator or security manager for the organization, and you must use an access token with the `repo` scope or `security_events` scope.
 * For public repositories, you may instead use the `public_repo` scope.
 *
 * GitHub Apps must have the `secret_scanning_alerts` read permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [direction] - The direction to sort the results by.
* @param [sort] - The property to sort the results by. `created` means when the alert was created. `updated` means when the alert was updated or resolved.
* @param [secretType] - A comma-separated list of secret types to return. By default all secret types are returned.
See "[Secret scanning patterns](https://docs.github.com/code-security/secret-scanning/secret-scanning-patterns#supported-secrets-for-advanced-security)"
for a complete list of secret types.
* @param [after] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events after this cursor.  To receive an initial cursor on your first request, include an empty "after" query string.
* @param [state] - Set to `open` or `resolved` to only list secret scanning alerts in a specific state.
* @param [resolution] - A comma-separated list of resolutions. Only secret scanning alerts with one of these resolutions are listed. Valid resolutions are `false_positive`, `wont_fix`, `revoked`, `pattern_edited`, `pattern_deleted` or `used_in_tests`.
* @param [before] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events before this cursor. To receive an initial cursor on your first request, include an empty "before" query string.
*/
var listAlertsForOrg$1 = {
    id: "secret-scanning/list-alerts-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/secret-scanning#list-secret-scanning-alerts-for-a-repository


* List secret scanning alerts for a repository
* Lists secret scanning alerts for an eligible repository, from newest to oldest.
 * To use this endpoint, you must be an administrator for the repository or for the organization that owns the repository, and you must use a personal access token with the `repo` scope or `security_events` scope.
 * For public repositories, you may instead use the `public_repo` scope.
 *
 * GitHub Apps must have the `secret_scanning_alerts` read permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [direction] - The direction to sort the results by.
* @param [sort] - The property to sort the results by. `created` means when the alert was created. `updated` means when the alert was updated or resolved.
* @param [secretType] - A comma-separated list of secret types to return. By default all secret types are returned.
See "[Secret scanning patterns](https://docs.github.com/code-security/secret-scanning/secret-scanning-patterns#supported-secrets-for-advanced-security)"
for a complete list of secret types.
* @param [after] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events after this cursor.  To receive an initial cursor on your first request, include an empty "after" query string.
* @param [state] - Set to `open` or `resolved` to only list secret scanning alerts in a specific state.
* @param [resolution] - A comma-separated list of resolutions. Only secret scanning alerts with one of these resolutions are listed. Valid resolutions are `false_positive`, `wont_fix`, `revoked`, `pattern_edited`, `pattern_deleted` or `used_in_tests`.
* @param [before] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events before this cursor. To receive an initial cursor on your first request, include an empty "before" query string.
*/
var listAlertsForRepo$1 = {
    id: "secret-scanning/list-alerts-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/secret-scanning#list-secret-scanning-alerts-for-an-enterprise


* List secret scanning alerts for an enterprise
* Lists secret scanning alerts for eligible repositories in an enterprise, from newest to oldest.
 * To use this endpoint, you must be a member of the enterprise, and you must use an access token with the `repo` scope or `security_events` scope. Alerts are only returned for organizations in the enterprise for which you are an organization owner or a [security manager](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/managing-security-managers-in-your-organization).
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param [perPage=30] - The number of results per page (max 100).
* @param [direction] - The direction to sort the results by.
* @param [before] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events before this cursor.
* @param [after] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events after this cursor.
* @param [sort] - The property to sort the results by. `created` means when the alert was created. `updated` means when the alert was updated or resolved.
* @param [secretType] - A comma-separated list of secret types to return. By default all secret types are returned.
See "[Secret scanning patterns](https://docs.github.com/code-security/secret-scanning/secret-scanning-patterns#supported-secrets-for-advanced-security)"
for a complete list of secret types.
* @param [state] - Set to `open` or `resolved` to only list secret scanning alerts in a specific state.
* @param [resolution] - A comma-separated list of resolutions. Only secret scanning alerts with one of these resolutions are listed. Valid resolutions are `false_positive`, `wont_fix`, `revoked`, `pattern_edited`, `pattern_deleted` or `used_in_tests`.
*/
var listAlertsForEnterprise$1 = {
    id: "secret-scanning/list-alerts-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/secret-scanning#get-a-secret-scanning-alert


* Get a secret scanning alert
* Gets a single secret scanning alert detected in an eligible repository.
 * To use this endpoint, you must be an administrator for the repository or for the organization that owns the repository, and you must use a personal access token with the `repo` scope or `security_events` scope.
 * For public repositories, you may instead use the `public_repo` scope.
 *
 * GitHub Apps must have the `secret_scanning_alerts` read permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param alertNumber - The number that identifies an alert. You can find this at the end of the URL for a code scanning alert within GitHub, and in the `number` field in the response from the `GET /repos/{owner}/{repo}/code-scanning/alerts` operation.
*/
var getAlert$1 = {
    id: "secret-scanning/get-alert",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/secret-scanning#update-a-secret-scanning-alert


* Update a secret scanning alert
* Updates the status of a secret scanning alert in an eligible repository.
 * To use this endpoint, you must be an administrator for the repository or for the organization that owns the repository, and you must use a personal access token with the `repo` scope or `security_events` scope.
 * For public repositories, you may instead use the `public_repo` scope.
 *
 * GitHub Apps must have the `secret_scanning_alerts` write permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param alertNumber - The number that identifies an alert. You can find this at the end of the URL for a code scanning alert within GitHub, and in the `number` field in the response from the `GET /repos/{owner}/{repo}/code-scanning/alerts` operation.
*/
var updateAlert$1 = {
    id: "secret-scanning/update-alert",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/secret-scanning#list-locations-for-a-secret-scanning-alert


* List locations for a secret scanning alert
* Lists all locations for a given secret scanning alert for an eligible repository.
 * To use this endpoint, you must be an administrator for the repository or for the organization that owns the repository, and you must use a personal access token with the `repo` scope or `security_events` scope.
 * For public repositories, you may instead use the `public_repo` scope.
 *
 * GitHub Apps must have the `secret_scanning_alerts` read permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param alertNumber - The number that identifies an alert. You can find this at the end of the URL for a code scanning alert within GitHub, and in the `number` field in the response from the `GET /repos/{owner}/{repo}/code-scanning/alerts` operation.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listLocationsForAlert = {
    id: "secret-scanning/list-locations-for-alert",
    clientId: "github",
    version: "1.1.5",
};

var secretScanning = /*#__PURE__*/Object.freeze({
  __proto__: null,
  listAlertsForOrg: listAlertsForOrg$1,
  listAlertsForRepo: listAlertsForRepo$1,
  listAlertsForEnterprise: listAlertsForEnterprise$1,
  getAlert: getAlert$1,
  updateAlert: updateAlert$1,
  listLocationsForAlert: listLocationsForAlert
});

/**
* @see https://docs.github.com/rest/reference/enterprise-admin#get-github-enterprise-server-statistics


* Get GitHub Enterprise Server statistics
* Returns aggregate usage metrics for your GitHub Enterprise Server 3.5+ instance for a specified time period up to 365 days.
 *
 * To use this endpoint, your GitHub Enterprise Server instance must be connected to GitHub Enterprise Cloud using GitHub Connect. You must enable Server Statistics, and for the API request provide your enterprise account name or organization name connected to the GitHub Enterprise Server. For more information, see "[Enabling Server Statistics for your enterprise](/admin/configuration/configuring-github-connect/enabling-server-statistics-for-your-enterprise)" in the GitHub Enterprise Server documentation.
 *
 * You'll need to use a personal access token:
 * - If you connected your GitHub Enterprise Server to an enterprise account and enabled Server Statistics, you'll need a personal access token with the `read:enterprise` permission.
 * - If you connected your GitHub Enterprise Server to an organization account and enabled Server Statistics, you'll need a personal access token with the `read:org` permission.
 *
 * For more information on creating a personal access token, see "[Creating a personal access token](/authentication/keeping-your-account-and-data-secure/creating-a-personal-access-token)."
* @param enterpriseOrOrg - The slug version of the enterprise name or the login of an organization.
* @param [dateStart] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events after this cursor.
* @param [dateEnd] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events before this cursor.
*/
var getServerStatistics$1 = {
    id: "enterprise-admin/get-server-statistics",
    clientId: "github",
    version: "1.1.5",
};

var serverStatistics = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getServerStatistics: getServerStatistics$1
});

/**
* @see https://docs.github.com/rest/reference/teams#list-teams-for-the-authenticated-user


* List teams for the authenticated user
* List all of the teams across all of the organizations to which the authenticated user belongs. This method requires `user`, `repo`, or `read:org` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/) when authenticating via [OAuth](https://docs.github.com/apps/building-oauth-apps/).
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listForAuthenticatedUser$2 = {
    id: "teams/list-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams/#get-a-team-legacy

* @deprecated

* Get a team (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the [Get a team by name](https://docs.github.com/rest/reference/teams#get-a-team-by-name) endpoint.
* @param teamId - The unique identifier of the team.
*/
var getLegacy = {
    id: "teams/get-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams/#delete-a-team-legacy

* @deprecated

* Delete a team (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Delete a team](https://docs.github.com/rest/reference/teams#delete-a-team) endpoint.
 *
 * To delete a team, the authenticated user must be an organization owner or team maintainer.
 *
 * If you are an organization owner, deleting a parent team will delete all of its child teams as well.
* @param teamId - The unique identifier of the team.
*/
var deleteLegacy = {
    id: "teams/delete-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams/#update-a-team-legacy

* @deprecated

* Update a team (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Update a team](https://docs.github.com/rest/reference/teams#update-a-team) endpoint.
 *
 * To edit a team, the authenticated user must either be an organization owner or a team maintainer.
 *
 * **Note:** With nested teams, the `privacy` for parent teams cannot be `secret`.
* @param teamId - The unique identifier of the team.
*/
var updateLegacy = {
    id: "teams/update-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-teams


* List teams
* Lists all teams in an organization that are visible to the authenticated user.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var list$3 = {
    id: "teams/list",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#create-a-team


* Create a team
* To create a team, the authenticated user must be a member or owner of `{org}`. By default, organization members can create teams. Organization owners can limit team creation to organization owners. For more information, see "[Setting team creation permissions](https://docs.github.com/en/articles/setting-team-creation-permissions-in-your-organization)."
 *
 * When you create a new team, you automatically become a team maintainer without explicitly adding yourself to the optional array of `maintainers`. For more information, see "[About teams](https://docs.github.com/en/github/setting-up-and-managing-organizations-and-teams/about-teams)".
* @param org - The organization name. The name is not case sensitive.
*/
var create$3 = {
    id: "teams/create",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams/#list-team-repositories-legacy

* @deprecated

* List team repositories (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [List team repositories](https://docs.github.com/rest/reference/teams#list-team-repositories) endpoint.
* @param teamId - The unique identifier of the team.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listReposLegacy = {
    id: "teams/list-repos-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams/#list-child-teams-legacy

* @deprecated

* List child teams (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`List child teams`](https://docs.github.com/rest/reference/teams#list-child-teams) endpoint.
* @param teamId - The unique identifier of the team.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listChildLegacy = {
    id: "teams/list-child-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-team-members-legacy

* @deprecated

* List team members (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`List team members`](https://docs.github.com/rest/reference/teams#list-team-members) endpoint.
 *
 * Team members will include the members of child teams.
* @param teamId - The unique identifier of the team.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [role] - Filters members returned by their role in the team.
*/
var listMembersLegacy = {
    id: "teams/list-members-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams/#list-team-projects-legacy

* @deprecated

* List team projects (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`List team projects`](https://docs.github.com/rest/reference/teams#list-team-projects) endpoint.
 *
 * Lists the organization projects for a team.
* @param teamId - The unique identifier of the team.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listProjectsLegacy = {
    id: "teams/list-projects-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-external-idp-groups-for-an-organization


* List external groups in an organization
* Lists external groups available in an organization. You can query the groups using the `display_name` parameter, only groups with a `group_name` containing the text provided in the `display_name` parameter will be returned.  You can also limit your page results using the `per_page` parameter. GitHub generates a url-encoded `page` token using a cursor value for where the next page begins. For more information on cursor pagination, see "[Offset and Cursor Pagination explained](https://dev.to/jackmarchant/offset-and-cursor-pagination-explained-b89)."
 *
 * You can manage team membership with your identity provider using Enterprise Managed Users for GitHub Enterprise Cloud. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)" in the GitHub Help documentation.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page] - Page token
* @param [displayName] - Limits the list to groups containing the text in the group name
*/
var listExternalIdpGroupsForOrg = {
    id: "teams/list-external-idp-groups-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-idp-groups-for-an-organization


* List IdP groups for an organization
* Team synchronization is available for organizations using GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * List IdP groups available in an organization. You can limit your page results using the `per_page` parameter. GitHub generates a url-encoded `page` token using a cursor value for where the next page begins. For more information on cursor pagination, see "[Offset and Cursor Pagination explained](https://dev.to/jackmarchant/offset-and-cursor-pagination-explained-b89)."
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page] - Page token
*/
var listIdpGroupsForOrg = {
    id: "teams/list-idp-groups-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-discussions-legacy

* @deprecated

* List discussions (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`List discussions`](https://docs.github.com/rest/reference/teams#list-discussions) endpoint.
 *
 * List all discussions on a team's page. OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param teamId - The unique identifier of the team.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [direction] - The direction to sort the results by.
*/
var listDiscussionsLegacy = {
    id: "teams/list-discussions-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#create-a-discussion-legacy

* @deprecated

* Create a discussion (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`Create a discussion`](https://docs.github.com/rest/reference/teams#create-a-discussion) endpoint.
 *
 * Creates a new discussion post on a team's page. OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
 *
 * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
* @param teamId - The unique identifier of the team.
*/
var createDiscussionLegacy = {
    id: "teams/create-discussion-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-pending-team-invitations-legacy

* @deprecated

* List pending team invitations (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`List pending team invitations`](https://docs.github.com/rest/reference/teams#list-pending-team-invitations) endpoint.
 *
 * The return hash contains a `role` field which refers to the Organization Invitation role and will be one of the following values: `direct_member`, `admin`, `billing_manager`, `hiring_manager`, or `reinstate`. If the invitee is not a GitHub member, the `login` field in the return hash will be `null`.
* @param teamId - The unique identifier of the team.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPendingInvitationsLegacy = {
    id: "teams/list-pending-invitations-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#get-a-team-by-name


* Get a team by name
* Gets a team using the team's `slug`. GitHub generates the `slug` from the team `name`.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
*/
var getByName = {
    id: "teams/get-by-name",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#delete-a-team


* Delete a team
* To delete a team, the authenticated user must be an organization owner or team maintainer.
 *
 * If you are an organization owner, deleting a parent team will delete all of its child teams as well.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `DELETE /organizations/{org_id}/team/{team_id}`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
*/
var deleteInOrg = {
    id: "teams/delete-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#update-a-team


* Update a team
* To edit a team, the authenticated user must either be an organization owner or a team maintainer.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `PATCH /organizations/{org_id}/team/{team_id}`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
*/
var updateInOrg = {
    id: "teams/update-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-team-repositories


* List team repositories
* Lists a team's repositories visible to the authenticated user.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/repos`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listReposInOrg = {
    id: "teams/list-repos-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-child-teams


* List child teams
* Lists the child teams of the team specified by `{team_slug}`.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/teams`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listChildInOrg = {
    id: "teams/list-child-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#get-team-member-legacy

* @deprecated

* Get team member (Legacy)
* The "Get team member" endpoint (described below) is deprecated.
 *
 * We recommend using the [Get team membership for a user](https://docs.github.com/rest/reference/teams#get-team-membership-for-a-user) endpoint instead. It allows you to get both active and pending memberships.
 *
 * To list members in a team, the team must be visible to the authenticated user.
* @param teamId - The unique identifier of the team.
* @param username - The handle for the GitHub user account.
*/
var getMemberLegacy = {
    id: "teams/get-member-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#add-team-member-legacy

* @deprecated

* Add team member (Legacy)
* The "Add team member" endpoint (described below) is deprecated.
 *
 * We recommend using the [Add or update team membership for a user](https://docs.github.com/rest/reference/teams#add-or-update-team-membership-for-a-user) endpoint instead. It allows you to invite new organization members to your teams.
 *
 * Team synchronization is available for organizations using GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * To add someone to a team, the authenticated user must be an organization owner or a team maintainer in the team they're changing. The person being added to the team must be a member of the team's organization.
 *
 * **Note:** When you have team synchronization set up for a team with your organization's identity provider (IdP), you will see an error if you attempt to use the API for making changes to the team's membership. If you have access to manage group membership in your IdP, you can manage GitHub team membership through your identity provider, which automatically adds and removes team members in an organization. For more information, see "[Synchronizing teams between your identity provider and GitHub](https://docs.github.com/articles/synchronizing-teams-between-your-identity-provider-and-github/)."
 *
 * Note that you'll need to set `Content-Length` to zero when calling out to this endpoint. For more information, see "[HTTP verbs](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-verbs)."
* @param teamId - The unique identifier of the team.
* @param username - The handle for the GitHub user account.
*/
var addMemberLegacy = {
    id: "teams/add-member-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#remove-team-member-legacy

* @deprecated

* Remove team member (Legacy)
* The "Remove team member" endpoint (described below) is deprecated.
 *
 * We recommend using the [Remove team membership for a user](https://docs.github.com/rest/reference/teams#remove-team-membership-for-a-user) endpoint instead. It allows you to remove both active and pending memberships.
 *
 * Team synchronization is available for organizations using GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * To remove a team member, the authenticated user must have 'admin' permissions to the team or be an owner of the org that the team is associated with. Removing a team member does not delete the user, it just removes them from the team.
 *
 * **Note:** When you have team synchronization set up for a team with your organization's identity provider (IdP), you will see an error if you attempt to use the API for making changes to the team's membership. If you have access to manage group membership in your IdP, you can manage GitHub team membership through your identity provider, which automatically adds and removes team members in an organization. For more information, see "[Synchronizing teams between your identity provider and GitHub](https://docs.github.com/articles/synchronizing-teams-between-your-identity-provider-and-github/)."
* @param teamId - The unique identifier of the team.
* @param username - The handle for the GitHub user account.
*/
var removeMemberLegacy = {
    id: "teams/remove-member-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#external-idp-group-info-for-an-organization


* Get an external group
* Displays information about the specific group's usage.  Provides a list of the group's external members as well as a list of teams that this group is connected to.
 *
 * You can manage team membership with your identity provider using Enterprise Managed Users for GitHub Enterprise Cloud. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)" in the GitHub Help documentation.
* @param org - The organization name. The name is not case sensitive.
* @param groupId - The unique identifier of the group.
*/
var externalIdpGroupInfoForOrg = {
    id: "teams/external-idp-group-info-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-team-members


* List team members
* Team members will include the members of child teams.
 *
 * To list members in a team, the team must be visible to the authenticated user.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [role] - Filters members returned by their role in the team.
*/
var listMembersInOrg = {
    id: "teams/list-members-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams/#check-team-permissions-for-a-repository-legacy

* @deprecated

* Check team permissions for a repository (Legacy)
* **Note**: Repositories inherited through a parent team will also be checked.
 *
 * **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Check team permissions for a repository](https://docs.github.com/rest/reference/teams#check-team-permissions-for-a-repository) endpoint.
 *
 * You can also get information about the specified repository, including what permissions the team grants on it, by passing the following custom [media type](https://docs.github.com/rest/overview/media-types/) via the `Accept` header:
* @param teamId - The unique identifier of the team.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var checkPermissionsForRepoLegacy = {
    id: "teams/check-permissions-for-repo-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams/#add-or-update-team-repository-permissions-legacy

* @deprecated

* Add or update team repository permissions (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new "[Add or update team repository permissions](https://docs.github.com/rest/reference/teams#add-or-update-team-repository-permissions)" endpoint.
 *
 * To add a repository to a team or update the team's permission on a repository, the authenticated user must have admin access to the repository, and must be able to see the team. The repository must be owned by the organization, or a direct fork of a repository owned by the organization. You will get a `422 Unprocessable Entity` status if you attempt to add a repository to a team that is not owned by the organization.
 *
 * Note that, if you choose not to pass any parameters, you'll need to set `Content-Length` to zero when calling out to this endpoint. For more information, see "[HTTP verbs](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-verbs)."
* @param teamId - The unique identifier of the team.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var addOrUpdateRepoPermissionsLegacy = {
    id: "teams/add-or-update-repo-permissions-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams/#remove-a-repository-from-a-team-legacy

* @deprecated

* Remove a repository from a team (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Remove a repository from a team](https://docs.github.com/rest/reference/teams#remove-a-repository-from-a-team) endpoint.
 *
 * If the authenticated user is an organization owner or a team maintainer, they can remove any repositories from the team. To remove a repository from a team as an organization member, the authenticated user must have admin access to the repository and must be able to see the team. NOTE: This does not delete the repository, it just removes it from the team.
* @param teamId - The unique identifier of the team.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var removeRepoLegacy = {
    id: "teams/remove-repo-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-team-projects


* List team projects
* Lists the organization projects for a team.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/projects`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listProjectsInOrg = {
    id: "teams/list-projects-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams/#check-team-permissions-for-a-project-legacy

* @deprecated

* Check team permissions for a project (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Check team permissions for a project](https://docs.github.com/rest/reference/teams#check-team-permissions-for-a-project) endpoint.
 *
 * Checks whether a team has `read`, `write`, or `admin` permissions for an organization project. The response includes projects inherited from a parent team.
* @param teamId - The unique identifier of the team.
* @param projectId - The unique identifier of the project.
*/
var checkPermissionsForProjectLegacy = {
    id: "teams/check-permissions-for-project-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams/#add-or-update-team-project-permissions-legacy

* @deprecated

* Add or update team project permissions (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Add or update team project permissions](https://docs.github.com/rest/reference/teams#add-or-update-team-project-permissions) endpoint.
 *
 * Adds an organization project to a team. To add a project to a team or update the team's permission on a project, the authenticated user must have `admin` permissions for the project. The project and team must be part of the same organization.
* @param teamId - The unique identifier of the team.
* @param projectId - The unique identifier of the project.
*/
var addOrUpdateProjectPermissionsLegacy = {
    id: "teams/add-or-update-project-permissions-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams/#remove-a-project-from-a-team-legacy

* @deprecated

* Remove a project from a team (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Remove a project from a team](https://docs.github.com/rest/reference/teams#remove-a-project-from-a-team) endpoint.
 *
 * Removes an organization project from a team. An organization owner or a team maintainer can remove any project from the team. To remove a project from a team as an organization member, the authenticated user must have `read` access to both the team and project, or `admin` access to the team or project. **Note:** This endpoint removes the project from the team, but does not delete it.
* @param teamId - The unique identifier of the team.
* @param projectId - The unique identifier of the project.
*/
var removeProjectLegacy = {
    id: "teams/remove-project-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#get-team-membership-for-a-user-legacy

* @deprecated

* Get team membership for a user (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Get team membership for a user](https://docs.github.com/rest/reference/teams#get-team-membership-for-a-user) endpoint.
 *
 * Team members will include the members of child teams.
 *
 * To get a user's membership with a team, the team must be visible to the authenticated user.
 *
 * **Note:**
 * The response contains the `state` of the membership and the member's `role`.
 *
 * The `role` for organization owners is set to `maintainer`. For more information about `maintainer` roles, see [Create a team](https://docs.github.com/rest/reference/teams#create-a-team).
* @param teamId - The unique identifier of the team.
* @param username - The handle for the GitHub user account.
*/
var getMembershipForUserLegacy = {
    id: "teams/get-membership-for-user-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#add-or-update-team-membership-for-a-user-legacy

* @deprecated

* Add or update team membership for a user (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Add or update team membership for a user](https://docs.github.com/rest/reference/teams#add-or-update-team-membership-for-a-user) endpoint.
 *
 * Team synchronization is available for organizations using GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * If the user is already a member of the team's organization, this endpoint will add the user to the team. To add a membership between an organization member and a team, the authenticated user must be an organization owner or a team maintainer.
 *
 * **Note:** When you have team synchronization set up for a team with your organization's identity provider (IdP), you will see an error if you attempt to use the API for making changes to the team's membership. If you have access to manage group membership in your IdP, you can manage GitHub team membership through your identity provider, which automatically adds and removes team members in an organization. For more information, see "[Synchronizing teams between your identity provider and GitHub](https://docs.github.com/articles/synchronizing-teams-between-your-identity-provider-and-github/)."
 *
 * If the user is unaffiliated with the team's organization, this endpoint will send an invitation to the user via email. This newly-created membership will be in the "pending" state until the user accepts the invitation, at which point the membership will transition to the "active" state and the user will be added as a member of the team. To add a membership between an unaffiliated user and a team, the authenticated user must be an organization owner.
 *
 * If the user is already a member of the team, this endpoint will update the role of the team member's role. To update the membership of a team member, the authenticated user must be an organization owner or a team maintainer.
* @param teamId - The unique identifier of the team.
* @param username - The handle for the GitHub user account.
*/
var addOrUpdateMembershipForUserLegacy = {
    id: "teams/add-or-update-membership-for-user-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#remove-team-membership-for-a-user-legacy

* @deprecated

* Remove team membership for a user (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Remove team membership for a user](https://docs.github.com/rest/reference/teams#remove-team-membership-for-a-user) endpoint.
 *
 * Team synchronization is available for organizations using GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * To remove a membership between a user and a team, the authenticated user must have 'admin' permissions to the team or be an owner of the organization that the team is associated with. Removing team membership does not delete the user, it just removes their membership from the team.
 *
 * **Note:** When you have team synchronization set up for a team with your organization's identity provider (IdP), you will see an error if you attempt to use the API for making changes to the team's membership. If you have access to manage group membership in your IdP, you can manage GitHub team membership through your identity provider, which automatically adds and removes team members in an organization. For more information, see "[Synchronizing teams between your identity provider and GitHub](https://docs.github.com/articles/synchronizing-teams-between-your-identity-provider-and-github/)."
* @param teamId - The unique identifier of the team.
* @param username - The handle for the GitHub user account.
*/
var removeMembershipForUserLegacy = {
    id: "teams/remove-membership-for-user-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-discussions


* List discussions
* List all discussions on a team's page. OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/discussions`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [direction] - The direction to sort the results by.
* @param [pinned] - Pinned discussions only filter
*/
var listDiscussionsInOrg = {
    id: "teams/list-discussions-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#create-a-discussion


* Create a discussion
* Creates a new discussion post on a team's page. OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
 *
 * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `POST /organizations/{org_id}/team/{team_id}/discussions`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
*/
var createDiscussionInOrg = {
    id: "teams/create-discussion-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-pending-team-invitations


* List pending team invitations
* The return hash contains a `role` field which refers to the Organization Invitation role and will be one of the following values: `direct_member`, `admin`, `billing_manager`, `hiring_manager`, or `reinstate`. If the invitee is not a GitHub member, the `login` field in the return hash will be `null`.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/invitations`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPendingInvitationsInOrg = {
    id: "teams/list-pending-invitations-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-idp-groups-for-a-team-legacy

* @deprecated

* List IdP groups for a team (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`List IdP groups for a team`](https://docs.github.com/rest/reference/teams#list-idp-groups-for-a-team) endpoint.
 *
 * Team synchronization is available for organizations using GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * List IdP groups connected to a team on GitHub.
* @param teamId - The unique identifier of the team.
*/
var listIdpGroupsForLegacy = {
    id: "teams/list-idp-groups-for-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#create-or-update-idp-group-connections-legacy

* @deprecated

* Create or update IdP group connections (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`Create or update IdP group connections`](https://docs.github.com/rest/reference/teams#create-or-update-idp-group-connections) endpoint.
 *
 * Team synchronization is available for organizations using GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Creates, updates, or removes a connection between a team and an IdP group. When adding groups to a team, you must include all new and existing groups to avoid replacing existing groups with the new ones. Specifying an empty `groups` array will remove all connections for a team.
* @param teamId - The unique identifier of the team.
*/
var createOrUpdateIdpGroupConnectionsLegacy = {
    id: "teams/create-or-update-idp-group-connections-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-external-idp-group-team-connection


* List a connection between an external group and a team
* Lists a connection between a team and an external group.
 *
 * You can manage team membership with your identity provider using Enterprise Managed Users for GitHub Enterprise Cloud. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)" in the GitHub Help documentation.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
*/
var listLinkedExternalIdpGroupsToTeamForOrg = {
    id: "teams/list-linked-external-idp-groups-to-team-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#unlink-external-idp-group-team-connection


* Remove the connection between an external group and a team
* Deletes a connection between a team and an external group.
 *
 * You can manage team membership with your IdP using Enterprise Managed Users for GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
*/
var unlinkExternalIdpGroupFromTeamForOrg = {
    id: "teams/unlink-external-idp-group-from-team-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#link-external-idp-group-team-connection


* Update the connection between an external group and a team
* Creates a connection between a team and an external group.  Only one external group can be linked to a team.
 *
 * You can manage team membership with your identity provider using Enterprise Managed Users for GitHub Enterprise Cloud. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)" in the GitHub Help documentation.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
*/
var linkExternalIdpGroupToTeamForOrg = {
    id: "teams/link-external-idp-group-to-team-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#get-a-discussion-legacy

* @deprecated

* Get a discussion (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Get a discussion](https://docs.github.com/rest/reference/teams#get-a-discussion) endpoint.
 *
 * Get a specific discussion on a team's page. OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param teamId - The unique identifier of the team.
* @param discussionNumber - The number that identifies the discussion.
*/
var getDiscussionLegacy = {
    id: "teams/get-discussion-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#delete-a-discussion-legacy

* @deprecated

* Delete a discussion (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [`Delete a discussion`](https://docs.github.com/rest/reference/teams#delete-a-discussion) endpoint.
 *
 * Delete a discussion from a team's page. OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param teamId - The unique identifier of the team.
* @param discussionNumber - The number that identifies the discussion.
*/
var deleteDiscussionLegacy = {
    id: "teams/delete-discussion-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#update-a-discussion-legacy

* @deprecated

* Update a discussion (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Update a discussion](https://docs.github.com/rest/reference/teams#update-a-discussion) endpoint.
 *
 * Edits the title and body text of a discussion post. Only the parameters you provide are updated. OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param teamId - The unique identifier of the team.
* @param discussionNumber - The number that identifies the discussion.
*/
var updateDiscussionLegacy = {
    id: "teams/update-discussion-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams/#check-team-permissions-for-a-repository


* Check team permissions for a repository
* Checks whether a team has `admin`, `push`, `maintain`, `triage`, or `pull` permission for a repository. Repositories inherited through a parent team will also be checked.
 *
 * You can also get information about the specified repository, including what permissions the team grants on it, by passing the following custom [media type](https://docs.github.com/rest/overview/media-types/) via the `application/vnd.github.v3.repository+json` accept header.
 *
 * If a team doesn't have permission for the repository, you will receive a `404 Not Found` response status.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/repos/{owner}/{repo}`.
* @param org - The organization name. The name is not case sensitive.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
*/
var checkPermissionsForRepoInOrg = {
    id: "teams/check-permissions-for-repo-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams/#add-or-update-team-repository-permissions


* Add or update team repository permissions
* To add a repository to a team or update the team's permission on a repository, the authenticated user must have admin access to the repository, and must be able to see the team. The repository must be owned by the organization, or a direct fork of a repository owned by the organization. You will get a `422 Unprocessable Entity` status if you attempt to add a repository to a team that is not owned by the organization. Note that, if you choose not to pass any parameters, you'll need to set `Content-Length` to zero when calling out to this endpoint. For more information, see "[HTTP verbs](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-verbs)."
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `PUT /organizations/{org_id}/team/{team_id}/repos/{owner}/{repo}`.
 *
 * For more information about the permission levels, see "[Repository permission levels for an organization](https://docs.github.com/en/github/setting-up-and-managing-organizations-and-teams/repository-permission-levels-for-an-organization#permission-levels-for-repositories-owned-by-an-organization)".
* @param org - The organization name. The name is not case sensitive.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
*/
var addOrUpdateRepoPermissionsInOrg = {
    id: "teams/add-or-update-repo-permissions-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams/#remove-a-repository-from-a-team


* Remove a repository from a team
* If the authenticated user is an organization owner or a team maintainer, they can remove any repositories from the team. To remove a repository from a team as an organization member, the authenticated user must have admin access to the repository and must be able to see the team. This does not delete the repository, it just removes it from the team.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `DELETE /organizations/{org_id}/team/{team_id}/repos/{owner}/{repo}`.
* @param org - The organization name. The name is not case sensitive.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
*/
var removeRepoInOrg = {
    id: "teams/remove-repo-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#check-team-permissions-for-a-project


* Check team permissions for a project
* Checks whether a team has `read`, `write`, or `admin` permissions for an organization project. The response includes projects inherited from a parent team.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/projects/{project_id}`.
* @param org - The organization name. The name is not case sensitive.
* @param projectId - The unique identifier of the project.
* @param teamSlug - The slug of the team name.
*/
var checkPermissionsForProjectInOrg = {
    id: "teams/check-permissions-for-project-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#add-or-update-team-project-permissions


* Add or update team project permissions
* Adds an organization project to a team. To add a project to a team or update the team's permission on a project, the authenticated user must have `admin` permissions for the project. The project and team must be part of the same organization.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `PUT /organizations/{org_id}/team/{team_id}/projects/{project_id}`.
* @param org - The organization name. The name is not case sensitive.
* @param projectId - The unique identifier of the project.
* @param teamSlug - The slug of the team name.
*/
var addOrUpdateProjectPermissionsInOrg = {
    id: "teams/add-or-update-project-permissions-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#remove-a-project-from-a-team


* Remove a project from a team
* Removes an organization project from a team. An organization owner or a team maintainer can remove any project from the team. To remove a project from a team as an organization member, the authenticated user must have `read` access to both the team and project, or `admin` access to the team or project. This endpoint removes the project from the team, but does not delete the project.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `DELETE /organizations/{org_id}/team/{team_id}/projects/{project_id}`.
* @param org - The organization name. The name is not case sensitive.
* @param projectId - The unique identifier of the project.
* @param teamSlug - The slug of the team name.
*/
var removeProjectInOrg = {
    id: "teams/remove-project-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#get-team-membership-for-a-user


* Get team membership for a user
* Team members will include the members of child teams.
 *
 * To get a user's membership with a team, the team must be visible to the authenticated user.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/memberships/{username}`.
 *
 * **Note:**
 * The response contains the `state` of the membership and the member's `role`.
 *
 * The `role` for organization owners is set to `maintainer`. For more information about `maintainer` roles, see see [Create a team](https://docs.github.com/rest/reference/teams#create-a-team).
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
* @param teamSlug - The slug of the team name.
*/
var getMembershipForUserInOrg = {
    id: "teams/get-membership-for-user-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#add-or-update-team-membership-for-a-user


* Add or update team membership for a user
* Team synchronization is available for organizations using GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Adds an organization member to a team. An authenticated organization owner or team maintainer can add organization members to a team.
 *
 * **Note:** When you have team synchronization set up for a team with your organization's identity provider (IdP), you will see an error if you attempt to use the API for making changes to the team's membership. If you have access to manage group membership in your IdP, you can manage GitHub team membership through your identity provider, which automatically adds and removes team members in an organization. For more information, see "[Synchronizing teams between your identity provider and GitHub](https://docs.github.com/articles/synchronizing-teams-between-your-identity-provider-and-github/)."
 *
 * An organization owner can add someone who is not part of the team's organization to a team. When an organization owner adds someone to a team who is not an organization member, this endpoint will send an invitation to the person via email. This newly-created membership will be in the "pending" state until the person accepts the invitation, at which point the membership will transition to the "active" state and the user will be added as a member of the team.
 *
 * If the user is already a member of the team, this endpoint will update the role of the team member's role. To update the membership of a team member, the authenticated user must be an organization owner or a team maintainer.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `PUT /organizations/{org_id}/team/{team_id}/memberships/{username}`.
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
* @param teamSlug - The slug of the team name.
*/
var addOrUpdateMembershipForUserInOrg = {
    id: "teams/add-or-update-membership-for-user-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#remove-team-membership-for-a-user


* Remove team membership for a user
* Team synchronization is available for organizations using GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * To remove a membership between a user and a team, the authenticated user must have 'admin' permissions to the team or be an owner of the organization that the team is associated with. Removing team membership does not delete the user, it just removes their membership from the team.
 *
 * **Note:** When you have team synchronization set up for a team with your organization's identity provider (IdP), you will see an error if you attempt to use the API for making changes to the team's membership. If you have access to manage group membership in your IdP, you can manage GitHub team membership through your identity provider, which automatically adds and removes team members in an organization. For more information, see "[Synchronizing teams between your identity provider and GitHub](https://docs.github.com/articles/synchronizing-teams-between-your-identity-provider-and-github/)."
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `DELETE /organizations/{org_id}/team/{team_id}/memberships/{username}`.
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
* @param teamSlug - The slug of the team name.
*/
var removeMembershipForUserInOrg = {
    id: "teams/remove-membership-for-user-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-idp-groups-for-a-team


* List IdP groups for a team
* Team synchronization is available for organizations using GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * List IdP groups connected to a team on GitHub.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/team-sync/group-mappings`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
*/
var listIdpGroupsInOrg = {
    id: "teams/list-idp-groups-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#create-or-update-idp-group-connections


* Create or update IdP group connections
* Team synchronization is available for organizations using GitHub Enterprise Cloud. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Creates, updates, or removes a connection between a team and an IdP group. When adding groups to a team, you must include all new and existing groups to avoid replacing existing groups with the new ones. Specifying an empty `groups` array will remove all connections for a team.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `PATCH /organizations/{org_id}/team/{team_id}/team-sync/group-mappings`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
*/
var createOrUpdateIdpGroupConnectionsInOrg = {
    id: "teams/create-or-update-idp-group-connections-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-discussion-comments-legacy

* @deprecated

* List discussion comments (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [List discussion comments](https://docs.github.com/rest/reference/teams#list-discussion-comments) endpoint.
 *
 * List all comments on a team discussion. OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param teamId - The unique identifier of the team.
* @param discussionNumber - The number that identifies the discussion.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [direction] - The direction to sort the results by.
*/
var listDiscussionCommentsLegacy = {
    id: "teams/list-discussion-comments-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#create-a-discussion-comment-legacy

* @deprecated

* Create a discussion comment (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Create a discussion comment](https://docs.github.com/rest/reference/teams#create-a-discussion-comment) endpoint.
 *
 * Creates a new comment on a team discussion. OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
 *
 * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
* @param teamId - The unique identifier of the team.
* @param discussionNumber - The number that identifies the discussion.
*/
var createDiscussionCommentLegacy = {
    id: "teams/create-discussion-comment-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#get-a-discussion


* Get a discussion
* Get a specific discussion on a team's page. OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param discussionNumber - The number that identifies the discussion.
*/
var getDiscussionInOrg = {
    id: "teams/get-discussion-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#delete-a-discussion


* Delete a discussion
* Delete a discussion from a team's page. OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `DELETE /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param discussionNumber - The number that identifies the discussion.
*/
var deleteDiscussionInOrg = {
    id: "teams/delete-discussion-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#update-a-discussion


* Update a discussion
* Edits the title and body text of a discussion post. Only the parameters you provide are updated. OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `PATCH /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param discussionNumber - The number that identifies the discussion.
*/
var updateDiscussionInOrg = {
    id: "teams/update-discussion-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#list-discussion-comments


* List discussion comments
* List all comments on a team discussion. OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}/comments`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param discussionNumber - The number that identifies the discussion.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [direction] - The direction to sort the results by.
*/
var listDiscussionCommentsInOrg = {
    id: "teams/list-discussion-comments-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#create-a-discussion-comment


* Create a discussion comment
* Creates a new comment on a team discussion. OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
 *
 * This endpoint triggers [notifications](https://docs.github.com/en/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `POST /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}/comments`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param discussionNumber - The number that identifies the discussion.
*/
var createDiscussionCommentInOrg = {
    id: "teams/create-discussion-comment-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#get-a-discussion-comment-legacy

* @deprecated

* Get a discussion comment (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Get a discussion comment](https://docs.github.com/rest/reference/teams#get-a-discussion-comment) endpoint.
 *
 * Get a specific comment on a team discussion. OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param teamId - The unique identifier of the team.
* @param discussionNumber - The number that identifies the discussion.
* @param commentNumber - The number that identifies the comment.
*/
var getDiscussionCommentLegacy = {
    id: "teams/get-discussion-comment-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#delete-a-discussion-comment-legacy

* @deprecated

* Delete a discussion comment (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Delete a discussion comment](https://docs.github.com/rest/reference/teams#delete-a-discussion-comment) endpoint.
 *
 * Deletes a comment on a team discussion. OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param teamId - The unique identifier of the team.
* @param discussionNumber - The number that identifies the discussion.
* @param commentNumber - The number that identifies the comment.
*/
var deleteDiscussionCommentLegacy = {
    id: "teams/delete-discussion-comment-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#update-a-discussion-comment-legacy

* @deprecated

* Update a discussion comment (Legacy)
* **Deprecation Notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Update a discussion comment](https://docs.github.com/rest/reference/teams#update-a-discussion-comment) endpoint.
 *
 * Edits the body text of a discussion comment. OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param teamId - The unique identifier of the team.
* @param discussionNumber - The number that identifies the discussion.
* @param commentNumber - The number that identifies the comment.
*/
var updateDiscussionCommentLegacy = {
    id: "teams/update-discussion-comment-legacy",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#get-a-discussion-comment


* Get a discussion comment
* Get a specific comment on a team discussion. OAuth access tokens require the `read:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}/comments/{comment_number}`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param discussionNumber - The number that identifies the discussion.
* @param commentNumber - The number that identifies the comment.
*/
var getDiscussionCommentInOrg = {
    id: "teams/get-discussion-comment-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#delete-a-discussion-comment


* Delete a discussion comment
* Deletes a comment on a team discussion. OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `DELETE /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}/comments/{comment_number}`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param discussionNumber - The number that identifies the discussion.
* @param commentNumber - The number that identifies the comment.
*/
var deleteDiscussionCommentInOrg = {
    id: "teams/delete-discussion-comment-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/teams#update-a-discussion-comment


* Update a discussion comment
* Edits the body text of a discussion comment. OAuth access tokens require the `write:discussion` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
 *
 * **Note:** You can also specify a team by `org_id` and `team_id` using the route `PATCH /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}/comments/{comment_number}`.
* @param org - The organization name. The name is not case sensitive.
* @param teamSlug - The slug of the team name.
* @param discussionNumber - The number that identifies the discussion.
* @param commentNumber - The number that identifies the comment.
*/
var updateDiscussionCommentInOrg = {
    id: "teams/update-discussion-comment-in-org",
    clientId: "github",
    version: "1.1.5",
};

var teams = /*#__PURE__*/Object.freeze({
  __proto__: null,
  listForAuthenticatedUser: listForAuthenticatedUser$2,
  getLegacy: getLegacy,
  deleteLegacy: deleteLegacy,
  updateLegacy: updateLegacy,
  list: list$3,
  create: create$3,
  listReposLegacy: listReposLegacy,
  listChildLegacy: listChildLegacy,
  listMembersLegacy: listMembersLegacy,
  listProjectsLegacy: listProjectsLegacy,
  listExternalIdpGroupsForOrg: listExternalIdpGroupsForOrg,
  listIdpGroupsForOrg: listIdpGroupsForOrg,
  listDiscussionsLegacy: listDiscussionsLegacy,
  createDiscussionLegacy: createDiscussionLegacy,
  listPendingInvitationsLegacy: listPendingInvitationsLegacy,
  getByName: getByName,
  deleteInOrg: deleteInOrg,
  updateInOrg: updateInOrg,
  listReposInOrg: listReposInOrg,
  listChildInOrg: listChildInOrg,
  getMemberLegacy: getMemberLegacy,
  addMemberLegacy: addMemberLegacy,
  removeMemberLegacy: removeMemberLegacy,
  externalIdpGroupInfoForOrg: externalIdpGroupInfoForOrg,
  listMembersInOrg: listMembersInOrg,
  checkPermissionsForRepoLegacy: checkPermissionsForRepoLegacy,
  addOrUpdateRepoPermissionsLegacy: addOrUpdateRepoPermissionsLegacy,
  removeRepoLegacy: removeRepoLegacy,
  listProjectsInOrg: listProjectsInOrg,
  checkPermissionsForProjectLegacy: checkPermissionsForProjectLegacy,
  addOrUpdateProjectPermissionsLegacy: addOrUpdateProjectPermissionsLegacy,
  removeProjectLegacy: removeProjectLegacy,
  getMembershipForUserLegacy: getMembershipForUserLegacy,
  addOrUpdateMembershipForUserLegacy: addOrUpdateMembershipForUserLegacy,
  removeMembershipForUserLegacy: removeMembershipForUserLegacy,
  listDiscussionsInOrg: listDiscussionsInOrg,
  createDiscussionInOrg: createDiscussionInOrg,
  listPendingInvitationsInOrg: listPendingInvitationsInOrg,
  listIdpGroupsForLegacy: listIdpGroupsForLegacy,
  createOrUpdateIdpGroupConnectionsLegacy: createOrUpdateIdpGroupConnectionsLegacy,
  listLinkedExternalIdpGroupsToTeamForOrg: listLinkedExternalIdpGroupsToTeamForOrg,
  unlinkExternalIdpGroupFromTeamForOrg: unlinkExternalIdpGroupFromTeamForOrg,
  linkExternalIdpGroupToTeamForOrg: linkExternalIdpGroupToTeamForOrg,
  getDiscussionLegacy: getDiscussionLegacy,
  deleteDiscussionLegacy: deleteDiscussionLegacy,
  updateDiscussionLegacy: updateDiscussionLegacy,
  checkPermissionsForRepoInOrg: checkPermissionsForRepoInOrg,
  addOrUpdateRepoPermissionsInOrg: addOrUpdateRepoPermissionsInOrg,
  removeRepoInOrg: removeRepoInOrg,
  checkPermissionsForProjectInOrg: checkPermissionsForProjectInOrg,
  addOrUpdateProjectPermissionsInOrg: addOrUpdateProjectPermissionsInOrg,
  removeProjectInOrg: removeProjectInOrg,
  getMembershipForUserInOrg: getMembershipForUserInOrg,
  addOrUpdateMembershipForUserInOrg: addOrUpdateMembershipForUserInOrg,
  removeMembershipForUserInOrg: removeMembershipForUserInOrg,
  listIdpGroupsInOrg: listIdpGroupsInOrg,
  createOrUpdateIdpGroupConnectionsInOrg: createOrUpdateIdpGroupConnectionsInOrg,
  listDiscussionCommentsLegacy: listDiscussionCommentsLegacy,
  createDiscussionCommentLegacy: createDiscussionCommentLegacy,
  getDiscussionInOrg: getDiscussionInOrg,
  deleteDiscussionInOrg: deleteDiscussionInOrg,
  updateDiscussionInOrg: updateDiscussionInOrg,
  listDiscussionCommentsInOrg: listDiscussionCommentsInOrg,
  createDiscussionCommentInOrg: createDiscussionCommentInOrg,
  getDiscussionCommentLegacy: getDiscussionCommentLegacy,
  deleteDiscussionCommentLegacy: deleteDiscussionCommentLegacy,
  updateDiscussionCommentLegacy: updateDiscussionCommentLegacy,
  getDiscussionCommentInOrg: getDiscussionCommentInOrg,
  deleteDiscussionCommentInOrg: deleteDiscussionCommentInOrg,
  updateDiscussionCommentInOrg: updateDiscussionCommentInOrg
});

/**
* @see https://docs.github.com/rest/reference/users#get-the-authenticated-user


* Get the authenticated user
* If the authenticated user is authenticated through basic authentication or OAuth with the `user` scope, then the response lists public and private profile information.
 *
 * If the authenticated user is authenticated through OAuth without the `user` scope, then the response lists only public profile information.
*/
var getAuthenticated$1 = {
    id: "users/get-authenticated",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users/#update-the-authenticated-user


* Update the authenticated user
* **Note:** If your email is set to private and you send an `email` parameter as part of this request to update your profile, your privacy settings are still enforced: the email address will not be displayed on your public profile or via the API.
*/
var updateAuthenticated = {
    id: "users/update-authenticated",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#list-users


* List users
* Lists all users, in the order that they signed up on GitHub. This list includes personal user accounts and organization accounts.
 *
 * Note: Pagination is powered exclusively by the `since` parameter. Use the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header) to get the URL for the next page of users.
* @param [perPage=30] - The number of results per page (max 100).
* @param [since] - A user ID. Only return users with an ID greater than this ID.
*/
var list$2 = {
    id: "users/list",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#list-public-ssh-keys-for-the-authenticated-user


* List public SSH keys for the authenticated user
* Lists the public SSH keys for the authenticated user's GitHub account. Requires that you are authenticated via Basic Auth or via OAuth with at least `read:public_key` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPublicSshKeysForAuthenticatedUser = {
    id: "users/list-public-ssh-keys-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#create-a-public-ssh-key-for-the-authenticated-user


* Create a public SSH key for the authenticated user
* Adds a public SSH key to the authenticated user's GitHub account. Requires that you are authenticated via Basic Auth, or OAuth with at least `write:public_key` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
*/
var createPublicSshKeyForAuthenticatedUser = {
    id: "users/create-public-ssh-key-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#list-users-blocked-by-the-authenticated-user


* List users blocked by the authenticated user
* List the users you've blocked on your personal account.
*/
var listBlockedByAuthenticatedUser = {
    id: "users/list-blocked-by-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#list-email-addresses-for-the-authenticated-user


* List email addresses for the authenticated user
* Lists all of your email addresses, and specifies which one is visible to the public. This endpoint is accessible with the `user:email` scope.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listEmailsForAuthenticatedUser = {
    id: "users/list-emails-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#add-an-email-address-for-the-authenticated-user


* Add an email address for the authenticated user
* This endpoint is accessible with the `user` scope.
*/
var addEmailForAuthenticatedUser = {
    id: "users/add-email-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#delete-an-email-address-for-the-authenticated-user


* Delete an email address for the authenticated user
* This endpoint is accessible with the `user` scope.
*/
var deleteEmailForAuthenticatedUser = {
    id: "users/delete-email-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#list-gpg-keys-for-the-authenticated-user


* List GPG keys for the authenticated user
* Lists the current user's GPG keys. Requires that you are authenticated via Basic Auth or via OAuth with at least `read:gpg_key` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listGpgKeysForAuthenticatedUser = {
    id: "users/list-gpg-keys-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#create-a-gpg-key-for-the-authenticated-user


* Create a GPG key for the authenticated user
* Adds a GPG key to the authenticated user's GitHub account. Requires that you are authenticated via Basic Auth, or OAuth with at least `write:gpg_key` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
*/
var createGpgKeyForAuthenticatedUser = {
    id: "users/create-gpg-key-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#list-followers-of-the-authenticated-user


* List followers of the authenticated user
* Lists the people following the authenticated user.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listFollowersForAuthenticatedUser = {
    id: "users/list-followers-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#list-the-people-the-authenticated-user-follows


* List the people the authenticated user follows
* Lists the people who the authenticated user follows.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listFollowedByAuthenticatedUser = {
    id: "users/list-followed-by-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#get-a-user


* Get a user
* Provides publicly available information about someone with a GitHub account.
 *
 * GitHub Apps with the `Plan` user permission can use this endpoint to retrieve information about a user's GitHub plan. The GitHub App must be authenticated as a user. See "[Identifying and authorizing users for GitHub Apps](https://docs.github.com/apps/building-github-apps/identifying-and-authorizing-users-for-github-apps/)" for details about authentication. For an example response, see 'Response with GitHub plan information' below"
 *
 * The `email` key in the following response is the publicly visible email address from your GitHub [profile page](https://github.com/settings/profile). When setting up your profile, you can select a primary email address to be “public” which provides an email entry for this endpoint. If you do not set a public email address for `email`, then it will have a value of `null`. You only see publicly visible email addresses when authenticated with GitHub. For more information, see [Authentication](https://docs.github.com/rest/overview/resources-in-the-rest-api#authentication).
 *
 * The Emails API enables you to list all of your email addresses, and toggle a primary email to be visible publicly. For more information, see "[Emails API](https://docs.github.com/rest/reference/users#emails)".
* @param username - The handle for the GitHub user account.
*/
var getByUsername = {
    id: "users/get-by-username",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#get-a-public-ssh-key-for-the-authenticated-user


* Get a public SSH key for the authenticated user
* View extended details for a single public SSH key. Requires that you are authenticated via Basic Auth or via OAuth with at least `read:public_key` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param keyId - The unique identifier of the key.
*/
var getPublicSshKeyForAuthenticatedUser = {
    id: "users/get-public-ssh-key-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#delete-a-public-ssh-key-for-the-authenticated-user


* Delete a public SSH key for the authenticated user
* Removes a public SSH key from the authenticated user's GitHub account. Requires that you are authenticated via Basic Auth or via OAuth with at least `admin:public_key` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param keyId - The unique identifier of the key.
*/
var deletePublicSshKeyForAuthenticatedUser = {
    id: "users/delete-public-ssh-key-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#list-public-email-addresses-for-the-authenticated-user


* List public email addresses for the authenticated user
* Lists your publicly visible email address, which you can set with the [Set primary email visibility for the authenticated user](https://docs.github.com/rest/reference/users#set-primary-email-visibility-for-the-authenticated-user) endpoint. This endpoint is accessible with the `user:email` scope.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPublicEmailsForAuthenticatedUser = {
    id: "users/list-public-emails-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#set-primary-email-visibility-for-the-authenticated-user


* Set primary email visibility for the authenticated user
* Sets the visibility for your primary email addresses.
*/
var setPrimaryEmailVisibilityForAuthenticatedUser = {
    id: "users/set-primary-email-visibility-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#list-public-keys-for-a-user


* List public keys for a user
* Lists the _verified_ public SSH keys for a user. This is accessible by anyone.
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPublicKeysForUser = {
    id: "users/list-public-keys-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#check-if-a-user-is-blocked-by-the-authenticated-user


* Check if a user is blocked by the authenticated user
* @param username - The handle for the GitHub user account.
*/
var checkBlocked = {
    id: "users/check-blocked",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#block-a-user


* Block a user
* @param username - The handle for the GitHub user account.
*/
var block = {
    id: "users/block",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#unblock-a-user


* Unblock a user
* @param username - The handle for the GitHub user account.
*/
var unblock = {
    id: "users/unblock",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#check-if-a-person-is-followed-by-the-authenticated-user


* Check if a person is followed by the authenticated user
* @param username - The handle for the GitHub user account.
*/
var checkPersonIsFollowedByAuthenticated = {
    id: "users/check-person-is-followed-by-authenticated",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#follow-a-user


* Follow a user
* Note that you'll need to set `Content-Length` to zero when calling out to this endpoint. For more information, see "[HTTP verbs](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-verbs)."
 *
 * Following a user requires the user to be logged in and authenticated with basic auth or OAuth with the `user:follow` scope.
* @param username - The handle for the GitHub user account.
*/
var follow = {
    id: "users/follow",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#unfollow-a-user


* Unfollow a user
* Unfollowing a user requires the user to be logged in and authenticated with basic auth or OAuth with the `user:follow` scope.
* @param username - The handle for the GitHub user account.
*/
var unfollow = {
    id: "users/unfollow",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#list-gpg-keys-for-a-user


* List GPG keys for a user
* Lists the GPG keys for a user. This information is accessible by anyone.
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listGpgKeysForUser = {
    id: "users/list-gpg-keys-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#get-a-gpg-key-for-the-authenticated-user


* Get a GPG key for the authenticated user
* View extended details for a single GPG key. Requires that you are authenticated via Basic Auth or via OAuth with at least `read:gpg_key` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param gpgKeyId - The unique identifier of the GPG key.
*/
var getGpgKeyForAuthenticatedUser = {
    id: "users/get-gpg-key-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#delete-a-gpg-key-for-the-authenticated-user


* Delete a GPG key for the authenticated user
* Removes a GPG key from the authenticated user's GitHub account. Requires that you are authenticated via Basic Auth or via OAuth with at least `admin:gpg_key` [scope](https://docs.github.com/apps/building-oauth-apps/understanding-scopes-for-oauth-apps/).
* @param gpgKeyId - The unique identifier of the GPG key.
*/
var deleteGpgKeyForAuthenticatedUser = {
    id: "users/delete-gpg-key-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#list-followers-of-a-user


* List followers of a user
* Lists the people following the specified user.
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listFollowersForUser = {
    id: "users/list-followers-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#list-the-people-a-user-follows


* List the people a user follows
* Lists the people who the specified user follows.
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listFollowingForUser = {
    id: "users/list-following-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#get-contextual-information-for-a-user


* Get contextual information for a user
* Provides hovercard information when authenticated through basic auth or OAuth with the `repo` scope. You can find out more about someone in relation to their pull requests, issues, repositories, and organizations.
 *
 * The `subject_type` and `subject_id` parameters provide context for the person's hovercard, which returns more information than without the parameters. For example, if you wanted to find out more about `octocat` who owns the `Spoon-Knife` repository via cURL, it would look like this:
 *
 * ```shell
 * curl -u username:token
 * https://api.github.com/users/octocat/hovercard?subject_type=repository&subject_id=1300192
 * ```
* @param username - The handle for the GitHub user account.
* @param [subjectType] - Identifies which additional information you'd like to receive about the person's hovercard. Can be `organization`, `repository`, `issue`, `pull_request`. **Required** when using `subject_id`.
* @param [subjectId] - Uses the ID for the `subject_type` you specified. **Required** when using `subject_type`.
*/
var getContextForUser = {
    id: "users/get-context-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/users#check-if-a-user-follows-another-user


* Check if a user follows another user
* @param username - The handle for the GitHub user account.
* @param targetUser
*/
var checkFollowingForUser = {
    id: "users/check-following-for-user",
    clientId: "github",
    version: "1.1.5",
};

var users = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getAuthenticated: getAuthenticated$1,
  updateAuthenticated: updateAuthenticated,
  list: list$2,
  listPublicSshKeysForAuthenticatedUser: listPublicSshKeysForAuthenticatedUser,
  createPublicSshKeyForAuthenticatedUser: createPublicSshKeyForAuthenticatedUser,
  listBlockedByAuthenticatedUser: listBlockedByAuthenticatedUser,
  listEmailsForAuthenticatedUser: listEmailsForAuthenticatedUser,
  addEmailForAuthenticatedUser: addEmailForAuthenticatedUser,
  deleteEmailForAuthenticatedUser: deleteEmailForAuthenticatedUser,
  listGpgKeysForAuthenticatedUser: listGpgKeysForAuthenticatedUser,
  createGpgKeyForAuthenticatedUser: createGpgKeyForAuthenticatedUser,
  listFollowersForAuthenticatedUser: listFollowersForAuthenticatedUser,
  listFollowedByAuthenticatedUser: listFollowedByAuthenticatedUser,
  getByUsername: getByUsername,
  getPublicSshKeyForAuthenticatedUser: getPublicSshKeyForAuthenticatedUser,
  deletePublicSshKeyForAuthenticatedUser: deletePublicSshKeyForAuthenticatedUser,
  listPublicEmailsForAuthenticatedUser: listPublicEmailsForAuthenticatedUser,
  setPrimaryEmailVisibilityForAuthenticatedUser: setPrimaryEmailVisibilityForAuthenticatedUser,
  listPublicKeysForUser: listPublicKeysForUser,
  checkBlocked: checkBlocked,
  block: block,
  unblock: unblock,
  checkPersonIsFollowedByAuthenticated: checkPersonIsFollowedByAuthenticated,
  follow: follow,
  unfollow: unfollow,
  listGpgKeysForUser: listGpgKeysForUser,
  getGpgKeyForAuthenticatedUser: getGpgKeyForAuthenticatedUser,
  deleteGpgKeyForAuthenticatedUser: deleteGpgKeyForAuthenticatedUser,
  listFollowersForUser: listFollowersForUser,
  listFollowingForUser: listFollowingForUser,
  getContextForUser: getContextForUser,
  checkFollowingForUser: checkFollowingForUser
});

/**
* @see https://docs.github.com/rest/reference/actions#list-self-hosted-runners-for-an-organization


* List self-hosted runners for an organization
* Lists all self-hosted runners configured in an organization.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listSelfHostedRunnersForOrg = {
    id: "actions/list-self-hosted-runners-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-organization-secrets


* List organization secrets
* Lists all secrets available in an organization without revealing their encrypted values. You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listOrgSecrets$1 = {
    id: "actions/list-org-secrets",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-github-actions-cache-usage-for-an-organization


* Get GitHub Actions cache usage for an organization
* Gets the total GitHub Actions cache usage for an organization.
 * The data fetched using this API is refreshed approximately every 5 minutes, so values returned from this endpoint may take at least 5 minutes to get updated.
 * You must authenticate using an access token with the `read:org` scope to use this endpoint. GitHub Apps must have the `organization_admistration:read` permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
*/
var getActionsCacheUsageForOrg = {
    id: "actions/get-actions-cache-usage-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-github-actions-permissions-for-an-organization


* Get GitHub Actions permissions for an organization
* Gets the GitHub Actions permissions policy for repositories and allowed actions and reusable workflows in an organization.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `administration` organization permission to use this API.
* @param org - The organization name. The name is not case sensitive.
*/
var getGithubActionsPermissionsOrganization = {
    id: "actions/get-github-actions-permissions-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-github-actions-permissions-for-an-organization


* Set GitHub Actions permissions for an organization
* Sets the GitHub Actions permissions policy for repositories and allowed actions and reusable workflows in an organization.
 *
 * If the organization belongs to an enterprise that has set restrictive permissions at the enterprise level, such as `allowed_actions` to `selected` actions and reusable workflows, then you cannot override them for the organization.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `administration` organization permission to use this API.
* @param org - The organization name. The name is not case sensitive.
*/
var setGithubActionsPermissionsOrganization = {
    id: "actions/set-github-actions-permissions-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-self-hosted-runner-groups-for-an-organization


* List self-hosted runner groups for an organization
* The self-hosted runner groups REST API is available with GitHub Enterprise Cloud. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)."
 *
 * Lists all self-hosted runner groups configured in an organization and inherited from an enterprise.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [visibleToRepository] - Only return runner groups that are allowed to be used by this repository.
*/
var listSelfHostedRunnerGroupsForOrg = {
    id: "actions/list-self-hosted-runner-groups-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#create-a-self-hosted-runner-group-for-an-organization


* Create a self-hosted runner group for an organization
* The self-hosted runner groups REST API is available with GitHub Enterprise Cloud and GitHub Enterprise Server. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)."
 *
 * Creates a new self-hosted runner group for an organization.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
*/
var createSelfHostedRunnerGroupForOrg = {
    id: "actions/create-self-hosted-runner-group-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-workflow-runs-for-a-repository


* List workflow runs for a repository
* Lists all workflow runs for a repository. You can use parameters to narrow the list of results. For more information about using parameters, see [Parameters](https://docs.github.com/rest/overview/resources-in-the-rest-api#parameters).
 *
 * Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [branch] - Returns workflow runs associated with a branch. Use the name of the branch of the `push`.
* @param [event] - Returns workflow run triggered by the event you specify. For example, `push`, `pull_request` or `issue`. For more information, see "[Events that trigger workflows](https://docs.github.com/en/actions/automating-your-workflow-with-github-actions/events-that-trigger-workflows)."
* @param [status] - Returns workflow runs with the check run `status` or `conclusion` that you specify. For example, a conclusion can be `success` or a status can be `in_progress`. Only GitHub can set a status of `waiting` or `requested`. For a list of the possible `status` and `conclusion` options, see "[Create a check run](https://docs.github.com/rest/reference/checks#create-a-check-run)."
* @param [checkSuiteId] - Returns workflow runs with the `check_suite_id` that you specify.
* @param [actor] - Returns someone's workflow runs. Use the login for the user who created the `push` associated with the check suite or workflow run.
* @param [created] - Returns workflow runs created within the given date-time range. For more information on the syntax, see "[Understanding the search syntax](https://docs.github.com/search-github/getting-started-with-searching-on-github/understanding-the-search-syntax#query-for-dates)."
* @param [excludePullRequests=false] - If `true` pull requests are omitted from the response (empty array).
*/
var listWorkflowRunsForRepo = {
    id: "actions/list-workflow-runs-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/actions/cache#list-github-actions-caches-for-a-repository


* List GitHub Actions caches for a repository
* Lists the GitHub Actions caches for a repository.
 * You must authenticate using an access token with the `repo` scope to use this endpoint.
 * GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [direction] - The direction to sort the results by.
* @param [sort] - The property to sort the results by. `created_at` means when the cache was created. `last_accessed_at` means when the cache was last accessed. `size_in_bytes` is the size of the cache in bytes.
* @param [ref] - The Git reference for the results you want to list. The `ref` for a branch can be formatted either as `refs/heads/<branch name>` or simply `<branch name>`. To reference a pull request use `refs/pull/<number>/merge`.
* @param [key] - An explicit key or prefix for identifying the cache
*/
var getActionsCacheList = {
    id: "actions/get-actions-cache-list",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/actions/cache#delete-github-actions-caches-for-a-repository-using-a-cache-key


* Delete GitHub Actions caches for a repository (using a cache key)
* Deletes one or more GitHub Actions caches for a repository, using a complete cache key. By default, all caches that match the provided key are deleted, but you can optionally provide a Git ref to restrict deletions to caches that match both the provided key and the Git ref.
 *
 * You must authenticate using an access token with the `repo` scope to use this endpoint.
 *
 * GitHub Apps must have the `actions:write` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param key - A key for identifying the cache.
* @param [ref] - The Git reference for the results you want to list. The `ref` for a branch can be formatted either as `refs/heads/<branch name>` or simply `<branch name>`. To reference a pull request use `refs/pull/<number>/merge`.
*/
var deleteActionsCacheByKey = {
    id: "actions/delete-actions-cache-by-key",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-runner-applications-for-an-organization


* List runner applications for an organization
* Lists binaries for the runner application that you can download and run.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
*/
var listRunnerApplicationsForOrg = {
    id: "actions/list-runner-applications-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-self-hosted-runners-for-a-repository


* List self-hosted runners for a repository
* Lists all self-hosted runners configured in a repository. You must authenticate using an access token with the `repo` scope to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listSelfHostedRunnersForRepo = {
    id: "actions/list-self-hosted-runners-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-repository-secrets


* List repository secrets
* Lists all secrets available in a repository without revealing their encrypted values. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `secrets` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listRepoSecrets$2 = {
    id: "actions/list-repo-secrets",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-an-organization-public-key


* Get an organization public key
* Gets your public key, which you need to encrypt secrets. You need to encrypt a secret before you can create or update secrets. You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
*/
var getOrgPublicKey$1 = {
    id: "actions/get-org-public-key",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-a-self-hosted-runner-for-an-organization


* Get a self-hosted runner for an organization
* Gets a specific self-hosted runner configured in an organization.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var getSelfHostedRunnerForOrg = {
    id: "actions/get-self-hosted-runner-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#delete-a-self-hosted-runner-from-an-organization


* Delete a self-hosted runner from an organization
* Forces the removal of a self-hosted runner from an organization. You can use this endpoint to completely remove the runner when the machine you were using no longer exists.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var deleteSelfHostedRunnerFromOrg = {
    id: "actions/delete-self-hosted-runner-from-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-artifacts-for-a-repository


* List artifacts for a repository
* Lists all artifacts for a repository. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listArtifactsForRepo = {
    id: "actions/list-artifacts-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-repository-workflows


* List repository workflows
* Lists the workflows in a repository. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listRepoWorkflows = {
    id: "actions/list-repo-workflows",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-default-workflow-permissions


* Get default workflow permissions for an organization
* Gets the default workflow permissions granted to the `GITHUB_TOKEN` when running workflows in an organization,
 * as well as whether GitHub Actions can submit approving pull request reviews. For more information, see
 * "[Setting the permissions of the GITHUB_TOKEN for your organization](https://docs.github.com/organizations/managing-organization-settings/disabling-or-limiting-github-actions-for-your-organization#setting-the-permissions-of-the-github_token-for-your-organization)."
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `administration` organization permission to use this API.
* @param org - The organization name. The name is not case sensitive.
*/
var getGithubActionsDefaultWorkflowPermissionsOrganization = {
    id: "actions/get-github-actions-default-workflow-permissions-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-default-workflow-permissions


* Set default workflow permissions for an organization
* Sets the default workflow permissions granted to the `GITHUB_TOKEN` when running workflows in an organization, and sets if GitHub Actions
 * can submit approving pull request reviews. For more information, see
 * "[Setting the permissions of the GITHUB_TOKEN for your organization](https://docs.github.com/organizations/managing-organization-settings/disabling-or-limiting-github-actions-for-your-organization#setting-the-permissions-of-the-github_token-for-your-organization)."
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `administration` organization permission to use this API.
* @param org - The organization name. The name is not case sensitive.
*/
var setGithubActionsDefaultWorkflowPermissionsOrganization = {
    id: "actions/set-github-actions-default-workflow-permissions-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#create-a-remove-token-for-an-organization


* Create a remove token for an organization
* Returns a token that you can pass to the `config` script to remove a self-hosted runner from an organization. The token expires after one hour.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
 *
 * #### Example using remove token
 *
 * To remove your self-hosted runner from an organization, replace `TOKEN` with the remove token provided by this
 * endpoint.
 *
 * ```
 * ./config.sh remove --token TOKEN
 * ```
* @param org - The organization name. The name is not case sensitive.
*/
var createRemoveTokenForOrg = {
    id: "actions/create-remove-token-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-an-organization-secret


* Get an organization secret
* Gets a single organization secret without revealing its encrypted value. You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var getOrgSecret$1 = {
    id: "actions/get-org-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#create-or-update-an-organization-secret


* Create or update an organization secret
* Creates or updates an organization secret with an encrypted value. Encrypt your secret using
 * [LibSodium](https://libsodium.gitbook.io/doc/bindings_for_other_languages). You must authenticate using an access
 * token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `secrets` organization permission to
 * use this endpoint.
 *
 * #### Example encrypting a secret using Node.js
 *
 * Encrypt your secret using the [tweetsodium](https://github.com/github/tweetsodium) library.
 *
 * ```
 * const sodium = require('tweetsodium');
 *
 * const key = "base64-encoded-public-key";
 * const value = "plain-text-secret";
 *
 * // Convert the message and key to Uint8Array's (Buffer implements that interface)
 * const messageBytes = Buffer.from(value);
 * const keyBytes = Buffer.from(key, 'base64');
 *
 * // Encrypt using LibSodium.
 * const encryptedBytes = sodium.seal(messageBytes, keyBytes);
 *
 * // Base64 the encrypted secret
 * const encrypted = Buffer.from(encryptedBytes).toString('base64');
 *
 * console.log(encrypted);
 * ```
 *
 *
 * #### Example encrypting a secret using Python
 *
 * Encrypt your secret using [pynacl](https://pynacl.readthedocs.io/en/latest/public/#nacl-public-sealedbox) with Python 3.
 *
 * ```
 * from base64 import b64encode
 * from nacl import encoding, public
 *
 * def encrypt(public_key: str, secret_value: str) -> str:
 * """Encrypt a Unicode string using the public key."""
 * public_key = public.PublicKey(public_key.encode("utf-8"), encoding.Base64Encoder())
 * sealed_box = public.SealedBox(public_key)
 * encrypted = sealed_box.encrypt(secret_value.encode("utf-8"))
 * return b64encode(encrypted).decode("utf-8")
 * ```
 *
 * #### Example encrypting a secret using C#
 *
 * Encrypt your secret using the [Sodium.Core](https://www.nuget.org/packages/Sodium.Core/) package.
 *
 * ```
 * var secretValue = System.Text.Encoding.UTF8.GetBytes("mySecret");
 * var publicKey = Convert.FromBase64String("2Sg8iYjAxxmI2LvUXpJjkYrMxURPc8r+dB7TJyvvcCU=");
 *
 * var sealedPublicKeyBox = Sodium.SealedPublicKeyBox.Create(secretValue, publicKey);
 *
 * Console.WriteLine(Convert.ToBase64String(sealedPublicKeyBox));
 * ```
 *
 * #### Example encrypting a secret using Ruby
 *
 * Encrypt your secret using the [rbnacl](https://github.com/RubyCrypto/rbnacl) gem.
 *
 * ```ruby
 * require "rbnacl"
 * require "base64"
 *
 * key = Base64.decode64("+ZYvJDZMHUfBkJdyq5Zm9SKqeuBQ4sj+6sfjlH4CgG0=")
 * public_key = RbNaCl::PublicKey.new(key)
 *
 * box = RbNaCl::Boxes::Sealed.from_public_key(public_key)
 * encrypted_secret = box.encrypt("my_secret")
 *
 * # Print the base64 encoded secret
 * puts Base64.strict_encode64(encrypted_secret)
 * ```
* @param org - The organization name. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var createOrUpdateOrgSecret$1 = {
    id: "actions/create-or-update-org-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#delete-an-organization-secret


* Delete an organization secret
* Deletes a secret in an organization using the secret name. You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var deleteOrgSecret$1 = {
    id: "actions/delete-org-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-github-actions-cache-usage-for-a-repository


* Get GitHub Actions cache usage for a repository
* Gets GitHub Actions cache usage for a repository.
 * The data fetched using this API is refreshed approximately every 5 minutes, so values returned from this endpoint may take at least 5 minutes to get updated.
 * Anyone with read access to the repository can use this endpoint. If the repository is private, you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getActionsCacheUsage = {
    id: "actions/get-actions-cache-usage",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-github-actions-permissions-for-a-repository


* Get GitHub Actions permissions for a repository
* Gets the GitHub Actions permissions policy for a repository, including whether GitHub Actions is enabled and the actions and reusable workflows allowed to run in the repository.
 *
 * You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `administration` repository permission to use this API.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getGithubActionsPermissionsRepository = {
    id: "actions/get-github-actions-permissions-repository",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-github-actions-permissions-for-a-repository


* Set GitHub Actions permissions for a repository
* Sets the GitHub Actions permissions policy for enabling GitHub Actions and allowed actions and reusable workflows in the repository.
 *
 * If the repository belongs to an organization or enterprise that has set restrictive permissions at the organization or enterprise levels, such as `allowed_actions` to `selected` actions and reusable workflows, then you cannot override them for the repository.
 *
 * You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `administration` repository permission to use this API.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var setGithubActionsPermissionsRepository = {
    id: "actions/set-github-actions-permissions-repository",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-a-job-for-a-workflow-run


* Get a job for a workflow run
* Gets a specific job in a workflow run. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param jobId - The unique identifier of the job.
*/
var getJobForWorkflowRun = {
    id: "actions/get-job-for-workflow-run",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-a-workflow-run


* Get a workflow run
* Gets a specific workflow run. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
* @param [excludePullRequests=false] - If `true` pull requests are omitted from the response (empty array).
*/
var getWorkflowRun = {
    id: "actions/get-workflow-run",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#delete-a-workflow-run


* Delete a workflow run
* Delete a specific workflow run. Anyone with write access to the repository can use this endpoint. If the repository is
 * private you must use an access token with the `repo` scope. GitHub Apps must have the `actions:write` permission to use
 * this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
*/
var deleteWorkflowRun = {
    id: "actions/delete-workflow-run",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-selected-repositories-enabled-for-github-actions-in-an-organization


* List selected repositories enabled for GitHub Actions in an organization
* Lists the selected repositories that are enabled for GitHub Actions in an organization. To use this endpoint, the organization permission policy for `enabled_repositories` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an organization](#set-github-actions-permissions-for-an-organization)."
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `administration` organization permission to use this API.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listSelectedRepositoriesEnabledGithubActionsOrganization = {
    id: "actions/list-selected-repositories-enabled-github-actions-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-selected-repositories-enabled-for-github-actions-in-an-organization


* Set selected repositories enabled for GitHub Actions in an organization
* Replaces the list of selected repositories that are enabled for GitHub Actions in an organization. To use this endpoint, the organization permission policy for `enabled_repositories` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an organization](#set-github-actions-permissions-for-an-organization)."
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `administration` organization permission to use this API.
* @param org - The organization name. The name is not case sensitive.
*/
var setSelectedRepositoriesEnabledGithubActionsOrganization = {
    id: "actions/set-selected-repositories-enabled-github-actions-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-github-actions-cache-usage-for-an-enterprise


* Get GitHub Actions cache usage for an enterprise
* Gets the total GitHub Actions cache usage for an enterprise.
 * The data fetched using this API is refreshed approximately every 5 minutes, so values returned from this endpoint may take at least 5 minutes to get updated.
 * You must authenticate using an access token with the `admin:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var getActionsCacheUsageForEnterprise = {
    id: "actions/get-actions-cache-usage-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-repositories-with-github-actions-cache-usage-for-an-organization


* List repositories with GitHub Actions cache usage for an organization
* Lists repositories and their GitHub Actions cache usage for an organization.
 * The data fetched using this API is refreshed approximately every 5 minutes, so values returned from this endpoint may take at least 5 minutes to get updated.
 * You must authenticate using an access token with the `read:org` scope to use this endpoint. GitHub Apps must have the `organization_admistration:read` permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var getActionsCacheUsageByRepoForOrg = {
    id: "actions/get-actions-cache-usage-by-repo-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#create-a-registration-token-for-an-organization


* Create a registration token for an organization
* Returns a token that you can pass to the `config` script. The token expires after one hour.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
 *
 * #### Example using registration token
 *
 * Configure your self-hosted runner, replacing `TOKEN` with the registration token provided by this endpoint.
 *
 * ```
 * ./config.sh --url https://github.com/octo-org --token TOKEN
 * ```
* @param org - The organization name. The name is not case sensitive.
*/
var createRegistrationTokenForOrg = {
    id: "actions/create-registration-token-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-labels-for-a-self-hosted-runner-for-an-organization


* List labels for a self-hosted runner for an organization
* Lists all labels for a self-hosted runner configured in an organization.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var listLabelsForSelfHostedRunnerForOrg = {
    id: "actions/list-labels-for-self-hosted-runner-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#add-custom-labels-to-a-self-hosted-runner-for-an-organization


* Add custom labels to a self-hosted runner for an organization
* Add custom labels to a self-hosted runner configured in an organization.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var addCustomLabelsToSelfHostedRunnerForOrg = {
    id: "actions/add-custom-labels-to-self-hosted-runner-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-custom-labels-for-a-self-hosted-runner-for-an-organization


* Set custom labels for a self-hosted runner for an organization
* Remove all previous custom labels and set the new custom labels for a specific
 * self-hosted runner configured in an organization.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var setCustomLabelsForSelfHostedRunnerForOrg = {
    id: "actions/set-custom-labels-for-self-hosted-runner-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#remove-all-custom-labels-from-a-self-hosted-runner-for-an-organization


* Remove all custom labels from a self-hosted runner for an organization
* Remove all custom labels from a self-hosted runner configured in an
 * organization. Returns the remaining read-only labels from the runner.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var removeAllCustomLabelsFromSelfHostedRunnerForOrg = {
    id: "actions/remove-all-custom-labels-from-self-hosted-runner-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/actions/cache#delete-a-github-actions-cache-for-a-repository-using-a-cache-id


* Delete a GitHub Actions cache for a repository (using a cache ID)
* Deletes a GitHub Actions cache for a repository, using a cache ID.
 *
 * You must authenticate using an access token with the `repo` scope to use this endpoint.
 *
 * GitHub Apps must have the `actions:write` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param cacheId - The unique identifier of the GitHub Actions cache.
*/
var deleteActionsCacheById = {
    id: "actions/delete-actions-cache-by-id",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-runner-applications-for-a-repository


* List runner applications for a repository
* Lists binaries for the runner application that you can download and run.
 *
 * You must authenticate using an access token with the `repo` scope to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var listRunnerApplicationsForRepo = {
    id: "actions/list-runner-applications-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-allowed-actions-for-an-organization


* Get allowed actions and reusable workflows for an organization
* Gets the selected actions and reusable workflows that are allowed in an organization. To use this endpoint, the organization permission policy for `allowed_actions` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an organization](#set-github-actions-permissions-for-an-organization).""
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `administration` organization permission to use this API.
* @param org - The organization name. The name is not case sensitive.
*/
var getAllowedActionsOrganization = {
    id: "actions/get-allowed-actions-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-allowed-actions-for-an-organization


* Set allowed actions and reusable workflows for an organization
* Sets the actions and reusable workflows that are allowed in an organization. To use this endpoint, the organization permission policy for `allowed_actions` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an organization](#set-github-actions-permissions-for-an-organization)."
 *
 * If the organization belongs to an enterprise that has `selected` actions and reusable workflows set at the enterprise level, then you cannot override any of the enterprise's allowed actions and reusable workflows settings.
 *
 * To use the `patterns_allowed` setting for private repositories, the organization must belong to an enterprise. If the organization does not belong to an enterprise, then the `patterns_allowed` setting only applies to public repositories in the organization.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `administration` organization permission to use this API.
* @param org - The organization name. The name is not case sensitive.
*/
var setAllowedActionsOrganization = {
    id: "actions/set-allowed-actions-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#download-job-logs-for-a-workflow-run


* Download job logs for a workflow run
* Gets a redirect URL to download a plain text file of logs for a workflow job. This link expires after 1 minute. Look
 * for `Location:` in the response header to find the URL for the download. Anyone with read access to the repository can
 * use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must
 * have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param jobId - The unique identifier of the job.
*/
var downloadJobLogsForWorkflowRun = {
    id: "actions/download-job-logs-for-workflow-run",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-workflow-access-level-to-a-repository


* Get the level of access for workflows outside of the repository
* Gets the level of access that workflows outside of the repository have to actions and reusable workflows in the repository.
 * This endpoint only applies to internal repositories. For more information, see "[Managing GitHub Actions settings for a repository](https://docs.github.com/repositories/managing-your-repositorys-settings-and-features/enabling-features-for-your-repository/managing-github-actions-settings-for-a-repository#allowing-access-to-components-in-an-internal-repository)."
 *
 * You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the
 * repository `administration` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getWorkflowAccessToRepository = {
    id: "actions/get-workflow-access-to-repository",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-workflow-access-to-a-repository


* Set the level of access for workflows outside of the repository
* Sets the level of access that workflows outside of the repository have to actions and reusable workflows in the repository.
 * This endpoint only applies to internal repositories. For more information, see "[Managing GitHub Actions settings for a repository](https://docs.github.com/repositories/managing-your-repositorys-settings-and-features/enabling-features-for-your-repository/managing-github-actions-settings-for-a-repository#allowing-access-to-components-in-an-internal-repository)."
 *
 * You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the
 * repository `administration` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var setWorkflowAccessToRepository = {
    id: "actions/set-workflow-access-to-repository",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-jobs-for-a-workflow-run


* List jobs for a workflow run
* Lists jobs for a workflow run. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint. You can use parameters to narrow the list of results. For more information about using parameters, see [Parameters](https://docs.github.com/rest/overview/resources-in-the-rest-api#parameters).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [filter] - Filters jobs by their `completed_at` timestamp. `latest` returns jobs from the most recent execution of the workflow run. `all` returns all jobs for a workflow run, including from old executions of the workflow run.
*/
var listJobsForWorkflowRun = {
    id: "actions/list-jobs-for-workflow-run",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#download-workflow-run-logs


* Download workflow run logs
* Gets a redirect URL to download an archive of log files for a workflow run. This link expires after 1 minute. Look for
 * `Location:` in the response header to find the URL for the download. Anyone with read access to the repository can use
 * this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have
 * the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
*/
var downloadWorkflowRunLogs = {
    id: "actions/download-workflow-run-logs",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#delete-workflow-run-logs


* Delete workflow run logs
* Deletes all logs for a workflow run. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `actions:write` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
*/
var deleteWorkflowRunLogs = {
    id: "actions/delete-workflow-run-logs",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-a-repository-public-key


* Get a repository public key
* Gets your public key, which you need to encrypt secrets. You need to encrypt a secret before you can create or update secrets. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `secrets` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getRepoPublicKey$2 = {
    id: "actions/get-repo-public-key",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#re-run-job-for-workflow-run


* Re-run a job from a workflow run
* Re-run a job and its dependent jobs in a workflow run. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `actions:write` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param jobId - The unique identifier of the job.
*/
var reRunJobForWorkflowRun = {
    id: "actions/re-run-job-for-workflow-run",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-a-self-hosted-runner-for-a-repository


* Get a self-hosted runner for a repository
* Gets a specific self-hosted runner configured in a repository.
 *
 * You must authenticate using an access token with the `repo` scope to use this
 * endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var getSelfHostedRunnerForRepo = {
    id: "actions/get-self-hosted-runner-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#delete-a-self-hosted-runner-from-a-repository


* Delete a self-hosted runner from a repository
* Forces the removal of a self-hosted runner from a repository. You can use this endpoint to completely remove the runner when the machine you were using no longer exists.
 *
 * You must authenticate using an access token with the `repo`
 * scope to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var deleteSelfHostedRunnerFromRepo = {
    id: "actions/delete-self-hosted-runner-from-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#re-run-a-workflow


* Re-run a workflow
* Re-runs your workflow run using its `id`. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `actions:write` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
*/
var reRunWorkflow = {
    id: "actions/re-run-workflow",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-default-workflow-permissions-for-a-repository


* Get default workflow permissions for a repository
* Gets the default workflow permissions granted to the `GITHUB_TOKEN` when running workflows in a repository,
 * as well as if GitHub Actions can submit approving pull request reviews.
 * For more information, see "[Setting the permissions of the GITHUB_TOKEN for your repository](https://docs.github.com/repositories/managing-your-repositorys-settings-and-features/enabling-features-for-your-repository/managing-github-actions-settings-for-a-repository#setting-the-permissions-of-the-github_token-for-your-repository)."
 *
 * You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the repository `administration` permission to use this API.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getGithubActionsDefaultWorkflowPermissionsRepository = {
    id: "actions/get-github-actions-default-workflow-permissions-repository",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-default-workflow-permissions-for-a-repository


* Set default workflow permissions for a repository
* Sets the default workflow permissions granted to the `GITHUB_TOKEN` when running workflows in a repository, and sets if GitHub Actions
 * can submit approving pull request reviews.
 * For more information, see "[Setting the permissions of the GITHUB_TOKEN for your repository](https://docs.github.com/repositories/managing-your-repositorys-settings-and-features/enabling-features-for-your-repository/managing-github-actions-settings-for-a-repository#setting-the-permissions-of-the-github_token-for-your-repository)."
 *
 * You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the repository `administration` permission to use this API.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var setGithubActionsDefaultWorkflowPermissionsRepository = {
    id: "actions/set-github-actions-default-workflow-permissions-repository",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#create-a-remove-token-for-a-repository


* Create a remove token for a repository
* Returns a token that you can pass to remove a self-hosted runner from a repository. The token expires after one hour.
 * You must authenticate using an access token with the `repo` scope to use this endpoint.
 *
 * #### Example using remove token
 *
 * To remove your self-hosted runner from a repository, replace TOKEN with the remove token provided by this endpoint.
 *
 * ```
 * ./config.sh remove --token TOKEN
 * ```
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createRemoveTokenForRepo = {
    id: "actions/create-remove-token-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#cancel-a-workflow-run


* Cancel a workflow run
* Cancels a workflow run using its `id`. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `actions:write` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
*/
var cancelWorkflowRun = {
    id: "actions/cancel-workflow-run",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-workflow-run-usage


* Get workflow run usage
* Gets the number of billable minutes and total run time for a specific workflow run. Billable minutes only apply to workflows in private repositories that use GitHub-hosted runners. Usage is listed for each GitHub-hosted runner operating system in milliseconds. Any job re-runs are also included in the usage. The usage does not include the multiplier for macOS and Windows runners and is not rounded up to the nearest whole minute. For more information, see "[Managing billing for GitHub Actions](https://docs.github.com/github/setting-up-and-managing-billing-and-payments-on-github/managing-billing-for-github-actions)".
 *
 * Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
*/
var getWorkflowRunUsage = {
    id: "actions/get-workflow-run-usage",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-a-self-hosted-runner-group-for-an-organization


* Get a self-hosted runner group for an organization
* The self-hosted runner groups REST API is available with GitHub Enterprise Cloud. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)."
 *
 * Gets a specific self-hosted runner group for an organization.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
*/
var getSelfHostedRunnerGroupForOrg = {
    id: "actions/get-self-hosted-runner-group-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#delete-a-self-hosted-runner-group-from-an-organization


* Delete a self-hosted runner group from an organization
* The self-hosted runner groups REST API is available with GitHub Enterprise Cloud. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)."
 *
 * Deletes a self-hosted runner group for an organization.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
*/
var deleteSelfHostedRunnerGroupFromOrg = {
    id: "actions/delete-self-hosted-runner-group-from-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#update-a-self-hosted-runner-group-for-an-organization


* Update a self-hosted runner group for an organization
* The self-hosted runner groups REST API is available with GitHub Enterprise Cloud. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)."
 *
 * Updates the `name` and `visibility` of a self-hosted runner group in an organization.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
*/
var updateSelfHostedRunnerGroupForOrg = {
    id: "actions/update-self-hosted-runner-group-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#approve-a-workflow-run-for-a-fork-pull-request


* Approve a workflow run for a fork pull request
* Approves a workflow run for a pull request from a public fork of a first time contributor. For more information, see ["Approving workflow runs from public forks](https://docs.github.com/actions/managing-workflow-runs/approving-workflow-runs-from-public-forks)."
 *
 * You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `actions:write` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
*/
var approveWorkflowRun = {
    id: "actions/approve-workflow-run",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-a-repository-secret


* Get a repository secret
* Gets a single repository secret without revealing its encrypted value. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `secrets` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var getRepoSecret$2 = {
    id: "actions/get-repo-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#create-or-update-a-repository-secret


* Create or update a repository secret
* Creates or updates a repository secret with an encrypted value. Encrypt your secret using
 * [LibSodium](https://libsodium.gitbook.io/doc/bindings_for_other_languages). You must authenticate using an access
 * token with the `repo` scope to use this endpoint. GitHub Apps must have the `secrets` repository permission to use
 * this endpoint.
 *
 * #### Example encrypting a secret using Node.js
 *
 * Encrypt your secret using the [tweetsodium](https://github.com/github/tweetsodium) library.
 *
 * ```
 * const sodium = require('tweetsodium');
 *
 * const key = "base64-encoded-public-key";
 * const value = "plain-text-secret";
 *
 * // Convert the message and key to Uint8Array's (Buffer implements that interface)
 * const messageBytes = Buffer.from(value);
 * const keyBytes = Buffer.from(key, 'base64');
 *
 * // Encrypt using LibSodium.
 * const encryptedBytes = sodium.seal(messageBytes, keyBytes);
 *
 * // Base64 the encrypted secret
 * const encrypted = Buffer.from(encryptedBytes).toString('base64');
 *
 * console.log(encrypted);
 * ```
 *
 *
 * #### Example encrypting a secret using Python
 *
 * Encrypt your secret using [pynacl](https://pynacl.readthedocs.io/en/latest/public/#nacl-public-sealedbox) with Python 3.
 *
 * ```
 * from base64 import b64encode
 * from nacl import encoding, public
 *
 * def encrypt(public_key: str, secret_value: str) -> str:
 * """Encrypt a Unicode string using the public key."""
 * public_key = public.PublicKey(public_key.encode("utf-8"), encoding.Base64Encoder())
 * sealed_box = public.SealedBox(public_key)
 * encrypted = sealed_box.encrypt(secret_value.encode("utf-8"))
 * return b64encode(encrypted).decode("utf-8")
 * ```
 *
 * #### Example encrypting a secret using C#
 *
 * Encrypt your secret using the [Sodium.Core](https://www.nuget.org/packages/Sodium.Core/) package.
 *
 * ```
 * var secretValue = System.Text.Encoding.UTF8.GetBytes("mySecret");
 * var publicKey = Convert.FromBase64String("2Sg8iYjAxxmI2LvUXpJjkYrMxURPc8r+dB7TJyvvcCU=");
 *
 * var sealedPublicKeyBox = Sodium.SealedPublicKeyBox.Create(secretValue, publicKey);
 *
 * Console.WriteLine(Convert.ToBase64String(sealedPublicKeyBox));
 * ```
 *
 * #### Example encrypting a secret using Ruby
 *
 * Encrypt your secret using the [rbnacl](https://github.com/RubyCrypto/rbnacl) gem.
 *
 * ```ruby
 * require "rbnacl"
 * require "base64"
 *
 * key = Base64.decode64("+ZYvJDZMHUfBkJdyq5Zm9SKqeuBQ4sj+6sfjlH4CgG0=")
 * public_key = RbNaCl::PublicKey.new(key)
 *
 * box = RbNaCl::Boxes::Sealed.from_public_key(public_key)
 * encrypted_secret = box.encrypt("my_secret")
 *
 * # Print the base64 encoded secret
 * puts Base64.strict_encode64(encrypted_secret)
 * ```
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var createOrUpdateRepoSecret$2 = {
    id: "actions/create-or-update-repo-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#delete-a-repository-secret


* Delete a repository secret
* Deletes a secret in a repository using the secret name. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `secrets` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var deleteRepoSecret$2 = {
    id: "actions/delete-repo-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/actions/oidc#get-the-opt-out-flag-of-an-oidc-subject-claim-customization-for-a-repository


* Get the opt-out flag of an OIDC subject claim customization for a repository
* Gets the `opt-out` flag of a GitHub Actions OpenID Connect (OIDC) subject claim customization for a repository.
 * You must authenticate using an access token with the `repo` scope to use this
 * endpoint. GitHub Apps must have the `organization_administration:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getCustomOidcSubClaimForRepo = {
    id: "actions/get-custom-oidc-sub-claim-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/actions/oidc#set-the-opt-out-flag-of-an-oidc-subject-claim-customization-for-a-repository


* Set the opt-out flag of an OIDC subject claim customization for a repository
* Sets the `opt-out` flag of a GitHub Actions OpenID Connect (OIDC) subject claim customization for a repository.
 * You must authenticate using an access token with the `repo` scope to use this
 * endpoint. GitHub Apps must have the `actions:write` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var setCustomOidcSubClaimForRepo = {
    id: "actions/set-custom-oidc-sub-claim-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#remove-a-custom-label-from-a-self-hosted-runner-for-an-organization


* Remove a custom label from a self-hosted runner for an organization
* Remove a custom label from a self-hosted runner configured
 * in an organization. Returns the remaining labels from the runner.
 *
 * This endpoint returns a `404 Not Found` status if the custom label is not
 * present on the runner.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
* @param name - The name of a self-hosted runner's custom label.
*/
var removeCustomLabelFromSelfHostedRunnerForOrg = {
    id: "actions/remove-custom-label-from-self-hosted-runner-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-an-artifact


* Get an artifact
* Gets a specific artifact for a workflow run. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param artifactId - The unique identifier of the artifact.
*/
var getArtifact = {
    id: "actions/get-artifact",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#delete-an-artifact


* Delete an artifact
* Deletes an artifact for a workflow run. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `actions:write` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param artifactId - The unique identifier of the artifact.
*/
var deleteArtifact = {
    id: "actions/delete-artifact",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-the-review-history-for-a-workflow-run


* Get the review history for a workflow run
* Anyone with read access to the repository can use this endpoint. If the repository is private, you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
*/
var getReviewsForRun = {
    id: "actions/get-reviews-for-run",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-workflow-run-artifacts


* List workflow run artifacts
* Lists artifacts for a workflow run. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listWorkflowRunArtifacts = {
    id: "actions/list-workflow-run-artifacts",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-a-workflow


* Get a workflow
* Gets a specific workflow. You can replace `workflow_id` with the workflow file name. For example, you could use `main.yaml`. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getWorkflow = {
    id: "actions/get-workflow",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-default-workflow-permissions-for-an-enterprise


* Get default workflow permissions for an enterprise
* Gets the default workflow permissions granted to the `GITHUB_TOKEN` when running workflows in an enterprise,
 * as well as whether GitHub Actions can submit approving pull request reviews. For more information, see
 * "[Enforcing a policy for workflow permissions in your enterprise](https://docs.github.com/enterprise-cloud@latest/admin/policies/enforcing-policies-for-your-enterprise/enforcing-policies-for-github-actions-in-your-enterprise#enforcing-a-policy-for-workflow-permissions-in-your-enterprise)."
 *
 * You must authenticate using an access token with the `admin:enterprise` scope to use this endpoint.
 * GitHub Apps must have the `enterprise_administration:write` permission to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var getGithubActionsDefaultWorkflowPermissionsEnterprise = {
    id: "actions/get-github-actions-default-workflow-permissions-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-default-workflow-permissions-for-an-enterprise


* Set default workflow permissions for an enterprise
* Sets the default workflow permissions granted to the `GITHUB_TOKEN` when running workflows in an enterprise, and sets
 * whether GitHub Actions can submit approving pull request reviews. For more information, see
 * "[Enforcing a policy for workflow permissions in your enterprise](https://docs.github.com/enterprise-cloud@latest/admin/policies/enforcing-policies-for-your-enterprise/enforcing-policies-for-github-actions-in-your-enterprise#enforcing-a-policy-for-workflow-permissions-in-your-enterprise)."
 *
 * You must authenticate using an access token with the `admin:enterprise` scope to use this endpoint.
 * GitHub Apps must have the `enterprise_administration:write` permission to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var setGithubActionsDefaultWorkflowPermissionsEnterprise = {
    id: "actions/set-github-actions-default-workflow-permissions-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-selected-repositories-for-an-organization-secret


* List selected repositories for an organization secret
* Lists all repositories that have been selected when the `visibility` for repository access to a secret is set to `selected`. You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param secretName - The name of the secret.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listSelectedReposForOrgSecret$1 = {
    id: "actions/list-selected-repos-for-org-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-selected-repositories-for-an-organization-secret


* Set selected repositories for an organization secret
* Replaces all repositories for an organization secret when the `visibility` for repository access is set to `selected`. The visibility is set when you [Create or update an organization secret](https://docs.github.com/rest/reference/actions#create-or-update-an-organization-secret). You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var setSelectedReposForOrgSecret$1 = {
    id: "actions/set-selected-repos-for-org-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#create-a-registration-token-for-a-repository


* Create a registration token for a repository
* Returns a token that you can pass to the `config` script. The token expires after one hour. You must authenticate
 * using an access token with the `repo` scope to use this endpoint.
 *
 * #### Example using registration token
 *
 * Configure your self-hosted runner, replacing `TOKEN` with the registration token provided by this endpoint.
 *
 * ```
 * ./config.sh --url https://github.com/octo-org/octo-repo-artifacts --token TOKEN
 * ```
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createRegistrationTokenForRepo = {
    id: "actions/create-registration-token-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-labels-for-a-self-hosted-runner-for-a-repository


* List labels for a self-hosted runner for a repository
* Lists all labels for a self-hosted runner configured in a repository.
 *
 * You must authenticate using an access token with the `repo` scope to use this
 * endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var listLabelsForSelfHostedRunnerForRepo = {
    id: "actions/list-labels-for-self-hosted-runner-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#add-custom-labels-to-a-self-hosted-runner-for-a-repository


* Add custom labels to a self-hosted runner for a repository
* Add custom labels to a self-hosted runner configured in a repository.
 *
 * You must authenticate using an access token with the `repo` scope to use this
 * endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var addCustomLabelsToSelfHostedRunnerForRepo = {
    id: "actions/add-custom-labels-to-self-hosted-runner-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-custom-labels-for-a-self-hosted-runner-for-a-repository


* Set custom labels for a self-hosted runner for a repository
* Remove all previous custom labels and set the new custom labels for a specific
 * self-hosted runner configured in a repository.
 *
 * You must authenticate using an access token with the `repo` scope to use this
 * endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var setCustomLabelsForSelfHostedRunnerForRepo = {
    id: "actions/set-custom-labels-for-self-hosted-runner-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#remove-all-custom-labels-from-a-self-hosted-runner-for-a-repository


* Remove all custom labels from a self-hosted runner for a repository
* Remove all custom labels from a self-hosted runner configured in a
 * repository. Returns the remaining read-only labels from the runner.
 *
 * You must authenticate using an access token with the `repo` scope to use this
 * endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var removeAllCustomLabelsFromSelfHostedRunnerForRepo = {
    id: "actions/remove-all-custom-labels-from-self-hosted-runner-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-allowed-actions-for-a-repository


* Get allowed actions and reusable workflows for a repository
* Gets the settings for selected actions and reusable workflows that are allowed in a repository. To use this endpoint, the repository policy for `allowed_actions` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for a repository](#set-github-actions-permissions-for-a-repository)."
 *
 * You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `administration` repository permission to use this API.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getAllowedActionsRepository = {
    id: "actions/get-allowed-actions-repository",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-allowed-actions-for-a-repository


* Set allowed actions and reusable workflows for a repository
* Sets the actions and reusable workflows that are allowed in a repository. To use this endpoint, the repository permission policy for `allowed_actions` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for a repository](#set-github-actions-permissions-for-a-repository)."
 *
 * If the repository belongs to an organization or enterprise that has `selected` actions and reusable workflows set at the organization or enterprise levels, then you cannot override any of the allowed actions and reusable workflows settings.
 *
 * To use the `patterns_allowed` setting for private repositories, the repository must belong to an enterprise. If the repository does not belong to an enterprise, then the `patterns_allowed` setting only applies to public repositories.
 *
 * You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `administration` repository permission to use this API.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var setAllowedActionsRepository = {
    id: "actions/set-allowed-actions-repository",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-workflow-runs


* List workflow runs
* List all workflow runs for a workflow. You can replace `workflow_id` with the workflow file name. For example, you could use `main.yaml`. You can use parameters to narrow the list of results. For more information about using parameters, see [Parameters](https://docs.github.com/rest/overview/resources-in-the-rest-api#parameters).
 *
 * Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [branch] - Returns workflow runs associated with a branch. Use the name of the branch of the `push`.
* @param [event] - Returns workflow run triggered by the event you specify. For example, `push`, `pull_request` or `issue`. For more information, see "[Events that trigger workflows](https://docs.github.com/en/actions/automating-your-workflow-with-github-actions/events-that-trigger-workflows)."
* @param [status] - Returns workflow runs with the check run `status` or `conclusion` that you specify. For example, a conclusion can be `success` or a status can be `in_progress`. Only GitHub can set a status of `waiting` or `requested`. For a list of the possible `status` and `conclusion` options, see "[Create a check run](https://docs.github.com/rest/reference/checks#create-a-check-run)."
* @param [checkSuiteId] - Returns workflow runs with the `check_suite_id` that you specify.
* @param [actor] - Returns someone's workflow runs. Use the login for the user who created the `push` associated with the check suite or workflow run.
* @param [created] - Returns workflow runs created within the given date-time range. For more information on the syntax, see "[Understanding the search syntax](https://docs.github.com/search-github/getting-started-with-searching-on-github/understanding-the-search-syntax#query-for-dates)."
* @param [excludePullRequests=false] - If `true` pull requests are omitted from the response (empty array).
*/
var listWorkflowRuns = {
    id: "actions/list-workflow-runs",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions/oidc#set-actions-oidc-custom-issuer-policy-for-enterprise


* Set the GitHub Actions OIDC custom issuer policy for an enterprise
* Sets the GitHub Actions OpenID Connect (OIDC) custom issuer policy for an enterprise.
 * You must authenticate using an access token with the `admin:enterprise` scope to use this endpoint.
 * GitHub Apps must have the `enterprise_administration:write` permission to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var setActionsOidcCustomIssuerPolicyForEnterprise = {
    id: "actions/set-actions-oidc-custom-issuer-policy-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-self-hosted-runners-in-a-group-for-an-organization


* List self-hosted runners in a group for an organization
* The self-hosted runner groups REST API is available with GitHub Enterprise Cloud. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)."
 *
 * Lists self-hosted runners that are in a specific organization group.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listSelfHostedRunnersInGroupForOrg = {
    id: "actions/list-self-hosted-runners-in-group-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-self-hosted-runners-in-a-group-for-an-organization


* Set self-hosted runners in a group for an organization
* The self-hosted runner groups REST API is available with GitHub Enterprise Cloud. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)."
 *
 * Replaces the list of self-hosted runners that are part of an organization runner group.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
*/
var setSelfHostedRunnersInGroupForOrg = {
    id: "actions/set-self-hosted-runners-in-group-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#enable-a-selected-repository-for-github-actions-in-an-organization


* Enable a selected repository for GitHub Actions in an organization
* Adds a repository to the list of selected repositories that are enabled for GitHub Actions in an organization. To use this endpoint, the organization permission policy for `enabled_repositories` must be must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an organization](#set-github-actions-permissions-for-an-organization)."
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `administration` organization permission to use this API.
* @param org - The organization name. The name is not case sensitive.
* @param repositoryId - The unique identifier of the repository.
*/
var enableSelectedRepositoryGithubActionsOrganization = {
    id: "actions/enable-selected-repository-github-actions-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#disable-a-selected-repository-for-github-actions-in-an-organization


* Disable a selected repository for GitHub Actions in an organization
* Removes a repository from the list of selected repositories that are enabled for GitHub Actions in an organization. To use this endpoint, the organization permission policy for `enabled_repositories` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an organization](#set-github-actions-permissions-for-an-organization)."
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `administration` organization permission to use this API.
* @param org - The organization name. The name is not case sensitive.
* @param repositoryId - The unique identifier of the repository.
*/
var disableSelectedRepositoryGithubActionsOrganization = {
    id: "actions/disable-selected-repository-github-actions-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#enable-a-workflow


* Enable a workflow
* Enables a workflow and sets the `state` of the workflow to `active`. You can replace `workflow_id` with the workflow file name. For example, you could use `main.yaml`.
 *
 * You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `actions:write` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var enableWorkflow = {
    id: "actions/enable-workflow",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-workflow-usage


* Get workflow usage
* Gets the number of billable minutes used by a specific workflow during the current billing cycle. Billable minutes only apply to workflows in private repositories that use GitHub-hosted runners. Usage is listed for each GitHub-hosted runner operating system in milliseconds. Any job re-runs are also included in the usage. The usage does not include the multiplier for macOS and Windows runners and is not rounded up to the nearest whole minute. For more information, see "[Managing billing for GitHub Actions](https://docs.github.com/github/setting-up-and-managing-billing-and-payments-on-github/managing-billing-for-github-actions)".
 *
 * You can replace `workflow_id` with the workflow file name. For example, you could use `main.yaml`. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getWorkflowUsage = {
    id: "actions/get-workflow-usage",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#re-run-workflow-failed-jobs


* Re-run failed jobs from a workflow run
* Re-run all of the failed jobs and their dependent jobs in a workflow run using the `id` of the workflow run. You must authenticate using an access token with the `repo` scope to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
*/
var reRunWorkflowFailedJobs = {
    id: "actions/re-run-workflow-failed-jobs",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#disable-a-workflow


* Disable a workflow
* Disables a workflow and sets the `state` of the workflow to `disabled_manually`. You can replace `workflow_id` with the workflow file name. For example, you could use `main.yaml`.
 *
 * You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `actions:write` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var disableWorkflow = {
    id: "actions/disable-workflow",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#remove-a-custom-label-from-a-self-hosted-runner-for-a-repository


* Remove a custom label from a self-hosted runner for a repository
* Remove a custom label from a self-hosted runner configured
 * in a repository. Returns the remaining labels from the runner.
 *
 * This endpoint returns a `404 Not Found` status if the custom label is not
 * present on the runner.
 *
 * You must authenticate using an access token with the `repo` scope to use this
 * endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
* @param name - The name of a self-hosted runner's custom label.
*/
var removeCustomLabelFromSelfHostedRunnerForRepo = {
    id: "actions/remove-custom-label-from-self-hosted-runner-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-pending-deployments-for-a-workflow-run


* Get pending deployments for a workflow run
* Get all deployment environments for a workflow run that are waiting for protection rules to pass.
 *
 * Anyone with read access to the repository can use this endpoint. If the repository is private, you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
*/
var getPendingDeploymentsForRun = {
    id: "actions/get-pending-deployments-for-run",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#review-pending-deployments-for-a-workflow-run


* Review pending deployments for a workflow run
* Approve or reject pending deployments that are waiting on approval by a required reviewer.
 *
 * Required reviewers with read access to the repository contents and deployments can use this endpoint. Required reviewers must authenticate using an access token with the `repo` scope to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
*/
var reviewPendingDeploymentsForRun = {
    id: "actions/review-pending-deployments-for-run",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-repository-access-to-a-self-hosted-runner-group-in-an-organization


* List repository access to a self-hosted runner group in an organization
* The self-hosted runner groups REST API is available with GitHub Enterprise Cloud and GitHub Enterprise Server. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)."
 *
 * Lists the repositories with access to a self-hosted runner group configured in an organization.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listRepoAccessToSelfHostedRunnerGroupInOrg = {
    id: "actions/list-repo-access-to-self-hosted-runner-group-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-repository-access-to-a-self-hosted-runner-group-in-an-organization


* Set repository access for a self-hosted runner group in an organization
* The self-hosted runner groups REST API is available with GitHub Enterprise Cloud. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)."
 *
 * Replaces the list of repositories that have access to a self-hosted runner group configured in an organization.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
*/
var setRepoAccessToSelfHostedRunnerGroupInOrg = {
    id: "actions/set-repo-access-to-self-hosted-runner-group-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#create-a-workflow-dispatch-event


* Create a workflow dispatch event
* You can use this endpoint to manually trigger a GitHub Actions workflow run. You can replace `workflow_id` with the workflow file name. For example, you could use `main.yaml`.
 *
 * You must configure your GitHub Actions workflow to run when the [`workflow_dispatch` webhook](/developers/webhooks-and-events/webhook-events-and-payloads#workflow_dispatch) event occurs. The `inputs` are configured in the workflow file. For more information about how to configure the `workflow_dispatch` event in the workflow file, see "[Events that trigger workflows](/actions/reference/events-that-trigger-workflows#workflow_dispatch)."
 *
 * You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `actions:write` permission to use this endpoint. For more information, see "[Creating a personal access token for the command line](https://docs.github.com/articles/creating-a-personal-access-token-for-the-command-line)."
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createWorkflowDispatch = {
    id: "actions/create-workflow-dispatch",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-a-workflow-run-attempt


* Get a workflow run attempt
* Gets a specific workflow run attempt. Anyone with read access to the repository
 * can use this endpoint. If the repository is private you must use an access token
 * with the `repo` scope. GitHub Apps must have the `actions:read` permission to
 * use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
* @param attemptNumber - The attempt number of the workflow run.
* @param [excludePullRequests=false] - If `true` pull requests are omitted from the response (empty array).
*/
var getWorkflowRunAttempt = {
    id: "actions/get-workflow-run-attempt",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-environment-secrets


* List environment secrets
* Lists all secrets available in an environment without revealing their encrypted values. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `secrets` repository permission to use this endpoint.
* @param repositoryId - The unique identifier of the repository.
* @param environmentName - The name of the environment
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listEnvironmentSecrets = {
    id: "actions/list-environment-secrets",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#add-selected-repository-to-an-organization-secret


* Add selected repository to an organization secret
* Adds a repository to an organization secret when the `visibility` for repository access is set to `selected`. The visibility is set when you [Create or update an organization secret](https://docs.github.com/rest/reference/actions#create-or-update-an-organization-secret). You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param secretName - The name of the secret.
* @param repositoryId
*/
var addSelectedRepoToOrgSecret$1 = {
    id: "actions/add-selected-repo-to-org-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#remove-selected-repository-from-an-organization-secret


* Remove selected repository from an organization secret
* Removes a repository from an organization secret when the `visibility` for repository access is set to `selected`. The visibility is set when you [Create or update an organization secret](https://docs.github.com/rest/reference/actions#create-or-update-an-organization-secret). You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param secretName - The name of the secret.
* @param repositoryId
*/
var removeSelectedRepoFromOrgSecret$1 = {
    id: "actions/remove-selected-repo-from-org-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#download-an-artifact


* Download an artifact
* Gets a redirect URL to download an archive for a repository. This URL expires after 1 minute. Look for `Location:` in
 * the response header to find the URL for the download. The `:archive_format` must be `zip`. Anyone with read access to
 * the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope.
 * GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param artifactId - The unique identifier of the artifact.
* @param archiveFormat
*/
var downloadArtifact = {
    id: "actions/download-artifact",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#add-a-self-hosted-runner-to-a-group-for-an-organization


* Add a self-hosted runner to a group for an organization
* The self-hosted runner groups REST API is available with GitHub Enterprise Cloud. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)."
 *
 *
 * Adds a self-hosted runner to a runner group configured in an organization.
 *
 * You must authenticate using an access token with the `admin:org`
 * scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
*/
var addSelfHostedRunnerToGroupForOrg = {
    id: "actions/add-self-hosted-runner-to-group-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#remove-a-self-hosted-runner-from-a-group-for-an-organization


* Remove a self-hosted runner from a group for an organization
* The self-hosted runner groups REST API is available with GitHub Enterprise Cloud. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)."
 *
 *
 * Removes a self-hosted runner from a group configured in an organization. The runner is then returned to the default group.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerId - Unique identifier of the self-hosted runner.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
*/
var removeSelfHostedRunnerFromGroupForOrg = {
    id: "actions/remove-self-hosted-runner-from-group-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-jobs-for-a-workflow-run-attempt


* List jobs for a workflow run attempt
* Lists jobs for a specific workflow run attempt. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `actions:read` permission to use this endpoint. You can use parameters to narrow the list of results. For more information about using parameters, see [Parameters](https://docs.github.com/rest/overview/resources-in-the-rest-api#parameters).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
* @param attemptNumber - The attempt number of the workflow run.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listJobsForWorkflowRunAttempt = {
    id: "actions/list-jobs-for-workflow-run-attempt",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#download-workflow-run-attempt-logs


* Download workflow run attempt logs
* Gets a redirect URL to download an archive of log files for a specific workflow run attempt. This link expires after
 * 1 minute. Look for `Location:` in the response header to find the URL for the download. Anyone with read access to
 * the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope.
 * GitHub Apps must have the `actions:read` permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param runId - The unique identifier of the workflow run.
* @param attemptNumber - The attempt number of the workflow run.
*/
var downloadWorkflowRunAttemptLogs = {
    id: "actions/download-workflow-run-attempt-logs",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#add-repository-acess-to-a-self-hosted-runner-group-in-an-organization


* Add repository access to a self-hosted runner group in an organization
* The self-hosted runner groups REST API is available with GitHub Enterprise Cloud. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)."
 *
 *
 * Adds a repository to the list of selected repositories that can access a self-hosted runner group. The runner group must have `visibility` set to `selected`. For more information, see "[Create a self-hosted runner group for an organization](#create-a-self-hosted-runner-group-for-an-organization)."
 *
 * You must authenticate using an access token with the `admin:org`
 * scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
* @param repositoryId - The unique identifier of the repository.
*/
var addRepoAccessToSelfHostedRunnerGroupInOrg = {
    id: "actions/add-repo-access-to-self-hosted-runner-group-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#remove-repository-access-to-a-self-hosted-runner-group-in-an-organization


* Remove repository access to a self-hosted runner group in an organization
* The self-hosted runner groups REST API is available with GitHub Enterprise Cloud. For more information, see "[GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products)."
 *
 *
 * Removes a repository from the list of selected repositories that can access a self-hosted runner group. The runner group must have `visibility` set to `selected`. For more information, see "[Create a self-hosted runner group for an organization](#create-a-self-hosted-runner-group-for-an-organization)."
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
* @param repositoryId - The unique identifier of the repository.
*/
var removeRepoAccessToSelfHostedRunnerGroupInOrg = {
    id: "actions/remove-repo-access-to-self-hosted-runner-group-in-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-an-environment-public-key


* Get an environment public key
* Get the public key for an environment, which you need to encrypt environment secrets. You need to encrypt a secret before you can create or update secrets. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `secrets` repository permission to use this endpoint.
* @param repositoryId - The unique identifier of the repository.
* @param environmentName - The name of the environment
*/
var getEnvironmentPublicKey = {
    id: "actions/get-environment-public-key",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-an-environment-secret


* Get an environment secret
* Gets a single environment secret without revealing its encrypted value. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `secrets` repository permission to use this endpoint.
* @param secretName - The name of the secret.
* @param repositoryId - The unique identifier of the repository.
* @param environmentName - The name of the environment
*/
var getEnvironmentSecret = {
    id: "actions/get-environment-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#create-or-update-an-environment-secret


* Create or update an environment secret
* Creates or updates an environment secret with an encrypted value. Encrypt your secret using
 * [LibSodium](https://libsodium.gitbook.io/doc/bindings_for_other_languages). You must authenticate using an access
 * token with the `repo` scope to use this endpoint. GitHub Apps must have the `secrets` repository permission to use
 * this endpoint.
 *
 * #### Example encrypting a secret using Node.js
 *
 * Encrypt your secret using the [tweetsodium](https://github.com/github/tweetsodium) library.
 *
 * ```
 * const sodium = require('tweetsodium');
 *
 * const key = "base64-encoded-public-key";
 * const value = "plain-text-secret";
 *
 * // Convert the message and key to Uint8Array's (Buffer implements that interface)
 * const messageBytes = Buffer.from(value);
 * const keyBytes = Buffer.from(key, 'base64');
 *
 * // Encrypt using LibSodium.
 * const encryptedBytes = sodium.seal(messageBytes, keyBytes);
 *
 * // Base64 the encrypted secret
 * const encrypted = Buffer.from(encryptedBytes).toString('base64');
 *
 * console.log(encrypted);
 * ```
 *
 *
 * #### Example encrypting a secret using Python
 *
 * Encrypt your secret using [pynacl](https://pynacl.readthedocs.io/en/latest/public/#nacl-public-sealedbox) with Python 3.
 *
 * ```
 * from base64 import b64encode
 * from nacl import encoding, public
 *
 * def encrypt(public_key: str, secret_value: str) -> str:
 * """Encrypt a Unicode string using the public key."""
 * public_key = public.PublicKey(public_key.encode("utf-8"), encoding.Base64Encoder())
 * sealed_box = public.SealedBox(public_key)
 * encrypted = sealed_box.encrypt(secret_value.encode("utf-8"))
 * return b64encode(encrypted).decode("utf-8")
 * ```
 *
 * #### Example encrypting a secret using C#
 *
 * Encrypt your secret using the [Sodium.Core](https://www.nuget.org/packages/Sodium.Core/) package.
 *
 * ```
 * var secretValue = System.Text.Encoding.UTF8.GetBytes("mySecret");
 * var publicKey = Convert.FromBase64String("2Sg8iYjAxxmI2LvUXpJjkYrMxURPc8r+dB7TJyvvcCU=");
 *
 * var sealedPublicKeyBox = Sodium.SealedPublicKeyBox.Create(secretValue, publicKey);
 *
 * Console.WriteLine(Convert.ToBase64String(sealedPublicKeyBox));
 * ```
 *
 * #### Example encrypting a secret using Ruby
 *
 * Encrypt your secret using the [rbnacl](https://github.com/RubyCrypto/rbnacl) gem.
 *
 * ```ruby
 * require "rbnacl"
 * require "base64"
 *
 * key = Base64.decode64("+ZYvJDZMHUfBkJdyq5Zm9SKqeuBQ4sj+6sfjlH4CgG0=")
 * public_key = RbNaCl::PublicKey.new(key)
 *
 * box = RbNaCl::Boxes::Sealed.from_public_key(public_key)
 * encrypted_secret = box.encrypt("my_secret")
 *
 * # Print the base64 encoded secret
 * puts Base64.strict_encode64(encrypted_secret)
 * ```
* @param secretName - The name of the secret.
* @param repositoryId - The unique identifier of the repository.
* @param environmentName - The name of the environment
*/
var createOrUpdateEnvironmentSecret = {
    id: "actions/create-or-update-environment-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#delete-an-environment-secret


* Delete an environment secret
* Deletes a secret in an environment using the secret name. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `secrets` repository permission to use this endpoint.
* @param secretName - The name of the secret.
* @param repositoryId - The unique identifier of the repository.
* @param environmentName - The name of the environment
*/
var deleteEnvironmentSecret = {
    id: "actions/delete-environment-secret",
    clientId: "github",
    version: "1.1.5",
};

var actions = /*#__PURE__*/Object.freeze({
  __proto__: null,
  listSelfHostedRunnersForOrg: listSelfHostedRunnersForOrg,
  listOrgSecrets: listOrgSecrets$1,
  getActionsCacheUsageForOrg: getActionsCacheUsageForOrg,
  getGithubActionsPermissionsOrganization: getGithubActionsPermissionsOrganization,
  setGithubActionsPermissionsOrganization: setGithubActionsPermissionsOrganization,
  listSelfHostedRunnerGroupsForOrg: listSelfHostedRunnerGroupsForOrg,
  createSelfHostedRunnerGroupForOrg: createSelfHostedRunnerGroupForOrg,
  listWorkflowRunsForRepo: listWorkflowRunsForRepo,
  getActionsCacheList: getActionsCacheList,
  deleteActionsCacheByKey: deleteActionsCacheByKey,
  listRunnerApplicationsForOrg: listRunnerApplicationsForOrg,
  listSelfHostedRunnersForRepo: listSelfHostedRunnersForRepo,
  listRepoSecrets: listRepoSecrets$2,
  getOrgPublicKey: getOrgPublicKey$1,
  getSelfHostedRunnerForOrg: getSelfHostedRunnerForOrg,
  deleteSelfHostedRunnerFromOrg: deleteSelfHostedRunnerFromOrg,
  listArtifactsForRepo: listArtifactsForRepo,
  listRepoWorkflows: listRepoWorkflows,
  getGithubActionsDefaultWorkflowPermissionsOrganization: getGithubActionsDefaultWorkflowPermissionsOrganization,
  setGithubActionsDefaultWorkflowPermissionsOrganization: setGithubActionsDefaultWorkflowPermissionsOrganization,
  createRemoveTokenForOrg: createRemoveTokenForOrg,
  getOrgSecret: getOrgSecret$1,
  createOrUpdateOrgSecret: createOrUpdateOrgSecret$1,
  deleteOrgSecret: deleteOrgSecret$1,
  getActionsCacheUsage: getActionsCacheUsage,
  getGithubActionsPermissionsRepository: getGithubActionsPermissionsRepository,
  setGithubActionsPermissionsRepository: setGithubActionsPermissionsRepository,
  getJobForWorkflowRun: getJobForWorkflowRun,
  getWorkflowRun: getWorkflowRun,
  deleteWorkflowRun: deleteWorkflowRun,
  listSelectedRepositoriesEnabledGithubActionsOrganization: listSelectedRepositoriesEnabledGithubActionsOrganization,
  setSelectedRepositoriesEnabledGithubActionsOrganization: setSelectedRepositoriesEnabledGithubActionsOrganization,
  getActionsCacheUsageForEnterprise: getActionsCacheUsageForEnterprise,
  getActionsCacheUsageByRepoForOrg: getActionsCacheUsageByRepoForOrg,
  createRegistrationTokenForOrg: createRegistrationTokenForOrg,
  listLabelsForSelfHostedRunnerForOrg: listLabelsForSelfHostedRunnerForOrg,
  addCustomLabelsToSelfHostedRunnerForOrg: addCustomLabelsToSelfHostedRunnerForOrg,
  setCustomLabelsForSelfHostedRunnerForOrg: setCustomLabelsForSelfHostedRunnerForOrg,
  removeAllCustomLabelsFromSelfHostedRunnerForOrg: removeAllCustomLabelsFromSelfHostedRunnerForOrg,
  deleteActionsCacheById: deleteActionsCacheById,
  listRunnerApplicationsForRepo: listRunnerApplicationsForRepo,
  getAllowedActionsOrganization: getAllowedActionsOrganization,
  setAllowedActionsOrganization: setAllowedActionsOrganization,
  downloadJobLogsForWorkflowRun: downloadJobLogsForWorkflowRun,
  getWorkflowAccessToRepository: getWorkflowAccessToRepository,
  setWorkflowAccessToRepository: setWorkflowAccessToRepository,
  listJobsForWorkflowRun: listJobsForWorkflowRun,
  downloadWorkflowRunLogs: downloadWorkflowRunLogs,
  deleteWorkflowRunLogs: deleteWorkflowRunLogs,
  getRepoPublicKey: getRepoPublicKey$2,
  reRunJobForWorkflowRun: reRunJobForWorkflowRun,
  getSelfHostedRunnerForRepo: getSelfHostedRunnerForRepo,
  deleteSelfHostedRunnerFromRepo: deleteSelfHostedRunnerFromRepo,
  reRunWorkflow: reRunWorkflow,
  getGithubActionsDefaultWorkflowPermissionsRepository: getGithubActionsDefaultWorkflowPermissionsRepository,
  setGithubActionsDefaultWorkflowPermissionsRepository: setGithubActionsDefaultWorkflowPermissionsRepository,
  createRemoveTokenForRepo: createRemoveTokenForRepo,
  cancelWorkflowRun: cancelWorkflowRun,
  getWorkflowRunUsage: getWorkflowRunUsage,
  getSelfHostedRunnerGroupForOrg: getSelfHostedRunnerGroupForOrg,
  deleteSelfHostedRunnerGroupFromOrg: deleteSelfHostedRunnerGroupFromOrg,
  updateSelfHostedRunnerGroupForOrg: updateSelfHostedRunnerGroupForOrg,
  approveWorkflowRun: approveWorkflowRun,
  getRepoSecret: getRepoSecret$2,
  createOrUpdateRepoSecret: createOrUpdateRepoSecret$2,
  deleteRepoSecret: deleteRepoSecret$2,
  getCustomOidcSubClaimForRepo: getCustomOidcSubClaimForRepo,
  setCustomOidcSubClaimForRepo: setCustomOidcSubClaimForRepo,
  removeCustomLabelFromSelfHostedRunnerForOrg: removeCustomLabelFromSelfHostedRunnerForOrg,
  getArtifact: getArtifact,
  deleteArtifact: deleteArtifact,
  getReviewsForRun: getReviewsForRun,
  listWorkflowRunArtifacts: listWorkflowRunArtifacts,
  getWorkflow: getWorkflow,
  getGithubActionsDefaultWorkflowPermissionsEnterprise: getGithubActionsDefaultWorkflowPermissionsEnterprise,
  setGithubActionsDefaultWorkflowPermissionsEnterprise: setGithubActionsDefaultWorkflowPermissionsEnterprise,
  listSelectedReposForOrgSecret: listSelectedReposForOrgSecret$1,
  setSelectedReposForOrgSecret: setSelectedReposForOrgSecret$1,
  createRegistrationTokenForRepo: createRegistrationTokenForRepo,
  listLabelsForSelfHostedRunnerForRepo: listLabelsForSelfHostedRunnerForRepo,
  addCustomLabelsToSelfHostedRunnerForRepo: addCustomLabelsToSelfHostedRunnerForRepo,
  setCustomLabelsForSelfHostedRunnerForRepo: setCustomLabelsForSelfHostedRunnerForRepo,
  removeAllCustomLabelsFromSelfHostedRunnerForRepo: removeAllCustomLabelsFromSelfHostedRunnerForRepo,
  getAllowedActionsRepository: getAllowedActionsRepository,
  setAllowedActionsRepository: setAllowedActionsRepository,
  listWorkflowRuns: listWorkflowRuns,
  setActionsOidcCustomIssuerPolicyForEnterprise: setActionsOidcCustomIssuerPolicyForEnterprise,
  listSelfHostedRunnersInGroupForOrg: listSelfHostedRunnersInGroupForOrg,
  setSelfHostedRunnersInGroupForOrg: setSelfHostedRunnersInGroupForOrg,
  enableSelectedRepositoryGithubActionsOrganization: enableSelectedRepositoryGithubActionsOrganization,
  disableSelectedRepositoryGithubActionsOrganization: disableSelectedRepositoryGithubActionsOrganization,
  enableWorkflow: enableWorkflow,
  getWorkflowUsage: getWorkflowUsage,
  reRunWorkflowFailedJobs: reRunWorkflowFailedJobs,
  disableWorkflow: disableWorkflow,
  removeCustomLabelFromSelfHostedRunnerForRepo: removeCustomLabelFromSelfHostedRunnerForRepo,
  getPendingDeploymentsForRun: getPendingDeploymentsForRun,
  reviewPendingDeploymentsForRun: reviewPendingDeploymentsForRun,
  listRepoAccessToSelfHostedRunnerGroupInOrg: listRepoAccessToSelfHostedRunnerGroupInOrg,
  setRepoAccessToSelfHostedRunnerGroupInOrg: setRepoAccessToSelfHostedRunnerGroupInOrg,
  createWorkflowDispatch: createWorkflowDispatch,
  getWorkflowRunAttempt: getWorkflowRunAttempt,
  listEnvironmentSecrets: listEnvironmentSecrets,
  addSelectedRepoToOrgSecret: addSelectedRepoToOrgSecret$1,
  removeSelectedRepoFromOrgSecret: removeSelectedRepoFromOrgSecret$1,
  downloadArtifact: downloadArtifact,
  addSelfHostedRunnerToGroupForOrg: addSelfHostedRunnerToGroupForOrg,
  removeSelfHostedRunnerFromGroupForOrg: removeSelfHostedRunnerFromGroupForOrg,
  listJobsForWorkflowRunAttempt: listJobsForWorkflowRunAttempt,
  downloadWorkflowRunAttemptLogs: downloadWorkflowRunAttemptLogs,
  addRepoAccessToSelfHostedRunnerGroupInOrg: addRepoAccessToSelfHostedRunnerGroupInOrg,
  removeRepoAccessToSelfHostedRunnerGroupInOrg: removeRepoAccessToSelfHostedRunnerGroupInOrg,
  getEnvironmentPublicKey: getEnvironmentPublicKey,
  getEnvironmentSecret: getEnvironmentSecret,
  createOrUpdateEnvironmentSecret: createOrUpdateEnvironmentSecret,
  deleteEnvironmentSecret: deleteEnvironmentSecret
});

/**
* @see https://docs.github.com/rest/reference/activity#get-feeds


* Get feeds
* GitHub provides several timeline resources in [Atom](http://en.wikipedia.org/wiki/Atom_(standard)) format. The Feeds API lists all the feeds available to the authenticated user:
 *
 * *   **Timeline**: The GitHub global public timeline
 * *   **User**: The public timeline for any user, using [URI template](https://docs.github.com/rest/overview/resources-in-the-rest-api#hypermedia)
 * *   **Current user public**: The public timeline for the authenticated user
 * *   **Current user**: The private timeline for the authenticated user
 * *   **Current user actor**: The private timeline for activity created by the authenticated user
 * *   **Current user organizations**: The private timeline for the organizations the authenticated user is a member of.
 * *   **Security advisories**: A collection of public announcements that provide information about security-related vulnerabilities in software on GitHub.
 *
 * **Note**: Private feeds are only returned when [authenticating via Basic Auth](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) since current feed URIs use the older, non revocable auth tokens.
*/
var getFeeds = {
    id: "activity/get-feeds",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-public-events


* List public events
* We delay the public events feed by five minutes, which means the most recent event returned by the public events API actually occurred at least five minutes ago.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPublicEvents = {
    id: "activity/list-public-events",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-repositories-starred-by-the-authenticated-user


* List repositories starred by the authenticated user
* Lists repositories the authenticated user has starred.
 *
 * You can also find out _when_ stars were created by passing the following custom [media type](https://docs.github.com/rest/overview/media-types/) via the `Accept` header:
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [direction] - The direction to sort the results by.
* @param [sort] - The property to sort the results by. `created` means when the repository was starred. `updated` means when the repository was last pushed to.
*/
var listReposStarredByAuthenticatedUser = {
    id: "activity/list-repos-starred-by-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-notifications-for-the-authenticated-user


* List notifications for the authenticated user
* List all notifications for the current user, sorted by most recently updated.
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [before] - Only show notifications updated before the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [all=false] - If `true`, show notifications marked as read.
* @param [participating=false] - If `true`, only shows notifications in which the user is directly participating or mentioned.
*/
var listNotificationsForAuthenticatedUser = {
    id: "activity/list-notifications-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#mark-notifications-as-read


* Mark notifications as read
* Marks all notifications as "read" removes it from the [default view on GitHub](https://github.com/notifications). If the number of notifications is too large to complete in one request, you will receive a `202 Accepted` status and GitHub will run an asynchronous process to mark notifications as "read." To check whether any "unread" notifications remain, you can use the [List notifications for the authenticated user](https://docs.github.com/rest/reference/activity#list-notifications-for-the-authenticated-user) endpoint and pass the query parameter `all=false`.
*/
var markNotificationsAsRead = {
    id: "activity/mark-notifications-as-read",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-public-organization-events


* List public organization events
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPublicOrgEvents = {
    id: "activity/list-public-org-events",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-repositories-watched-by-the-authenticated-user


* List repositories watched by the authenticated user
* Lists repositories the authenticated user is watching.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listWatchedReposForAuthenticatedUser = {
    id: "activity/list-watched-repos-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-events-for-the-authenticated-user


* List events for the authenticated user
* If you are authenticated as the given user, you will see your private events. Otherwise, you'll only see public events.
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listEventsForAuthenticatedUser = {
    id: "activity/list-events-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-repositories-starred-by-a-user


* List repositories starred by a user
* Lists repositories a user has starred.
 *
 * You can also find out _when_ stars were created by passing the following custom [media type](https://docs.github.com/rest/overview/media-types/) via the `Accept` header:
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [direction] - The direction to sort the results by.
* @param [sort] - The property to sort the results by. `created` means when the repository was starred. `updated` means when the repository was last pushed to.
*/
var listReposStarredByUser = {
    id: "activity/list-repos-starred-by-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-repository-events


* List repository events
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listRepoEvents = {
    id: "activity/list-repo-events",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#check-if-a-repository-is-starred-by-the-authenticated-user


* Check if a repository is starred by the authenticated user
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var checkRepoIsStarredByAuthenticatedUser = {
    id: "activity/check-repo-is-starred-by-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#star-a-repository-for-the-authenticated-user


* Star a repository for the authenticated user
* Note that you'll need to set `Content-Length` to zero when calling out to this endpoint. For more information, see "[HTTP verbs](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-verbs)."
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var starRepoForAuthenticatedUser = {
    id: "activity/star-repo-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#unstar-a-repository-for-the-authenticated-user


* Unstar a repository for the authenticated user
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var unstarRepoForAuthenticatedUser = {
    id: "activity/unstar-repo-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-public-events-for-a-network-of-repositories


* List public events for a network of repositories
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPublicEventsForRepoNetwork = {
    id: "activity/list-public-events-for-repo-network",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-public-events-for-a-user


* List public events for a user
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPublicEventsForUser = {
    id: "activity/list-public-events-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-repositories-watched-by-a-user


* List repositories watched by a user
* Lists repositories a user is watching.
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listReposWatchedByUser = {
    id: "activity/list-repos-watched-by-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-stargazers


* List stargazers
* Lists the people that have starred the repository.
 *
 * You can also find out _when_ stars were created by passing the following custom [media type](https://docs.github.com/rest/overview/media-types/) via the `Accept` header:
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listStargazersForRepo = {
    id: "activity/list-stargazers-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-watchers


* List watchers
* Lists the people watching the specified repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listWatchersForRepo = {
    id: "activity/list-watchers-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-events-received-by-the-authenticated-user


* List events received by the authenticated user
* These are events that you've received by watching repos and following users. If you are authenticated as the given user, you will see private events. Otherwise, you'll only see public events.
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listReceivedEventsForUser = {
    id: "activity/list-received-events-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#get-a-thread


* Get a thread
* @param threadId - The unique identifier of the pull request thread.
*/
var getThread = {
    id: "activity/get-thread",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#mark-a-thread-as-read


* Mark a thread as read
* @param threadId - The unique identifier of the pull request thread.
*/
var markThreadAsRead = {
    id: "activity/mark-thread-as-read",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#get-a-repository-subscription


* Get a repository subscription
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getRepoSubscription = {
    id: "activity/get-repo-subscription",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#set-a-repository-subscription


* Set a repository subscription
* If you would like to watch a repository, set `subscribed` to `true`. If you would like to ignore notifications made within a repository, set `ignored` to `true`. If you would like to stop watching a repository, [delete the repository's subscription](https://docs.github.com/rest/reference/activity#delete-a-repository-subscription) completely.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var setRepoSubscription = {
    id: "activity/set-repo-subscription",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#delete-a-repository-subscription


* Delete a repository subscription
* This endpoint should only be used to stop watching a repository. To control whether or not you wish to receive notifications from a repository, [set the repository's subscription manually](https://docs.github.com/rest/reference/activity#set-a-repository-subscription).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var deleteRepoSubscription = {
    id: "activity/delete-repo-subscription",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-repository-notifications-for-the-authenticated-user


* List repository notifications for the authenticated user
* List all notifications for the current user.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [before] - Only show notifications updated before the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [all=false] - If `true`, show notifications marked as read.
* @param [participating=false] - If `true`, only shows notifications in which the user is directly participating or mentioned.
*/
var listRepoNotificationsForAuthenticatedUser = {
    id: "activity/list-repo-notifications-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#mark-repository-notifications-as-read


* Mark repository notifications as read
* Marks all notifications in a repository as "read" removes them from the [default view on GitHub](https://github.com/notifications). If the number of notifications is too large to complete in one request, you will receive a `202 Accepted` status and GitHub will run an asynchronous process to mark notifications as "read." To check whether any "unread" notifications remain, you can use the [List repository notifications for the authenticated user](https://docs.github.com/rest/reference/activity#list-repository-notifications-for-the-authenticated-user) endpoint and pass the query parameter `all=false`.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var markRepoNotificationsAsRead = {
    id: "activity/mark-repo-notifications-as-read",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-organization-events-for-the-authenticated-user


* List organization events for the authenticated user
* This is the user's organization dashboard. You must be authenticated as the user to view this.
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listOrgEventsForAuthenticatedUser = {
    id: "activity/list-org-events-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#list-public-events-received-by-a-user


* List public events received by a user
* @param username - The handle for the GitHub user account.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listReceivedPublicEventsForUser = {
    id: "activity/list-received-public-events-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#get-a-thread-subscription-for-the-authenticated-user


* Get a thread subscription for the authenticated user
* This checks to see if the current user is subscribed to a thread. You can also [get a repository subscription](https://docs.github.com/rest/reference/activity#get-a-repository-subscription).
 *
 * Note that subscriptions are only generated if a user is participating in a conversation--for example, they've replied to the thread, were **@mentioned**, or manually subscribe to a thread.
* @param threadId - The unique identifier of the pull request thread.
*/
var getThreadSubscriptionForAuthenticatedUser = {
    id: "activity/get-thread-subscription-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#set-a-thread-subscription


* Set a thread subscription
* If you are watching a repository, you receive notifications for all threads by default. Use this endpoint to ignore future notifications for threads until you comment on the thread or get an **@mention**.
 *
 * You can also use this endpoint to subscribe to threads that you are currently not receiving notifications for or to subscribed to threads that you have previously ignored.
 *
 * Unsubscribing from a conversation in a repository that you are not watching is functionally equivalent to the [Delete a thread subscription](https://docs.github.com/rest/reference/activity#delete-a-thread-subscription) endpoint.
* @param threadId - The unique identifier of the pull request thread.
*/
var setThreadSubscription = {
    id: "activity/set-thread-subscription",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/activity#delete-a-thread-subscription


* Delete a thread subscription
* Mutes all future notifications for a conversation until you comment on the thread or get an **@mention**. If you are watching the repository of the thread, you will still receive notifications. To ignore future notifications for a repository you are watching, use the [Set a thread subscription](https://docs.github.com/rest/reference/activity#set-a-thread-subscription) endpoint and set `ignore` to `true`.
* @param threadId - The unique identifier of the pull request thread.
*/
var deleteThreadSubscription = {
    id: "activity/delete-thread-subscription",
    clientId: "github",
    version: "1.1.5",
};

var activity = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getFeeds: getFeeds,
  listPublicEvents: listPublicEvents,
  listReposStarredByAuthenticatedUser: listReposStarredByAuthenticatedUser,
  listNotificationsForAuthenticatedUser: listNotificationsForAuthenticatedUser,
  markNotificationsAsRead: markNotificationsAsRead,
  listPublicOrgEvents: listPublicOrgEvents,
  listWatchedReposForAuthenticatedUser: listWatchedReposForAuthenticatedUser,
  listEventsForAuthenticatedUser: listEventsForAuthenticatedUser,
  listReposStarredByUser: listReposStarredByUser,
  listRepoEvents: listRepoEvents,
  checkRepoIsStarredByAuthenticatedUser: checkRepoIsStarredByAuthenticatedUser,
  starRepoForAuthenticatedUser: starRepoForAuthenticatedUser,
  unstarRepoForAuthenticatedUser: unstarRepoForAuthenticatedUser,
  listPublicEventsForRepoNetwork: listPublicEventsForRepoNetwork,
  listPublicEventsForUser: listPublicEventsForUser,
  listReposWatchedByUser: listReposWatchedByUser,
  listStargazersForRepo: listStargazersForRepo,
  listWatchersForRepo: listWatchersForRepo,
  listReceivedEventsForUser: listReceivedEventsForUser,
  getThread: getThread,
  markThreadAsRead: markThreadAsRead,
  getRepoSubscription: getRepoSubscription,
  setRepoSubscription: setRepoSubscription,
  deleteRepoSubscription: deleteRepoSubscription,
  listRepoNotificationsForAuthenticatedUser: listRepoNotificationsForAuthenticatedUser,
  markRepoNotificationsAsRead: markRepoNotificationsAsRead,
  listOrgEventsForAuthenticatedUser: listOrgEventsForAuthenticatedUser,
  listReceivedPublicEventsForUser: listReceivedPublicEventsForUser,
  getThreadSubscriptionForAuthenticatedUser: getThreadSubscriptionForAuthenticatedUser,
  setThreadSubscription: setThreadSubscription,
  deleteThreadSubscription: deleteThreadSubscription
});

/**
* @see https://docs.github.com/rest/reference/apps#get-the-authenticated-app


* Get the authenticated app
* Returns the GitHub App associated with the authentication credentials used. To see how many app installations are associated with this GitHub App, see the `installations_count` in the response. For more details about your app's installations, see the "[List installations for the authenticated app](https://docs.github.com/rest/reference/apps#list-installations-for-the-authenticated-app)" endpoint.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
*/
var getAuthenticated = {
    id: "apps/get-authenticated",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#get-a-webhook-configuration-for-an-app


* Get a webhook configuration for an app
* Returns the webhook configuration for a GitHub App. For more information about configuring a webhook for your app, see "[Creating a GitHub App](/developers/apps/creating-a-github-app)."
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
*/
var getWebhookConfigForApp = {
    id: "apps/get-webhook-config-for-app",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#update-a-webhook-configuration-for-an-app


* Update a webhook configuration for an app
* Updates the webhook configuration for a GitHub App. For more information about configuring a webhook for your app, see "[Creating a GitHub App](/developers/apps/creating-a-github-app)."
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
*/
var updateWebhookConfigForApp = {
    id: "apps/update-webhook-config-for-app",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps/#get-an-app


* Get an app
* **Note**: The `:app_slug` is just the URL-friendly name of your GitHub App. You can find this on the settings page for your GitHub App (e.g., `https://github.com/settings/apps/:app_slug`).
 *
 * If the GitHub App you specify is public, you can access this endpoint without authenticating. If the GitHub App you specify is private, you must authenticate with a [personal access token](https://docs.github.com/articles/creating-a-personal-access-token-for-the-command-line/) or an [installation access token](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-an-installation) to access this endpoint.
* @param appSlug
*/
var getBySlug = {
    id: "apps/get-by-slug",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#list-installations-for-the-authenticated-app


* List installations for the authenticated app
* You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
 *
 * The permissions the installation has are included under the `permissions` key.
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [outdated]
*/
var listInstallations = {
    id: "apps/list-installations",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#revoke-an-installation-access-token


* Revoke an installation access token
* Revokes the installation token you're using to authenticate as an installation and access this endpoint.
 *
 * Once an installation token is revoked, the token is invalidated and cannot be used. Other endpoints that require the revoked installation token must have a new installation token to work. You can create a new token using the "[Create an installation access token for an app](https://docs.github.com/rest/reference/apps#create-an-installation-access-token-for-an-app)" endpoint.
 *
 * You must use an [installation access token](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-an-installation) to access this endpoint.
*/
var revokeInstallationAccessToken = {
    id: "apps/revoke-installation-access-token",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#list-app-installations-accessible-to-the-user-access-token


* List app installations accessible to the user access token
* Lists installations of your GitHub App that the authenticated user has explicit permission (`:read`, `:write`, or `:admin`) to access.
 *
 * You must use a [user-to-server OAuth access token](https://docs.github.com/apps/building-github-apps/identifying-and-authorizing-users-for-github-apps/#identifying-users-on-your-site), created for a user who has authorized your GitHub App, to access this endpoint.
 *
 * The authenticated user has explicit permission to access repositories they own, repositories where they are a collaborator, and repositories that they can access through an organization membership.
 *
 * You can find the permissions for the installation under the `permissions` key.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listInstallationsForAuthenticatedUser = {
    id: "apps/list-installations-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#list-deliveries-for-an-app-webhook


* List deliveries for an app webhook
* Returns a list of webhook deliveries for the webhook configured for a GitHub App.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
* @param [perPage=30] - The number of results per page (max 100).
* @param [cursor] - Used for pagination: the starting delivery from which the page of deliveries is fetched. Refer to the `link` header for the next and previous page cursors.
*/
var listWebhookDeliveries = {
    id: "apps/list-webhook-deliveries",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#get-an-organization-installation-for-the-authenticated-app


* Get an organization installation for the authenticated app
* Enables an authenticated GitHub App to find the organization's installation information.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
* @param org - The organization name. The name is not case sensitive.
*/
var getOrgInstallation = {
    id: "apps/get-org-installation",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#list-repositories-accessible-to-the-app-installation


* List repositories accessible to the app installation
* List repositories that an app installation can access.
 *
 * You must use an [installation access token](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-an-installation) to access this endpoint.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listReposAccessibleToInstallation = {
    id: "apps/list-repos-accessible-to-installation",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#list-plans


* List plans
* Lists all plans that are part of your GitHub Marketplace listing.
 *
 * GitHub Apps must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint. OAuth Apps must use [basic authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) with their client ID and client secret to access this endpoint.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPlans = {
    id: "apps/list-plans",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#list-subscriptions-for-the-authenticated-user


* List subscriptions for the authenticated user
* Lists the active subscriptions for the authenticated user. You must use a [user-to-server OAuth access token](https://docs.github.com/apps/building-github-apps/identifying-and-authorizing-users-for-github-apps/#identifying-users-on-your-site), created for a user who has authorized your GitHub App, to access this endpoint. . OAuth Apps must authenticate using an [OAuth token](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/).
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listSubscriptionsForAuthenticatedUser = {
    id: "apps/list-subscriptions-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#get-a-user-installation-for-the-authenticated-app


* Get a user installation for the authenticated app
* Enables an authenticated GitHub App to find the user’s installation information.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
* @param username - The handle for the GitHub user account.
*/
var getUserInstallation = {
    id: "apps/get-user-installation",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#delete-an-app-authorization


* Delete an app authorization
* OAuth application owners can revoke a grant for their OAuth application and a specific user. You must use [Basic Authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) when accessing this endpoint, using the OAuth application's `client_id` and `client_secret` as the username and password. You must also provide a valid OAuth `access_token` as an input parameter and the grant for the token's owner will be deleted.
 * Deleting an OAuth application's grant will also delete all OAuth tokens associated with the application for the user. Once deleted, the application will have no access to the user's account and will no longer be listed on [the application authorizations settings screen within GitHub](https://github.com/settings/applications#authorized).
* @param clientId - The client ID of the GitHub app.
*/
var deleteAuthorization = {
    id: "apps/delete-authorization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#check-a-token


* Check a token
* OAuth applications can use a special API method for checking OAuth token validity without exceeding the normal rate limits for failed login attempts. Authentication works differently with this particular endpoint. You must use [Basic Authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) to use this endpoint, where the username is the OAuth application `client_id` and the password is its `client_secret`. Invalid tokens will return `404 NOT FOUND`.
* @param clientId - The client ID of the GitHub app.
*/
var checkToken = {
    id: "apps/check-token",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#delete-an-app-token


* Delete an app token
* OAuth application owners can revoke a single token for an OAuth application. You must use [Basic Authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) when accessing this endpoint, using the OAuth application's `client_id` and `client_secret` as the username and password.
* @param clientId - The client ID of the GitHub app.
*/
var deleteToken = {
    id: "apps/delete-token",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#reset-a-token


* Reset a token
* OAuth applications can use this API method to reset a valid OAuth token without end-user involvement. Applications must save the "token" property in the response because changes take effect immediately. You must use [Basic Authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) when accessing this endpoint, using the OAuth application's `client_id` and `client_secret` as the username and password. Invalid tokens will return `404 NOT FOUND`.
* @param clientId - The client ID of the GitHub app.
*/
var resetToken = {
    id: "apps/reset-token",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#create-a-github-app-from-a-manifest


* Create a GitHub App from a manifest
* Use this endpoint to complete the handshake necessary when implementing the [GitHub App Manifest flow](https://docs.github.com/apps/building-github-apps/creating-github-apps-from-a-manifest/). When you create a GitHub App with the manifest flow, you receive a temporary `code` used to retrieve the GitHub App's `id`, `pem` (private key), and `webhook_secret`.
* @param code
*/
var createFromManifest = {
    id: "apps/create-from-manifest",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#get-a-delivery-for-an-app-webhook


* Get a delivery for an app webhook
* Returns a delivery for the webhook configured for a GitHub App.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
* @param deliveryId
*/
var getWebhookDelivery = {
    id: "apps/get-webhook-delivery",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#list-plans-stubbed


* List plans (stubbed)
* Lists all plans that are part of your GitHub Marketplace listing.
 *
 * GitHub Apps must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint. OAuth Apps must use [basic authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) with their client ID and client secret to access this endpoint.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPlansStubbed = {
    id: "apps/list-plans-stubbed",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#get-a-repository-installation-for-the-authenticated-app


* Get a repository installation for the authenticated app
* Enables an authenticated GitHub App to find the repository's installation information. The installation's account type will be either an organization or a user account, depending which account the repository belongs to.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getRepoInstallation = {
    id: "apps/get-repo-installation",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#list-subscriptions-for-the-authenticated-user-stubbed


* List subscriptions for the authenticated user (stubbed)
* Lists the active subscriptions for the authenticated user. You must use a [user-to-server OAuth access token](https://docs.github.com/apps/building-github-apps/identifying-and-authorizing-users-for-github-apps/#identifying-users-on-your-site), created for a user who has authorized your GitHub App, to access this endpoint. . OAuth Apps must authenticate using an [OAuth token](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/).
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listSubscriptionsForAuthenticatedUserStubbed = {
    id: "apps/list-subscriptions-for-authenticated-user-stubbed",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#get-an-installation-for-the-authenticated-app


* Get an installation for the authenticated app
* Enables an authenticated GitHub App to find an installation's information using the installation id.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
* @param installationId - The unique identifier of the installation.
*/
var getInstallation = {
    id: "apps/get-installation",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#delete-an-installation-for-the-authenticated-app


* Delete an installation for the authenticated app
* Uninstalls a GitHub App on a user, organization, or business account. If you prefer to temporarily suspend an app's access to your account's resources, then we recommend the "[Suspend an app installation](https://docs.github.com/rest/reference/apps/#suspend-an-app-installation)" endpoint.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
* @param installationId - The unique identifier of the installation.
*/
var deleteInstallation = {
    id: "apps/delete-installation",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#create-a-scoped-access-token


* Create a scoped access token
* Use a non-scoped user-to-server OAuth access token to create a repository scoped and/or permission scoped user-to-server OAuth access token. You can specify which repositories the token can access and which permissions are granted to the token. You must use [Basic Authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) when accessing this endpoint, using the OAuth application's `client_id` and `client_secret` as the username and password. Invalid tokens will return `404 NOT FOUND`.
* @param clientId - The client ID of the GitHub app.
*/
var scopeToken = {
    id: "apps/scope-token",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#get-a-subscription-plan-for-an-account


* Get a subscription plan for an account
* Shows whether the user or organization account actively subscribes to a plan listed by the authenticated GitHub App. When someone submits a plan change that won't be processed until the end of their billing cycle, you will also see the upcoming pending change.
 *
 * GitHub Apps must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint. OAuth Apps must use [basic authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) with their client ID and client secret to access this endpoint.
* @param accountId - account_id parameter
*/
var getSubscriptionPlanForAccount = {
    id: "apps/get-subscription-plan-for-account",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#redeliver-a-delivery-for-an-app-webhook


* Redeliver a delivery for an app webhook
* Redeliver a delivery for the webhook configured for a GitHub App.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
* @param deliveryId
*/
var redeliverWebhookDelivery = {
    id: "apps/redeliver-webhook-delivery",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#list-accounts-for-a-plan


* List accounts for a plan
* Returns user and organization accounts associated with the specified plan, including free plans. For per-seat pricing, you see the list of accounts that have purchased the plan, including the number of seats purchased. When someone submits a plan change that won't be processed until the end of their billing cycle, you will also see the upcoming pending change.
 *
 * GitHub Apps must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint. OAuth Apps must use [basic authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) with their client ID and client secret to access this endpoint.
* @param planId - The unique identifier of the plan.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [sort] - The property to sort the results by. `created` means when the repository was starred. `updated` means when the repository was last pushed to.
* @param [direction] - To return the oldest accounts first, set to `asc`. Ignored without the `sort` parameter.
*/
var listAccountsForPlan = {
    id: "apps/list-accounts-for-plan",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#suspend-an-app-installation


* Suspend an app installation
* Suspends a GitHub App on a user, organization, or business account, which blocks the app from accessing the account's resources. When a GitHub App is suspended, the app's access to the GitHub API or webhook events is blocked for that account.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
* @param installationId - The unique identifier of the installation.
*/
var suspendInstallation = {
    id: "apps/suspend-installation",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#unsuspend-an-app-installation


* Unsuspend an app installation
* Removes a GitHub App installation suspension.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
* @param installationId - The unique identifier of the installation.
*/
var unsuspendInstallation = {
    id: "apps/unsuspend-installation",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps/#create-an-installation-access-token-for-an-app


* Create an installation access token for an app
* Creates an installation access token that enables a GitHub App to make authenticated API requests for the app's installation on an organization or individual account. Installation tokens expire one hour from the time you create them. Using an expired token produces a status code of `401 - Unauthorized`, and requires creating a new installation token. By default the installation token has access to all repositories that the installation can access. To restrict the access to specific repositories, you can provide the `repository_ids` when creating the token. When you omit `repository_ids`, the response does not contain the `repositories` key.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
* @param installationId - The unique identifier of the installation.
*/
var createInstallationAccessToken = {
    id: "apps/create-installation-access-token",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#get-a-subscription-plan-for-an-account-stubbed


* Get a subscription plan for an account (stubbed)
* Shows whether the user or organization account actively subscribes to a plan listed by the authenticated GitHub App. When someone submits a plan change that won't be processed until the end of their billing cycle, you will also see the upcoming pending change.
 *
 * GitHub Apps must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint. OAuth Apps must use [basic authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) with their client ID and client secret to access this endpoint.
* @param accountId - account_id parameter
*/
var getSubscriptionPlanForAccountStubbed = {
    id: "apps/get-subscription-plan-for-account-stubbed",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#list-repositories-accessible-to-the-user-access-token


* List repositories accessible to the user access token
* List repositories that the authenticated user has explicit permission (`:read`, `:write`, or `:admin`) to access for an installation.
 *
 * The authenticated user has explicit permission to access repositories they own, repositories where they are a collaborator, and repositories that they can access through an organization membership.
 *
 * You must use a [user-to-server OAuth access token](https://docs.github.com/apps/building-github-apps/identifying-and-authorizing-users-for-github-apps/#identifying-users-on-your-site), created for a user who has authorized your GitHub App, to access this endpoint.
 *
 * The access the user has to each repository is included in the hash under the `permissions` key.
* @param installationId - The unique identifier of the installation.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listInstallationReposForAuthenticatedUser = {
    id: "apps/list-installation-repos-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#list-accounts-for-a-plan-stubbed


* List accounts for a plan (stubbed)
* Returns repository and organization accounts associated with the specified plan, including free plans. For per-seat pricing, you see the list of accounts that have purchased the plan, including the number of seats purchased. When someone submits a plan change that won't be processed until the end of their billing cycle, you will also see the upcoming pending change.
 *
 * GitHub Apps must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint. OAuth Apps must use [basic authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication) with their client ID and client secret to access this endpoint.
* @param planId - The unique identifier of the plan.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [sort] - The property to sort the results by. `created` means when the repository was starred. `updated` means when the repository was last pushed to.
* @param [direction] - To return the oldest accounts first, set to `asc`. Ignored without the `sort` parameter.
*/
var listAccountsForPlanStubbed = {
    id: "apps/list-accounts-for-plan-stubbed",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#add-a-repository-to-an-app-installation


* Add a repository to an app installation
* Add a single repository to an installation. The authenticated user must have admin access to the repository.
 *
 * You must use a personal access token (which you can create via the [command line](https://docs.github.com/github/authenticating-to-github/creating-a-personal-access-token) or [Basic Authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication)) to access this endpoint.
* @param installationId - The unique identifier of the installation.
* @param repositoryId - The unique identifier of the repository.
*/
var addRepoToInstallationForAuthenticatedUser = {
    id: "apps/add-repo-to-installation-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/apps#remove-a-repository-from-an-app-installation


* Remove a repository from an app installation
* Remove a single repository from an installation. The authenticated user must have admin access to the repository.
 *
 * You must use a personal access token (which you can create via the [command line](https://docs.github.com/github/authenticating-to-github/creating-a-personal-access-token) or [Basic Authentication](https://docs.github.com/rest/overview/other-authentication-methods#basic-authentication)) to access this endpoint.
* @param installationId - The unique identifier of the installation.
* @param repositoryId - The unique identifier of the repository.
*/
var removeRepoFromInstallationForAuthenticatedUser = {
    id: "apps/remove-repo-from-installation-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};

var apps = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getAuthenticated: getAuthenticated,
  getWebhookConfigForApp: getWebhookConfigForApp,
  updateWebhookConfigForApp: updateWebhookConfigForApp,
  getBySlug: getBySlug,
  listInstallations: listInstallations,
  revokeInstallationAccessToken: revokeInstallationAccessToken,
  listInstallationsForAuthenticatedUser: listInstallationsForAuthenticatedUser,
  listWebhookDeliveries: listWebhookDeliveries,
  getOrgInstallation: getOrgInstallation,
  listReposAccessibleToInstallation: listReposAccessibleToInstallation,
  listPlans: listPlans,
  listSubscriptionsForAuthenticatedUser: listSubscriptionsForAuthenticatedUser,
  getUserInstallation: getUserInstallation,
  deleteAuthorization: deleteAuthorization,
  checkToken: checkToken,
  deleteToken: deleteToken,
  resetToken: resetToken,
  createFromManifest: createFromManifest,
  getWebhookDelivery: getWebhookDelivery,
  listPlansStubbed: listPlansStubbed,
  getRepoInstallation: getRepoInstallation,
  listSubscriptionsForAuthenticatedUserStubbed: listSubscriptionsForAuthenticatedUserStubbed,
  getInstallation: getInstallation,
  deleteInstallation: deleteInstallation,
  scopeToken: scopeToken,
  getSubscriptionPlanForAccount: getSubscriptionPlanForAccount,
  redeliverWebhookDelivery: redeliverWebhookDelivery,
  listAccountsForPlan: listAccountsForPlan,
  suspendInstallation: suspendInstallation,
  unsuspendInstallation: unsuspendInstallation,
  createInstallationAccessToken: createInstallationAccessToken,
  getSubscriptionPlanForAccountStubbed: getSubscriptionPlanForAccountStubbed,
  listInstallationReposForAuthenticatedUser: listInstallationReposForAuthenticatedUser,
  listAccountsForPlanStubbed: listAccountsForPlanStubbed,
  addRepoToInstallationForAuthenticatedUser: addRepoToInstallationForAuthenticatedUser,
  removeRepoFromInstallationForAuthenticatedUser: removeRepoFromInstallationForAuthenticatedUser
});

/**
* @see https://docs.github.com/rest/reference/billing#get-github-actions-billing-for-an-organization


* Get GitHub Actions billing for an organization
* Gets the summary of the free and paid GitHub Actions minutes used.
 *
 * Paid minutes only apply to workflows in private repositories that use GitHub-hosted runners. Minutes used is listed for each GitHub-hosted runner operating system. Any job re-runs are also included in the usage. The usage returned includes any minute multipliers for macOS and Windows runners, and is rounded up to the nearest whole minute. For more information, see "[Managing billing for GitHub Actions](https://docs.github.com/github/setting-up-and-managing-billing-and-payments-on-github/managing-billing-for-github-actions)".
 *
 * Access tokens must have the `repo` or `admin:org` scope.
* @param org - The organization name. The name is not case sensitive.
*/
var getGithubActionsBillingOrg = {
    id: "billing/get-github-actions-billing-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/billing#get-github-packages-billing-for-an-organization


* Get GitHub Packages billing for an organization
* Gets the free and paid storage used for GitHub Packages in gigabytes.
 *
 * Paid minutes only apply to packages stored for private repositories. For more information, see "[Managing billing for GitHub Packages](https://docs.github.com/github/setting-up-and-managing-billing-and-payments-on-github/managing-billing-for-github-packages)."
 *
 * Access tokens must have the `repo` or `admin:org` scope.
* @param org - The organization name. The name is not case sensitive.
*/
var getGithubPackagesBillingOrg = {
    id: "billing/get-github-packages-billing-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/billing#get-github-actions-billing-for-a-user


* Get GitHub Actions billing for a user
* Gets the summary of the free and paid GitHub Actions minutes used.
 *
 * Paid minutes only apply to workflows in private repositories that use GitHub-hosted runners. Minutes used is listed for each GitHub-hosted runner operating system. Any job re-runs are also included in the usage. The usage returned includes any minute multipliers for macOS and Windows runners, and is rounded up to the nearest whole minute. For more information, see "[Managing billing for GitHub Actions](https://docs.github.com/github/setting-up-and-managing-billing-and-payments-on-github/managing-billing-for-github-actions)".
 *
 * Access tokens must have the `user` scope.
* @param username - The handle for the GitHub user account.
*/
var getGithubActionsBillingUser = {
    id: "billing/get-github-actions-billing-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/billing#get-shared-storage-billing-for-an-organization


* Get shared storage billing for an organization
* Gets the estimated paid and estimated total storage used for GitHub Actions and GitHub Packages.
 *
 * Paid minutes only apply to packages stored for private repositories. For more information, see "[Managing billing for GitHub Packages](https://docs.github.com/github/setting-up-and-managing-billing-and-payments-on-github/managing-billing-for-github-packages)."
 *
 * Access tokens must have the `repo` or `admin:org` scope.
* @param org - The organization name. The name is not case sensitive.
*/
var getSharedStorageBillingOrg = {
    id: "billing/get-shared-storage-billing-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/billing#get-github-packages-billing-for-a-user


* Get GitHub Packages billing for a user
* Gets the free and paid storage used for GitHub Packages in gigabytes.
 *
 * Paid minutes only apply to packages stored for private repositories. For more information, see "[Managing billing for GitHub Packages](https://docs.github.com/github/setting-up-and-managing-billing-and-payments-on-github/managing-billing-for-github-packages)."
 *
 * Access tokens must have the `user` scope.
* @param username - The handle for the GitHub user account.
*/
var getGithubPackagesBillingUser = {
    id: "billing/get-github-packages-billing-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/billing#get-github-advanced-security-active-committers-for-an-organization


* Get GitHub Advanced Security active committers for an organization
* Gets the GitHub Advanced Security active committers for an organization per repository.
 *
 * Each distinct user login across all repositories is counted as a single Advanced Security seat, so the `total_advanced_security_committers` is not the sum of advanced_security_committers for each repository.
 *
 * If this organization defers to an enterprise for billing, the `total_advanced_security_committers` returned from the organization API may include some users that are in more than one organization, so they will only consume a single Advanced Security seat at the enterprise level.
 *
 * The total number of repositories with committer information is tracked by the `total_count` field.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var getGithubAdvancedSecurityBillingOrg = {
    id: "billing/get-github-advanced-security-billing-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/billing#get-shared-storage-billing-for-a-user


* Get shared storage billing for a user
* Gets the estimated paid and estimated total storage used for GitHub Actions and GitHub Packages.
 *
 * Paid minutes only apply to packages stored for private repositories. For more information, see "[Managing billing for GitHub Packages](https://docs.github.com/github/setting-up-and-managing-billing-and-payments-on-github/managing-billing-for-github-packages)."
 *
 * Access tokens must have the `user` scope.
* @param username - The handle for the GitHub user account.
*/
var getSharedStorageBillingUser = {
    id: "billing/get-shared-storage-billing-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/billing#get-github-actions-billing-for-an-enterprise


* Get GitHub Actions billing for an enterprise
* Gets the summary of the free and paid GitHub Actions minutes used.
 *
 * Paid minutes only apply to workflows in private repositories that use GitHub-hosted runners. Minutes used is listed for each GitHub-hosted runner operating system. Any job re-runs are also included in the usage. The usage does not include the multiplier for macOS and Windows runners and is not rounded up to the nearest whole minute. For more information, see "[Managing billing for GitHub Actions](https://docs.github.com/github/setting-up-and-managing-billing-and-payments-on-github/managing-billing-for-github-actions)".
 *
 * The authenticated user must be an enterprise admin.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var getGithubActionsBillingGhe = {
    id: "billing/get-github-actions-billing-ghe",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/billing#get-github-packages-billing-for-an-enterprise


* Get GitHub Packages billing for an enterprise
* Gets the free and paid storage used for GitHub Packages in gigabytes.
 *
 * Paid minutes only apply to packages stored for private repositories. For more information, see "[Managing billing for GitHub Packages](https://docs.github.com/github/setting-up-and-managing-billing-and-payments-on-github/managing-billing-for-github-packages)."
 *
 * The authenticated user must be an enterprise admin.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var getGithubPackagesBillingGhe = {
    id: "billing/get-github-packages-billing-ghe",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/billing#get-shared-storage-billing-for-an-enterprise


* Get shared storage billing for an enterprise
* Gets the estimated paid and estimated total storage used for GitHub Actions and GitHub Packages.
 *
 * Paid minutes only apply to packages stored for private repositories. For more information, see "[Managing billing for GitHub Packages](https://docs.github.com/github/setting-up-and-managing-billing-and-payments-on-github/managing-billing-for-github-packages)."
 *
 * The authenticated user must be an enterprise admin.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var getSharedStorageBillingGhe = {
    id: "billing/get-shared-storage-billing-ghe",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/billing#export-advanced-security-active-committers-data-for-enterprise


* Get GitHub Advanced Security active committers for an enterprise
* Gets the GitHub Advanced Security active committers for an enterprise per repository.
 *
 * Each distinct user login across all repositories is counted as a single Advanced Security seat, so the `total_advanced_security_committers` is not the sum of active_users for each repository.
 *
 * The total number of repositories with committer information is tracked by the `total_count` field.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var getGithubAdvancedSecurityBillingGhe = {
    id: "billing/get-github-advanced-security-billing-ghe",
    clientId: "github",
    version: "1.1.5",
};

var billing = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getGithubActionsBillingOrg: getGithubActionsBillingOrg,
  getGithubPackagesBillingOrg: getGithubPackagesBillingOrg,
  getGithubActionsBillingUser: getGithubActionsBillingUser,
  getSharedStorageBillingOrg: getSharedStorageBillingOrg,
  getGithubPackagesBillingUser: getGithubPackagesBillingUser,
  getGithubAdvancedSecurityBillingOrg: getGithubAdvancedSecurityBillingOrg,
  getSharedStorageBillingUser: getSharedStorageBillingUser,
  getGithubActionsBillingGhe: getGithubActionsBillingGhe,
  getGithubPackagesBillingGhe: getGithubPackagesBillingGhe,
  getSharedStorageBillingGhe: getSharedStorageBillingGhe,
  getGithubAdvancedSecurityBillingGhe: getGithubAdvancedSecurityBillingGhe
});

/**
* @see https://docs.github.com/rest/reference/checks#create-a-check-run


* Create a check run
* **Note:** The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty `pull_requests` array.
 *
 * Creates a new check run for a specific commit in a repository. Your GitHub App must have the `checks:write` permission to create check runs.
 *
 * In a check suite, GitHub limits the number of check runs with the same name to 1000. Once these check runs exceed 1000, GitHub will start to automatically delete older check runs.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var create$2 = {
    id: "checks/create",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/checks#create-a-check-suite


* Create a check suite
* **Note:** The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty `pull_requests` array and a `null` value for `head_branch`.
 *
 * By default, check suites are automatically created when you create a [check run](https://docs.github.com/rest/reference/checks#check-runs). You only need to use this endpoint for manually creating check suites when you've disabled automatic creation using "[Update repository preferences for check suites](https://docs.github.com/rest/reference/checks#update-repository-preferences-for-check-suites)". Your GitHub App must have the `checks:write` permission to create check suites.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createSuite = {
    id: "checks/create-suite",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/checks#update-repository-preferences-for-check-suites


* Update repository preferences for check suites
* Changes the default automatic flow when creating check suites. By default, a check suite is automatically created each time code is pushed to a repository. When you disable the automatic creation of check suites, you can manually [Create a check suite](https://docs.github.com/rest/reference/checks#create-a-check-suite). You must have admin permissions in the repository to set preferences for check suites.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var setSuitesPreferences = {
    id: "checks/set-suites-preferences",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/checks#list-check-runs-for-a-git-reference


* List check runs for a Git reference
* **Note:** The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty `pull_requests` array.
 *
 * Lists check runs for a commit ref. The `ref` can be a SHA, branch name, or a tag name. GitHub Apps must have the `checks:read` permission on a private repository or pull access to a public repository to get check runs. OAuth Apps and authenticated users must have the `repo` scope to get check runs in a private repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param ref - ref parameter
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [checkName] - Returns check runs with the specified `name`.
* @param [filter] - Filters check runs by their `completed_at` timestamp. `latest` returns the most recent check runs.
* @param [status] - Returns check runs with the specified `status`.
* @param [appId]
*/
var listForRef = {
    id: "checks/list-for-ref",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/checks#get-a-check-run


* Get a check run
* **Note:** The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty `pull_requests` array.
 *
 * Gets a single check run using its `id`. GitHub Apps must have the `checks:read` permission on a private repository or pull access to a public repository to get check runs. OAuth Apps and authenticated users must have the `repo` scope to get check runs in a private repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param checkRunId - The unique identifier of the check run.
*/
var getCheck = {
    id: "checks/get",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/checks#update-a-check-run


* Update a check run
* **Note:** The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty `pull_requests` array.
 *
 * Updates a check run for a specific commit in a repository. Your GitHub App must have the `checks:write` permission to edit check runs.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param checkRunId - The unique identifier of the check run.
*/
var update$2 = {
    id: "checks/update",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/checks#list-check-suites-for-a-git-reference


* List check suites for a Git reference
* **Note:** The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty `pull_requests` array and a `null` value for `head_branch`.
 *
 * Lists check suites for a commit `ref`. The `ref` can be a SHA, branch name, or a tag name. GitHub Apps must have the `checks:read` permission on a private repository or pull access to a public repository to list check suites. OAuth Apps and authenticated users must have the `repo` scope to get check suites in a private repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param ref - ref parameter
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [checkName] - Returns check runs with the specified `name`.
* @param [appId] - Filters check suites by GitHub App `id`.
*/
var listSuitesForRef = {
    id: "checks/list-suites-for-ref",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/checks#get-a-check-suite


* Get a check suite
* **Note:** The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty `pull_requests` array and a `null` value for `head_branch`.
 *
 * Gets a single check suite using its `id`. GitHub Apps must have the `checks:read` permission on a private repository or pull access to a public repository to get check suites. OAuth Apps and authenticated users must have the `repo` scope to get check suites in a private repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param checkSuiteId - The unique identifier of the check suite.
*/
var getSuite = {
    id: "checks/get-suite",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/checks#rerequest-a-check-run


* Rerequest a check run
* Triggers GitHub to rerequest an existing check run, without pushing new code to a repository. This endpoint will trigger the [`check_run` webhook](https://docs.github.com/webhooks/event-payloads/#check_run) event with the action `rerequested`. When a check run is `rerequested`, its `status` is reset to `queued` and the `conclusion` is cleared.
 *
 * To rerequest a check run, your GitHub App must have the `checks:read` permission on a private repository or pull access to a public repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param checkRunId - The unique identifier of the check run.
*/
var rerequestRun = {
    id: "checks/rerequest-run",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/checks#list-check-run-annotations


* List check run annotations
* Lists annotations for a check run using the annotation `id`. GitHub Apps must have the `checks:read` permission on a private repository or pull access to a public repository to get annotations for a check run. OAuth Apps and authenticated users must have the `repo` scope to get annotations for a check run in a private repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param checkRunId - The unique identifier of the check run.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listAnnotations = {
    id: "checks/list-annotations",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/checks#rerequest-a-check-suite


* Rerequest a check suite
* Triggers GitHub to rerequest an existing check suite, without pushing new code to a repository. This endpoint will trigger the [`check_suite` webhook](https://docs.github.com/webhooks/event-payloads/#check_suite) event with the action `rerequested`. When a check suite is `rerequested`, its `status` is reset to `queued` and the `conclusion` is cleared.
 *
 * To rerequest a check suite, your GitHub App must have the `checks:read` permission on a private repository or pull access to a public repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param checkSuiteId - The unique identifier of the check suite.
*/
var rerequestSuite = {
    id: "checks/rerequest-suite",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/checks#list-check-runs-in-a-check-suite


* List check runs in a check suite
* **Note:** The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty `pull_requests` array.
 *
 * Lists check runs for a check suite using its `id`. GitHub Apps must have the `checks:read` permission on a private repository or pull access to a public repository to get check runs. OAuth Apps and authenticated users must have the `repo` scope to get check runs in a private repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param checkSuiteId - The unique identifier of the check suite.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [checkName] - Returns check runs with the specified `name`.
* @param [status] - Returns check runs with the specified `status`.
* @param [filter] - Filters check runs by their `completed_at` timestamp. `latest` returns the most recent check runs.
*/
var listForSuite = {
    id: "checks/list-for-suite",
    clientId: "github",
    version: "1.1.5",
};

var checks = /*#__PURE__*/Object.freeze({
  __proto__: null,
  create: create$2,
  createSuite: createSuite,
  setSuitesPreferences: setSuitesPreferences,
  listForRef: listForRef,
  getCheck: getCheck,
  update: update$2,
  listSuitesForRef: listSuitesForRef,
  getSuite: getSuite,
  rerequestRun: rerequestRun,
  listAnnotations: listAnnotations,
  rerequestSuite: rerequestSuite,
  listForSuite: listForSuite
});

/**
* @see https://docs.github.com/rest/reference/code-scanning#list-code-scanning-alerts-by-organization


* List code scanning alerts for an organization
* Lists code scanning alerts for the default branch for all eligible repositories in an organization. Eligible repositories are repositories that are owned by organizations that you own or for which you are a security manager. For more information, see "[Managing security managers in your organization](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/managing-security-managers-in-your-organization)."
 *
 * To use this endpoint, you must be an owner or security manager for the organization, and you must use an access token with the `repo` scope or `security_events` scope.
 *
 * GitHub Apps must have the `security_events` read permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [direction] - The direction to sort the results by.
* @param [sort] - The property by which to sort the results.
* @param [state] - If specified, only code scanning alerts with this state will be returned.
* @param [toolName] - The name of a code scanning tool. Only results by this tool will be listed. You can specify the tool by using either `tool_name` or `tool_guid`, but not both.
* @param [before] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events before this cursor.
* @param [after] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events after this cursor.
* @param [toolGuid] - The GUID of a code scanning tool. Only results by this tool will be listed. Note that some code scanning tools may not include a GUID in their analysis data. You can specify the tool by using either `tool_guid` or `tool_name`, but not both.
*/
var listAlertsForOrg = {
    id: "code-scanning/list-alerts-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/code-scanning#list-code-scanning-alerts-for-a-repository


* List code scanning alerts for a repository
* Lists code scanning alerts.
 *
 * To use this endpoint, you must use an access token with the `security_events` scope or, for alerts from public repositories only, an access token with the `public_repo` scope.
 *
 * GitHub Apps must have the `security_events` read
 * permission to use this endpoint.
 *
 * The response includes a `most_recent_instance` object.
 * This provides details of the most recent instance of this alert
 * for the default branch (or for the specified Git reference if you used `ref` in the request).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [direction] - The direction to sort the results by.
* @param [toolName] - The name of a code scanning tool. Only results by this tool will be listed. You can specify the tool by using either `tool_name` or `tool_guid`, but not both.
* @param [toolGuid] - The GUID of a code scanning tool. Only results by this tool will be listed. Note that some code scanning tools may not include a GUID in their analysis data. You can specify the tool by using either `tool_guid` or `tool_name`, but not both.
* @param [ref] - The Git reference for the results you want to list. The `ref` for a branch can be formatted either as `refs/heads/<branch name>` or simply `<branch name>`. To reference a pull request use `refs/pull/<number>/merge`.
* @param [sort] - The property by which to sort the results.
* @param [state] - If specified, only code scanning alerts with this state will be returned.
*/
var listAlertsForRepo = {
    id: "code-scanning/list-alerts-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/code-scanning#upload-a-sarif-file


* Upload an analysis as SARIF data
* Uploads SARIF data containing the results of a code scanning analysis to make the results available in a repository. You must use an access token with the `security_events` scope to use this endpoint for private repositories. You can also use tokens with the `public_repo` scope for public repositories only. GitHub Apps must have the `security_events` write permission to use this endpoint.
 *
 * There are two places where you can upload code scanning results.
 * - If you upload to a pull request, for example `--ref refs/pull/42/merge` or `--ref refs/pull/42/head`, then the results appear as alerts in a pull request check. For more information, see "[Triaging code scanning alerts in pull requests](/code-security/secure-coding/triaging-code-scanning-alerts-in-pull-requests)."
 * - If you upload to a branch, for example `--ref refs/heads/my-branch`, then the results appear in the **Security** tab for your repository. For more information, see "[Managing code scanning alerts for your repository](/code-security/secure-coding/managing-code-scanning-alerts-for-your-repository#viewing-the-alerts-for-a-repository)."
 *
 * You must compress the SARIF-formatted analysis data that you want to upload, using `gzip`, and then encode it as a Base64 format string. For example:
 *
 * ```
 * gzip -c analysis-data.sarif | base64 -w0
 * ```
 *
 * SARIF upload supports a maximum of 5000 results per analysis run. Any results over this limit are ignored and any SARIF uploads with more than 25,000 results are rejected. Typically, but not necessarily, a SARIF file contains a single run of a single tool. If a code scanning tool generates too many results, you should update the analysis configuration to run only the most important rules or queries.
 *
 * The `202 Accepted`, response includes an `id` value.
 * You can use this ID to check the status of the upload by using this for the `/sarifs/{sarif_id}` endpoint.
 * For more information, see "[Get information about a SARIF upload](/rest/reference/code-scanning#get-information-about-a-sarif-upload)."
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var uploadSarif = {
    id: "code-scanning/upload-sarif",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/code-scanning#list-code-scanning-analyses-for-a-repository


* List code scanning analyses for a repository
* Lists the details of all code scanning analyses for a repository,
 * starting with the most recent.
 * The response is paginated and you can use the `page` and `per_page` parameters
 * to list the analyses you're interested in.
 * By default 30 analyses are listed per page.
 *
 * The `rules_count` field in the response give the number of rules
 * that were run in the analysis.
 * For very old analyses this data is not available,
 * and `0` is returned in this field.
 *
 * You must use an access token with the `security_events` scope to use this endpoint with private repos,
 * the `public_repo` scope also grants permission to read security events on public repos only.
 * GitHub Apps must have the `security_events` read permission to use this endpoint.
 *
 * **Deprecation notice**:
 * The `tool_name` field is deprecated and will, in future, not be included in the response for this endpoint. The example response reflects this change. The tool name can now be found inside the `tool` field.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [toolName] - The name of a code scanning tool. Only results by this tool will be listed. You can specify the tool by using either `tool_name` or `tool_guid`, but not both.
* @param [toolGuid] - The GUID of a code scanning tool. Only results by this tool will be listed. Note that some code scanning tools may not include a GUID in their analysis data. You can specify the tool by using either `tool_guid` or `tool_name`, but not both.
* @param [ref] - The Git reference for the analyses you want to list. The `ref` for a branch can be formatted either as `refs/heads/<branch name>` or simply `<branch name>`. To reference a pull request use `refs/pull/<number>/merge`.
* @param [sarifId] - Filter analyses belonging to the same SARIF upload.
*/
var listRecentAnalyses = {
    id: "code-scanning/list-recent-analyses",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/code-scanning#list-code-scanning-alerts-for-an-enterprise


* List code scanning alerts for an enterprise
* Lists code scanning alerts for the default branch for all eligible repositories in an enterprise. Eligible repositories are repositories that are owned by organizations that you own or for which you are a security manager. For more information, see "[Managing security managers in your organization](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/managing-security-managers-in-your-organization)."
 *
 * To use this endpoint, you must be a member of the enterprise,
 * and you must use an access token with the `repo` scope or `security_events` scope.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [direction] - The direction to sort the results by.
* @param [toolName] - The name of a code scanning tool. Only results by this tool will be listed. You can specify the tool by using either `tool_name` or `tool_guid`, but not both.
* @param [before] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events before this cursor.
* @param [after] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events after this cursor.
* @param [toolGuid] - The GUID of a code scanning tool. Only results by this tool will be listed. Note that some code scanning tools may not include a GUID in their analysis data. You can specify the tool by using either `tool_guid` or `tool_name`, but not both.
* @param [sort] - The property by which to sort the results.
* @param [state] - If specified, only code scanning alerts with this state will be returned.
*/
var listAlertsForEnterprise = {
    id: "code-scanning/list-alerts-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/code-scanning#list-recent-code-scanning-analyses-for-a-repository


* Get information about a SARIF upload
* Gets information about a SARIF upload, including the status and the URL of the analysis that was uploaded so that you can retrieve details of the analysis. For more information, see "[Get a code scanning analysis for a repository](/rest/reference/code-scanning#get-a-code-scanning-analysis-for-a-repository)." You must use an access token with the `security_events` scope to use this endpoint with private repos, the `public_repo` scope also grants permission to read security events on public repos only. GitHub Apps must have the `security_events` read permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param sarifId - The SARIF ID obtained after uploading.
*/
var getSarif = {
    id: "code-scanning/get-sarif",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/code-scanning#get-a-code-scanning-alert


* Get a code scanning alert
* Gets a single code scanning alert. You must use an access token with the `security_events` scope to use this endpoint with private repos, the `public_repo` scope also grants permission to read security events on public repos only. GitHub Apps must have the `security_events` read permission to use this endpoint.
 *
 * **Deprecation notice**:
 * The instances field is deprecated and will, in future, not be included in the response for this endpoint. The example response reflects this change. The same information can now be retrieved via a GET request to the URL specified by `instances_url`.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param alertNumber - The number that identifies an alert. You can find this at the end of the URL for a code scanning alert within GitHub, and in the `number` field in the response from the `GET /repos/{owner}/{repo}/code-scanning/alerts` operation.
*/
var getAlert = {
    id: "code-scanning/get-alert",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/code-scanning#update-a-code-scanning-alert


* Update a code scanning alert
* Updates the status of a single code scanning alert. You must use an access token with the `security_events` scope to use this endpoint with private repositories. You can also use tokens with the `public_repo` scope for public repositories only. GitHub Apps must have the `security_events` write permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param alertNumber - The number that identifies an alert. You can find this at the end of the URL for a code scanning alert within GitHub, and in the `number` field in the response from the `GET /repos/{owner}/{repo}/code-scanning/alerts` operation.
*/
var updateAlert = {
    id: "code-scanning/update-alert",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/code-scanning#get-a-code-scanning-analysis-for-a-repository


* Get a code scanning analysis for a repository
* Gets a specified code scanning analysis for a repository.
 * You must use an access token with the `security_events` scope to use this endpoint with private repos,
 * the `public_repo` scope also grants permission to read security events on public repos only.
 * GitHub Apps must have the `security_events` read permission to use this endpoint.
 *
 * The default JSON response contains fields that describe the analysis.
 * This includes the Git reference and commit SHA to which the analysis relates,
 * the datetime of the analysis, the name of the code scanning tool,
 * and the number of alerts.
 *
 * The `rules_count` field in the default response give the number of rules
 * that were run in the analysis.
 * For very old analyses this data is not available,
 * and `0` is returned in this field.
 *
 * If you use the Accept header `application/sarif+json`,
 * the response contains the analysis data that was uploaded.
 * This is formatted as
 * [SARIF version 2.1.0](https://docs.oasis-open.org/sarif/sarif/v2.1.0/cs01/sarif-v2.1.0-cs01.html).
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param analysisId - The ID of the analysis, as returned from the `GET /repos/{owner}/{repo}/code-scanning/analyses` operation.
*/
var getAnalysis = {
    id: "code-scanning/get-analysis",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/code-scanning#delete-a-code-scanning-analysis-from-a-repository


* Delete a code scanning analysis from a repository
* Deletes a specified code scanning analysis from a repository. For
 * private repositories, you must use an access token with the `repo` scope. For public repositories,
 * you must use an access token with `public_repo` scope.
 * GitHub Apps must have the `security_events` write permission to use this endpoint.
 *
 * You can delete one analysis at a time.
 * To delete a series of analyses, start with the most recent analysis and work backwards.
 * Conceptually, the process is similar to the undo function in a text editor.
 *
 * When you list the analyses for a repository,
 * one or more will be identified as deletable in the response:
 *
 * ```
 * "deletable": true
 * ```
 *
 * An analysis is deletable when it's the most recent in a set of analyses.
 * Typically, a repository will have multiple sets of analyses
 * for each enabled code scanning tool,
 * where a set is determined by a unique combination of analysis values:
 *
 * * `ref`
 * * `tool`
 * * `analysis_key`
 * * `environment`
 *
 * If you attempt to delete an analysis that is not the most recent in a set,
 * you'll get a 400 response with the message:
 *
 * ```
 * Analysis specified is not deletable.
 * ```
 *
 * The response from a successful `DELETE` operation provides you with
 * two alternative URLs for deleting the next analysis in the set:
 * `next_analysis_url` and `confirm_delete_url`.
 * Use the `next_analysis_url` URL if you want to avoid accidentally deleting the final analysis
 * in a set. This is a useful option if you want to preserve at least one analysis
 * for the specified tool in your repository.
 * Use the `confirm_delete_url` URL if you are content to remove all analyses for a tool.
 * When you delete the last analysis in a set, the value of `next_analysis_url` and `confirm_delete_url`
 * in the 200 response is `null`.
 *
 * As an example of the deletion process,
 * let's imagine that you added a workflow that configured a particular code scanning tool
 * to analyze the code in a repository. This tool has added 15 analyses:
 * 10 on the default branch, and another 5 on a topic branch.
 * You therefore have two separate sets of analyses for this tool.
 * You've now decided that you want to remove all of the analyses for the tool.
 * To do this you must make 15 separate deletion requests.
 * To start, you must find an analysis that's identified as deletable.
 * Each set of analyses always has one that's identified as deletable.
 * Having found the deletable analysis for one of the two sets,
 * delete this analysis and then continue deleting the next analysis in the set until they're all deleted.
 * Then repeat the process for the second set.
 * The procedure therefore consists of a nested loop:
 *
 * **Outer loop**:
 * * List the analyses for the repository, filtered by tool.
 * * Parse this list to find a deletable analysis. If found:
 *
 * **Inner loop**:
 * * Delete the identified analysis.
 * * Parse the response for the value of `confirm_delete_url` and, if found, use this in the next iteration.
 *
 * The above process assumes that you want to remove all trace of the tool's analyses from the GitHub user interface, for the specified repository, and it therefore uses the `confirm_delete_url` value. Alternatively, you could use the `next_analysis_url` value, which would leave the last analysis in each set undeleted to avoid removing a tool's analysis entirely.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param analysisId - The ID of the analysis, as returned from the `GET /repos/{owner}/{repo}/code-scanning/analyses` operation.
* @param [confirmDelete] - Allow deletion if the specified analysis is the last in a set. If you attempt to delete the final analysis in a set without setting this parameter to `true`, you'll get a 400 response with the message: `Analysis is last of its type and deletion may result in the loss of historical alert data. Please specify confirm_delete.`
*/
var deleteAnalysis = {
    id: "code-scanning/delete-analysis",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/code-scanning#list-instances-of-a-code-scanning-alert


* List instances of a code scanning alert
* Lists all instances of the specified code scanning alert.
 * You must use an access token with the `security_events` scope to use this endpoint with private repos,
 * the `public_repo` scope also grants permission to read security events on public repos only.
 * GitHub Apps must have the `security_events` read permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param alertNumber - The number that identifies an alert. You can find this at the end of the URL for a code scanning alert within GitHub, and in the `number` field in the response from the `GET /repos/{owner}/{repo}/code-scanning/alerts` operation.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [ref] - The Git reference for the results you want to list. The `ref` for a branch can be formatted either as `refs/heads/<branch name>` or simply `<branch name>`. To reference a pull request use `refs/pull/<number>/merge`.
*/
var listAlertInstances = {
    id: "code-scanning/list-alert-instances",
    clientId: "github",
    version: "1.1.5",
};

var codeScanning = /*#__PURE__*/Object.freeze({
  __proto__: null,
  listAlertsForOrg: listAlertsForOrg,
  listAlertsForRepo: listAlertsForRepo,
  uploadSarif: uploadSarif,
  listRecentAnalyses: listRecentAnalyses,
  listAlertsForEnterprise: listAlertsForEnterprise,
  getSarif: getSarif,
  getAlert: getAlert,
  updateAlert: updateAlert,
  getAnalysis: getAnalysis,
  deleteAnalysis: deleteAnalysis,
  listAlertInstances: listAlertInstances
});

/**
* @see https://docs.github.com/rest/reference/codes-of-conduct#get-all-codes-of-conduct


* Get all codes of conduct
*/
var getAllCodesOfConduct = {
    id: "codes-of-conduct/get-all-codes-of-conduct",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codes-of-conduct#get-a-code-of-conduct


* Get a code of conduct
* @param key
*/
var getConductCode = {
    id: "codes-of-conduct/get-conduct-code",
    clientId: "github",
    version: "1.1.5",
};

var codesOfConduct = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getAllCodesOfConduct: getAllCodesOfConduct,
  getConductCode: getConductCode
});

/**
* @see https://docs.github.com/rest/reference/codespaces#list-codespaces-for-the-authenticated-user


* List codespaces for the authenticated user
* Lists the authenticated user's codespaces.
 *
 * You must authenticate using an access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have read access to the `codespaces` repository permission to use this endpoint.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [repositoryId] - ID of the Repository to filter on
*/
var listForAuthenticatedUser$1 = {
    id: "codespaces/list-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#create-a-codespace-for-the-authenticated-user


* Create a codespace for the authenticated user
* Creates a new codespace, owned by the authenticated user.
 *
 * This endpoint requires either a `repository_id` OR a `pull_request` but not both.
 *
 * You must authenticate using an access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have write access to the `codespaces` repository permission to use this endpoint.
*/
var createForAuthenticatedUser = {
    id: "codespaces/create-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#list-in-organization


* List codespaces for the organization
* Lists the codespaces associated to a specified organization.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listInOrganization = {
    id: "codespaces/list-in-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#list-secrets-for-the-authenticated-user


* List secrets for the authenticated user
* Lists all secrets available for a user's Codespaces without revealing their
 * encrypted values.
 *
 * You must authenticate using an access token with the `codespace` or `codespace:secrets` scope to use this endpoint. User must have Codespaces access to use this endpoint.
 *
 * GitHub Apps must have read access to the `codespaces_user_secrets` user permission to use this endpoint.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listSecretsForAuthenticatedUser = {
    id: "codespaces/list-secrets-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#list-codespaces-in-a-repository-for-the-authenticated-user


* List codespaces in a repository for the authenticated user
* Lists the codespaces associated to a specified repository and the authenticated user.
 *
 * You must authenticate using an access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have read access to the `codespaces` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listInRepositoryForAuthenticatedUser = {
    id: "codespaces/list-in-repository-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#create-a-codespace-in-a-repository


* Create a codespace in a repository
* Creates a codespace owned by the authenticated user in the specified repository.
 *
 * You must authenticate using an access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have write access to the `codespaces` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createWithRepoForAuthenticatedUser = {
    id: "codespaces/create-with-repo-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#get-a-codespace-for-the-authenticated-user


* Get a codespace for the authenticated user
* Gets information about a user's codespace.
 *
 * You must authenticate using an access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have read access to the `codespaces` repository permission to use this endpoint.
* @param codespaceName - The name of the codespace.
*/
var getForAuthenticatedUser = {
    id: "codespaces/get-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#delete-a-codespace-for-the-authenticated-user


* Delete a codespace for the authenticated user
* Deletes a user's codespace.
 *
 * You must authenticate using an access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have write access to the `codespaces` repository permission to use this endpoint.
* @param codespaceName - The name of the codespace.
*/
var deleteForAuthenticatedUser = {
    id: "codespaces/delete-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#update-a-codespace-for-the-authenticated-user


* Update a codespace for the authenticated user
* Updates a codespace owned by the authenticated user. Currently only the codespace's machine type and recent folders can be modified using this endpoint.
 *
 * If you specify a new machine type it will be applied the next time your codespace is started.
 *
 * You must authenticate using an access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have write access to the `codespaces` repository permission to use this endpoint.
* @param codespaceName - The name of the codespace.
*/
var updateForAuthenticatedUser = {
    id: "codespaces/update-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#get-public-key-for-the-authenticated-user


* Get public key for the authenticated user
* Gets your public key, which you need to encrypt secrets. You need to encrypt a secret before you can create or update secrets.
 *
 * You must authenticate using an access token with the `codespace` or `codespace:secrets` scope to use this endpoint. User must have Codespaces access to use this endpoint.
 *
 * GitHub Apps must have read access to the `codespaces_user_secrets` user permission to use this endpoint.
*/
var getPublicKeyForAuthenticatedUser = {
    id: "codespaces/get-public-key-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#preview-attributes-for-a-new-codespace


* Get default attributes for a codespace
* Gets the default attributes for codespaces created by the user with the repository.
 *
 * You must authenticate using an access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have write access to the `codespaces` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [ref] - The branch or commit to check for a default devcontainer path. If not specified, the default branch will be checked.
* @param [clientIp] - An alternative IP for default location auto-detection, such as when proxying a request.
*/
var preFlightWithRepoForAuthenticatedUser = {
    id: "codespaces/pre-flight-with-repo-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#get-a-secret-for-the-authenticated-user


* Get a secret for the authenticated user
* Gets a secret available to a user's codespaces without revealing its encrypted value.
 *
 * You must authenticate using an access token with the `codespace` or `codespace:secrets` scope to use this endpoint. User must have Codespaces access to use this endpoint.
 *
 * GitHub Apps must have read access to the `codespaces_user_secrets` user permission to use this endpoint.
* @param secretName - The name of the secret.
*/
var getSecretForAuthenticatedUser = {
    id: "codespaces/get-secret-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#create-or-update-a-secret-for-the-authenticated-user


* Create or update a secret for the authenticated user
* Creates or updates a secret for a user's codespace with an encrypted value. Encrypt your secret using
 * [LibSodium](https://libsodium.gitbook.io/doc/bindings_for_other_languages).
 *
 * You must authenticate using an access token with the `codespace` or `codespace:secrets` scope to use this endpoint. User must also have Codespaces access to use this endpoint.
 *
 * GitHub Apps must have read access to the `codespaces_user_secrets` user permission and `codespaces_secrets` repository permission on all referenced repositories to use this endpoint.
 *
 * #### Example encrypting a secret using Node.js
 *
 * Encrypt your secret using the [tweetsodium](https://github.com/github/tweetsodium) library.
 *
 * ```
 * const sodium = require('tweetsodium');
 *
 * const key = "base64-encoded-public-key";
 * const value = "plain-text-secret";
 *
 * // Convert the message and key to Uint8Array's (Buffer implements that interface)
 * const messageBytes = Buffer.from(value);
 * const keyBytes = Buffer.from(key, 'base64');
 *
 * // Encrypt using LibSodium.
 * const encryptedBytes = sodium.seal(messageBytes, keyBytes);
 *
 * // Base64 the encrypted secret
 * const encrypted = Buffer.from(encryptedBytes).toString('base64');
 *
 * console.log(encrypted);
 * ```
 *
 *
 * #### Example encrypting a secret using Python
 *
 * Encrypt your secret using [pynacl](https://pynacl.readthedocs.io/en/latest/public/#nacl-public-sealedbox) with Python 3.
 *
 * ```
 * from base64 import b64encode
 * from nacl import encoding, public
 *
 * def encrypt(public_key: str, secret_value: str) -> str:
 * """Encrypt a Unicode string using the public key."""
 * public_key = public.PublicKey(public_key.encode("utf-8"), encoding.Base64Encoder())
 * sealed_box = public.SealedBox(public_key)
 * encrypted = sealed_box.encrypt(secret_value.encode("utf-8"))
 * return b64encode(encrypted).decode("utf-8")
 * ```
 *
 * #### Example encrypting a secret using C#
 *
 * Encrypt your secret using the [Sodium.Core](https://www.nuget.org/packages/Sodium.Core/) package.
 *
 * ```
 * var secretValue = System.Text.Encoding.UTF8.GetBytes("mySecret");
 * var publicKey = Convert.FromBase64String("2Sg8iYjAxxmI2LvUXpJjkYrMxURPc8r+dB7TJyvvcCU=");
 *
 * var sealedPublicKeyBox = Sodium.SealedPublicKeyBox.Create(secretValue, publicKey);
 *
 * Console.WriteLine(Convert.ToBase64String(sealedPublicKeyBox));
 * ```
 *
 * #### Example encrypting a secret using Ruby
 *
 * Encrypt your secret using the [rbnacl](https://github.com/RubyCrypto/rbnacl) gem.
 *
 * ```ruby
 * require "rbnacl"
 * require "base64"
 *
 * key = Base64.decode64("+ZYvJDZMHUfBkJdyq5Zm9SKqeuBQ4sj+6sfjlH4CgG0=")
 * public_key = RbNaCl::PublicKey.new(key)
 *
 * box = RbNaCl::Boxes::Sealed.from_public_key(public_key)
 * encrypted_secret = box.encrypt("my_secret")
 *
 * # Print the base64 encoded secret
 * puts Base64.strict_encode64(encrypted_secret)
 * ```
* @param secretName - The name of the secret.
*/
var createOrUpdateSecretForAuthenticatedUser = {
    id: "codespaces/create-or-update-secret-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#delete-a-secret-for-the-authenticated-user


* Delete a secret for the authenticated user
* Deletes a secret from a user's codespaces using the secret name. Deleting the secret will remove access from all codespaces that were allowed to access the secret.
 *
 * You must authenticate using an access token with the `codespace` or `codespace:secrets` scope to use this endpoint. User must have Codespaces access to use this endpoint.
 *
 * GitHub Apps must have write access to the `codespaces_user_secrets` user permission to use this endpoint.
* @param secretName - The name of the secret.
*/
var deleteSecretForAuthenticatedUser = {
    id: "codespaces/delete-secret-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#stop-a-codespace-for-the-authenticated-user


* Stop a codespace for the authenticated user
* Stops a user's codespace.
 *
 * You must authenticate using an access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have write access to the `codespaces_lifecycle_admin` repository permission to use this endpoint.
* @param codespaceName - The name of the codespace.
*/
var stopForAuthenticatedUser = {
    id: "codespaces/stop-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#start-a-codespace-for-the-authenticated-user


* Start a codespace for the authenticated user
* Starts a user's codespace.
 *
 * You must authenticate using an access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have write access to the `codespaces_lifecycle_admin` repository permission to use this endpoint.
* @param codespaceName - The name of the codespace.
*/
var startForAuthenticatedUser = {
    id: "codespaces/start-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#list-repository-secrets


* List repository secrets
* Lists all secrets available in a repository without revealing their encrypted values. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `codespaces_secrets` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listRepoSecrets$1 = {
    id: "codespaces/list-repo-secrets",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#list-available-machine-types-for-a-repository


* List available machine types for a repository
* List the machine types available for a given repository based on its configuration.
 *
 * You must authenticate using an access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have write access to the `codespaces_metadata` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [location] - The location to check for available machines. Assigned by IP if not provided.
* @param [clientIp] - IP for location auto-detection when proxying a request
*/
var repoMachinesForAuthenticatedUser = {
    id: "codespaces/repo-machines-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**


* Export a codespace for the authenticated user
* Triggers an export of the specified codespace and returns a URL and ID where the status of the export can be monitored.
 *
 * You must authenticate using a personal access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have write access to the `codespaces_lifecycle_admin` repository permission to use this endpoint.
* @param codespaceName - The name of the codespace.
*/
var exportForAuthenticatedUser = {
    id: "codespaces/export-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#list-machine-types-for-a-codespace


* List machine types for a codespace
* List the machine types a codespace can transition to use.
 *
 * You must authenticate using an access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have read access to the `codespaces_metadata` repository permission to use this endpoint.
* @param codespaceName - The name of the codespace.
*/
var codespaceMachinesForAuthenticatedUser = {
    id: "codespaces/codespace-machines-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#list-devcontainers-in-a-repository-for-the-authenticated-user


* List devcontainer configurations in a repository for the authenticated user
* Lists the devcontainer.json files associated with a specified repository and the authenticated user. These files
 * specify launchpoint configurations for codespaces created within the repository.
 *
 * You must authenticate using an access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have read access to the `codespaces_metadata` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listDevcontainersInRepositoryForAuthenticatedUser = {
    id: "codespaces/list-devcontainers-in-repository-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#get-a-repository-public-key


* Get a repository public key
* Gets your public key, which you need to encrypt secrets. You need to encrypt a secret before you can create or update secrets. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `codespaces_secrets` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getRepoPublicKey$1 = {
    id: "codespaces/get-repo-public-key",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#list-selected-repositories-for-a-user-secret


* List selected repositories for a user secret
* List the repositories that have been granted the ability to use a user's codespace secret.
 *
 * You must authenticate using an access token with the `codespace` or `codespace:secrets` scope to use this endpoint. User must have Codespaces access to use this endpoint.
 *
 * GitHub Apps must have read access to the `codespaces_user_secrets` user permission and write access to the `codespaces_secrets` repository permission on all referenced repositories to use this endpoint.
* @param secretName - The name of the secret.
*/
var listRepositoriesForSecretForAuthenticatedUser = {
    id: "codespaces/list-repositories-for-secret-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#set-selected-repositories-for-a-user-secret


* Set selected repositories for a user secret
* Select the repositories that will use a user's codespace secret.
 *
 * You must authenticate using an access token with the `codespace` or `codespace:secrets` scope to use this endpoint. User must have Codespaces access to use this endpoint.
 *
 * GitHub Apps must have write access to the `codespaces_user_secrets` user permission and write access to the `codespaces_secrets` repository permission on all referenced repositories to use this endpoint.
* @param secretName - The name of the secret.
*/
var setRepositoriesForSecretForAuthenticatedUser = {
    id: "codespaces/set-repositories-for-secret-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#create-a-codespace-from-a-pull-request


* Create a codespace from a pull request
* Creates a codespace owned by the authenticated user for the specified pull request.
 *
 * You must authenticate using an access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have write access to the `codespaces` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param pullNumber - The number that identifies the pull request.
*/
var createWithPrForAuthenticatedUser = {
    id: "codespaces/create-with-pr-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**


* Get details about a codespace export
* Gets information about an export of a codespace.
 *
 * You must authenticate using a personal access token with the `codespace` scope to use this endpoint.
 *
 * GitHub Apps must have read access to the `codespaces_lifecycle_admin` repository permission to use this endpoint.
* @param codespaceName - The name of the codespace.
* @param exportId - The ID of the export operation, or `latest`. Currently only `latest` is currently supported.
*/
var getExportDetailsForAuthenticatedUser = {
    id: "codespaces/get-export-details-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#get-a-repository-secret


* Get a repository secret
* Gets a single repository secret without revealing its encrypted value. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `codespaces_secrets` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var getRepoSecret$1 = {
    id: "codespaces/get-repo-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#create-or-update-a-repository-secret


* Create or update a repository secret
* Creates or updates a repository secret with an encrypted value. Encrypt your secret using
 * [LibSodium](https://libsodium.gitbook.io/doc/bindings_for_other_languages). You must authenticate using an access
 * token with the `repo` scope to use this endpoint. GitHub Apps must have the `codespaces_secrets` repository
 * permission to use this endpoint.
 *
 * #### Example of encrypting a secret using Node.js
 *
 * Encrypt your secret using the [tweetsodium](https://github.com/github/tweetsodium) library.
 *
 * ```
 * const sodium = require('tweetsodium');
 *
 * const key = "base64-encoded-public-key";
 * const value = "plain-text-secret";
 *
 * // Convert the message and key to Uint8Array's (Buffer implements that interface)
 * const messageBytes = Buffer.from(value);
 * const keyBytes = Buffer.from(key, 'base64');
 *
 * // Encrypt using LibSodium.
 * const encryptedBytes = sodium.seal(messageBytes, keyBytes);
 *
 * // Base64 the encrypted secret
 * const encrypted = Buffer.from(encryptedBytes).toString('base64');
 *
 * console.log(encrypted);
 * ```
 *
 *
 * #### Example of encrypting a secret using Python
 *
 * Encrypt your secret using [pynacl](https://pynacl.readthedocs.io/en/latest/public/#nacl-public-sealedbox) with Python 3.
 *
 * ```
 * from base64 import b64encode
 * from nacl import encoding, public
 *
 * def encrypt(public_key: str, secret_value: str) -> str:
 * """Encrypt a Unicode string using the public key."""
 * public_key = public.PublicKey(public_key.encode("utf-8"), encoding.Base64Encoder())
 * sealed_box = public.SealedBox(public_key)
 * encrypted = sealed_box.encrypt(secret_value.encode("utf-8"))
 * return b64encode(encrypted).decode("utf-8")
 * ```
 *
 * #### Example of encrypting a secret using C#
 *
 * Encrypt your secret using the [Sodium.Core](https://www.nuget.org/packages/Sodium.Core/) package.
 *
 * ```
 * var secretValue = System.Text.Encoding.UTF8.GetBytes("mySecret");
 * var publicKey = Convert.FromBase64String("2Sg8iYjAxxmI2LvUXpJjkYrMxURPc8r+dB7TJyvvcCU=");
 *
 * var sealedPublicKeyBox = Sodium.SealedPublicKeyBox.Create(secretValue, publicKey);
 *
 * Console.WriteLine(Convert.ToBase64String(sealedPublicKeyBox));
 * ```
 *
 * #### Example of encrypting a secret using Ruby
 *
 * Encrypt your secret using the [rbnacl](https://github.com/RubyCrypto/rbnacl) gem.
 *
 * ```ruby
 * require "rbnacl"
 * require "base64"
 *
 * key = Base64.decode64("+ZYvJDZMHUfBkJdyq5Zm9SKqeuBQ4sj+6sfjlH4CgG0=")
 * public_key = RbNaCl::PublicKey.new(key)
 *
 * box = RbNaCl::Boxes::Sealed.from_public_key(public_key)
 * encrypted_secret = box.encrypt("my_secret")
 *
 * # Print the base64 encoded secret
 * puts Base64.strict_encode64(encrypted_secret)
 * ```
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var createOrUpdateRepoSecret$1 = {
    id: "codespaces/create-or-update-repo-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#delete-a-repository-secret


* Delete a repository secret
* Deletes a secret in a repository using the secret name. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `codespaces_secrets` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var deleteRepoSecret$1 = {
    id: "codespaces/delete-repo-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces


* Delete a codespace from the organization
* Deletes a user's codespace.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
* @param codespaceName - The name of the codespace.
*/
var deleteFromOrganization = {
    id: "codespaces/delete-from-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces


* Stop a codespace for an organization user
* Stops a user's codespace.
 *
 * You must authenticate using an access token with the `admin:org` scope to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param username - The handle for the GitHub user account.
* @param codespaceName - The name of the codespace.
*/
var stopInOrganization = {
    id: "codespaces/stop-in-organization",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#add-a-selected-repository-to-a-user-secret


* Add a selected repository to a user secret
* Adds a repository to the selected repositories for a user's codespace secret.
 * You must authenticate using an access token with the `codespace` or `codespace:secrets` scope to use this endpoint. User must have Codespaces access to use this endpoint.
 * GitHub Apps must have write access to the `codespaces_user_secrets` user permission and write access to the `codespaces_secrets` repository permission on the referenced repository to use this endpoint.
* @param secretName - The name of the secret.
* @param repositoryId
*/
var addRepositoryForSecretForAuthenticatedUser = {
    id: "codespaces/add-repository-for-secret-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/codespaces#remove-a-selected-repository-from-a-user-secret


* Remove a selected repository from a user secret
* Removes a repository from the selected repositories for a user's codespace secret.
 * You must authenticate using an access token with the `codespace` or `codespace:secrets` scope to use this endpoint. User must have Codespaces access to use this endpoint.
 * GitHub Apps must have write access to the `codespaces_user_secrets` user permission to use this endpoint.
* @param secretName - The name of the secret.
* @param repositoryId
*/
var removeRepositoryForSecretForAuthenticatedUser = {
    id: "codespaces/remove-repository-for-secret-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};

var codespaces = /*#__PURE__*/Object.freeze({
  __proto__: null,
  listForAuthenticatedUser: listForAuthenticatedUser$1,
  createForAuthenticatedUser: createForAuthenticatedUser,
  listInOrganization: listInOrganization,
  listSecretsForAuthenticatedUser: listSecretsForAuthenticatedUser,
  listInRepositoryForAuthenticatedUser: listInRepositoryForAuthenticatedUser,
  createWithRepoForAuthenticatedUser: createWithRepoForAuthenticatedUser,
  getForAuthenticatedUser: getForAuthenticatedUser,
  deleteForAuthenticatedUser: deleteForAuthenticatedUser,
  updateForAuthenticatedUser: updateForAuthenticatedUser,
  getPublicKeyForAuthenticatedUser: getPublicKeyForAuthenticatedUser,
  preFlightWithRepoForAuthenticatedUser: preFlightWithRepoForAuthenticatedUser,
  getSecretForAuthenticatedUser: getSecretForAuthenticatedUser,
  createOrUpdateSecretForAuthenticatedUser: createOrUpdateSecretForAuthenticatedUser,
  deleteSecretForAuthenticatedUser: deleteSecretForAuthenticatedUser,
  stopForAuthenticatedUser: stopForAuthenticatedUser,
  startForAuthenticatedUser: startForAuthenticatedUser,
  listRepoSecrets: listRepoSecrets$1,
  repoMachinesForAuthenticatedUser: repoMachinesForAuthenticatedUser,
  exportForAuthenticatedUser: exportForAuthenticatedUser,
  codespaceMachinesForAuthenticatedUser: codespaceMachinesForAuthenticatedUser,
  listDevcontainersInRepositoryForAuthenticatedUser: listDevcontainersInRepositoryForAuthenticatedUser,
  getRepoPublicKey: getRepoPublicKey$1,
  listRepositoriesForSecretForAuthenticatedUser: listRepositoriesForSecretForAuthenticatedUser,
  setRepositoriesForSecretForAuthenticatedUser: setRepositoriesForSecretForAuthenticatedUser,
  createWithPrForAuthenticatedUser: createWithPrForAuthenticatedUser,
  getExportDetailsForAuthenticatedUser: getExportDetailsForAuthenticatedUser,
  getRepoSecret: getRepoSecret$1,
  createOrUpdateRepoSecret: createOrUpdateRepoSecret$1,
  deleteRepoSecret: deleteRepoSecret$1,
  deleteFromOrganization: deleteFromOrganization,
  stopInOrganization: stopInOrganization,
  addRepositoryForSecretForAuthenticatedUser: addRepositoryForSecretForAuthenticatedUser,
  removeRepositoryForSecretForAuthenticatedUser: removeRepositoryForSecretForAuthenticatedUser
});

/**
* @see https://docs.github.com/rest/reference/emojis#get-emojis


* Get emojis
* Lists all the emojis available to use on GitHub.
*/
var getEmojis = {
    id: "emojis/get",
    clientId: "github",
    version: "1.1.5",
};

var emojis = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getEmojis: getEmojis
});

/**
* @see https://docs.github.com/rest/reference/enterprise-admin#get-the-audit-log-for-an-enterprise


* Get the audit log for an enterprise
* Gets the audit log for an enterprise. To use this endpoint, you must be an enterprise admin, and you must use an access token with the `admin:enterprise` scope.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [phrase] - A search phrase. For more information, see [Searching the audit log](https://docs.github.com/github/setting-up-and-managing-organizations-and-teams/reviewing-the-audit-log-for-your-organization#searching-the-audit-log).
* @param [order] - The order of audit log events. To list newest events first, specify `desc`. To list oldest events first, specify `asc`.

The default is `desc`.
* @param [include] - The event types to include:

- `web` - returns web (non-Git) events.
- `git` - returns Git events.
- `all` - returns both web and Git events.

The default is `web`.
* @param [after] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events after this cursor.
* @param [before] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events before this cursor.
*/
var getAuditLog = {
    id: "enterprise-admin/get-audit-log",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/enterprise-admin#list-scim-provisioned-identities-for-an-enterprise


* List SCIM provisioned identities for an enterprise
* **Note:** The SCIM API endpoints for enterprise accounts are currently in beta and are subject to change.
 *
 * Retrieves a paginated list of all provisioned enterprise members, including pending invitations.
 *
 * When a user with a SAML-provisioned external identity leaves (or is removed from) an enterprise, the account's metadata is immediately removed. However, the returned list of user accounts might not always match the organization or enterprise member list you see on GitHub. This can happen in certain cases where an external identity associated with an organization will not match an organization member:
 * - When a user with a SCIM-provisioned external identity is removed from an enterprise, the account's metadata is preserved to allow the user to re-join the organization in the future.
 * - When inviting a user to join an organization, you can expect to see their external identity in the results before they accept the invitation, or if the invitation is cancelled (or never accepted).
 * - When a user is invited over SCIM, an external identity is created that matches with the invitee's email address. However, this identity is only linked to a user account when the user accepts the invitation by going through SAML SSO.
 *
 * The returned list of external identities can include an entry for a `null` user. These are unlinked SAML identities that are created when a user goes through the following Single Sign-On (SSO) process but does not sign in to their GitHub account after completing SSO:
 *
 * 1. The user is granted access by the IdP and is not a member of the GitHub enterprise.
 *
 * 1. The user attempts to access the GitHub enterprise and initiates the SAML SSO process, and is not currently signed in to their GitHub account.
 *
 * 1. After successfully authenticating with the SAML SSO IdP, the `null` external identity entry is created and the user is prompted to sign in to their GitHub account:
 * - If the user signs in, their GitHub account is linked to this entry.
 * - If the user does not sign in (or does not create a new account when prompted), they are not added to the GitHub enterprise, and the external identity `null` entry remains in place.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param [filter] - filter results
* @param [startIndex] - Used for pagination: the index of the first result to return.
* @param [count] - Used for pagination: the number of results to return.
*/
var listProvisionedIdentitiesEnterprise = {
    id: "enterprise-admin/list-provisioned-identities-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/enterprise-admin#provision-and-invite-a-scim-enterprise-user


* Provision and invite a SCIM enterprise user
* **Note:** The SCIM API endpoints for enterprise accounts are currently in beta and are subject to change.
 *
 * Provision enterprise membership for a user, and send organization invitation emails to the email address.
 *
 * You can optionally include the groups a user will be invited to join. If you do not provide a list of `groups`, the user is provisioned for the enterprise, but no organization invitation emails will be sent.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var provisionAndInviteEnterpriseUser = {
    id: "enterprise-admin/provision-and-invite-enterprise-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/enterprise-admin#list-provisioned-scim-groups-for-an-enterprise


* List provisioned SCIM groups for an enterprise
* **Note:** The SCIM API endpoints for enterprise accounts are currently in beta and are subject to change.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param [startIndex] - Used for pagination: the index of the first result to return.
* @param [count] - Used for pagination: the number of results to return.
* @param [excludedAttributes] - attributes to exclude
* @param [filter] - filter results
*/
var listProvisionedGroupsEnterprise = {
    id: "enterprise-admin/list-provisioned-groups-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/enterprise-admin#provision-a-scim-enterprise-group-and-invite-users


* Provision a SCIM enterprise group and invite users
* **Note:** The SCIM API endpoints for enterprise accounts are currently in beta and are subject to change.
 *
 * Provision an enterprise group, and invite users to the group. This sends invitation emails to the email address of the invited users to join the GitHub organization that the SCIM group corresponds to.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var provisionAndInviteEnterpriseGroup = {
    id: "enterprise-admin/provision-and-invite-enterprise-group",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-self-hosted-runners-for-an-enterprise


* List self-hosted runners for an enterprise
* Lists all self-hosted runners configured for an enterprise.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listSelfHostedRunnersForEnterprise = {
    id: "enterprise-admin/list-self-hosted-runners-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-github-actions-permissions-for-an-enterprise


* Get GitHub Actions permissions for an enterprise
* Gets the GitHub Actions permissions policy for organizations and allowed actions and reusable workflows in an enterprise.
 *
 * You must authenticate using an access token with the `admin:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var getGithubActionsPermissionsEnterprise = {
    id: "enterprise-admin/get-github-actions-permissions-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-github-actions-permissions-for-an-enterprise


* Set GitHub Actions permissions for an enterprise
* Sets the GitHub Actions permissions policy for organizations and allowed actions and reusable workflows in an enterprise.
 *
 * You must authenticate using an access token with the `admin:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var setGithubActionsPermissionsEnterprise = {
    id: "enterprise-admin/set-github-actions-permissions-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-self-hosted-runner-groups-for-an-enterprise


* List self-hosted runner groups for an enterprise
* Lists all self-hosted runner groups for an enterprise.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [visibleToOrganization] - Only return runner groups that are allowed to be used by this organization.
*/
var listSelfHostedRunnerGroupsForEnterprise = {
    id: "enterprise-admin/list-self-hosted-runner-groups-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#create-self-hosted-runner-group-for-an-enterprise


* Create a self-hosted runner group for an enterprise
* Creates a new self-hosted runner group for an enterprise.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var createSelfHostedRunnerGroupForEnterprise = {
    id: "enterprise-admin/create-self-hosted-runner-group-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-runner-applications-for-an-enterprise


* List runner applications for an enterprise
* Lists binaries for the runner application that you can download and run.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var listRunnerApplicationsForEnterprise = {
    id: "enterprise-admin/list-runner-applications-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-a-self-hosted-runner-for-an-enterprise


* Get a self-hosted runner for an enterprise
* Gets a specific self-hosted runner configured in an enterprise.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var getSelfHostedRunnerForEnterprise = {
    id: "enterprise-admin/get-self-hosted-runner-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#delete-self-hosted-runner-from-an-enterprise


* Delete a self-hosted runner from an enterprise
* Forces the removal of a self-hosted runner from an enterprise. You can use this endpoint to completely remove the runner when the machine you were using no longer exists.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var deleteSelfHostedRunnerFromEnterprise = {
    id: "enterprise-admin/delete-self-hosted-runner-from-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#create-a-remove-token-for-an-enterprise


* Create a remove token for an enterprise
* Returns a token that you can pass to the `config` script to remove a self-hosted runner from an enterprise. The token expires after one hour.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
 *
 * #### Example using remove token
 *
 * To remove your self-hosted runner from an enterprise, replace `TOKEN` with the remove token provided by this
 * endpoint.
 *
 * ```
 * ./config.sh remove --token TOKEN
 * ```
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var createRemoveTokenForEnterprise = {
    id: "enterprise-admin/create-remove-token-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/enterprise-admin#get-scim-provisioning-information-for-an-enterprise-user


* Get SCIM provisioning information for an enterprise user
* **Note:** The SCIM API endpoints for enterprise accounts are currently in beta and are subject to change.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param scimUserId - The unique identifier of the SCIM user.
*/
var getProvisioningInformationForEnterpriseUser = {
    id: "enterprise-admin/get-provisioning-information-for-enterprise-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/enterprise-admin#set-scim-information-for-a-provisioned-enterprise-user


* Set SCIM information for a provisioned enterprise user
* **Note:** The SCIM API endpoints for enterprise accounts are currently in beta and are subject to change.
 *
 * Replaces an existing provisioned user's information. You must provide all the information required for the user as if you were provisioning them for the first time. Any existing user information that you don't provide will be removed. If you want to only update a specific attribute, use the [Update an attribute for a SCIM user](#update-an-attribute-for-an-enterprise-scim-user) endpoint instead.
 *
 * You must at least provide the required values for the user: `userName`, `name`, and `emails`.
 *
 * **Warning:** Setting `active: false` removes the user from the enterprise, deletes the external identity, and deletes the associated `{scim_user_id}`.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param scimUserId - The unique identifier of the SCIM user.
*/
var setInformationForProvisionedEnterpriseUser = {
    id: "enterprise-admin/set-information-for-provisioned-enterprise-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/enterprise-admin#delete-a-scim-user-from-an-enterprise


* Delete a SCIM user from an enterprise
* **Note:** The SCIM API endpoints for enterprise accounts are currently in beta and are subject to change.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param scimUserId - The unique identifier of the SCIM user.
*/
var deleteUserFromEnterprise = {
    id: "enterprise-admin/delete-user-from-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/enterprise-admin#update-an-attribute-for-a-scim-enterprise-user


* Update an attribute for a SCIM enterprise user
* **Note:** The SCIM API endpoints for enterprise accounts are currently in beta and are subject to change.
 *
 * Allows you to change a provisioned user's individual attributes. To change a user's values, you must provide a specific `Operations` JSON format that contains at least one of the `add`, `remove`, or `replace` operations. For examples and more information on the SCIM operations format, see the [SCIM specification](https://tools.ietf.org/html/rfc7644#section-3.5.2).
 *
 * **Note:** Complicated SCIM `path` selectors that include filters are not supported. For example, a `path` selector defined as `"path": "emails[type eq \"work\"]"` will not work.
 *
 * **Warning:** If you set `active:false` using the `replace` operation (as shown in the JSON example below), it removes the user from the enterprise, deletes the external identity, and deletes the associated `:scim_user_id`.
 *
 * ```
 * {
 * "Operations":[{
 * "op":"replace",
 * "value":{
 * "active":false
 * }
 * }]
 * }
 * ```
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param scimUserId - The unique identifier of the SCIM user.
*/
var updateAttributeForEnterpriseUser = {
    id: "enterprise-admin/update-attribute-for-enterprise-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/enterprise-admin#get-scim-provisioning-information-for-an-enterprise-group


* Get SCIM provisioning information for an enterprise group
* **Note:** The SCIM API endpoints for enterprise accounts are currently in beta and are subject to change.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param scimGroupId - Identifier generated by the GitHub SCIM endpoint.
* @param [excludedAttributes] - Attributes to exclude.
*/
var getProvisioningInformationForEnterpriseGroup = {
    id: "enterprise-admin/get-provisioning-information-for-enterprise-group",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/enterprise-admin#set-scim-information-for-a-provisioned-enterprise-group


* Set SCIM information for a provisioned enterprise group
* **Note:** The SCIM API endpoints for enterprise accounts are currently in beta and are subject to change.
 *
 * Replaces an existing provisioned group’s information. You must provide all the information required for the group as if you were provisioning it for the first time. Any existing group information that you don't provide will be removed, including group membership. If you want to only update a specific attribute, use the [Update an attribute for a SCIM enterprise group](#update-an-attribute-for-a-scim-enterprise-group) endpoint instead.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param scimGroupId - Identifier generated by the GitHub SCIM endpoint.
*/
var setInformationForProvisionedEnterpriseGroup = {
    id: "enterprise-admin/set-information-for-provisioned-enterprise-group",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/enterprise-admin#delete-a-scim-group-from-an-enterprise


* Delete a SCIM group from an enterprise
* **Note:** The SCIM API endpoints for enterprise accounts are currently in beta and are subject to change.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param scimGroupId - Identifier generated by the GitHub SCIM endpoint.
*/
var deleteScimGroupFromEnterprise = {
    id: "enterprise-admin/delete-scim-group-from-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/enterprise-admin#update-an-attribute-for-a-scim-enterprise-group


* Update an attribute for a SCIM enterprise group
* **Note:** The SCIM API endpoints for enterprise accounts are currently in beta and are subject to change.
 *
 * Allows you to change a provisioned group’s individual attributes. To change a group’s values, you must provide a specific Operations JSON format that contains at least one of the add, remove, or replace operations. For examples and more information on the SCIM operations format, see the [SCIM specification](https://tools.ietf.org/html/rfc7644#section-3.5.2).
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param scimGroupId - Identifier generated by the GitHub SCIM endpoint.
*/
var updateAttributeForEnterpriseGroup = {
    id: "enterprise-admin/update-attribute-for-enterprise-group",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-selected-organizations-enabled-for-github-actions-in-an-enterprise


* List selected organizations enabled for GitHub Actions in an enterprise
* Lists the organizations that are selected to have GitHub Actions enabled in an enterprise. To use this endpoint, the enterprise permission policy for `enabled_organizations` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an enterprise](#set-github-actions-permissions-for-an-enterprise)."
 *
 * You must authenticate using an access token with the `admin:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listSelectedOrganizationsEnabledGithubActionsEnterprise = {
    id: "enterprise-admin/list-selected-organizations-enabled-github-actions-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-selected-organizations-enabled-for-github-actions-in-an-enterprise


* Set selected organizations enabled for GitHub Actions in an enterprise
* Replaces the list of selected organizations that are enabled for GitHub Actions in an enterprise. To use this endpoint, the enterprise permission policy for `enabled_organizations` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an enterprise](#set-github-actions-permissions-for-an-enterprise)."
 *
 * You must authenticate using an access token with the `admin:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var setSelectedOrganizationsEnabledGithubActionsEnterprise = {
    id: "enterprise-admin/set-selected-organizations-enabled-github-actions-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#create-a-registration-token-for-an-enterprise


* Create a registration token for an enterprise
* Returns a token that you can pass to the `config` script. The token expires after one hour.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
 *
 * #### Example using registration token
 *
 * Configure your self-hosted runner, replacing `TOKEN` with the registration token provided by this endpoint.
 *
 * ```
 * ./config.sh --url https://github.com/enterprises/octo-enterprise --token TOKEN
 * ```
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var createRegistrationTokenForEnterprise = {
    id: "enterprise-admin/create-registration-token-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-labels-for-a-self-hosted-runner-for-an-enterprise


* List labels for a self-hosted runner for an enterprise
* Lists all labels for a self-hosted runner configured in an enterprise.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var listLabelsForSelfHostedRunnerForEnterprise = {
    id: "enterprise-admin/list-labels-for-self-hosted-runner-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#add-custom-labels-to-a-self-hosted-runner-for-an-enterprise


* Add custom labels to a self-hosted runner for an enterprise
* Add custom labels to a self-hosted runner configured in an enterprise.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var addCustomLabelsToSelfHostedRunnerForEnterprise = {
    id: "enterprise-admin/add-custom-labels-to-self-hosted-runner-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-custom-labels-for-a-self-hosted-runner-for-an-enterprise


* Set custom labels for a self-hosted runner for an enterprise
* Remove all previous custom labels and set the new custom labels for a specific
 * self-hosted runner configured in an enterprise.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var setCustomLabelsForSelfHostedRunnerForEnterprise = {
    id: "enterprise-admin/set-custom-labels-for-self-hosted-runner-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#remove-all-custom-labels-from-a-self-hosted-runner-for-an-enterprise


* Remove all custom labels from a self-hosted runner for an enterprise
* Remove all custom labels from a self-hosted runner configured in an
 * enterprise. Returns the remaining read-only labels from the runner.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerId - Unique identifier of the self-hosted runner.
*/
var removeAllCustomLabelsFromSelfHostedRunnerForEnterprise = {
    id: "enterprise-admin/remove-all-custom-labels-from-self-hosted-runner-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/enterprise-admin#get-github-enterprise-server-statistics


* Get GitHub Enterprise Server statistics
* Returns aggregate usage metrics for your GitHub Enterprise Server 3.5+ instance for a specified time period up to 365 days.
 *
 * To use this endpoint, your GitHub Enterprise Server instance must be connected to GitHub Enterprise Cloud using GitHub Connect. You must enable Server Statistics, and for the API request provide your enterprise account name or organization name connected to the GitHub Enterprise Server. For more information, see "[Enabling Server Statistics for your enterprise](/admin/configuration/configuring-github-connect/enabling-server-statistics-for-your-enterprise)" in the GitHub Enterprise Server documentation.
 *
 * You'll need to use a personal access token:
 * - If you connected your GitHub Enterprise Server to an enterprise account and enabled Server Statistics, you'll need a personal access token with the `read:enterprise` permission.
 * - If you connected your GitHub Enterprise Server to an organization account and enabled Server Statistics, you'll need a personal access token with the `read:org` permission.
 *
 * For more information on creating a personal access token, see "[Creating a personal access token](/authentication/keeping-your-account-and-data-secure/creating-a-personal-access-token)."
* @param enterpriseOrOrg - The slug version of the enterprise name or the login of an organization.
* @param [dateStart] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events after this cursor.
* @param [dateEnd] - A cursor, as given in the [Link header](https://docs.github.com/rest/overview/resources-in-the-rest-api#link-header). If specified, the query only searches for events before this cursor.
*/
var getServerStatistics = {
    id: "enterprise-admin/get-server-statistics",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-allowed-actions-for-an-enterprise


* Get allowed actions and reusable workflows for an enterprise
* Gets the selected actions and reusable workflows that are allowed in an enterprise. To use this endpoint, the enterprise permission policy for `allowed_actions` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an enterprise](#set-github-actions-permissions-for-an-enterprise)."
 *
 * You must authenticate using an access token with the `admin:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var getAllowedActionsEnterprise = {
    id: "enterprise-admin/get-allowed-actions-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-allowed-actions-for-an-enterprise


* Set allowed actions and reusable workflows for an enterprise
* Sets the actions and reusable workflows that are allowed in an enterprise. To use this endpoint, the enterprise permission policy for `allowed_actions` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an enterprise](#set-github-actions-permissions-for-an-enterprise)."
 *
 * You must authenticate using an access token with the `admin:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
*/
var setAllowedActionsEnterprise = {
    id: "enterprise-admin/set-allowed-actions-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#get-a-self-hosted-runner-group-for-an-enterprise


* Get a self-hosted runner group for an enterprise
* Gets a specific self-hosted runner group for an enterprise.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
*/
var getSelfHostedRunnerGroupForEnterprise = {
    id: "enterprise-admin/get-self-hosted-runner-group-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#delete-a-self-hosted-runner-group-from-an-enterprise


* Delete a self-hosted runner group from an enterprise
* Deletes a self-hosted runner group for an enterprise.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
*/
var deleteSelfHostedRunnerGroupFromEnterprise = {
    id: "enterprise-admin/delete-self-hosted-runner-group-from-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#update-a-self-hosted-runner-group-for-an-enterprise


* Update a self-hosted runner group for an enterprise
* Updates the `name` and `visibility` of a self-hosted runner group in an enterprise.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
*/
var updateSelfHostedRunnerGroupForEnterprise = {
    id: "enterprise-admin/update-self-hosted-runner-group-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#remove-a-custom-label-from-a-self-hosted-runner-for-an-enterprise


* Remove a custom label from a self-hosted runner for an enterprise
* Remove a custom label from a self-hosted runner configured
 * in an enterprise. Returns the remaining labels from the runner.
 *
 * This endpoint returns a `404 Not Found` status if the custom label is not
 * present on the runner.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerId - Unique identifier of the self-hosted runner.
* @param name - The name of a self-hosted runner's custom label.
*/
var removeCustomLabelFromSelfHostedRunnerForEnterprise = {
    id: "enterprise-admin/remove-custom-label-from-self-hosted-runner-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#enable-a-selected-organization-for-github-actions-in-an-enterprise


* Enable a selected organization for GitHub Actions in an enterprise
* Adds an organization to the list of selected organizations that are enabled for GitHub Actions in an enterprise. To use this endpoint, the enterprise permission policy for `enabled_organizations` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an enterprise](#set-github-actions-permissions-for-an-enterprise)."
 *
 * You must authenticate using an access token with the `admin:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param orgId - The unique identifier of the organization.
*/
var enableSelectedOrganizationGithubActionsEnterprise = {
    id: "enterprise-admin/enable-selected-organization-github-actions-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#disable-a-selected-organization-for-github-actions-in-an-enterprise


* Disable a selected organization for GitHub Actions in an enterprise
* Removes an organization from the list of selected organizations that are enabled for GitHub Actions in an enterprise. To use this endpoint, the enterprise permission policy for `enabled_organizations` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an enterprise](#set-github-actions-permissions-for-an-enterprise)."
 *
 * You must authenticate using an access token with the `admin:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param orgId - The unique identifier of the organization.
*/
var disableSelectedOrganizationGithubActionsEnterprise = {
    id: "enterprise-admin/disable-selected-organization-github-actions-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-self-hosted-runners-in-a-group-for-an-enterprise


* List self-hosted runners in a group for an enterprise
* Lists the self-hosted runners that are in a specific enterprise group.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listSelfHostedRunnersInGroupForEnterprise = {
    id: "enterprise-admin/list-self-hosted-runners-in-group-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-self-hosted-runners-in-a-group-for-an-enterprise


* Set self-hosted runners in a group for an enterprise
* Replaces the list of self-hosted runners that are part of an enterprise runner group.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
*/
var setSelfHostedRunnersInGroupForEnterprise = {
    id: "enterprise-admin/set-self-hosted-runners-in-group-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#list-organization-access-to-a-self-hosted-runner-group-in-a-enterprise


* List organization access to a self-hosted runner group in an enterprise
* Lists the organizations with access to a self-hosted runner group.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listOrgAccessToSelfHostedRunnerGroupInEnterprise = {
    id: "enterprise-admin/list-org-access-to-self-hosted-runner-group-in-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#set-organization-access-to-a-self-hosted-runner-group-in-an-enterprise


* Set organization access for a self-hosted runner group in an enterprise
* Replaces the list of organizations that have access to a self-hosted runner configured in an enterprise.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
*/
var setOrgAccessToSelfHostedRunnerGroupInEnterprise = {
    id: "enterprise-admin/set-org-access-to-self-hosted-runner-group-in-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#add-a-self-hosted-runner-to-a-group-for-an-enterprise


* Add a self-hosted runner to a group for an enterprise
* Adds a self-hosted runner to a runner group configured in an enterprise.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise`
 * scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerId - Unique identifier of the self-hosted runner.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
*/
var addSelfHostedRunnerToGroupForEnterprise = {
    id: "enterprise-admin/add-self-hosted-runner-to-group-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#remove-a-self-hosted-runner-from-a-group-for-an-enterprise


* Remove a self-hosted runner from a group for an enterprise
* Removes a self-hosted runner from a group configured in an enterprise. The runner is then returned to the default group.
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerId - Unique identifier of the self-hosted runner.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
*/
var removeSelfHostedRunnerFromGroupForEnterprise = {
    id: "enterprise-admin/remove-self-hosted-runner-from-group-for-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#add-organization-access-to-a-self-hosted-runner-group-in-an-enterprise


* Add organization access to a self-hosted runner group in an enterprise
* Adds an organization to the list of selected organizations that can access a self-hosted runner group. The runner group must have `visibility` set to `selected`. For more information, see "[Create a self-hosted runner group for an enterprise](#create-a-self-hosted-runner-group-for-an-enterprise)."
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
* @param orgId - The unique identifier of the organization.
*/
var addOrgAccessToSelfHostedRunnerGroupInEnterprise = {
    id: "enterprise-admin/add-org-access-to-self-hosted-runner-group-in-enterprise",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/actions#remove-organization-access-to-a-self-hosted-runner-group-in-an-enterprise


* Remove organization access to a self-hosted runner group in an enterprise
* Removes an organization from the list of selected organizations that can access a self-hosted runner group. The runner group must have `visibility` set to `selected`. For more information, see "[Create a self-hosted runner group for an enterprise](#create-a-self-hosted-runner-group-for-an-enterprise)."
 *
 * You must authenticate using an access token with the `manage_runners:enterprise` scope to use this endpoint.
* @param enterprise - The slug version of the enterprise name. You can also substitute this value with the enterprise id.
* @param runnerGroupId - Unique identifier of the self-hosted runner group.
* @param orgId - The unique identifier of the organization.
*/
var removeOrgAccessToSelfHostedRunnerGroupInEnterprise = {
    id: "enterprise-admin/remove-org-access-to-self-hosted-runner-group-in-enterprise",
    clientId: "github",
    version: "1.1.5",
};

var enterpriseAdmin = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getAuditLog: getAuditLog,
  listProvisionedIdentitiesEnterprise: listProvisionedIdentitiesEnterprise,
  provisionAndInviteEnterpriseUser: provisionAndInviteEnterpriseUser,
  listProvisionedGroupsEnterprise: listProvisionedGroupsEnterprise,
  provisionAndInviteEnterpriseGroup: provisionAndInviteEnterpriseGroup,
  listSelfHostedRunnersForEnterprise: listSelfHostedRunnersForEnterprise,
  getGithubActionsPermissionsEnterprise: getGithubActionsPermissionsEnterprise,
  setGithubActionsPermissionsEnterprise: setGithubActionsPermissionsEnterprise,
  listSelfHostedRunnerGroupsForEnterprise: listSelfHostedRunnerGroupsForEnterprise,
  createSelfHostedRunnerGroupForEnterprise: createSelfHostedRunnerGroupForEnterprise,
  listRunnerApplicationsForEnterprise: listRunnerApplicationsForEnterprise,
  getSelfHostedRunnerForEnterprise: getSelfHostedRunnerForEnterprise,
  deleteSelfHostedRunnerFromEnterprise: deleteSelfHostedRunnerFromEnterprise,
  createRemoveTokenForEnterprise: createRemoveTokenForEnterprise,
  getProvisioningInformationForEnterpriseUser: getProvisioningInformationForEnterpriseUser,
  setInformationForProvisionedEnterpriseUser: setInformationForProvisionedEnterpriseUser,
  deleteUserFromEnterprise: deleteUserFromEnterprise,
  updateAttributeForEnterpriseUser: updateAttributeForEnterpriseUser,
  getProvisioningInformationForEnterpriseGroup: getProvisioningInformationForEnterpriseGroup,
  setInformationForProvisionedEnterpriseGroup: setInformationForProvisionedEnterpriseGroup,
  deleteScimGroupFromEnterprise: deleteScimGroupFromEnterprise,
  updateAttributeForEnterpriseGroup: updateAttributeForEnterpriseGroup,
  listSelectedOrganizationsEnabledGithubActionsEnterprise: listSelectedOrganizationsEnabledGithubActionsEnterprise,
  setSelectedOrganizationsEnabledGithubActionsEnterprise: setSelectedOrganizationsEnabledGithubActionsEnterprise,
  createRegistrationTokenForEnterprise: createRegistrationTokenForEnterprise,
  listLabelsForSelfHostedRunnerForEnterprise: listLabelsForSelfHostedRunnerForEnterprise,
  addCustomLabelsToSelfHostedRunnerForEnterprise: addCustomLabelsToSelfHostedRunnerForEnterprise,
  setCustomLabelsForSelfHostedRunnerForEnterprise: setCustomLabelsForSelfHostedRunnerForEnterprise,
  removeAllCustomLabelsFromSelfHostedRunnerForEnterprise: removeAllCustomLabelsFromSelfHostedRunnerForEnterprise,
  getServerStatistics: getServerStatistics,
  getAllowedActionsEnterprise: getAllowedActionsEnterprise,
  setAllowedActionsEnterprise: setAllowedActionsEnterprise,
  getSelfHostedRunnerGroupForEnterprise: getSelfHostedRunnerGroupForEnterprise,
  deleteSelfHostedRunnerGroupFromEnterprise: deleteSelfHostedRunnerGroupFromEnterprise,
  updateSelfHostedRunnerGroupForEnterprise: updateSelfHostedRunnerGroupForEnterprise,
  removeCustomLabelFromSelfHostedRunnerForEnterprise: removeCustomLabelFromSelfHostedRunnerForEnterprise,
  enableSelectedOrganizationGithubActionsEnterprise: enableSelectedOrganizationGithubActionsEnterprise,
  disableSelectedOrganizationGithubActionsEnterprise: disableSelectedOrganizationGithubActionsEnterprise,
  listSelfHostedRunnersInGroupForEnterprise: listSelfHostedRunnersInGroupForEnterprise,
  setSelfHostedRunnersInGroupForEnterprise: setSelfHostedRunnersInGroupForEnterprise,
  listOrgAccessToSelfHostedRunnerGroupInEnterprise: listOrgAccessToSelfHostedRunnerGroupInEnterprise,
  setOrgAccessToSelfHostedRunnerGroupInEnterprise: setOrgAccessToSelfHostedRunnerGroupInEnterprise,
  addSelfHostedRunnerToGroupForEnterprise: addSelfHostedRunnerToGroupForEnterprise,
  removeSelfHostedRunnerFromGroupForEnterprise: removeSelfHostedRunnerFromGroupForEnterprise,
  addOrgAccessToSelfHostedRunnerGroupInEnterprise: addOrgAccessToSelfHostedRunnerGroupInEnterprise,
  removeOrgAccessToSelfHostedRunnerGroupInEnterprise: removeOrgAccessToSelfHostedRunnerGroupInEnterprise
});

/**
* @see https://docs.github.com/rest/reference/dependabot#list-organization-secrets


* List organization secrets
* Lists all secrets available in an organization without revealing their encrypted values. You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `dependabot_secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listOrgSecrets = {
    id: "dependabot/list-org-secrets",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/dependabot#list-repository-secrets


* List repository secrets
* Lists all secrets available in a repository without revealing their encrypted values. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `dependabot_secrets` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listRepoSecrets = {
    id: "dependabot/list-repo-secrets",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/dependabot#get-an-organization-public-key


* Get an organization public key
* Gets your public key, which you need to encrypt secrets. You need to encrypt a secret before you can create or update secrets. You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `dependabot_secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
*/
var getOrgPublicKey = {
    id: "dependabot/get-org-public-key",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/dependabot#get-an-organization-secret


* Get an organization secret
* Gets a single organization secret without revealing its encrypted value. You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `dependabot_secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var getOrgSecret = {
    id: "dependabot/get-org-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/dependabot#create-or-update-an-organization-secret


* Create or update an organization secret
* Creates or updates an organization secret with an encrypted value. Encrypt your secret using
 * [LibSodium](https://libsodium.gitbook.io/doc/bindings_for_other_languages). You must authenticate using an access
 * token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `dependabot_secrets` organization
 * permission to use this endpoint.
 *
 * #### Example encrypting a secret using Node.js
 *
 * Encrypt your secret using the [tweetsodium](https://github.com/github/tweetsodium) library.
 *
 * ```
 * const sodium = require('tweetsodium');
 *
 * const key = "base64-encoded-public-key";
 * const value = "plain-text-secret";
 *
 * // Convert the message and key to Uint8Array's (Buffer implements that interface)
 * const messageBytes = Buffer.from(value);
 * const keyBytes = Buffer.from(key, 'base64');
 *
 * // Encrypt using LibSodium.
 * const encryptedBytes = sodium.seal(messageBytes, keyBytes);
 *
 * // Base64 the encrypted secret
 * const encrypted = Buffer.from(encryptedBytes).toString('base64');
 *
 * console.log(encrypted);
 * ```
 *
 *
 * #### Example encrypting a secret using Python
 *
 * Encrypt your secret using [pynacl](https://pynacl.readthedocs.io/en/latest/public/#nacl-public-sealedbox) with Python 3.
 *
 * ```
 * from base64 import b64encode
 * from nacl import encoding, public
 *
 * def encrypt(public_key: str, secret_value: str) -> str:
 * """Encrypt a Unicode string using the public key."""
 * public_key = public.PublicKey(public_key.encode("utf-8"), encoding.Base64Encoder())
 * sealed_box = public.SealedBox(public_key)
 * encrypted = sealed_box.encrypt(secret_value.encode("utf-8"))
 * return b64encode(encrypted).decode("utf-8")
 * ```
 *
 * #### Example encrypting a secret using C#
 *
 * Encrypt your secret using the [Sodium.Core](https://www.nuget.org/packages/Sodium.Core/) package.
 *
 * ```
 * var secretValue = System.Text.Encoding.UTF8.GetBytes("mySecret");
 * var publicKey = Convert.FromBase64String("2Sg8iYjAxxmI2LvUXpJjkYrMxURPc8r+dB7TJyvvcCU=");
 *
 * var sealedPublicKeyBox = Sodium.SealedPublicKeyBox.Create(secretValue, publicKey);
 *
 * Console.WriteLine(Convert.ToBase64String(sealedPublicKeyBox));
 * ```
 *
 * #### Example encrypting a secret using Ruby
 *
 * Encrypt your secret using the [rbnacl](https://github.com/RubyCrypto/rbnacl) gem.
 *
 * ```ruby
 * require "rbnacl"
 * require "base64"
 *
 * key = Base64.decode64("+ZYvJDZMHUfBkJdyq5Zm9SKqeuBQ4sj+6sfjlH4CgG0=")
 * public_key = RbNaCl::PublicKey.new(key)
 *
 * box = RbNaCl::Boxes::Sealed.from_public_key(public_key)
 * encrypted_secret = box.encrypt("my_secret")
 *
 * # Print the base64 encoded secret
 * puts Base64.strict_encode64(encrypted_secret)
 * ```
* @param org - The organization name. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var createOrUpdateOrgSecret = {
    id: "dependabot/create-or-update-org-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/dependabot#delete-an-organization-secret


* Delete an organization secret
* Deletes a secret in an organization using the secret name. You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `dependabot_secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var deleteOrgSecret = {
    id: "dependabot/delete-org-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/dependabot#get-a-repository-public-key


* Get a repository public key
* Gets your public key, which you need to encrypt secrets. You need to encrypt a secret before you can create or update secrets. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the `repo` scope. GitHub Apps must have the `dependabot_secrets` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getRepoPublicKey = {
    id: "dependabot/get-repo-public-key",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/dependabot#get-a-repository-secret


* Get a repository secret
* Gets a single repository secret without revealing its encrypted value. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `dependabot_secrets` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var getRepoSecret = {
    id: "dependabot/get-repo-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/dependabot#create-or-update-a-repository-secret


* Create or update a repository secret
* Creates or updates a repository secret with an encrypted value. Encrypt your secret using
 * [LibSodium](https://libsodium.gitbook.io/doc/bindings_for_other_languages). You must authenticate using an access
 * token with the `repo` scope to use this endpoint. GitHub Apps must have the `dependabot_secrets` repository
 * permission to use this endpoint.
 *
 * #### Example encrypting a secret using Node.js
 *
 * Encrypt your secret using the [tweetsodium](https://github.com/github/tweetsodium) library.
 *
 * ```
 * const sodium = require('tweetsodium');
 *
 * const key = "base64-encoded-public-key";
 * const value = "plain-text-secret";
 *
 * // Convert the message and key to Uint8Array's (Buffer implements that interface)
 * const messageBytes = Buffer.from(value);
 * const keyBytes = Buffer.from(key, 'base64');
 *
 * // Encrypt using LibSodium.
 * const encryptedBytes = sodium.seal(messageBytes, keyBytes);
 *
 * // Base64 the encrypted secret
 * const encrypted = Buffer.from(encryptedBytes).toString('base64');
 *
 * console.log(encrypted);
 * ```
 *
 *
 * #### Example encrypting a secret using Python
 *
 * Encrypt your secret using [pynacl](https://pynacl.readthedocs.io/en/latest/public/#nacl-public-sealedbox) with Python 3.
 *
 * ```
 * from base64 import b64encode
 * from nacl import encoding, public
 *
 * def encrypt(public_key: str, secret_value: str) -> str:
 * """Encrypt a Unicode string using the public key."""
 * public_key = public.PublicKey(public_key.encode("utf-8"), encoding.Base64Encoder())
 * sealed_box = public.SealedBox(public_key)
 * encrypted = sealed_box.encrypt(secret_value.encode("utf-8"))
 * return b64encode(encrypted).decode("utf-8")
 * ```
 *
 * #### Example encrypting a secret using C#
 *
 * Encrypt your secret using the [Sodium.Core](https://www.nuget.org/packages/Sodium.Core/) package.
 *
 * ```
 * var secretValue = System.Text.Encoding.UTF8.GetBytes("mySecret");
 * var publicKey = Convert.FromBase64String("2Sg8iYjAxxmI2LvUXpJjkYrMxURPc8r+dB7TJyvvcCU=");
 *
 * var sealedPublicKeyBox = Sodium.SealedPublicKeyBox.Create(secretValue, publicKey);
 *
 * Console.WriteLine(Convert.ToBase64String(sealedPublicKeyBox));
 * ```
 *
 * #### Example encrypting a secret using Ruby
 *
 * Encrypt your secret using the [rbnacl](https://github.com/RubyCrypto/rbnacl) gem.
 *
 * ```ruby
 * require "rbnacl"
 * require "base64"
 *
 * key = Base64.decode64("+ZYvJDZMHUfBkJdyq5Zm9SKqeuBQ4sj+6sfjlH4CgG0=")
 * public_key = RbNaCl::PublicKey.new(key)
 *
 * box = RbNaCl::Boxes::Sealed.from_public_key(public_key)
 * encrypted_secret = box.encrypt("my_secret")
 *
 * # Print the base64 encoded secret
 * puts Base64.strict_encode64(encrypted_secret)
 * ```
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var createOrUpdateRepoSecret = {
    id: "dependabot/create-or-update-repo-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/dependabot#delete-a-repository-secret


* Delete a repository secret
* Deletes a secret in a repository using the secret name. You must authenticate using an access token with the `repo` scope to use this endpoint. GitHub Apps must have the `dependabot_secrets` repository permission to use this endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var deleteRepoSecret = {
    id: "dependabot/delete-repo-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/dependabot#list-selected-repositories-for-an-organization-secret


* List selected repositories for an organization secret
* Lists all repositories that have been selected when the `visibility` for repository access to a secret is set to `selected`. You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `dependabot_secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param secretName - The name of the secret.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listSelectedReposForOrgSecret = {
    id: "dependabot/list-selected-repos-for-org-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/dependabot#set-selected-repositories-for-an-organization-secret


* Set selected repositories for an organization secret
* Replaces all repositories for an organization secret when the `visibility` for repository access is set to `selected`. The visibility is set when you [Create or update an organization secret](https://docs.github.com/rest/reference/dependabot#create-or-update-an-organization-secret). You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `dependabot_secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param secretName - The name of the secret.
*/
var setSelectedReposForOrgSecret = {
    id: "dependabot/set-selected-repos-for-org-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/dependabot#add-selected-repository-to-an-organization-secret


* Add selected repository to an organization secret
* Adds a repository to an organization secret when the `visibility` for repository access is set to `selected`. The visibility is set when you [Create or update an organization secret](https://docs.github.com/rest/reference/dependabot#create-or-update-an-organization-secret). You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `dependabot_secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param secretName - The name of the secret.
* @param repositoryId
*/
var addSelectedRepoToOrgSecret = {
    id: "dependabot/add-selected-repo-to-org-secret",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/dependabot#remove-selected-repository-from-an-organization-secret


* Remove selected repository from an organization secret
* Removes a repository from an organization secret when the `visibility` for repository access is set to `selected`. The visibility is set when you [Create or update an organization secret](https://docs.github.com/rest/reference/dependabot#create-or-update-an-organization-secret). You must authenticate using an access token with the `admin:org` scope to use this endpoint. GitHub Apps must have the `dependabot_secrets` organization permission to use this endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param secretName - The name of the secret.
* @param repositoryId
*/
var removeSelectedRepoFromOrgSecret = {
    id: "dependabot/remove-selected-repo-from-org-secret",
    clientId: "github",
    version: "1.1.5",
};

var dependabot = /*#__PURE__*/Object.freeze({
  __proto__: null,
  listOrgSecrets: listOrgSecrets,
  listRepoSecrets: listRepoSecrets,
  getOrgPublicKey: getOrgPublicKey,
  getOrgSecret: getOrgSecret,
  createOrUpdateOrgSecret: createOrUpdateOrgSecret,
  deleteOrgSecret: deleteOrgSecret,
  getRepoPublicKey: getRepoPublicKey,
  getRepoSecret: getRepoSecret,
  createOrUpdateRepoSecret: createOrUpdateRepoSecret,
  deleteRepoSecret: deleteRepoSecret,
  listSelectedReposForOrgSecret: listSelectedReposForOrgSecret,
  setSelectedReposForOrgSecret: setSelectedReposForOrgSecret,
  addSelectedRepoToOrgSecret: addSelectedRepoToOrgSecret,
  removeSelectedRepoFromOrgSecret: removeSelectedRepoFromOrgSecret
});

/**
* @see https://docs.github.com/rest/reference/dependency-graph#create-a-snapshot-of-dependencies-for-a-repository


* Create a snapshot of dependencies for a repository
* Create a new snapshot of a repository's dependencies. You must authenticate using an access token with the `repo` scope to use this endpoint for a repository that the requesting user has access to.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createRepositorySnapshot = {
    id: "dependency-graph/create-repository-snapshot",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/dependency-graph#get-a-diff-of-the-dependencies-between-commits


* Get a diff of the dependencies between commits
* Gets the diff of the dependency changes between two commits of a repository, based on the changes to the dependency manifests made in those commits.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param basehead - The base and head Git revisions to compare. The Git revisions will be resolved to commit SHAs. Named revisions will be resolved to their corresponding HEAD commits, and an appropriate merge base will be determined. This parameter expects the format `{base}...{head}`.
* @param [name] - The full path, relative to the repository root, of the dependency manifest file.
*/
var diffRange = {
    id: "dependency-graph/diff-range",
    clientId: "github",
    version: "1.1.5",
};

var dependencyGraph = /*#__PURE__*/Object.freeze({
  __proto__: null,
  createRepositorySnapshot: createRepositorySnapshot,
  diffRange: diffRange
});

/**
* @see https://docs.github.com/rest/reference/gists#list-gists-for-the-authenticated-user


* List gists for the authenticated user
* Lists the authenticated user's gists or if called anonymously, this endpoint returns all public gists:
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var list$1 = {
    id: "gists/list",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#create-a-gist


* Create a gist
* Allows you to add a new gist with one or more files.
 *
 * **Note:** Don't name your files "gistfile" with a numerical suffix. This is the format of the automatic naming scheme that Gist uses internally.
*/
var create$1 = {
    id: "gists/create",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#list-public-gists


* List public gists
* List public gists sorted by most recently updated to least recently updated.
 *
 * Note: With [pagination](https://docs.github.com/rest/overview/resources-in-the-rest-api#pagination), you can fetch up to 3000 gists. For example, you can fetch 100 pages with 30 gists per page or 30 pages with 100 gists per page.
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listPublic = {
    id: "gists/list-public",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#list-starred-gists


* List starred gists
* List the authenticated user's starred gists:
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listStarred = {
    id: "gists/list-starred",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#get-a-gist


* Get a gist
* @param gistId - The unique identifier of the gist.
*/
var getGist = {
    id: "gists/get",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#delete-a-gist


* Delete a gist
* @param gistId - The unique identifier of the gist.
*/
var deleteGist = {
    id: "gists/delete",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists/#update-a-gist


* Update a gist
* Allows you to update or delete a gist file and rename gist files. Files from the previous version of the gist that aren't explicitly changed during an edit are unchanged.
* @param gistId - The unique identifier of the gist.
*/
var update$1 = {
    id: "gists/update",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#check-if-a-gist-is-starred


* Check if a gist is starred
* @param gistId - The unique identifier of the gist.
*/
var checkIsStarred = {
    id: "gists/check-is-starred",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#star-a-gist


* Star a gist
* Note that you'll need to set `Content-Length` to zero when calling out to this endpoint. For more information, see "[HTTP verbs](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-verbs)."
* @param gistId - The unique identifier of the gist.
*/
var star = {
    id: "gists/star",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#unstar-a-gist


* Unstar a gist
* @param gistId - The unique identifier of the gist.
*/
var unstar = {
    id: "gists/unstar",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#list-gist-forks


* List gist forks
* @param gistId - The unique identifier of the gist.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listForks = {
    id: "gists/list-forks",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#fork-a-gist


* Fork a gist
* **Note**: This was previously `/gists/:gist_id/fork`.
* @param gistId - The unique identifier of the gist.
*/
var fork = {
    id: "gists/fork",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#get-a-gist-revision


* Get a gist revision
* @param gistId - The unique identifier of the gist.
* @param sha
*/
var getRevision = {
    id: "gists/get-revision",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#list-gists-for-a-user


* List gists for a user
* Lists public gists for the specified user:
* @param username - The handle for the GitHub user account.
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listForUser = {
    id: "gists/list-for-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#list-gist-commits


* List gist commits
* @param gistId - The unique identifier of the gist.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listCommits = {
    id: "gists/list-commits",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#list-gist-comments


* List gist comments
* @param gistId - The unique identifier of the gist.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listComments$1 = {
    id: "gists/list-comments",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#create-a-gist-comment


* Create a gist comment
* @param gistId - The unique identifier of the gist.
*/
var createComment$1 = {
    id: "gists/create-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#get-a-gist-comment


* Get a gist comment
* @param gistId - The unique identifier of the gist.
* @param commentId - The unique identifier of the comment.
*/
var getComment$1 = {
    id: "gists/get-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#delete-a-gist-comment


* Delete a gist comment
* @param gistId - The unique identifier of the gist.
* @param commentId - The unique identifier of the comment.
*/
var deleteComment$1 = {
    id: "gists/delete-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gists#update-a-gist-comment


* Update a gist comment
* @param gistId - The unique identifier of the gist.
* @param commentId - The unique identifier of the comment.
*/
var updateComment$1 = {
    id: "gists/update-comment",
    clientId: "github",
    version: "1.1.5",
};

var gists = /*#__PURE__*/Object.freeze({
  __proto__: null,
  list: list$1,
  create: create$1,
  listPublic: listPublic,
  listStarred: listStarred,
  getGist: getGist,
  deleteGist: deleteGist,
  update: update$1,
  checkIsStarred: checkIsStarred,
  star: star,
  unstar: unstar,
  listForks: listForks,
  fork: fork,
  getRevision: getRevision,
  listForUser: listForUser,
  listCommits: listCommits,
  listComments: listComments$1,
  createComment: createComment$1,
  getComment: getComment$1,
  deleteComment: deleteComment$1,
  updateComment: updateComment$1
});

/**
* @see https://docs.github.com/rest/reference/git#create-a-reference


* Create a reference
* Creates a reference for your repository. You are unable to create new references for empty repositories, even if the commit SHA-1 hash used exists. Empty repositories are repositories without branches.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createRef = {
    id: "git/create-ref",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/git#create-a-tag-object


* Create a tag object
* Note that creating a tag object does not create the reference that makes a tag in Git. If you want to create an annotated tag in Git, you have to do this call to create the tag object, and then [create](https://docs.github.com/rest/reference/git#create-a-reference) the `refs/tags/[tag]` reference. If you want to create a lightweight tag, you only have to [create](https://docs.github.com/rest/reference/git#create-a-reference) the tag reference - this call would be unnecessary.
 *
 * **Signature verification object**
 *
 * The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
 *
 * | Name | Type | Description |
 * | ---- | ---- | ----------- |
 * | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
 * | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in table below. |
 * | `signature` | `string` | The signature that was extracted from the commit. |
 * | `payload` | `string` | The value that was signed. |
 *
 * These are the possible values for `reason` in the `verification` object:
 *
 * | Value | Description |
 * | ----- | ----------- |
 * | `expired_key` | The key that made the signature is expired. |
 * | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
 * | `gpgverify_error` | There was an error communicating with the signature verification service. |
 * | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
 * | `unsigned` | The object does not include a signature. |
 * | `unknown_signature_type` | A non-PGP signature was found in the commit. |
 * | `no_user` | No user was associated with the `committer` email address in the commit. |
 * | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on her/his account. |
 * | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
 * | `unknown_key` | The key that made the signature has not been registered with any user's account. |
 * | `malformed_signature` | There was an error parsing the signature. |
 * | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
 * | `valid` | None of the above errors applied, so the signature is considered to be verified. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createTag = {
    id: "git/create-tag",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/git#create-a-blob


* Create a blob
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createBlob = {
    id: "git/create-blob",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/git#create-a-tree


* Create a tree
* The tree creation API accepts nested entries. If you specify both a tree and a nested path modifying that tree, this endpoint will overwrite the contents of the tree with the new path contents, and create a new tree structure.
 *
 * If you use this endpoint to add, delete, or modify the file contents in a tree, you will need to commit the tree and then update a branch to point to the commit. For more information see "[Create a commit](https://docs.github.com/rest/reference/git#create-a-commit)" and "[Update a reference](https://docs.github.com/rest/reference/git#update-a-reference)."
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createTree = {
    id: "git/create-tree",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/git#create-a-commit


* Create a commit
* Creates a new Git [commit object](https://git-scm.com/book/en/v1/Git-Internals-Git-Objects#Commit-Objects).
 *
 * **Signature verification object**
 *
 * The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
 *
 * | Name | Type | Description |
 * | ---- | ---- | ----------- |
 * | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
 * | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in the table below. |
 * | `signature` | `string` | The signature that was extracted from the commit. |
 * | `payload` | `string` | The value that was signed. |
 *
 * These are the possible values for `reason` in the `verification` object:
 *
 * | Value | Description |
 * | ----- | ----------- |
 * | `expired_key` | The key that made the signature is expired. |
 * | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
 * | `gpgverify_error` | There was an error communicating with the signature verification service. |
 * | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
 * | `unsigned` | The object does not include a signature. |
 * | `unknown_signature_type` | A non-PGP signature was found in the commit. |
 * | `no_user` | No user was associated with the `committer` email address in the commit. |
 * | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on her/his account. |
 * | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
 * | `unknown_key` | The key that made the signature has not been registered with any user's account. |
 * | `malformed_signature` | There was an error parsing the signature. |
 * | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
 * | `valid` | None of the above errors applied, so the signature is considered to be verified. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createCommit = {
    id: "git/create-commit",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/git#get-a-reference


* Get a reference
* Returns a single reference from your Git database. The `:ref` in the URL must be formatted as `heads/<branch name>` for branches and `tags/<tag name>` for tags. If the `:ref` doesn't match an existing ref, a `404` is returned.
 *
 * **Note:** You need to explicitly [request a pull request](https://docs.github.com/rest/reference/pulls#get-a-pull-request) to trigger a test merge commit, which checks the mergeability of pull requests. For more information, see "[Checking mergeability of pull requests](https://docs.github.com/rest/guides/getting-started-with-the-git-database-api#checking-mergeability-of-pull-requests)".
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param ref - ref parameter
*/
var getRef = {
    id: "git/get-ref",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/git#delete-a-reference


* Delete a reference
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param ref - ref parameter
*/
var deleteRef = {
    id: "git/delete-ref",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/git#update-a-reference


* Update a reference
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param ref - ref parameter
*/
var updateRef = {
    id: "git/update-ref",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/git#get-a-tag


* Get a tag
* **Signature verification object**
 *
 * The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
 *
 * | Name | Type | Description |
 * | ---- | ---- | ----------- |
 * | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
 * | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in table below. |
 * | `signature` | `string` | The signature that was extracted from the commit. |
 * | `payload` | `string` | The value that was signed. |
 *
 * These are the possible values for `reason` in the `verification` object:
 *
 * | Value | Description |
 * | ----- | ----------- |
 * | `expired_key` | The key that made the signature is expired. |
 * | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
 * | `gpgverify_error` | There was an error communicating with the signature verification service. |
 * | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
 * | `unsigned` | The object does not include a signature. |
 * | `unknown_signature_type` | A non-PGP signature was found in the commit. |
 * | `no_user` | No user was associated with the `committer` email address in the commit. |
 * | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on her/his account. |
 * | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
 * | `unknown_key` | The key that made the signature has not been registered with any user's account. |
 * | `malformed_signature` | There was an error parsing the signature. |
 * | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
 * | `valid` | None of the above errors applied, so the signature is considered to be verified. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param tagSha
*/
var getTag = {
    id: "git/get-tag",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/git#get-a-blob


* Get a blob
* The `content` in the response will always be Base64 encoded.
 *
 * _Note_: This API supports blobs up to 100 megabytes in size.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param fileSha
*/
var getBlob = {
    id: "git/get-blob",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/git#get-a-tree


* Get a tree
* Returns a single tree using the SHA1 value for that tree.
 *
 * If `truncated` is `true` in the response then the number of items in the `tree` array exceeded our maximum limit. If you need to fetch more items, use the non-recursive method of fetching trees, and fetch one sub-tree at a time.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param treeSha
* @param [recursive] - Setting this parameter to any value returns the objects or subtrees referenced by the tree specified in `:tree_sha`. For example, setting `recursive` to any of the following will enable returning objects or subtrees: `0`, `1`, `"true"`, and `"false"`. Omit this parameter to prevent recursively returning objects or subtrees.
*/
var getTree = {
    id: "git/get-tree",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/git#list-matching-references


* List matching references
* Returns an array of references from your Git database that match the supplied name. The `:ref` in the URL must be formatted as `heads/<branch name>` for branches and `tags/<tag name>` for tags. If the `:ref` doesn't exist in the repository, but existing refs start with `:ref`, they will be returned as an array.
 *
 * When you use this endpoint without providing a `:ref`, it will return an array of all the references from your Git database, including notes and stashes if they exist on the server. Anything in the namespace is returned, not just `heads` and `tags`.
 *
 * **Note:** You need to explicitly [request a pull request](https://docs.github.com/rest/reference/pulls#get-a-pull-request) to trigger a test merge commit, which checks the mergeability of pull requests. For more information, see "[Checking mergeability of pull requests](https://docs.github.com/rest/guides/getting-started-with-the-git-database-api#checking-mergeability-of-pull-requests)".
 *
 * If you request matching references for a branch named `feature` but the branch `feature` doesn't exist, the response can still include other matching head refs that start with the word `feature`, such as `featureA` and `featureB`.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param ref - ref parameter
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listMatchingRefs = {
    id: "git/list-matching-refs",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/git#get-a-commit


* Get a commit
* Gets a Git [commit object](https://git-scm.com/book/en/v1/Git-Internals-Git-Objects#Commit-Objects).
 *
 * **Signature verification object**
 *
 * The response will include a `verification` object that describes the result of verifying the commit's signature. The following fields are included in the `verification` object:
 *
 * | Name | Type | Description |
 * | ---- | ---- | ----------- |
 * | `verified` | `boolean` | Indicates whether GitHub considers the signature in this commit to be verified. |
 * | `reason` | `string` | The reason for verified value. Possible values and their meanings are enumerated in the table below. |
 * | `signature` | `string` | The signature that was extracted from the commit. |
 * | `payload` | `string` | The value that was signed. |
 *
 * These are the possible values for `reason` in the `verification` object:
 *
 * | Value | Description |
 * | ----- | ----------- |
 * | `expired_key` | The key that made the signature is expired. |
 * | `not_signing_key` | The "signing" flag is not among the usage flags in the GPG key that made the signature. |
 * | `gpgverify_error` | There was an error communicating with the signature verification service. |
 * | `gpgverify_unavailable` | The signature verification service is currently unavailable. |
 * | `unsigned` | The object does not include a signature. |
 * | `unknown_signature_type` | A non-PGP signature was found in the commit. |
 * | `no_user` | No user was associated with the `committer` email address in the commit. |
 * | `unverified_email` | The `committer` email address in the commit was associated with a user, but the email address is not verified on her/his account. |
 * | `bad_email` | The `committer` email address in the commit is not included in the identities of the PGP key that made the signature. |
 * | `unknown_key` | The key that made the signature has not been registered with any user's account. |
 * | `malformed_signature` | There was an error parsing the signature. |
 * | `invalid` | The signature could not be cryptographically verified using the key whose key-id was found in the signature. |
 * | `valid` | None of the above errors applied, so the signature is considered to be verified. |
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commitSha - The SHA of the commit.
*/
var getCommit = {
    id: "git/get-commit",
    clientId: "github",
    version: "1.1.5",
};

var git = /*#__PURE__*/Object.freeze({
  __proto__: null,
  createRef: createRef,
  createTag: createTag,
  createBlob: createBlob,
  createTree: createTree,
  createCommit: createCommit,
  getRef: getRef,
  deleteRef: deleteRef,
  updateRef: updateRef,
  getTag: getTag,
  getBlob: getBlob,
  getTree: getTree,
  listMatchingRefs: listMatchingRefs,
  getCommit: getCommit
});

/**
* @see https://docs.github.com/rest/reference/gitignore#get-all-gitignore-templates


* Get all gitignore templates
* List all templates available to pass as an option when [creating a repository](https://docs.github.com/rest/reference/repos#create-a-repository-for-the-authenticated-user).
*/
var getAllTemplates = {
    id: "gitignore/get-all-templates",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/gitignore#get-a-gitignore-template


* Get a gitignore template
* The API also allows fetching the source of a single template.
 * Use the raw [media type](https://docs.github.com/rest/overview/media-types/) to get the raw contents.
* @param name
*/
var getTemplate = {
    id: "gitignore/get-template",
    clientId: "github",
    version: "1.1.5",
};

var gitignore = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getAllTemplates: getAllTemplates,
  getTemplate: getTemplate
});

/**
* @see https://docs.github.com/rest/reference/interactions#get-interaction-restrictions-for-your-public-repositories


* Get interaction restrictions for your public repositories
* Shows which type of GitHub user can interact with your public repositories and when the restriction expires.
*/
var getRestrictionsForAuthenticatedUser = {
    id: "interactions/get-restrictions-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/interactions#set-interaction-restrictions-for-your-public-repositories


* Set interaction restrictions for your public repositories
* Temporarily restricts which type of GitHub user can interact with your public repositories. Setting the interaction limit at the user level will overwrite any interaction limits that are set for individual repositories owned by the user.
*/
var setRestrictionsForAuthenticatedUser = {
    id: "interactions/set-restrictions-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/interactions#remove-interaction-restrictions-from-your-public-repositories


* Remove interaction restrictions from your public repositories
* Removes any interaction restrictions from your public repositories.
*/
var removeRestrictionsForAuthenticatedUser = {
    id: "interactions/remove-restrictions-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/interactions#get-interaction-restrictions-for-an-organization


* Get interaction restrictions for an organization
* Shows which type of GitHub user can interact with this organization and when the restriction expires. If there is no restrictions, you will see an empty response.
* @param org - The organization name. The name is not case sensitive.
*/
var getRestrictionsForOrg = {
    id: "interactions/get-restrictions-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/interactions#set-interaction-restrictions-for-an-organization


* Set interaction restrictions for an organization
* Temporarily restricts interactions to a certain type of GitHub user in any public repository in the given organization. You must be an organization owner to set these restrictions. Setting the interaction limit at the organization level will overwrite any interaction limits that are set for individual repositories owned by the organization.
* @param org - The organization name. The name is not case sensitive.
*/
var setRestrictionsForOrg = {
    id: "interactions/set-restrictions-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/interactions#remove-interaction-restrictions-for-an-organization


* Remove interaction restrictions for an organization
* Removes all interaction restrictions from public repositories in the given organization. You must be an organization owner to remove restrictions.
* @param org - The organization name. The name is not case sensitive.
*/
var removeRestrictionsForOrg = {
    id: "interactions/remove-restrictions-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/interactions#get-interaction-restrictions-for-a-repository


* Get interaction restrictions for a repository
* Shows which type of GitHub user can interact with this repository and when the restriction expires. If there are no restrictions, you will see an empty response.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getRestrictionsForRepo = {
    id: "interactions/get-restrictions-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/interactions#set-interaction-restrictions-for-a-repository


* Set interaction restrictions for a repository
* Temporarily restricts interactions to a certain type of GitHub user within the given repository. You must have owner or admin access to set these restrictions. If an interaction limit is set for the user or organization that owns this repository, you will receive a `409 Conflict` response and will not be able to use this endpoint to change the interaction limit for a single repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var setRestrictionsForRepo = {
    id: "interactions/set-restrictions-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/interactions#remove-interaction-restrictions-for-a-repository


* Remove interaction restrictions for a repository
* Removes all interaction restrictions from the given repository. You must have owner or admin access to remove restrictions. If the interaction limit is set for the user or organization that owns this repository, you will receive a `409 Conflict` response and will not be able to use this endpoint to change the interaction limit for a single repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var removeRestrictionsForRepo = {
    id: "interactions/remove-restrictions-for-repo",
    clientId: "github",
    version: "1.1.5",
};

var interactions = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getRestrictionsForAuthenticatedUser: getRestrictionsForAuthenticatedUser,
  setRestrictionsForAuthenticatedUser: setRestrictionsForAuthenticatedUser,
  removeRestrictionsForAuthenticatedUser: removeRestrictionsForAuthenticatedUser,
  getRestrictionsForOrg: getRestrictionsForOrg,
  setRestrictionsForOrg: setRestrictionsForOrg,
  removeRestrictionsForOrg: removeRestrictionsForOrg,
  getRestrictionsForRepo: getRestrictionsForRepo,
  setRestrictionsForRepo: setRestrictionsForRepo,
  removeRestrictionsForRepo: removeRestrictionsForRepo
});

/**
* @see https://docs.github.com/rest/reference/issues#list-issues-assigned-to-the-authenticated-user


* List issues assigned to the authenticated user
* List issues assigned to the authenticated user across all visible repositories including owned repositories, member
 * repositories, and organization repositories. You can use the `filter` query parameter to fetch issues that are not
 * necessarily assigned to you.
 *
 *
 * **Note**: GitHub's REST API v3 considers every pull request an issue, but not every issue is a pull request. For this
 * reason, "Issues" endpoints may return both issues and pull requests in the response. You can identify pull requests by
 * the `pull_request` key. Be aware that the `id` of a pull request returned from "Issues" endpoints will be an _issue id_. To find out the pull
 * request id, use the "[List pull requests](https://docs.github.com/rest/reference/pulls#list-pull-requests)" endpoint.
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [orgs]
* @param [pulls]
* @param [owned]
* @param [sort] - What to sort results by. Can be either `created`, `updated`, `comments`.
* @param [state] - Indicates the state of the issues to return. Can be either `open`, `closed`, or `all`.
* @param [collab]
* @param [filter] - Indicates which sorts of issues to return. `assigned` means issues assigned to you. `created` means issues created by you. `mentioned` means issues mentioning you. `subscribed` means issues you're subscribed to updates for. `all` or `repos` means all issues you can see, regardless of participation or creation.
* @param [labels] - A list of comma separated label names. Example: `bug,ui,@high`
* @param [direction] - The direction to sort the results by.
*/
var list = {
    id: "issues/list",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#list-user-account-issues-assigned-to-the-authenticated-user


* List user account issues assigned to the authenticated user
* List issues across owned and member repositories assigned to the authenticated user.
 *
 * **Note**: GitHub's REST API v3 considers every pull request an issue, but not every issue is a pull request. For this
 * reason, "Issues" endpoints may return both issues and pull requests in the response. You can identify pull requests by
 * the `pull_request` key. Be aware that the `id` of a pull request returned from "Issues" endpoints will be an _issue id_. To find out the pull
 * request id, use the "[List pull requests](https://docs.github.com/rest/reference/pulls#list-pull-requests)" endpoint.
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [labels] - A list of comma separated label names. Example: `bug,ui,@high`
* @param [direction] - The direction to sort the results by.
* @param [filter] - Indicates which sorts of issues to return. `assigned` means issues assigned to you. `created` means issues created by you. `mentioned` means issues mentioning you. `subscribed` means issues you're subscribed to updates for. `all` or `repos` means all issues you can see, regardless of participation or creation.
* @param [state] - Indicates the state of the issues to return. Can be either `open`, `closed`, or `all`.
* @param [sort] - What to sort results by. Can be either `created`, `updated`, `comments`.
*/
var listForAuthenticatedUser = {
    id: "issues/list-for-authenticated-user",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#list-organization-issues-assigned-to-the-authenticated-user


* List organization issues assigned to the authenticated user
* List issues in an organization assigned to the authenticated user.
 *
 * **Note**: GitHub's REST API v3 considers every pull request an issue, but not every issue is a pull request. For this
 * reason, "Issues" endpoints may return both issues and pull requests in the response. You can identify pull requests by
 * the `pull_request` key. Be aware that the `id` of a pull request returned from "Issues" endpoints will be an _issue id_. To find out the pull
 * request id, use the "[List pull requests](https://docs.github.com/rest/reference/pulls#list-pull-requests)" endpoint.
* @param org - The organization name. The name is not case sensitive.
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [labels] - A list of comma separated label names. Example: `bug,ui,@high`
* @param [direction] - The direction to sort the results by.
* @param [state] - Indicates the state of the issues to return. Can be either `open`, `closed`, or `all`.
* @param [sort] - What to sort results by. Can be either `created`, `updated`, `comments`.
* @param [filter] - Indicates which sorts of issues to return. `assigned` means issues assigned to you. `created` means issues created by you. `mentioned` means issues mentioning you. `subscribed` means issues you're subscribed to updates for. `all` or `repos` means all issues you can see, regardless of participation or creation.
*/
var listForOrg = {
    id: "issues/list-for-org",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#list-repository-issues


* List repository issues
* List issues in a repository.
 *
 * **Note**: GitHub's REST API v3 considers every pull request an issue, but not every issue is a pull request. For this
 * reason, "Issues" endpoints may return both issues and pull requests in the response. You can identify pull requests by
 * the `pull_request` key. Be aware that the `id` of a pull request returned from "Issues" endpoints will be an _issue id_. To find out the pull
 * request id, use the "[List pull requests](https://docs.github.com/rest/reference/pulls#list-pull-requests)" endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [labels] - A list of comma separated label names. Example: `bug,ui,@high`
* @param [direction] - The direction to sort the results by.
* @param [mentioned] - A user that's mentioned in the issue.
* @param [creator] - The user that created the issue.
* @param [assignee] - Can be the name of a user. Pass in `none` for issues with no assigned user, and `*` for issues assigned to any user.
* @param [state] - Indicates the state of the issues to return. Can be either `open`, `closed`, or `all`.
* @param [sort] - What to sort results by. Can be either `created`, `updated`, `comments`.
* @param [milestone] - If an `integer` is passed, it should refer to a milestone by its `number` field. If the string `*` is passed, issues with any milestone are accepted. If the string `none` is passed, issues without milestones are returned.
*/
var listForRepo = {
    id: "issues/list-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#create-an-issue


* Create an issue
* Any user with pull access to a repository can create an issue. If [issues are disabled in the repository](https://docs.github.com/articles/disabling-issues/), the API returns a `410 Gone` status.
 *
 * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var create = {
    id: "issues/create",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#list-labels-for-a-repository


* List labels for a repository
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listLabelsForRepo = {
    id: "issues/list-labels-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#create-a-label


* Create a label
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createLabel = {
    id: "issues/create-label",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#list-assignees


* List assignees
* Lists the [available assignees](https://docs.github.com/articles/assigning-issues-and-pull-requests-to-other-github-users/) for issues in a repository.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listAssignees = {
    id: "issues/list-assignees",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#list-milestones


* List milestones
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [state] - The state of the milestone. Either `open`, `closed`, or `all`.
* @param [sort] - What to sort results by. Either `due_on` or `completeness`.
* @param [direction] - The direction of the sort. Either `asc` or `desc`.
*/
var listMilestones = {
    id: "issues/list-milestones",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#create-a-milestone


* Create a milestone
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var createMilestone = {
    id: "issues/create-milestone",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#list-issue-events-for-a-repository


* List issue events for a repository
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listEventsForRepo = {
    id: "issues/list-events-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#get-a-label


* Get a label
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param name
*/
var getLabel = {
    id: "issues/get-label",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#delete-a-label


* Delete a label
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param name
*/
var deleteLabel = {
    id: "issues/delete-label",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#update-a-label


* Update a label
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param name
*/
var updateLabel = {
    id: "issues/update-label",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#list-issue-comments-for-a-repository


* List issue comments for a repository
* By default, Issue Comments are ordered by ascending ID.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [sort] - The property to sort the results by. `created` means when the repository was starred. `updated` means when the repository was last pushed to.
* @param [direction] - Either `asc` or `desc`. Ignored without the `sort` parameter.
*/
var listCommentsForRepo = {
    id: "issues/list-comments-for-repo",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#check-if-a-user-can-be-assigned


* Check if a user can be assigned
* Checks if a user has permission to be assigned to an issue in this repository.
 *
 * If the `assignee` can be assigned to issues in the repository, a `204` header with no content is returned.
 *
 * Otherwise a `404` status code is returned.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param assignee
*/
var checkUserCanBeAssigned = {
    id: "issues/check-user-can-be-assigned",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#get-an-issue


* Get an issue
* The API returns a [`301 Moved Permanently` status](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-redirects-redirects) if the issue was
 * [transferred](https://docs.github.com/articles/transferring-an-issue-to-another-repository/) to another repository. If
 * the issue was transferred to or deleted from a repository where the authenticated user lacks read access, the API
 * returns a `404 Not Found` status. If the issue was deleted from a repository where the authenticated user has read
 * access, the API returns a `410 Gone` status. To receive webhook events for transferred and deleted issues, subscribe
 * to the [`issues`](https://docs.github.com/webhooks/event-payloads/#issues) webhook.
 *
 * **Note**: GitHub's REST API v3 considers every pull request an issue, but not every issue is a pull request. For this
 * reason, "Issues" endpoints may return both issues and pull requests in the response. You can identify pull requests by
 * the `pull_request` key. Be aware that the `id` of a pull request returned from "Issues" endpoints will be an _issue id_. To find out the pull
 * request id, use the "[List pull requests](https://docs.github.com/rest/reference/pulls#list-pull-requests)" endpoint.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
*/
var getIssue = {
    id: "issues/get",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues/#update-an-issue


* Update an issue
* Issue owners and users with push access can edit an issue.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
*/
var update = {
    id: "issues/update",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#get-an-issue-event


* Get an issue event
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param eventId
*/
var getEvent = {
    id: "issues/get-event",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#lock-an-issue


* Lock an issue
* Users with push access can lock an issue or pull request's conversation.
 *
 * Note that, if you choose not to pass any parameters, you'll need to set `Content-Length` to zero when calling out to this endpoint. For more information, see "[HTTP verbs](https://docs.github.com/rest/overview/resources-in-the-rest-api#http-verbs)."
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
*/
var lock = {
    id: "issues/lock",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#unlock-an-issue


* Unlock an issue
* Users with push access can unlock an issue's conversation.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
*/
var unlock = {
    id: "issues/unlock",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#get-an-issue-comment


* Get an issue comment
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
*/
var getComment = {
    id: "issues/get-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#delete-an-issue-comment


* Delete an issue comment
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
*/
var deleteComment = {
    id: "issues/delete-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#update-an-issue-comment


* Update an issue comment
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param commentId - The unique identifier of the comment.
*/
var updateComment = {
    id: "issues/update-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#list-issue-events


* List issue events
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listEvents = {
    id: "issues/list-events",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#list-labels-for-an-issue


* List labels for an issue
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listLabelsOnIssue = {
    id: "issues/list-labels-on-issue",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#add-labels-to-an-issue


* Add labels to an issue
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
*/
var addLabels = {
    id: "issues/add-labels",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#set-labels-for-an-issue


* Set labels for an issue
* Removes any previous labels and sets the new labels for an issue.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
*/
var setLabels = {
    id: "issues/set-labels",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#remove-all-labels-from-an-issue


* Remove all labels from an issue
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
*/
var removeAllLabels = {
    id: "issues/remove-all-labels",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#get-a-milestone


* Get a milestone
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param milestoneNumber - The number that identifies the milestone.
*/
var getMilestone = {
    id: "issues/get-milestone",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#delete-a-milestone


* Delete a milestone
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param milestoneNumber - The number that identifies the milestone.
*/
var deleteMilestone = {
    id: "issues/delete-milestone",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#update-a-milestone


* Update a milestone
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param milestoneNumber - The number that identifies the milestone.
*/
var updateMilestone = {
    id: "issues/update-milestone",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#list-issue-comments


* List issue comments
* Issue Comments are ordered by ascending ID.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
* @param [since] - Only show notifications updated after the given time. This is a timestamp in [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) format: `YYYY-MM-DDTHH:MM:SSZ`.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listComments = {
    id: "issues/list-comments",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#create-an-issue-comment


* Create an issue comment
* This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. See "[Secondary rate limits](https://docs.github.com/rest/overview/resources-in-the-rest-api#secondary-rate-limits)" and "[Dealing with secondary rate limits](https://docs.github.com/rest/guides/best-practices-for-integrators#dealing-with-secondary-rate-limits)" for details.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
*/
var createComment = {
    id: "issues/create-comment",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#list-timeline-events-for-an-issue


* List timeline events for an issue
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listEventsForTimeline = {
    id: "issues/list-events-for-timeline",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#add-assignees-to-an-issue


* Add assignees to an issue
* Adds up to 10 assignees to an issue. Users already assigned to an issue are not replaced.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
*/
var addAssignees = {
    id: "issues/add-assignees",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#remove-assignees-from-an-issue


* Remove assignees from an issue
* Removes one or more assignees from an issue.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
*/
var removeAssignees = {
    id: "issues/remove-assignees",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#remove-a-label-from-an-issue


* Remove a label from an issue
* Removes the specified label from the issue, and returns the remaining labels on the issue. This endpoint returns a `404 Not Found` status if the label does not exist.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param issueNumber - The number that identifies the issue.
* @param name
*/
var removeLabel = {
    id: "issues/remove-label",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/issues#list-labels-for-issues-in-a-milestone


* List labels for issues in a milestone
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
* @param milestoneNumber - The number that identifies the milestone.
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
*/
var listLabelsForMilestone = {
    id: "issues/list-labels-for-milestone",
    clientId: "github",
    version: "1.1.5",
};

var issues = /*#__PURE__*/Object.freeze({
  __proto__: null,
  list: list,
  listForAuthenticatedUser: listForAuthenticatedUser,
  listForOrg: listForOrg,
  listForRepo: listForRepo,
  create: create,
  listLabelsForRepo: listLabelsForRepo,
  createLabel: createLabel,
  listAssignees: listAssignees,
  listMilestones: listMilestones,
  createMilestone: createMilestone,
  listEventsForRepo: listEventsForRepo,
  getLabel: getLabel,
  deleteLabel: deleteLabel,
  updateLabel: updateLabel,
  listCommentsForRepo: listCommentsForRepo,
  checkUserCanBeAssigned: checkUserCanBeAssigned,
  getIssue: getIssue,
  update: update,
  getEvent: getEvent,
  lock: lock,
  unlock: unlock,
  getComment: getComment,
  deleteComment: deleteComment,
  updateComment: updateComment,
  listEvents: listEvents,
  listLabelsOnIssue: listLabelsOnIssue,
  addLabels: addLabels,
  setLabels: setLabels,
  removeAllLabels: removeAllLabels,
  getMilestone: getMilestone,
  deleteMilestone: deleteMilestone,
  updateMilestone: updateMilestone,
  listComments: listComments,
  createComment: createComment,
  listEventsForTimeline: listEventsForTimeline,
  addAssignees: addAssignees,
  removeAssignees: removeAssignees,
  removeLabel: removeLabel,
  listLabelsForMilestone: listLabelsForMilestone
});

/**
* @see https://docs.github.com/rest/reference/licenses#get-all-commonly-used-licenses


* Get all commonly used licenses
* @param [perPage=30] - The number of results per page (max 100).
* @param [page=1] - Page number of the results to fetch.
* @param [featured]
*/
var getAllCommonlyUsed = {
    id: "licenses/get-all-commonly-used",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/licenses#get-a-license


* Get a license
* @param license
*/
var getLicense = {
    id: "licenses/get",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/licenses/#get-the-license-for-a-repository


* Get the license for a repository
* This method returns the contents of the repository's license file, if one is detected.
 *
 * Similar to [Get repository content](https://docs.github.com/rest/reference/repos#get-repository-content), this method also supports [custom media types](https://docs.github.com/rest/overview/media-types) for retrieving the raw license content or rendered license HTML.
* @param owner - The account owner of the repository. The name is not case sensitive.
* @param repo - The name of the repository. The name is not case sensitive.
*/
var getForRepo = {
    id: "licenses/get-for-repo",
    clientId: "github",
    version: "1.1.5",
};

var licenses = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getAllCommonlyUsed: getAllCommonlyUsed,
  getLicense: getLicense,
  getForRepo: getForRepo
});

/**
* @see https://docs.github.com/rest/reference/markdown#render-a-markdown-document


* Render a Markdown document
*/
var render = {
    id: "markdown/render",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/markdown#render-a-markdown-document-in-raw-mode


* Render a Markdown document in raw mode
* You must send Markdown as plain text (using a `Content-Type` header of `text/plain` or `text/x-markdown`) to this endpoint, rather than using JSON format. In raw mode, [GitHub Flavored Markdown](https://github.github.com/gfm/) is not supported and Markdown will be rendered in plain format like a README.md file. Markdown content must be 400 KB or less.
*/
var renderRaw = {
    id: "markdown/render-raw",
    clientId: "github",
    version: "1.1.5",
};

var markdown = /*#__PURE__*/Object.freeze({
  __proto__: null,
  render: render,
  renderRaw: renderRaw
});

/**
* @see https://docs.github.com/rest/overview/resources-in-the-rest-api#root-endpoint


* GitHub API Root
* Get Hypermedia links to resources accessible in GitHub's REST API
*/
var root = {
    id: "meta/root",
    clientId: "github",
    version: "1.1.5",
};
/**


* Get the Zen of GitHub
* Get a random sentence from the Zen of GitHub
*/
var getZen = {
    id: "meta/get-zen",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/meta#get-github-meta-information


* Get GitHub meta information
* Returns meta information about GitHub, including a list of GitHub's IP addresses. For more information, see "[About GitHub's IP addresses](https://docs.github.com/articles/about-github-s-ip-addresses/)."
 *
 * **Note:** The IP addresses shown in the documentation's response are only example values. You must always query the API directly to get the latest list of IP addresses.
*/
var getMetas = {
    id: "meta/get",
    clientId: "github",
    version: "1.1.5",
};
/**
* @see https://docs.github.com/rest/reference/meta#get-octocat


* Get Octocat
* Get the octocat as ASCII art
* @param [s] - The words to show in Octocat's speech bubble
*/
var getOctocat = {
    id: "meta/get-octocat",
    clientId: "github",
    version: "1.1.5",
};

var meta = /*#__PURE__*/Object.freeze({
  __proto__: null,
  root: root,
  getZen: getZen,
  getMetas: getMetas,
  getOctocat: getOctocat
});

exports.actions = actions;
exports.activity = activity;
exports.apps = apps;
exports.billing = billing;
exports.checks = checks;
exports.codeScanning = codeScanning;
exports.codesOfConduct = codesOfConduct;
exports.codespaces = codespaces;
exports.dependabot = dependabot;
exports.dependencyGraph = dependencyGraph;
exports.emojis = emojis;
exports.enterpriseAdmin = enterpriseAdmin;
exports.gists = gists;
exports.git = git;
exports.gitignore = gitignore;
exports.interactions = interactions;
exports.issues = issues;
exports.licenses = licenses;
exports.markdown = markdown;
exports.meta = meta;
exports.migrations = migrations;
exports.oauthAuthorizations = oauthAuthorizations;
exports.oidc = oidc;
exports.orgs = orgs;
exports.packages = packages;
exports.projects = projects;
exports.pulls = pulls;
exports.rateLimit = rateLimit;
exports.reactions = reactions;
exports.repos = repos$1;
exports.scim = scim;
exports.search = search;
exports.secretScanning = secretScanning;
exports.serverStatistics = serverStatistics;
exports.teams = teams;
exports.users = users;
